(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4603020,     128889]*)
(*NotebookOutlinePosition[   4603697,     128913]*)
(*  CellTagsIndexPosition[   4603653,     128909]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Pneuman sim...", "Subsection"]], "Text"],

Cell["Load in package", "Text"],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input"],

Cell["Set up origin definitions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(origin = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(XAxis = {1, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(YAxis = {0, 1, 0};\)\), "\[IndentingNewLine]", 
    \(\(ZAxis = {0, 0, 1};\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(XAxis\)\" is similar to \
existing symbol \"\!\(Axis\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(YAxis\)\" is similar to \
existing symbols \!\({Axis, XAxis}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ZAxis\)\" is similar to \
existing symbols \!\({Axis, XAxis, YAxis}\)."\)], "Message"]
}, Open  ]],

Cell["Assign body numbers...", "Text"],

Cell[BoxData[{
    \(\(ground = 1;\)\), "\[IndentingNewLine]", 
    \(\(base\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(LFSteerAsm = 3;\)\), "\[IndentingNewLine]", 
    \(\(RFSteerAsm = 4;\)\), "\[IndentingNewLine]", 
    \(\(RRSteerAsm = 5;\)\), "\[IndentingNewLine]", 
    \(\(LRSteerAsm = 6;\)\), "\[IndentingNewLine]", 
    \(\(LFWheel = 7;\)\), "\[IndentingNewLine]", 
    \(\(RFWheel = 8;\)\), "\[IndentingNewLine]", 
    \(\(RRWheel = 9;\)\), "\[IndentingNewLine]", 
    \(\(LRWheel = 10;\)\), "\[IndentingNewLine]", 
    \(\(UpperTorso = 11;\)\), "\[IndentingNewLine]", 
    \(\(UBlock = 12;\)\), "\[IndentingNewLine]", 
    \(\(NeckTilt = 13;\)\), "\[IndentingNewLine]", 
    \(\(NeckPan = 14;\)\), "\[IndentingNewLine]", 
    \(\(StereoHead = 15;\)\), "\[IndentingNewLine]", 
    \(\(REyeConv = 16;\)\), "\[IndentingNewLine]", 
    \(\(LEyeConv = 17;\)\), "\[IndentingNewLine]", 
    \(\(RUpperArmPitch = 18;\)\), "\[IndentingNewLine]", 
    \(\(RUpperArmYaw = 19;\)\), "\[IndentingNewLine]", 
    \(\(RUpperArmRoll = 20;\)\), "\[IndentingNewLine]", 
    \(\(RLowerArm = 21;\)\), "\[IndentingNewLine]", 
    \(\(LUpperArmPitch = 22;\)\), "\[IndentingNewLine]", 
    \(\(LUpperArmYaw = 23;\)\), "\[IndentingNewLine]", 
    \(\(LUpperArmRoll = 24;\)\), "\[IndentingNewLine]", 
    \(\(LLowerArm = 25;\)\), "\[IndentingNewLine]", 
    \(\(RGripper = 26;\)\), "\[IndentingNewLine]", 
    \(\(LGripper = 27;\)\), "\[IndentingNewLine]", 
    \(\(LFWheelVelVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RFWheelVelVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RRWheelVelVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LRWheelVelVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LFSteerAngVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RFSteerAngVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RRSteerAngVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LRSteerAngVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(WaistPitchVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(WaistYawVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(NeckTiltVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(NeckPanVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(EyeTiltVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(REyeConvVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LEyeConvVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RArmPitchVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RArmYawVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RArmRollVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RArmElbowVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(RArmWristVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LArmPitchVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LArmYawVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LArmRollVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LArmElbowVal =. ;\)\), "\[IndentingNewLine]", 
    \(\(LArmWristVal =. ;\)\[IndentingNewLine]\)}], "Input"],

Cell["Set up origin for ground", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[ground] = 
      Body[ground, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) ZAxis}]\)], "Input"],

Cell[BoxData[
    \(SysBody[1, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(bd[base] = 
      Body[base, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              0.25} (*base\ upper\ plane*) , \[IndentingNewLine] (*p6*) \
{\(-6.45\), 
              6.45, \(-8.25\)} (*LF\ ptA*) , \[IndentingNewLine] (*p7*) \
{\(-6.45\), 6.45, 0} (*LF\ ptB*) , \[IndentingNewLine] (*p8*) {6.45, 
              6.45, \(-8.25\)} (*RF\ ptA*) , \[IndentingNewLine] (*p9*) \
{6.45, 6.45, 
              0} (*RF\ ptB*) , \[IndentingNewLine] (*p10*) {6.45, \(-6.45\), \
\(-8.25\)} (*RR\ ptA*) , \[IndentingNewLine] (*p11*) {6.45, \(-6.45\), 
              0} (*RR\ ptB*) , \[IndentingNewLine] (*p12*) {\(-6.45\), \
\(-6.45\), \(-8.25\)} (*LR\ ptA*) , \[IndentingNewLine] (*p13*) {\(-6.45\), \
\(-6.45\), 0} (*LR\ ptB*) , \[IndentingNewLine] (*p14*) {0, 0, 
              18.25} (*waist\ DOF*) , \[IndentingNewLine] (*p15*) {0, 1, 
              18.25} (*waist\ DOF\ axis*) }]\)\)\)], "Input"],

Cell[BoxData[
    \(SysBody[2, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LFSteerAsm] = 
      Body[LFSteerAsm, \[IndentingNewLine]PointList \[Rule] {\
\[IndentingNewLine] (*p1*) origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              8.25}}, \[IndentingNewLine]InitialGuess \[Rule] {{\(-6.45\), 
              6.45, \(-8.25\)}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[3, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RFSteerAsm] = 
      Body[RFSteerAsm, \[IndentingNewLine]PointList \[Rule] {\
\[IndentingNewLine] (*p1*) origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              8.25}}, \[IndentingNewLine]InitialGuess \[Rule] {{6.45, 
              6.45, \(-8.25\)}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[4, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RRSteerAsm] = 
      Body[RRSteerAsm, \ \[IndentingNewLine]PointList \[Rule] {\
\[IndentingNewLine] (*p1*) origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              8.25}}, \[IndentingNewLine]InitialGuess \[Rule] {{6.45, \(-6.45\
\), \(-8.25\)}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[5, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LRSteerAsm] = 
      Body[LRSteerAsm, \[IndentingNewLine]PointList \[Rule] {\
\[IndentingNewLine] (*p1*) origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              8.25}}, \[IndentingNewLine]InitialGuess \[Rule] {{\(-6.45\), \
\(-6.45\), \(-8.25\)}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[6, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LFWheel] = 
      Body[LFWheel, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {\(-0.5\), \ 0, 
              0} (*wheel\ plane\ pointA*) , \[IndentingNewLine] (*p6*) {0.5, 
              0, 0} (*wheel\ plane\ pointB*) }, \
\[IndentingNewLine]InitialGuess \[Rule] {{\(-6.45\), 6.45, \(-8.25\)}, {1, 0, 
              0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[7, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RFWheel] = 
      Body[RFWheel, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {\(-0.5\), \ 0, 
              0} (*wheel\ plane\ pointA*) , \[IndentingNewLine] (*p6*) {0.5, 
              0, 0} (*wheel\ plane\ pointB*) }, \
\[IndentingNewLine]InitialGuess \[Rule] {{6.45, 6.45, \(-8.25\)}, {1, 0, 0, 
              0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[8, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RRWheel] = 
      Body[RRWheel, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {\(-0.5\), \ 0, 
              0} (*wheel\ plane\ pointA*) , \[IndentingNewLine] (*p6*) {0.5, 
              0, 0} (*wheel\ plane\ pointB*) }, \
\[IndentingNewLine]InitialGuess \[Rule] {{6.45, \(-6.45\), \(-8.25\)}, {1, 0, 
              0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[9, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LRWheel] = 
      Body[LRWheel, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {\(-0.5\), \ 0, 
              0} (*wheel\ plane\ pointA*) , \[IndentingNewLine] (*p6*) {0.5, 
              0, 0} (*wheel\ plane\ pointB*) }, \
\[IndentingNewLine]InitialGuess \[Rule] {{\(-6.45\), \(-6.45\), \(-8.25\)}, \
{1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[10, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[UpperTorso] = 
      Body[UpperTorso, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              9.56} (*T\ base*) , \[IndentingNewLine] (*p6*) {6.39, 0, 
              11.56} (*T\ R\ side*) , \[IndentingNewLine] (*p7*) {\(-6.39\), 
              0, 11.56} (*T\ L\ side*) , \[IndentingNewLine] (*p8*) {0, 0, 
              13.56} (*Neck\ intersectionA*) , \[IndentingNewLine] (*p9*) \
{2.6, 0, 15.06} (*RArm\ start*) , \[IndentingNewLine] (*p10*) {9.55, 0, 
              15.06} (*RArm\ intersection*) , \[IndentingNewLine] (*p11*) \
{10.55, 0, 15.06}, \[IndentingNewLine] (*p12*) {\(-2.6\), 0, 
              15.06} (*LArm\ start*) , \[IndentingNewLine] (*p13*) \
{\(-9.55\), \ 0, \ 
              15.06} (*LArm\ intersection*) , \[IndentingNewLine] (*p14*) \
{\(-10.55\), 0, 15.06}, \[IndentingNewLine] (*p15*) {1, 0, 
              13.56} (*Neck\ intersectionB*) }, \
\[IndentingNewLine]InitialGuess \[Rule] {{0, 0, 18.25}, {1, 0, 0, 
              0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[11, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[UBlock] = 
      Body[UBlock, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis}, \[IndentingNewLine]InitialGuess \[Rule] {{0, 0, 
              18.25}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[12, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[NeckTilt] = 
      Body[NeckTilt, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              10.51}}, \[IndentingNewLine]InitialGuess \[Rule] {{0, 0, 
              31.81}, {1, 0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[13, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[NeckPan] = 
      Body[NeckPan, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 0, 
              10.51} (*StereoHead\ attachment*) , \[IndentingNewLine] (*p6*) \
{1, 0, 10.51}}, \[IndentingNewLine]InitialGuess \[Rule] {{0, 0, 31.81}, {1, 
              0, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[14, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[StereoHead] = 
      Body[StereoHead, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {4, 0, 
              0} (*REye\ attachment*) , \[IndentingNewLine] (*p6*) {4, 0, 
              1}, \[IndentingNewLine] (*p7*) {\(-4\), 0, 
              0} (*LEye\ attachment*) , \[IndentingNewLine] (*p8*) {\(-4\), 
              0, 1}, \[IndentingNewLine] (*p9*) {6, 0, 
              0} (*R\ wall*) , \[IndentingNewLine] (*p10*) {\(-6\), 0, 
              0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[15, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[REyeConv] = 
      Body[REyeConv, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 3, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[16, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LEyeConv] = 
      Body[LEyeConv, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 3, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[17, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RUpperArmRoll] = 
      Body[RUpperArmRoll, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 
              0, \(-10.5\)},  (*Elbow\ ptA*) \[IndentingNewLine] (*p6*) {1, 
              0, \(-10.5\)} (*Elbow\ ptB*) }]\)], "Input"],

Cell[BoxData[
    \(SysBody[20, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RUpperArmPitch] = 
      Body[RUpperArmPitch, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) ZAxis}]\)], "Input"],

Cell[BoxData[
    \(SysBody[18, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RUpperArmYaw] = 
      Body[RUpperArmYaw, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) ZAxis}]\)], "Input"],

Cell[BoxData[
    \(SysBody[19, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RLowerArm] = 
      Body[RLowerArm, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 
              0, \(-6.375\)} (*Wrtist\ ptA*) , \[IndentingNewLine] (*p6*) {0, 
              0, \(-5.375\)}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[21, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LUpperArmRoll] = 
      Body[LUpperArmRoll, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 
              0, \(-10.5\)},  (*Elbow\ ptA*) \[IndentingNewLine] (*p6*) {1, 
              0, \(-10.5\)} (*Elbow\ ptB*) }]\)], "Input"],

Cell[BoxData[
    \(SysBody[24, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LUpperArmPitch] = 
      Body[LUpperArmPitch, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) ZAxis}]\)], "Input"],

Cell[BoxData[
    \(SysBody[22, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LUpperArmYaw] = 
      Body[LUpperArmYaw, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) ZAxis}]\)], "Input"],

Cell[BoxData[
    \(SysBody[23, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LLowerArm] = 
      Body[LLowerArm, \ 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {0, 
              0, \(-6.375\)} (*Wrtist\ ptA*) , \[IndentingNewLine] (*p6*) {0, 
              0, \(-5.375\)}}]\)], "Input"],

Cell[BoxData[
    \(SysBody[25, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[RGripper] = 
      Body[RGripper, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {1, 
              0, \(-4\)} (*RSide*) , \[IndentingNewLine] (*p6*) {\(-1\), 
              0, \(-4\)} (*LSide*) }]\)], "Input"],

Cell[BoxData[
    \(SysBody[26, "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bd[LGripper] = 
      Body[LGripper, 
        PointList \[Rule] {\[IndentingNewLine] (*p1*) 
              origin, \[IndentingNewLine] (*p2*) 
              XAxis, \[IndentingNewLine] (*p3*) 
              YAxis, \[IndentingNewLine] (*p4*) 
              ZAxis, \[IndentingNewLine] (*p5*) {1, 
              0, \(-4\)} (*RSide*) , \[IndentingNewLine] (*p6*) {\(-1\), 
              0, \(-4\)} (*LSide*) }]\)], "Input"],

Cell[BoxData[
    \(SysBody[27, "<>"]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(SetBodies[bd[1], bd[2], bd[3], bd[4], bd[5], bd[6], bd[7], bd[8], 
      bd[9], bd[10], bd[11], bd[12], bd[13], bd[14], bd[15], bd[16], bd[17], 
      bd[18], bd[19], bd[20], bd[21], bd[22], bd[23], bd[24], bd[25], bd[26], 
      bd[27]]\)], "Input"],

Cell["\<\
Constrain the wheels to spin about the X axis of the wheel assembly\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[1] = 
      Revolute5[1, \ Line[LFWheel, \ 1, 2], 
        Line[LFSteerAsm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[2] = 
      Revolute5[2, \ Line[RFWheel, \ 1, 2], 
        Line[RFSteerAsm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[3] = 
      Revolute5[3, \ Line[RRWheel, \ 1, 2], 
        Line[RRSteerAsm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[4] = 
      Revolute5[4, \ Line[LRWheel, \ 1, 2], 
        Line[LRSteerAsm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell["\<\
Constrain the steering assemblies to rotate about their respective points\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[5] = 
      Revolute5[5, Line[LFSteerAsm, \ 1, \ 4], Line[base, 6, 7]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[6] = 
      Revolute5[6, Line[RFSteerAsm, \ 1, 4], Line[base, 8, 9]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[7] = 
      Revolute5[7, Line[RRSteerAsm, 1, 4], Line[base, 10, 11]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[8] = 
      Revolute5[8, Line[LRSteerAsm, 1, 4], Line[base, 12, 13]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell["Constrain steering asseblies so wheels steer...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[9] = 
      ProjectedAngle1[9, Vector[LFSteerAsm, \ 3], Vector[base, 3], 
        Vector[LFSteerAsm, 4], \ 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[10] = 
      ProjectedAngle1[10, Vector[RFSteerAsm, \ 3], Vector[base, 3], 
        Vector[RFSteerAsm, 4], \ 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[11] = 
      ProjectedAngle1[11, Vector[RRSteerAsm, \ 3], Vector[base, 3], 
        Vector[RRSteerAsm, 4], 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[12] = 
      ProjectedAngle1[12, Vector[LRSteerAsm, \ 3], Vector[base, 3], 
        Vector[LRSteerAsm, 4], \ 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Constrain wheels so they turn...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[13] = 
      ProjectedAngle1[13, Vector[LFWheel, 4], Vector[LFSteerAsm, 4], 
        Vector[LFSteerAsm, 2], 2  N\ [\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[14] = 
      ProjectedAngle1[14, Vector[RFWheel, 4], Vector[RFSteerAsm, 4], 
        Vector[RFSteerAsm, 2], 2  N\ [\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[15] = 
      ProjectedAngle1[15, Vector[RRWheel, 4], Vector[RRSteerAsm, 4], 
        Vector[RRSteerAsm, 2], 2  N\ [\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[16] = 
      ProjectedAngle1[16, Vector[LRWheel, 4], Vector[LRSteerAsm, 4], 
        Vector[LRSteerAsm, 2], 2  N\ [\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["For the base", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[17] = OriginLock3[17, base, {0, 0, 0}]\)], "Input"],

Cell[BoxData[
    \(SysCon["OriginLock3", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[18] = RotationLock3[18, base, {0, {1, 0, 0}}]\)], "Input"],

Cell[BoxData[
    \(SysCon["RotationLock3", "<>"]\)], "Output"]
}, Open  ]],

Cell["For the universal waist joint", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[19] = 
      Revolute5[19, \ Line[base, 14, 15], Line[UBlock, 1, 3]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[20] = 
      Revolute5[20, \ Line[UBlock, 1, 2], Line[UpperTorso, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[21] = 
      ProjectedAngle1[21, \ Vector[UBlock, 4], Vector[base, 4], 
        Vector[base, 3], N[WaistYawVal]]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[22] = 
      ProjectedAngle1[22, Vector[UBlock, 3], Vector[UpperTorso, 3], 
        Vector[UBlock, 2], N[WaistPitchVal]]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["For the Neck joint...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[23] = 
      Revolute5[23, Line[UpperTorso, 8, 15], Line[NeckTilt, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[24] = 
      ProjectedAngle1[24, Vector[UpperTorso, 4], Vector[NeckTilt, 4], 
        Vector[NeckTilt, 2], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[25] = 
      Revolute5[25, \ Line[NeckTilt, 1, 4], Line[NeckPan, 1, 4]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[26] = 
      ProjectedAngle1[26, Vector[NeckTilt, 3], Vector[NeckPan, 3], 
        Vector[NeckTilt, 4], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["For neck/stereo head", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[27] = 
      Revolute5[27, Line[NeckPan, 5, 6], Line[StereoHead, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[28] = 
      ProjectedAngle1[28, Vector[NeckPan, 4], Vector[StereoHead, 4], 
        Vector[StereoHead, 2], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["REye...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[29] = 
      Revolute5[29, Line[StereoHead, 5, 6], Line[REyeConv, 1, 4]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[30] = 
      ProjectedAngle1[30, Vector[StereoHead, 3], Vector[REyeConv, 3], 
        Vector[REyeConv, 4], 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Leye...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[31] = 
      Revolute5[31, Line[StereoHead, 7, 8], Line[LEyeConv, 1, 4]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[32] = 
      ProjectedAngle1[32, Vector[StereoHead, 3], Vector[LEyeConv, 3], 
        Vector[LEyeConv, 4], 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["R shoulder pitch...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[33] = 
      Revolute5[33, Line[UpperTorso, 10, 11], 
        Line[RUpperArmPitch, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[34] = 
      ProjectedAngle1[34, Vector[UpperTorso, 4], Vector[RUpperArmPitch, 4], 
        Vector[RUpperArmPitch, 2], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["R arm yaw...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[35] = 
      Revolute5[35, Line[RUpperArmPitch, 1, 3], 
        Line[RUpperArmYaw, 1, 3]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[36] = 
      ProjectedAngle1[36, Vector[RUpperArmPitch, 4], Vector[RUpperArmYaw, 4], 
        Vector[RUpperArmYaw, 3], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["R arm roll...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[37] = 
      Revolute5[37, Line[RUpperArmYaw, 1, 4], 
        Line[RUpperArmRoll, 1, 4]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[38] = 
      ProjectedAngle1[38, Vector[RUpperArmYaw, 3], Vector[RUpperArmRoll, 3], 
        Vector[RUpperArmRoll, 4], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Lower R arm/elbow...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[39] = 
      Revolute5[39, Line[RUpperArmRoll, 5, 6], 
        Line[RLowerArm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[40] = 
      ProjectedAngle1[40, Vector[RUpperArmRoll, 4], Vector[RLowerArm, 4], 
        Vector[RLowerArm, 2], 2  N[\[Pi]] T]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["L shoulder pitch...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[41] = 
      Revolute5[41, Line[UpperTorso, 13, 14], 
        Line[LUpperArmPitch, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[42] = 
      ProjectedAngle1[42, Vector[UpperTorso, 4], Vector[LUpperArmPitch, 4], 
        Vector[LUpperArmPitch, 2], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["LArm yaw...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[43] = 
      Revolute5[43, Line[LUpperArmPitch, \ 1, \ 3], 
        Line[LUpperArmYaw, 1, 3]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[44] = 
      ProjectedAngle1[44, Vector[LUpperArmPitch, 4], Vector[LUpperArmYaw, 4], 
        Vector[LUpperArmYaw, 3], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Larm roll...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[45] = 
      Revolute5[45, Line[LUpperArmYaw, 1, 4], 
        Line[LUpperArmRoll, 1, 4]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[46] = 
      ProjectedAngle1[46, Vector[LUpperArmYaw, 3], Vector[LUpperArmRoll, 3], 
        Vector[LUpperArmRoll, 4], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Lower L arm/elbow...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[47] = 
      Revolute5[47, Line[LUpperArmRoll, 5, 6], 
        Line[LLowerArm, 1, 2]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[48] = 
      ProjectedAngle1[48, Vector[LUpperArmRoll, 4], Vector[LLowerArm, 4], 
        Vector[LLowerArm, 2], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["RGripper.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[49] = 
      Revolute5[49, Line[RGripper, 1, 4], Line[RLowerArm, 5, 6]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[50] = 
      ProjectedAngle1[50, Vector[RGripper, 3], Vector[RLowerArm, 3], 
        Vector[RGripper, 4], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell["Lgripper", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[51] = 
      Revolute5[51, Line[LGripper, \ 1, 4], 
        Line[LLowerArm, \ 5, 6]]\)], "Input"],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs[52] = 
      ProjectedAngle1[52, Vector[LGripper, 3], Vector[LLowerArm, 3], 
        Vector[LGripper, 4], 0]\)], "Input"],

Cell[BoxData[
    \(SysCon["ProjectedAngle1", "<>"]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4], cs[5], cs[6], cs[7], cs[8], 
      cs[9], cs[10], cs[11], cs[12], cs[13], cs[14], cs[15], cs[16], cs[17], 
      cs[18], cs[19], cs[20], cs[21], cs[22], cs[23], cs[24], cs[25], cs[26], 
      cs[27], cs[28], cs[29], cs[30], cs[31], cs[32], cs[33], cs[34], cs[35], 
      cs[36], cs[37], cs[38], cs[39], cs[40], cs[41], cs[42], cs[43], cs[44], 
      cs[45], cs[46], cs[47], cs[48], cs[49], cs[50], cs[51], 
      cs[52]]\)], "Input"],

Cell[BoxData[{
    \(\(LFSteerAngVal = \[Pi]/2;\)\), "\[IndentingNewLine]", 
    \(\(RFSteerAngVal = 1.0;\)\), "\[IndentingNewLine]", 
    \(\(RRSteerAngVal = 1.0;\)\), "\[IndentingNewLine]", 
    \(\(LRSteerAngVal = \[Pi]/2;\)\), "\[IndentingNewLine]", 
    \(\(WaistYawVal = 0;\)\), "\[IndentingNewLine]", 
    \(\(WaistPitchVal = 0;\)\[IndentingNewLine]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckSystem[]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(graph := 
      Graphics3D[{Thickness[
            0.01], \[IndentingNewLine] \
(*ground*) \[IndentingNewLine]{Line[{{30, 30, 0}, {\(-30\), 30, 
                  0}, {\(-30\), \(-30\), 0}, {30, \(-30\), 0}, {30, 30, 
                  0}}]}, \[IndentingNewLine] (*base*) \[IndentingNewLine]Bar[
            Line[base, 1, 5], 13.0, 30], \[IndentingNewLine]Bar[
            Line[base, 1, 14], 2, 
            8], \[IndentingNewLine] (*RUpperArm*) \[IndentingNewLine]Bar[
            Line[RUpperArmRoll, 1, 5], 3, 
            4], \[IndentingNewLine] (*LUpperArm*) \[IndentingNewLine]Bar[
            Line[LUpperArmRoll, \ 1, 5], 3, 
            4], \[IndentingNewLine] (*RLowerArm*) \[IndentingNewLine]Bar[
            Line[RLowerArm, \ 1, 5], 2, 
            4], \[IndentingNewLine] (*LLowerArm*) \[IndentingNewLine]Bar[
            Line[LLowerArm, 1, 5], 2, 
            4], \[IndentingNewLine] (*RGripper*) \[IndentingNewLine]Bar[
            Line[RGripper, 1, 5], 0.5, 3], \[IndentingNewLine]Bar[
            Line[RGripper, 1, 6], 0.5, 
            3], \[IndentingNewLine] (*LGripper*) \[IndentingNewLine]Bar[
            Line[LGripper, 1, 5], 0.5, 3], \[IndentingNewLine]Bar[
            Line[LGripper, 1, 6], 0.5, 
            3], \[IndentingNewLine] (*UpperTorso*) \[IndentingNewLine]Bar[
            Line[UpperTorso, 1, 5], 3, 
            6],  (*T\ center*) \[IndentingNewLine]Bar[Line[UpperTorso, 6, 7], 
            4, 6],  (*T\ cross*) \[IndentingNewLine]Bar[
            Line[UpperTorso, 9, 10], 3, 
            6],  (*R\ shoulder*) \[IndentingNewLine]Bar[
            Line[UpperTorso, 12, 13], 3, 
            6],  (*L\ shoulder*) \[IndentingNewLine] (*Neck\
*) \[IndentingNewLine]Bar[Line[NeckPan, 1, 5], 1.5, 
            6], \[IndentingNewLine] (*StereoHead*) \[IndentingNewLine]Bar[
            Line[StereoHead, 10, 9], 2, 
            8], \[IndentingNewLine] (*REye*) \[IndentingNewLine]Bar[
            Line[REyeConv, 0, 5], 1, 
            4], \[IndentingNewLine] (*LEye*) \[IndentingNewLine]Bar[
            Line[LEyeConv, 0, 5], 1, 
            4], \[IndentingNewLine] (*LFSteerAsm*) \[IndentingNewLine]Bar[
            Line[LFSteerAsm, 1, 5], 2.5, 
            8], \[IndentingNewLine] (*RFSteerAsm*) \[IndentingNewLine]Bar[
            Line[RFSteerAsm, 1, 5], 2.5, 
            8], \[IndentingNewLine] (*RRSteerAsm*) \[IndentingNewLine]Bar[
            Line[RRSteerAsm, \ 1, 5], 2.5, 
            8], \[IndentingNewLine] (*LRSteerAsm*) \[IndentingNewLine]Bar[
            Line[LRSteerAsm, 1, 5], 2.5, 
            8], \ \[IndentingNewLine] (*LFWheel*) \[IndentingNewLine]Bar[
            Line[LFWheel, 5, 6], 3.0, 
            30], \[IndentingNewLine] (*RFWheel*) \[IndentingNewLine]Bar[
            Line[RFWheel, 5, 6], 3.0, 
            30], \[IndentingNewLine] (*RRWheel*) \[IndentingNewLine]Bar[
            Line[RRWheel, 5, 6], 3.0, 
            30], \[IndentingNewLine] (*LRWheel*) \[IndentingNewLine]Bar[
            Line[LRWheel, 5, 6], 3.0, 
            30]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-20\), 
              20}, {\(-20\), 20}, {\(-12\), 60}}, 
        Boxed \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(\(SetGuess[];\)\)], "Input"],

Cell[BoxData[
    \(\(postab = SolveMech[{0, \ 5}, 15];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((Show[graph /. #1, ViewPoint \[Rule] {0, \(-2\), 0}] &)\) /@ 
        Rest[postab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.63642 .41352 m .63642 .24629 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.6714 .41055 m .66146 .4114 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.66146 .4114 m .63642 .41352 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.66183 .20472 m .66984 .24491 L .67214 .24168 L .917 .749 .658 r
F
.67171 .25432 m .67201 .2453 L p .66984 .24491 L F P
0 g
s
.67201 .2453 m .67214 .24168 L p .66984 .24491 L .917 .749 .658 r
F P
0 g
s
.63642 .24629 m .66146 .24344 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.66931 .26624 m .67171 .25432 L .68532 .251 L p .238 .097 .478 r
F P
0 g
s
.66931 .26624 m .67171 .25432 L p .66984 .24491 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .66665 .24435 L .66984 .24491 L .917 .749 .658 r
F
.66665 .24435 m .66931 .26624 L .66984 .24491 L F
.59949 .24402 m .63642 .24629 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.63642 .24629 m .66146 .24344 L p .66146 .28232 L .511 .417 .685 r
F P
0 g
s
.64617 .29211 m .66146 .28232 L .66146 .36389 L .511 .417 .685 r
F
.63642 .24629 m .66146 .28232 L .64617 .29211 L F
.66146 .28232 m .66505 .27692 L .6709 .27553 L p .131 0 .124 r
F P
0 g
s
.6709 .27553 m .67275 .2751 L p .6714 .27596 L .131 0 .124 r
F P
0 g
s
.66146 .28232 m .6709 .27553 L .6714 .27596 L .131 0 .124 r
F
.6714 .41055 m .6714 .27596 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.67431 .27849 m .67505 .2878 L .6714 .27596 L 0 0 .415 r
F
.67505 .2878 m .68443 .40456 L .67505 .31202 L F
.67505 .2878 m .67505 .31202 L .6714 .27596 L F
.64311 .29734 m .65167 .29282 L p .65745 .24273 L .917 .749 .658 r
F P
0 g
s
.66146 .20794 m .65443 .2422 L .65745 .24273 L .917 .749 .658 r
F
.65443 .2422 m .64311 .29734 L .65745 .24273 L F
.66146 .20656 m .65426 .24217 L .66146 .20794 L F
.65426 .24217 m .64311 .29734 L .65443 .2422 L F
.65426 .24217 m .65443 .2422 L .66146 .20794 L F
.58156 .23673 m .59949 .24402 L p .63899 .23948 L .289 .763 .934 r
F P
0 g
s
.68418 .22538 m .68574 .23829 L .67214 .24168 L p .296 .298 .693 r
F P
0 g
s
.67214 .24168 m .67058 .22884 L .68418 .22538 L p .296 .298 .693 r
F P
0 g
s
.6807 .21282 m .68418 .22538 L .67058 .22884 L p .316 .382 .773 r
F P
0 g
s
.67058 .22884 m .6671 .21634 L .6807 .21282 L p .316 .382 .773 r
F P
0 g
s
.67543 .20113 m .6807 .21282 L .6671 .21634 L p .331 .461 .841 r
F P
0 g
s
.67543 .20113 m .67505 .21216 L .6767 .24034 L .918 .75 .657 r
F
.67543 .20113 m .6767 .24034 L .67717 .24043 L F
.67505 .27595 m .67505 .27551 L .67864 .27371 L .131 0 .124 r
F
.66146 .36389 m .6685 .27782 L .6714 .41055 L .511 .417 .685 r
F
.68532 .251 m .68292 .26297 L .66931 .26624 L p .238 .097 .478 r
F P
0 g
s
.66931 .26624 m .68292 .26297 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.66505 .27692 m .66777 .2701 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.66777 .2701 m .66931 .26624 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.67171 .25432 m .67214 .24168 L .68574 .23829 L p .271 .205 .597 r
F P
0 g
s
.68574 .23829 m .68532 .251 L .67171 .25432 L p .271 .205 .597 r
F P
0 g
s
.68292 .26297 m .68137 .26686 L p .66505 .27692 L .193 0 .325 r
F P
0 g
s
.68137 .26686 m .67864 .27371 L .67275 .2751 L p .193 0 .325 r
F P
0 g
s
.67275 .2751 m .66505 .27692 L p .68137 .26686 L .193 0 .325 r
F P
0 g
s
.66505 .27692 m .66931 .26624 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.65908 .28591 m .66505 .27692 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66146 .24344 m .6714 .24231 L p .66838 .27928 L .511 .417 .685 r
F P
0 g
s
.66146 .2859 m .66838 .27928 L .66146 .36389 L .511 .417 .685 r
F
.66146 .24344 m .66838 .27928 L .66146 .2859 L F
.67717 .24043 m .6767 .24034 L .67864 .27371 L .918 .75 .657 r
F
.67275 .2751 m .67864 .27371 L p .6724 .27684 L .131 0 .124 r
F P
0 g
s
.6714 .27596 m .6714 .41055 L p .6685 .27782 L .511 .417 .685 r
F P
0 g
s
.66146 .28232 m .6714 .27596 L .6724 .27684 L .131 0 .124 r
F
.6714 .27596 m .67275 .2751 L .6724 .27684 L F
.67214 .24168 m .67058 .22884 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.65167 .29282 m .65908 .28591 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.63899 .23948 m .59949 .24402 L .65343 .24202 L .289 .763 .934 r
F
.59949 .24402 m .63642 .24629 L .63642 .41352 L p .797 .651 .701 r
F P
0 g
s
.63377 .29926 m .64311 .29734 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.6714 .24231 m .67505 .24005 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.67505 .21216 m .67505 .24005 L .6767 .24034 L .918 .75 .657 r
F
.66701 .23862 m .65343 .24202 L .67505 .24005 L .289 .763 .934 r
F
.6714 .24231 m .67505 .24005 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.67267 .28274 m .65908 .28591 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67864 .27371 m .67505 .27914 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67431 .27849 m .68443 .29898 L .67458 .2819 L 0 0 .415 r
F
.68107 .28436 m .68443 .29898 L .67431 .27849 L F
.67505 .27914 m .67267 .28274 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67505 .27914 m .67864 .27371 L p .6767 .24034 L .918 .75 .657 r
F P
0 g
s
.65908 .28591 m .67505 .27551 L .67505 .27595 L .131 0 .124 r
F
.65908 .28591 m .66146 .28232 L p .67505 .27551 L F P
0 g
s
.6714 .24231 m .67505 .2582 L .67431 .27849 L 0 0 .415 r
F
.67505 .24005 m .67505 .27914 L .6767 .24034 L .918 .75 .657 r
F
.67505 .2582 m .68107 .28436 L .67505 .27914 L 0 0 .415 r
F
.67505 .2582 m .67505 .27914 L .67431 .27849 L F
.67864 .27371 m .68292 .26297 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.6714 .24231 m .68443 .28728 L .68107 .28436 L 0 0 .415 r
F
.67326 .26543 m .67431 .27849 L .67286 .27723 L F
.67326 .26543 m .67286 .27723 L .6714 .27596 L F
.6714 .27596 m .6714 .24231 L p .67326 .26543 L F P
0 g
s
.67267 .28274 m .67505 .27914 L p .67505 .21216 L .918 .75 .657 r
F P
0 g
s
.6714 .24231 m .6714 .27596 L p .6685 .27782 L .511 .417 .685 r
F P
0 g
s
.65167 .29282 m .65908 .28591 L .67267 .28274 L p .046 0 0 r
F P
0 g
s
.67267 .28274 m .66525 .28968 L .65167 .29282 L p .046 0 0 r
F P
0 g
s
.66525 .28968 m .67267 .28274 L p .67412 .23988 L .918 .75 .657 r
F P
0 g
s
.67505 .21216 m .6716 .23944 L .67412 .23988 L .918 .75 .657 r
F
.66146 .24344 m .6714 .24231 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.6716 .23944 m .66525 .28968 L .67412 .23988 L .918 .75 .657 r
F
.62406 .29847 m .63377 .29926 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.61438 .295 m .62406 .29847 L p .64724 .24093 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .64317 .24022 L .64724 .24093 L .917 .749 .658 r
F
.64317 .24022 m .61438 .295 L .64724 .24093 L F
.67505 .20437 m .66525 .28968 L .67505 .21216 L .918 .75 .657 r
F
.61836 .23584 m .58156 .23673 L .63899 .23948 L .289 .763 .934 r
F
.63642 .41352 m .59949 .41183 L .59949 .24402 L p .797 .651 .701 r
F P
0 g
s
.60517 .28897 m .61438 .295 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58156 .23673 m .59949 .24402 L .59949 .41183 L p .999 .816 .524 r
F P
0 g
s
.59684 .28063 m .60517 .28897 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .59016 .26999 L .59684 .28063 L .917 .749 .658 r
F
.59016 .2709 m .59684 .28063 L p .59016 .26999 L F P
0 g
s
.59949 .41183 m .58156 .4064 L .58156 .23673 L p .999 .816 .524 r
F P
0 g
s
.58156 .23673 m .58156 .4064 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.59016 .23087 m .58156 .23673 L p .61836 .23584 L .289 .763 .934 r
F P
0 g
s
.66183 .20472 m .59016 .25448 L .59016 .26999 L .917 .749 .658 r
F
.59016 .23087 m .58156 .23673 L p .58893 .27321 L 0 0 .389 r
F P
0 g
s
.59016 .2709 m .58893 .27321 L .59016 .27929 L 0 0 .389 r
F
.59016 .23087 m .58893 .27321 L .59016 .2709 L F
.59684 .28063 m .61033 .27738 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.59016 .2709 m .59684 .28063 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.58065 .2458 m .58429 .25856 L p .59016 .25448 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .59016 .24098 L .59016 .25448 L .917 .749 .658 r
F
.59016 .24098 m .58065 .2458 L .59016 .25448 L F
.57901 .23264 m .58065 .2458 L p .66183 .20472 L F P
0 g
s
.68532 .251 m .68574 .23829 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.68292 .26297 m .68532 .251 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67058 .22884 m .6671 .21634 L .66183 .20472 L p .917 .749 .658 r
F P
0 g
s
.64311 .29734 m .65167 .29282 L .66525 .28968 L p 0 0 0 r
F P
0 g
s
.66525 .28968 m .65668 .29421 L .64311 .29734 L p 0 0 0 r
F P
0 g
s
.65668 .29421 m .66525 .28968 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64746 .23514 m .59016 .23087 L .61836 .23584 L .289 .763 .934 r
F
.67543 .20113 m .66447 .23817 L .66784 .23877 L .918 .75 .657 r
F
.66701 .23862 m .63899 .23948 L .65343 .24202 L .289 .763 .934 r
F
.65894 .23718 m .63899 .23948 L .66701 .23862 L F
.63759 .29534 m .64732 .29613 L p .66447 .23817 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .66081 .23752 L .66447 .23817 L .918 .75 .657 r
F
.66081 .23752 m .63759 .29534 L .66447 .23817 L F
.5936 .22854 m .59343 .23099 L p .63185 .23237 L .289 .763 .934 r
F P
0 g
s
.65894 .23718 m .61836 .23584 L .63899 .23948 L .289 .763 .934 r
F
.64746 .23514 m .61836 .23584 L .65894 .23718 L F
.6279 .29184 m .63759 .29534 L p .66081 .23752 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .65674 .23679 L .66081 .23752 L .918 .75 .657 r
F
.65674 .23679 m .6279 .29184 L .66081 .23752 L F
.6671 .21634 m .66183 .20472 L .67543 .20113 L p .331 .461 .841 r
F P
0 g
s
.61868 .28577 m .6279 .29184 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.63185 .23237 m .59016 .23087 L .64746 .23514 L .289 .763 .934 r
F
.61033 .27738 m .61868 .28577 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .60364 .26668 L .61033 .27738 L .918 .75 .657 r
F
.60364 .26759 m .61033 .27738 L p .60364 .26668 L F P
0 g
s
.59684 .28063 m .60517 .28897 L .61868 .28577 L p .324 .605 .949 r
F P
0 g
s
.61868 .28577 m .61033 .27738 L .59684 .28063 L p .324 .605 .949 r
F P
0 g
s
.5936 .22854 m .59016 .23087 L p .59016 .2709 L 0 0 .389 r
F P
0 g
s
.61033 .27738 m .60364 .26759 L p .59054 .27019 L .319 .529 .901 r
F P
0 g
s
.59036 .27054 m .61033 .27738 L .59054 .27019 L .319 .529 .901 r
F
.5936 .22854 m .59016 .2709 L .59057 .27015 L 0 0 .389 r
F
.59057 .27015 m .60246 .26723 L p .59351 .26267 L .309 .451 .841 r
F P
0 g
s
.59351 .26267 m .60246 .26723 L .59652 .26402 L .309 .451 .841 r
F
.60246 .26723 m .59057 .27015 L p .60364 .26759 L .319 .529 .901 r
F P
0 g
s
.59054 .27019 m .60364 .26759 L .59057 .27015 L .319 .529 .901 r
F
.5936 .40031 m .5936 .26446 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.60364 .22735 m .5936 .22854 L p .61945 .23016 L .289 .763 .934 r
F P
0 g
s
.61945 .23016 m .5936 .22854 L .63185 .23237 L .289 .763 .934 r
F
.60364 .22735 m .5936 .22854 L p .59651 .26402 L .504 .412 .684 r
F P
0 g
s
.59685 .2642 m .59651 .26402 L .59663 .2654 L .504 .412 .684 r
F
.60364 .22735 m .59651 .26402 L .59685 .2642 L F
.5936 .26244 m .5936 .22854 L p .59083 .26949 L 0 0 .389 r
F P
0 g
s
.5936 .22854 m .59057 .27015 L .59083 .26949 L 0 0 .389 r
F
.59016 .25448 m .58429 .25856 L .59016 .26999 L .917 .749 .658 r
F
.58429 .25856 m .59351 .26267 L .5936 .26244 L .309 .451 .841 r
F
.5936 .22854 m .5936 .26244 L p .59651 .26402 L .504 .412 .684 r
F P
0 g
s
.59631 .25554 m .58573 .2582 L p .5936 .26244 L .309 .451 .841 r
F P
0 g
s
.58573 .2582 m .58429 .25856 L p .5936 .26244 L .309 .451 .841 r
F P
0 g
s
.60364 .22735 m .59685 .2642 L .60364 .26759 L .504 .412 .684 r
F
.59685 .2642 m .59663 .2654 L .60246 .26723 L F
.59685 .2642 m .60246 .26723 L .60364 .26759 L F
.5936 .26244 m .60325 .26703 L .59631 .25554 L .309 .451 .841 r
F
.59351 .26267 m .59652 .26402 L .5936 .26244 L F
.59652 .26402 m .60325 .26703 L .5936 .26244 L F
.60325 .26703 m .59776 .25518 L .59631 .25554 L p F P
0 g
s
.5936 .26446 m .5936 .26244 L p .59081 .26968 L 0 0 .389 r
F P
0 g
s
.59083 .26949 m .59081 .26968 L .5936 .26244 L 0 0 .389 r
F
.59081 .26968 m .59016 .27929 L .5936 .26446 L F
.59057 .27015 m .58978 .27034 L p .59054 .27019 L .319 .529 .901 r
F P
0 g
s
.60364 .26759 m .59663 .2654 L .60364 .35076 L .504 .412 .684 r
F
.60246 .26723 m .60325 .26703 L p .59652 .26402 L .309 .451 .841 r
F P
0 g
s
.59663 .2654 m .59651 .26402 L .5936 .26446 L .504 .412 .684 r
F
.5936 .26244 m .5936 .26446 L p .59651 .26402 L F P
0 g
s
.59083 .26949 m .59057 .27015 L .59081 .26968 L 0 0 .389 r
F
.58429 .25856 m .58978 .27034 L p .59016 .26999 L .917 .749 .658 r
F P
0 g
s
.58429 .25856 m .58978 .27034 L .59057 .27015 L p .309 .451 .841 r
F P
0 g
s
.58429 .25856 m .59057 .27015 L .59351 .26267 L .309 .451 .841 r
F
.59081 .26968 m .59016 .2709 L .59016 .27929 L 0 0 .389 r
F
.58978 .27034 m .59016 .2709 L p .59016 .26999 L .917 .749 .658 r
F P
0 g
s
.58978 .27034 m .59036 .27054 L .59054 .27019 L .319 .529 .901 r
F
.60364 .26759 m .60325 .26703 L .60246 .26723 L p F P
0 g
s
.60364 .35076 m .59663 .2654 L .5936 .40031 L .504 .412 .684 r
F
.5936 .26446 m .5936 .40031 L p .59663 .2654 L F P
0 g
s
.67543 .20113 m .60364 .25109 L .60364 .26668 L .918 .75 .657 r
F
.59411 .24235 m .59776 .25518 L p .67543 .20113 L F P
0 g
s
.66183 .20472 m .66146 .20656 L .66146 .20794 L .917 .749 .658 r
F
.59247 .22912 m .59411 .24235 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.62927 .22434 m .62823 .22945 L p .68443 .23425 L .289 .763 .934 r
F P
0 g
s
.68443 .23425 m .60364 .22735 L .61945 .23016 L .289 .763 .934 r
F
.68443 .23425 m .61945 .23016 L .63185 .23237 L F
.61438 .295 m .62406 .29847 L .63759 .29534 L p .297 .732 .968 r
F P
0 g
s
.63759 .29534 m .6279 .29184 L .61438 .295 L p .297 .732 .968 r
F P
0 g
s
.60517 .28897 m .61438 .295 L .6279 .29184 L p .318 .675 .977 r
F P
0 g
s
.6279 .29184 m .61868 .28577 L .60517 .28897 L p .318 .675 .977 r
F P
0 g
s
.62927 .22434 m .60364 .22735 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.59776 .25518 m .60325 .26703 L p .60364 .26668 L .918 .75 .657 r
F P
0 g
s
.60364 .25109 m .59776 .25518 L .60364 .26668 L .918 .75 .657 r
F
.60325 .26703 m .60364 .26759 L p .60364 .26668 L F P
0 g
s
.62406 .29847 m .63377 .29926 L .64732 .29613 L p .249 .752 .89 r
F P
0 g
s
.64732 .29613 m .63759 .29534 L .62406 .29847 L p .249 .752 .89 r
F P
0 g
s
.62927 .39718 m .62927 .22434 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.5936 .40031 m .60364 .39943 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.60364 .39943 m .62927 .39718 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.68443 .23425 m .63185 .23237 L .64746 .23514 L .289 .763 .934 r
F
.64732 .29613 m .65668 .29421 L p .66784 .23877 L .918 .75 .657 r
F P
0 g
s
.66447 .23817 m .64732 .29613 L .66784 .23877 L .918 .75 .657 r
F
.58978 .27034 m .59016 .2709 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.58156 .4064 m .59016 .40205 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.59016 .40205 m .5936 .40031 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.68443 .23425 m .64746 .23514 L .65894 .23718 L .289 .763 .934 r
F
.67505 .24005 m .68443 .23425 L p .66701 .23862 L F P
0 g
s
.68443 .23425 m .68443 .28728 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.67505 .24005 m .68443 .23425 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.68443 .28728 m .68443 .29898 L p .68107 .28436 L 0 0 .415 r
F P
0 g
s
.68443 .29898 m .68443 .40456 L p .67458 .2819 L 0 0 .415 r
F P
0 g
s
.68443 .23425 m .65894 .23718 L .66701 .23862 L .289 .763 .934 r
F
.67543 .20113 m .67505 .20437 L .67505 .21216 L .918 .75 .657 r
F
.68443 .40456 m .67505 .40887 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.67505 .40887 m .6714 .41055 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.66719 .39897 m .68443 .40456 L .68443 .23425 L p 1 .816 .507 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.63642 .41352 m .6714 .41055 L .68443 .40456 L p .224 .73 .894 r
F P
0 g
s
.59949 .41183 m .63642 .41352 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58156 .4064 m .59949 .41183 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.5936 .40031 m .58156 .4064 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.62927 .39718 m .5936 .40031 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.68443 .40456 m .66719 .39897 L .62927 .39718 L p .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.37493 .41352 m .37493 .24629 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.40832 .41055 m .39884 .4114 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.39884 .4114 m .37493 .41352 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.39923 .20472 m .4078 .24491 L .41026 .24168 L .908 .741 .664 r
F
.40981 .25432 m .41013 .2453 L p .4078 .24491 L F P
0 g
s
.41013 .2453 m .41026 .24168 L p .4078 .24491 L .908 .741 .664 r
F P
0 g
s
.37493 .24629 m .39884 .24344 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.40724 .26624 m .40981 .25432 L .42207 .251 L p .188 .048 .447 r
F P
0 g
s
.40724 .26624 m .40981 .25432 L p .4078 .24491 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .40439 .24435 L .4078 .24491 L .908 .741 .664 r
F
.40439 .24435 m .40724 .26624 L .4078 .24491 L F
.3371 .24402 m .37493 .24629 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.37493 .24629 m .39884 .24344 L p .39884 .28232 L .501 .409 .683 r
F P
0 g
s
.38425 .29211 m .39884 .28232 L .39884 .36389 L .501 .409 .683 r
F
.37493 .24629 m .39884 .28232 L .38425 .29211 L F
.39884 .28232 m .40268 .27692 L .40795 .27553 L p .071 0 .064 r
F P
0 g
s
.40795 .27553 m .40961 .2751 L p .40832 .27596 L .071 0 .064 r
F P
0 g
s
.39884 .28232 m .40795 .27553 L .40832 .27596 L .071 0 .064 r
F
.37919 .29734 m .38835 .29282 L p .39454 .24273 L .908 .741 .664 r
F P
0 g
s
.39884 .20794 m .39131 .2422 L .39454 .24273 L .908 .741 .664 r
F
.39131 .2422 m .37919 .29734 L .39454 .24273 L F
.39884 .20656 m .39113 .24217 L .39884 .20794 L F
.39113 .24217 m .37919 .29734 L .39131 .2422 L F
.39113 .24217 m .39131 .2422 L .39884 .20794 L F
.31625 .23673 m .3371 .24402 L p .37478 .23948 L .289 .763 .934 r
F P
0 g
s
.42085 .22538 m .42252 .23829 L .41026 .24168 L p .256 .27 .683 r
F P
0 g
s
.41026 .24168 m .4086 .22884 L .42085 .22538 L p .256 .27 .683 r
F P
0 g
s
.41712 .21282 m .42085 .22538 L .4086 .22884 L p .28 .362 .769 r
F P
0 g
s
.4086 .22884 m .40487 .21634 L .41712 .21282 L p .28 .362 .769 r
F P
0 g
s
.41147 .20113 m .41712 .21282 L .40487 .21634 L p .299 .447 .841 r
F P
0 g
s
.41147 .20113 m .41107 .21216 L .41283 .24034 L .909 .742 .663 r
F
.41147 .20113 m .41283 .24034 L .41334 .24043 L F
.40832 .41055 m .40832 .27596 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.41051 .27849 m .41107 .2878 L .40832 .27596 L 0 0 .339 r
F
.41107 .2878 m .41813 .40456 L .41107 .31202 L F
.41107 .2878 m .41107 .31202 L .40832 .27596 L F
.40981 .25432 m .41026 .24168 L .42252 .23829 L p .226 .167 .578 r
F P
0 g
s
.42252 .23829 m .42207 .251 L .40981 .25432 L p .226 .167 .578 r
F P
0 g
s
.42207 .251 m .4195 .26297 L .40724 .26624 L p .188 .048 .447 r
F P
0 g
s
.40268 .27692 m .40724 .26624 L .4195 .26297 L p .138 0 .279 r
F P
0 g
s
.39884 .36389 m .40544 .27928 L .40832 .41055 L .501 .409 .683 r
F
.4195 .26297 m .41784 .26686 L p .40268 .27692 L .138 0 .279 r
F P
0 g
s
.40961 .2751 m .40268 .27692 L p .41784 .26686 L .138 0 .279 r
F P
0 g
s
.40268 .27692 m .40724 .26624 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.40832 .24231 m .40832 .27639 L p .40544 .27928 L .501 .409 .683 r
F P
0 g
s
.40832 .27639 m .40832 .41055 L p .40544 .27928 L .501 .409 .683 r
F P
0 g
s
.41784 .26686 m .41492 .27371 L .40961 .2751 L p .138 0 .279 r
F P
0 g
s
.41334 .24043 m .41283 .24034 L .41492 .27371 L .909 .742 .663 r
F
.40946 .27728 m .40908 .27684 L .41492 .27371 L .071 0 .064 r
F
.39629 .28591 m .40268 .27692 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.39884 .24344 m .40832 .24231 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.40961 .2751 m .41492 .27371 L p .39884 .28232 L .071 0 .064 r
F P
0 g
s
.41813 .28728 m .41813 .40456 L p .41051 .27849 L 0 0 .339 r
F P
0 g
s
.41492 .27371 m .40852 .28274 L .39629 .28591 L p .071 0 .064 r
F P
0 g
s
.41107 .27914 m .41492 .27371 L p .41283 .24034 L .909 .742 .663 r
F P
0 g
s
.41107 .21216 m .41107 .24005 L .41283 .24034 L .909 .742 .663 r
F
.41107 .24005 m .41107 .27914 L .41283 .24034 L F
.41026 .24168 m .4086 .22884 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.38835 .29282 m .39629 .28591 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37478 .23948 m .3371 .24402 L .39024 .24202 L .289 .763 .934 r
F
.3371 .24402 m .37493 .24629 L .37493 .41352 L p .795 .649 .701 r
F P
0 g
s
.3692 .29926 m .37919 .29734 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.40832 .24231 m .41107 .24005 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.40246 .23862 m .39024 .24202 L .41107 .24005 L .289 .763 .934 r
F
.4195 .26297 m .42207 .251 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41492 .27371 m .4195 .26297 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.40832 .24231 m .41813 .23425 L .41813 .28728 L p 0 0 .339 r
F P
0 g
s
.40832 .24231 m .41813 .28728 L .41051 .27849 L 0 0 .339 r
F
.39629 .28591 m .40873 .27702 L .4087 .27778 L .071 0 .064 r
F
.39629 .28591 m .39884 .28232 L p .40873 .27702 L F P
0 g
s
.40936 .25951 m .41051 .27849 L .40875 .27646 L 0 0 .339 r
F
.40936 .25951 m .40875 .27646 L .40832 .27596 L F
.40832 .27596 m .40832 .24231 L p .40936 .25951 L F P
0 g
s
.3588 .29847 m .3692 .29926 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37493 .41352 m .3371 .41183 L .3371 .24402 L p .795 .649 .701 r
F P
0 g
s
.34844 .295 m .3588 .29847 L p .38361 .24093 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .37926 .24022 L .38361 .24093 L .908 .741 .664 r
F
.37926 .24022 m .34844 .295 L .38361 .24093 L F
.41107 .21216 m .40738 .23944 L .41007 .23988 L .909 .742 .663 r
F
.39884 .24344 m .40832 .24231 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.4086 .22884 m .40487 .21634 L .39923 .20472 L p .908 .741 .664 r
F P
0 g
s
.38835 .29282 m .39629 .28591 L .40852 .28274 L p 0 0 0 r
F P
0 g
s
.40852 .28274 m .40057 .28968 L .38835 .29282 L p 0 0 0 r
F P
0 g
s
.41107 .20437 m .40057 .28968 L .41107 .21216 L .909 .742 .663 r
F
.4087 .27778 m .40873 .27702 L .40908 .27684 L .071 0 .064 r
F
.4087 .27778 m .40908 .27684 L .40946 .27728 L F
.40852 .28274 m .41107 .27914 L p .41107 .24005 L .909 .742 .663 r
F P
0 g
s
.41107 .21216 m .41007 .23988 L .41107 .24005 L .909 .742 .663 r
F
.41007 .23988 m .40852 .28274 L .41107 .24005 L F
.32251 .23087 m .31625 .23673 L p .3527 .23584 L .289 .763 .934 r
F P
0 g
s
.3527 .23584 m .31625 .23673 L .37478 .23948 L .289 .763 .934 r
F
.3371 .41183 m .31625 .4064 L .31625 .23673 L p .992 .81 .557 r
F P
0 g
s
.31625 .23673 m .3371 .24402 L .3371 .41183 L p .992 .81 .557 r
F P
0 g
s
.39923 .20472 m .32251 .25448 L .32251 .26999 L .908 .741 .664 r
F
.31625 .23673 m .31625 .4064 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.39923 .20472 m .32251 .24098 L .32251 .25448 L .908 .741 .664 r
F
.32251 .23087 m .31625 .23673 L p .32162 .27321 L 0 0 .305 r
F P
0 g
s
.32251 .2709 m .32162 .27321 L .32251 .27929 L 0 0 .305 r
F
.32251 .23087 m .32162 .27321 L .32251 .2709 L F
.32967 .28063 m .33858 .28897 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.3221 .27034 m .32967 .28063 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.32967 .28063 m .34175 .27738 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.32251 .2709 m .32967 .28063 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.31057 .23264 m .31233 .2458 L p .32251 .24098 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .32251 .22888 L .32251 .24098 L .908 .741 .664 r
F
.32251 .22888 m .31057 .23264 L .32251 .24098 L F
.33858 .28897 m .34844 .295 L p .39923 .20472 L F P
0 g
s
.37919 .29734 m .38835 .29282 L .40057 .28968 L p 0 0 0 r
F P
0 g
s
.40057 .28968 m .39139 .29421 L .37919 .29734 L p 0 0 0 r
F P
0 g
s
.39139 .29421 m .40057 .28968 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.38151 .23514 m .32251 .23087 L .3527 .23584 L .289 .763 .934 r
F
.41147 .20113 m .39974 .23817 L .40335 .23877 L .909 .742 .663 r
F
.40246 .23862 m .37478 .23948 L .39024 .24202 L .289 .763 .934 r
F
.39381 .23718 m .37478 .23948 L .40246 .23862 L F
.37095 .29534 m .38137 .29613 L p .39974 .23817 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .39582 .23752 L .39974 .23817 L .909 .742 .663 r
F
.39582 .23752 m .37095 .29534 L .39974 .23817 L F
.39381 .23718 m .3527 .23584 L .37478 .23948 L .289 .763 .934 r
F
.38151 .23514 m .3527 .23584 L .39381 .23718 L F
.40487 .21634 m .39923 .20472 L .41147 .20113 L p .299 .447 .841 r
F P
0 g
s
.36056 .29184 m .37095 .29534 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.35069 .28577 m .36056 .29184 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.3648 .23237 m .32251 .23087 L .38151 .23514 L .289 .763 .934 r
F
.34175 .27738 m .35069 .28577 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .33458 .26668 L .34175 .27738 L .909 .742 .663 r
F
.33458 .26759 m .34175 .27738 L p .33458 .26668 L F P
0 g
s
.32501 .22854 m .32489 .23096 L p .3648 .23237 L .289 .763 .934 r
F P
0 g
s
.32501 .22854 m .32251 .23087 L p .32251 .2709 L 0 0 .305 r
F P
0 g
s
.34175 .27738 m .33458 .26759 L p .32279 .27019 L .289 .519 .902 r
F P
0 g
s
.32265 .27054 m .34175 .27738 L .32279 .27019 L .289 .519 .902 r
F
.32501 .22854 m .32251 .2709 L .32281 .27015 L 0 0 .305 r
F
.32281 .27015 m .33346 .26723 L p .32495 .26267 L .274 .436 .841 r
F P
0 g
s
.32495 .26267 m .33346 .26723 L .32779 .26402 L .274 .436 .841 r
F
.33346 .26723 m .32281 .27015 L p .33458 .26759 L .289 .519 .902 r
F P
0 g
s
.32279 .27019 m .33458 .26759 L .32281 .27015 L .289 .519 .902 r
F
.32501 .40031 m .32501 .26446 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.33458 .22735 m .32501 .22854 L p .35151 .23016 L .289 .763 .934 r
F P
0 g
s
.35151 .23016 m .32501 .22854 L .3648 .23237 L .289 .763 .934 r
F
.33458 .22735 m .32501 .22854 L p .32779 .26402 L .494 .403 .682 r
F P
0 g
s
.32811 .2642 m .32779 .26402 L .3279 .2654 L .494 .403 .682 r
F
.33458 .22735 m .32779 .26402 L .32811 .2642 L F
.33458 .22735 m .3279 .2654 L .33458 .26759 L F
.32501 .22854 m .32501 .26244 L p .32779 .26402 L F P
0 g
s
.32501 .26244 m .33417 .26703 L .32699 .25554 L .274 .436 .841 r
F
.32495 .26267 m .32779 .26402 L .32501 .26244 L F
.32779 .26402 m .33417 .26703 L .32501 .26244 L F
.33417 .26703 m .32829 .25518 L .32699 .25554 L p F P
0 g
s
.32501 .26244 m .32501 .22854 L p .323 .26949 L 0 0 .305 r
F P
0 g
s
.32501 .22854 m .32281 .27015 L .323 .26949 L 0 0 .305 r
F
.32251 .25448 m .31623 .25856 L .32251 .26999 L .908 .741 .664 r
F
.32699 .25554 m .31623 .25856 L p .32495 .26267 L .274 .436 .841 r
F P
0 g
s
.32501 .26446 m .32501 .26244 L p .32299 .26968 L 0 0 .305 r
F P
0 g
s
.323 .26949 m .32299 .26968 L .32501 .26244 L 0 0 .305 r
F
.32299 .26968 m .32251 .27929 L .32501 .26446 L F
.32281 .27015 m .3221 .27034 L p .32279 .27019 L .289 .519 .902 r
F P
0 g
s
.32967 .28063 m .33858 .28897 L .35069 .28577 L p .298 .597 .948 r
F P
0 g
s
.35069 .28577 m .34175 .27738 L .32967 .28063 L p .298 .597 .948 r
F P
0 g
s
.33458 .26759 m .3279 .2654 L .33458 .35076 L .494 .403 .682 r
F
.33346 .26723 m .33417 .26703 L p .32779 .26402 L .274 .436 .841 r
F P
0 g
s
.3279 .2654 m .32779 .26402 L .32501 .26446 L .494 .403 .682 r
F
.32501 .26244 m .32501 .26446 L p .32779 .26402 L F P
0 g
s
.323 .26949 m .32281 .27015 L .32299 .26968 L 0 0 .305 r
F
.31623 .25856 m .3221 .27034 L p .32251 .26999 L .908 .741 .664 r
F P
0 g
s
.31623 .25856 m .3221 .27034 L .32281 .27015 L p .274 .436 .841 r
F P
0 g
s
.31623 .25856 m .32281 .27015 L .32495 .26267 L .274 .436 .841 r
F
.32299 .26968 m .32251 .2709 L .32251 .27929 L 0 0 .305 r
F
.3221 .27034 m .32265 .27054 L .32279 .27019 L .289 .519 .902 r
F
.33458 .26759 m .33417 .26703 L .33346 .26723 L p F P
0 g
s
.33458 .35076 m .3279 .2654 L .32501 .40031 L .494 .403 .682 r
F
.32501 .26446 m .32501 .40031 L p .3279 .2654 L F P
0 g
s
.41147 .20113 m .33458 .25109 L .33458 .26668 L .909 .742 .663 r
F
.39923 .20472 m .39884 .20656 L .39884 .20794 L .908 .741 .664 r
F
.32437 .24235 m .32829 .25518 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.32262 .22912 m .32437 .24235 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.359 .22434 m .35805 .22929 L p .41813 .23425 L .289 .763 .934 r
F P
0 g
s
.41813 .23425 m .33458 .22735 L .35151 .23016 L .289 .763 .934 r
F
.41813 .23425 m .35151 .23016 L .3648 .23237 L F
.33858 .28897 m .34844 .295 L .36056 .29184 L p .299 .67 .974 r
F P
0 g
s
.36056 .29184 m .35069 .28577 L .33858 .28897 L p .299 .67 .974 r
F P
0 g
s
.359 .22434 m .33458 .22735 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.32829 .25518 m .33417 .26703 L p .33458 .26668 L .909 .742 .663 r
F P
0 g
s
.33458 .25109 m .32829 .25518 L .33458 .26668 L .909 .742 .663 r
F
.33417 .26703 m .33458 .26759 L p .33458 .26668 L F P
0 g
s
.3588 .29847 m .3692 .29926 L .38137 .29613 L p .254 .755 .893 r
F P
0 g
s
.38137 .29613 m .37095 .29534 L .3588 .29847 L p .254 .755 .893 r
F P
0 g
s
.34844 .295 m .3588 .29847 L .37095 .29534 L p .287 .729 .964 r
F P
0 g
s
.37095 .29534 m .36056 .29184 L .34844 .295 L p .287 .729 .964 r
F P
0 g
s
.359 .39718 m .359 .22434 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.32501 .40031 m .33458 .39943 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.33458 .39943 m .359 .39718 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.41813 .23425 m .3648 .23237 L .38151 .23514 L .289 .763 .934 r
F
.38137 .29613 m .39139 .29421 L p .40335 .23877 L .909 .742 .663 r
F P
0 g
s
.39974 .23817 m .38137 .29613 L .40335 .23877 L .909 .742 .663 r
F
.3221 .27034 m .32251 .2709 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.31233 .2458 m .31623 .25856 L p .32251 .25448 L .908 .741 .664 r
F P
0 g
s
.32251 .24098 m .31233 .2458 L .32251 .25448 L .908 .741 .664 r
F
.31625 .4064 m .32251 .40205 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.32251 .40205 m .32501 .40031 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.41813 .23425 m .38151 .23514 L .39381 .23718 L .289 .763 .934 r
F
.40057 .28968 m .40852 .28274 L p .41007 .23988 L .909 .742 .663 r
F P
0 g
s
.40738 .23944 m .40057 .28968 L .41007 .23988 L .909 .742 .663 r
F
.41107 .24005 m .41813 .23425 L p .40246 .23862 L .289 .763 .934 r
F P
0 g
s
.41147 .20113 m .41107 .20437 L .41107 .21216 L .909 .742 .663 r
F
.41813 .23425 m .39381 .23718 L .40246 .23862 L .289 .763 .934 r
F
.41813 .40456 m .41107 .40887 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.41107 .40887 m .40832 .41055 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.68443 .23425 m .66719 .22675 L .62927 .22434 L p .289 .763 .934 r
F P
0 g
s
.68443 .23425 m .66719 .22675 L .66719 .39897 L p 1 .816 .507 r
F P
0 g
s
.63377 .29926 m .64311 .29734 L .65668 .29421 L p .167 .701 .709 r
F P
0 g
s
.65668 .29421 m .64732 .29613 L .63377 .29926 L p .167 .701 .709 r
F P
0 g
s
.62927 .39718 m .66719 .39897 L .66719 .22675 L p .799 .653 .7 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37493 .41352 m .40832 .41055 L .41813 .40456 L p .224 .73 .894 r
F P
0 g
s
.3371 .41183 m .37493 .41352 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67882 .75036 m .66446 .74536 L .67945 .73601 L closepath p .754 .814 .9 r
F P
0 g
s
.70373 .79883 m .70499 .74247 L .70399 .79891 L .835 .44 .3 r
F
.70349 .79915 m .70499 .74247 L .70371 .79976 L F
.70499 .74247 m .71963 .7518 L .70399 .79891 L p F P
0 g
s
.71963 .7518 m .70499 .74247 L .72041 .73745 L closepath p .566 .654 .895 r
F P
0 g
s
.69445 .7735 m .70499 .74247 L p .70349 .79915 L .835 .44 .3 r
F P
0 g
s
.70405 .78482 m .70333 .79901 L .68466 .76195 L p 0 0 .434 r
F P
0 g
s
.66446 .74536 m .67882 .75036 L .70333 .79901 L p .758 .258 .031 r
F P
0 g
s
.70333 .79901 m .69847 .79735 L p .66446 .74536 L .758 .258 .031 r
F P
0 g
s
.68799 .79253 m .68714 .79083 L p .69847 .79735 L .758 .258 .031 r
F P
0 g
s
.68714 .79083 m .66446 .74536 L p .69847 .79735 L .758 .258 .031 r
F P
0 g
s
.70334 .79872 m .70333 .79901 L .69847 .79735 L p .754 .82 .904 r
F P
0 g
s
.6885 .79103 m .69445 .7735 L p .70281 .79857 L .835 .44 .3 r
F P
0 g
s
.70311 .79949 m .70033 .79788 L .70281 .79857 L .835 .44 .3 r
F
.70033 .79788 m .6885 .79103 L .70281 .79857 L F
.69847 .79735 m .6885 .79103 L p .70311 .79949 L F P
0 g
s
.72041 .73745 m .70499 .74247 L .69445 .7735 L p .243 0 .096 r
F P
0 g
s
.74033 .79253 m .7207 .80757 L p .71033 .78269 L .662 .743 .91 r
F P
0 g
s
.69709 .77661 m .72041 .73745 L .69445 .7735 L .243 0 .096 r
F
.71963 .7518 m .72041 .73745 L .70444 .78528 L p .862 .789 .293 r
F P
0 g
s
.70348 .79966 m .69445 .7735 L .70349 .79915 L .835 .44 .3 r
F
.70311 .79949 m .69445 .7735 L .70348 .79966 L F
.70334 .79872 m .69848 .79717 L .69895 .7877 L .754 .82 .904 r
F
.70405 .78482 m .70334 .79872 L p .69895 .7877 L F P
0 g
s
.69847 .79735 m .6885 .79103 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.6885 .79103 m .69895 .7877 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.6885 .79103 m .69895 .7877 L p .72041 .73745 L .243 0 .096 r
F P
0 g
s
.69942 .77832 m .69941 .77848 L .69324 .77005 L 0 0 .434 r
F
.70473 .78443 m .72041 .73745 L p .69895 .7877 L .243 0 .096 r
F P
0 g
s
.70406 .78453 m .69941 .77848 L .69942 .77832 L 0 0 .434 r
F
.70406 .78453 m .70405 .78482 L p .69941 .77848 L F P
0 g
s
.69312 .76972 m .69324 .77005 L .67882 .75036 L 0 0 .434 r
F
.70406 .78453 m .69324 .77005 L .69312 .76972 L F
.68466 .76195 m .67882 .75036 L p .70405 .78482 L F P
0 g
s
.69445 .7735 m .6885 .79103 L p .69709 .77661 L .243 0 .096 r
F P
0 g
s
.68532 .74757 m .70406 .78453 L p .69312 .76972 L 0 0 .434 r
F P
0 g
s
.69312 .76972 m .67882 .75036 L .68532 .74757 L 0 0 .434 r
F
.67882 .75036 m .67945 .73601 L .68532 .74757 L p F P
0 g
s
.67945 .73601 m .66446 .74536 L .68799 .79253 L p .389 .092 .335 r
F P
0 g
s
.69706 .82569 m .66781 .80142 L p .69895 .7877 L .662 .743 .91 r
F P
0 g
s
.69847 .79735 m .68874 .79404 L .68799 .79253 L p .758 .258 .031 r
F P
0 g
s
.68799 .79253 m .68874 .79404 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.68846 .79232 m .67945 .73601 L .68799 .79253 L .389 .092 .335 r
F
.70406 .78453 m .67945 .73601 L p .68846 .79232 L F P
0 g
s
.68874 .79404 m .69895 .7877 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.69895 .7877 m .70406 .78453 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.69895 .7877 m .70406 .78453 L .70405 .78482 L p .754 .82 .904 r
F P
0 g
s
.70444 .78528 m .70473 .78443 L p .69895 .7877 L .243 0 .096 r
F P
0 g
s
.70112 .78675 m .70039 .75882 L .70521 .77038 L .662 .743 .91 r
F
.69847 .79735 m .69848 .79717 L .70334 .79872 L .754 .82 .904 r
F
.69847 .79735 m .69895 .7877 L .70112 .78675 L .662 .743 .91 r
F
.69895 .7877 m .70039 .75882 L .70112 .78675 L F
.6571 .79253 m .70039 .75882 L p .69895 .7877 L F P
0 g
s
.66781 .80142 m .6571 .79253 L p .69895 .7877 L .662 .743 .91 r
F P
0 g
s
.69847 .79735 m .68874 .79404 L p .69848 .79717 L .754 .82 .904 r
F P
0 g
s
.69847 .79735 m .70112 .78675 L .70371 .79976 L .662 .743 .91 r
F
.69706 .82569 m .69847 .79735 L .70371 .79976 L F
.7207 .80757 m .7026 .82145 L p .70371 .79976 L F P
0 g
s
.7026 .82145 m .69706 .82569 L p .70371 .79976 L .662 .743 .91 r
F P
0 g
s
.70112 .78675 m .70444 .78528 L .70371 .79976 L .662 .743 .91 r
F
.70371 .79976 m .70346 .80051 L p .70349 .79915 L .835 .44 .3 r
F P
0 g
s
.70419 .78603 m .70346 .80051 L .70371 .79976 L p .862 .789 .293 r
F P
0 g
s
.70399 .79891 m .70371 .79976 L p .70373 .79883 L .835 .44 .3 r
F P
0 g
s
.70371 .79976 m .71963 .7518 L p .70443 .7855 L .862 .789 .293 r
F P
0 g
s
.70419 .78603 m .70371 .79976 L .70443 .7855 L .862 .789 .293 r
F
.70346 .80051 m .69847 .79735 L .70333 .80015 L .835 .44 .3 r
F
.70333 .80015 m .69973 .79793 L p .70311 .79949 L F P
0 g
s
.69847 .79735 m .69848 .79717 L .70347 .80023 L .56 .655 .899 r
F
.70346 .80051 m .70311 .79949 L .70348 .79966 L .835 .44 .3 r
F
.70419 .78603 m .70347 .80023 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.69895 .7877 m .70419 .78603 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.68874 .79404 m .69895 .7877 L p .69848 .79717 L .754 .82 .904 r
F P
0 g
s
.70112 .78675 m .70521 .77038 L .70444 .78528 L .662 .743 .91 r
F
.69895 .7877 m .70419 .78603 L .70444 .78528 L p .243 0 .096 r
F P
0 g
s
.70444 .78528 m .70419 .78603 L p .70443 .7855 L .862 .789 .293 r
F P
0 g
s
.70443 .7855 m .71963 .7518 L .70444 .78528 L .862 .789 .293 r
F
.70371 .79976 m .70521 .77038 L .7207 .80757 L .662 .743 .91 r
F
.70039 .75882 m .72238 .77738 L p .71033 .78269 L F P
0 g
s
.72238 .77738 m .74033 .79253 L p .71033 .78269 L .662 .743 .91 r
F P
0 g
s
.70347 .80023 m .70346 .80051 L .69847 .79735 L p .56 .655 .899 r
F P
0 g
s
.31625 .4064 m .3371 .41183 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.66859 .19082 m .67543 .20113 L .66183 .20472 L p .343 .537 .9 r
F P
0 g
s
.66183 .20472 m .65501 .19447 L .66859 .19082 L p .343 .537 .9 r
F P
0 g
s
.57946 .21968 m .57901 .23264 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58197 .20751 m .57946 .21968 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58643 .19667 m .58197 .20751 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.59263 .18765 m .58643 .19667 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.60028 .18085 m .59263 .18765 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.60903 .17655 m .60028 .18085 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.61849 .17492 m .60903 .17655 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.62824 .17603 m .61849 .17492 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.63785 .17979 m .62824 .17603 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.6469 .18603 m .63785 .17979 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .65501 .19447 L .6469 .18603 L p .917 .749 .658 r
F P
0 g
s
.40415 .19082 m .41147 .20113 L .39923 .20472 L p .315 .528 .902 r
F P
0 g
s
.39923 .20472 m .39193 .19447 L .40415 .19082 L p .315 .528 .902 r
F P
0 g
s
.31105 .21968 m .31057 .23264 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.31374 .20751 m .31105 .21968 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.31852 .19667 m .31374 .20751 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.32515 .18765 m .31852 .19667 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.33334 .18085 m .32515 .18765 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.34271 .17655 m .33334 .18085 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.35284 .17492 m .34271 .17655 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.36328 .17603 m .35284 .17492 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37356 .17979 m .36328 .17603 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.38325 .18603 m .37356 .17979 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .39193 .19447 L .38325 .18603 L p .908 .741 .664 r
F P
0 g
s
.66047 .18233 m .66859 .19082 L .65501 .19447 L p .349 .611 .948 r
F P
0 g
s
.65501 .19447 m .6469 .18603 L .66047 .18233 L p .349 .611 .948 r
F P
0 g
s
.39545 .18233 m .40415 .19082 L .39193 .19447 L p .326 .605 .949 r
F P
0 g
s
.39193 .19447 m .38325 .18603 L .39545 .18233 L p .326 .605 .949 r
F P
0 g
s
.68574 .23829 m .68418 .22538 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.42252 .23829 m .42085 .22538 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.42207 .251 m .42252 .23829 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.68418 .22538 m .6807 .21282 L .67543 .20113 L p .918 .75 .657 r
F P
0 g
s
.42085 .22538 m .41712 .21282 L .41147 .20113 L p .909 .742 .663 r
F P
0 g
s
.6514 .17605 m .66047 .18233 L .6469 .18603 L p .348 .683 .979 r
F P
0 g
s
.6469 .18603 m .63785 .17979 L .6514 .17605 L p .348 .683 .979 r
F P
0 g
s
.38574 .17605 m .39545 .18233 L .38325 .18603 L p .331 .679 .978 r
F P
0 g
s
.38325 .18603 m .37356 .17979 L .38574 .17605 L p .331 .679 .978 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.39789 .39897 m .41813 .40456 L .41813 .23425 L p .996 .813 .545 r
F P
0 g
s
.66719 .22675 m .62927 .22434 L .62927 .39718 L p .799 .653 .7 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32501 .40031 m .31625 .4064 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.359 .39718 m .32501 .40031 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.41813 .40456 m .39789 .39897 L .359 .39718 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3692 .29926 m .37919 .29734 L .39139 .29421 L p .193 .721 .734 r
F P
0 g
s
.59292 .2161 m .59247 .22912 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.59544 .20386 m .59292 .2161 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.5999 .19297 m .59544 .20386 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.60611 .18391 m .5999 .19297 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.61378 .17708 m .60611 .18391 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.63785 .17979 m .62824 .17603 L .64178 .17226 L p .334 .744 .98 r
F P
0 g
s
.63202 .17114 m .64178 .17226 L .62824 .17603 L p .297 .777 .921 r
F P
0 g
s
.62824 .17603 m .61849 .17492 L .63202 .17114 L p .297 .777 .921 r
F P
0 g
s
.62254 .17276 m .63202 .17114 L .61849 .17492 L p .225 .745 .764 r
F P
0 g
s
.61849 .17492 m .60903 .17655 L .62254 .17276 L p .225 .745 .764 r
F P
0 g
s
.62254 .17276 m .61378 .17708 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64178 .17226 m .6514 .17605 L .63785 .17979 L p .334 .744 .98 r
F P
0 g
s
.63202 .17114 m .62254 .17276 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64178 .17226 m .63202 .17114 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.6514 .17605 m .64178 .17226 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.66047 .18233 m .6514 .17605 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .66859 .19082 L .66047 .18233 L p .918 .75 .657 r
F P
0 g
s
.3231 .2161 m .32262 .22912 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.32579 .20386 m .3231 .2161 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.33058 .19297 m .32579 .20386 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.33723 .18391 m .33058 .19297 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.34544 .17708 m .33723 .18391 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.36328 .17603 m .35284 .17492 L .36498 .17114 L p .302 .779 .923 r
F P
0 g
s
.35483 .17276 m .36498 .17114 L .35284 .17492 L p .251 .763 .787 r
F P
0 g
s
.35284 .17492 m .34271 .17655 L .35483 .17276 L p .251 .763 .787 r
F P
0 g
s
.35483 .17276 m .34544 .17708 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.37544 .17226 m .38574 .17605 L .37356 .17979 L p .325 .742 .977 r
F P
0 g
s
.37356 .17979 m .36328 .17603 L .37544 .17226 L p .325 .742 .977 r
F P
0 g
s
.36498 .17114 m .37544 .17226 L .36328 .17603 L p .302 .779 .923 r
F P
0 g
s
.36498 .17114 m .35483 .17276 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.37544 .17226 m .36498 .17114 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.38574 .17605 m .37544 .17226 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.39545 .18233 m .38574 .17605 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .40415 .19082 L .39545 .18233 L p .909 .742 .663 r
F P
0 g
s
.39139 .29421 m .38137 .29613 L .3692 .29926 L p .193 .721 .734 r
F P
0 g
s
.69706 .82569 m .74033 .79253 L .74865 .87438 L p .148 0 .23 r
F P
0 g
s
.70111 .87494 m .69706 .82569 L p .71679 .84432 L .148 0 .23 r
F P
0 g
s
.70331 .87416 m .70111 .87494 L .71679 .84432 L .148 0 .23 r
F
.70914 .87485 m .70111 .87494 L .73606 .8625 L F
.77017 .87438 m .77017 1.10042 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.70914 .87485 m .77017 .87438 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.77017 .87438 m .70914 .87485 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.75802 .87427 m .77017 .87438 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 1.10042 m .70139 1.09633 L .70139 .8784 L p .347 .283 .642 r
F P
0 g
s
.70139 .8784 m .70111 .87494 L p .70548 .87653 L .148 0 .23 r
F P
0 g
s
.70139 .8784 m .70139 .8749 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.77017 1.10042 m .70139 .8784 L .70233 .87797 L .347 .283 .642 r
F
.70556 .87489 m .70548 .87653 L p .70111 .87494 L .148 0 .23 r
F P
0 g
s
.70548 .87653 m .70383 .90798 L .70139 .8784 L p .148 0 .23 r
F P
0 g
s
.74865 .87438 m .70914 .87485 L .73606 .8625 L .148 0 .23 r
F
.70139 .8749 m .70914 .87485 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.73606 .8625 m .70331 .87416 L .71679 .84432 L .148 0 .23 r
F
.70739 .8402 m .74865 .87438 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.70739 .8402 m .74865 .87438 L .74033 .79253 L p .882 .449 .124 r
F P
0 g
s
.70996 .87384 m .75802 .87427 L p .74817 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74817 .87438 L .012 .587 .719 r
F
.70559 .87438 m .70996 .87384 L .74817 .87438 L F
.6571 .79253 m .69706 .82569 L .70111 .87494 L p .886 .458 .145 r
F P
0 g
s
.6996 .87492 m .6571 .79253 L .70111 .87494 L .886 .458 .145 r
F
.68929 .87208 m .6571 .79253 L .70139 .8784 L F
.69459 .87485 m .64101 .87438 L .65493 .87427 L p .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .69459 .87485 L p .70139 .8784 L .954 .779 .626 r
F P
0 g
s
.70139 .8784 m .70139 1.04154 L p .66439 .96031 L .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .66439 .96031 L .70139 1.04154 L .954 .779 .626 r
F
.55483 1.09633 m .55502 1.07831 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44517 1.09633 L .36524 1.09633 L p .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.63508 1.08393 m .6913 1.07831 L .70139 1.09633 L .678 .717 .878 r
F
.60506 1.07831 m .63522 1.07831 L .63508 1.08393 L F
.63522 1.07831 m .6913 1.07831 L .63508 1.08393 L F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L .678 .717 .878 r
F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L 0 0 .063 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.5554 1.043 m .63614 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.63614 1.043 m .70347 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.60506 1.07831 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63614 1.043 m .63772 1.04435 L .67151 1.043 L .066 0 0 r
F
.63772 1.04435 m .63806 1.04464 L .64101 1.04449 L F
.63772 1.04435 m .64101 1.04449 L .67151 1.043 L F
.70139 1.09633 m .64101 1.04449 L .64101 .98856 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04449 L p .954 .779 .626 r
F P
0 g
s
.66439 .96031 m .64101 .87438 L .70139 .8784 L .954 .779 .626 r
F
.70139 .8784 m .70383 .90798 L p .68929 .87208 L .886 .458 .145 r
F P
0 g
s
.64101 .87438 m .64101 1.04449 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.70383 .90798 m .66253 .87438 L .6571 .79253 L p .886 .458 .145 r
F P
0 g
s
.66276 .87421 m .70739 .8402 L p .70562 .87387 L .657 .749 .918 r
F P
0 g
s
.70559 .87438 m .66276 .87421 L .70562 .87387 L .657 .749 .918 r
F
.66253 .87438 m .66276 .87421 L p .70559 .87438 L F P
0 g
s
.70139 .8749 m .69459 .87485 L p .70996 .87384 L .012 .587 .719 r
F P
0 g
s
.70039 .75882 m .6571 .79253 L .66253 .87438 L p .13 0 .214 r
F P
0 g
s
.66253 .87438 m .70739 .8402 L .70039 .75882 L p .13 0 .214 r
F P
0 g
s
.65493 .87427 m .70996 .87384 L p .69459 .87485 L .012 .587 .719 r
F P
0 g
s
.70111 .87494 m .70139 .8784 L p .6996 .87492 L .886 .458 .145 r
F P
0 g
s
.69459 .87485 m .70139 .8749 L .70139 .8784 L p .954 .779 .626 r
F P
0 g
s
.70914 .87485 m .70139 .8749 L p .75802 .87427 L .012 .587 .719 r
F P
0 g
s
.70383 .90798 m .66253 .87438 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.74865 .87438 m .70383 .90798 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.70996 .87384 m .65493 .87427 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.65493 .87427 m .64101 .87438 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63806 1.04464 m .70775 1.04601 L .67151 1.043 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44344 1.15905 m .44461 1.09757 L .44459 1.11724 L F
.63538 1.08458 m .60923 1.09451 L .44497 1.07958 L .682 .404 .495 r
F
.44497 1.07874 m .44497 1.07958 L .43099 1.07831 L F
.63538 1.08458 m .44497 1.07958 L .44497 1.07874 L F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.44461 1.09757 m .44498 1.07831 L .44479 1.09692 L .732 .598 .026 r
F
.44461 1.09757 m .44479 1.09692 L .44459 1.11724 L F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.37905 1.28726 m .36515 1.31058 L .3511 1.29143 L p .968 .79 .61 r
F P
0 g
s
.53516 1.26808 m .54815 1.28726 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.39587 1.28899 m .53159 1.27227 L .53205 1.27361 L .691 .686 .84 r
F
.53732 1.28899 m .49763 1.28899 L p .53205 1.27361 L F P
0 g
s
.49763 1.28899 m .39587 1.28899 L p .53205 1.27361 L .691 .686 .84 r
F P
0 g
s
.54815 1.28726 m .53516 1.31058 L .53205 1.30604 L p .975 .796 .599 r
F P
0 g
s
.37209 1.3207 m .37224 1.31162 L p .37285 1.31157 L .694 .457 .559 r
F P
0 g
s
.51885 1.2995 m .51733 1.29875 L .53478 1.2972 L .694 .457 .559 r
F
.37209 1.3207 m .53478 1.2972 L .53372 1.30062 L F
.54815 1.28726 m .53205 1.30604 L .53732 1.28899 L .975 .796 .599 r
F
.56574 1.28899 m .6274 1.28899 L p .57513 1.29362 L .694 .457 .559 r
F P
0 g
s
.55907 1.28311 m .56574 1.28899 L .55611 1.28424 L .289 .557 .927 r
F
.62791 1.2604 m .62789 1.26135 L p .55843 1.28255 L .691 .686 .84 r
F P
0 g
s
.55825 1.28238 m .62791 1.2604 L .55843 1.28255 L .691 .686 .84 r
F
.54108 1.29995 m .54815 1.28726 L .56574 1.28899 L p .398 .064 .278 r
F P
0 g
s
.56574 1.28899 m .54815 1.28726 L p .55611 1.28424 L .289 .557 .927 r
F P
0 g
s
.54815 1.28726 m .53516 1.26808 L .54283 1.2688 L p .289 .557 .927 r
F P
0 g
s
.55907 1.28311 m .54815 1.28726 L .54283 1.2688 L .289 .557 .927 r
F
.56574 1.28899 m .53732 1.28899 L p .55843 1.28255 L .691 .686 .84 r
F P
0 g
s
.55843 1.28255 m .62789 1.26135 L .56574 1.28899 L .691 .686 .84 r
F
.53205 1.27361 m .53516 1.26808 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.53516 1.26808 m .53205 1.27361 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.53205 1.27361 m .62791 1.2604 L .53732 1.28899 L .691 .686 .84 r
F
.53159 1.27227 m .53638 1.27168 L .53205 1.27361 L F
.53638 1.27168 m .62791 1.2604 L .53205 1.27361 L F
.54283 1.2688 m .53516 1.26808 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.3932 1.28668 m .62791 1.2604 L .39587 1.28899 L .691 .686 .84 r
F
.39587 1.28899 m .37905 1.28726 L p .38907 1.28311 L .269 .551 .927 r
F P
0 g
s
.3511 1.29143 m .36515 1.26808 L .37905 1.28726 L p .968 .79 .61 r
F P
0 g
s
.37287 1.27873 m .36515 1.26808 L .37225 1.26878 L p .269 .551 .927 r
F P
0 g
s
.36515 1.31058 m .37148 1.29995 L p .37279 1.29936 L .386 .047 .262 r
F P
0 g
s
.39587 1.28899 m .37252 1.3054 L .37279 1.29936 L .386 .047 .262 r
F
.37252 1.3054 m .36515 1.31058 L .37279 1.29936 L F
.37148 1.29995 m .37905 1.28726 L .39587 1.28899 L p F P
0 g
s
.37693 1.30713 m .36515 1.31058 L .39587 1.28899 L .386 .047 .262 r
F
.3511 1.29143 m .36182 1.30604 L p .37203 1.30798 L .261 .548 .926 r
F P
0 g
s
.53516 1.31058 m .54108 1.29995 L p .56574 1.28899 L .398 .064 .278 r
F P
0 g
s
.54718 1.30713 m .53516 1.31058 L .56574 1.28899 L .398 .064 .278 r
F
.37224 1.31162 m .56574 1.28899 L .55958 1.295 L .694 .457 .559 r
F
.39587 1.28899 m .56574 1.28899 L p .37224 1.31162 L F P
0 g
s
.38683 1.31857 m .37285 1.31157 L .51733 1.29875 L .694 .457 .559 r
F
.38683 1.31857 m .51733 1.29875 L .51885 1.2995 L F
.6274 1.28899 m .62791 1.3207 L .53331 1.3207 L p F P
0 g
s
.54283 1.31139 m .53516 1.31058 L p .54718 1.30713 L .398 .064 .278 r
F P
0 g
s
.53205 1.30604 m .53516 1.31058 L .54283 1.31139 L p .281 .554 .927 r
F P
0 g
s
.53331 1.3207 m .37209 1.3207 L p .52364 1.30188 L .694 .457 .559 r
F P
0 g
s
.52364 1.30188 m .55676 1.29776 L .54283 1.31139 L .694 .457 .559 r
F
.52364 1.30188 m .54283 1.31139 L .53331 1.3207 L F
.55676 1.29776 m .6274 1.28899 L .53331 1.3207 L F
.53372 1.30062 m .53478 1.2972 L .6274 1.28899 L F
.599 1.29226 m .58611 1.31592 L .54283 1.31139 L p .398 .064 .278 r
F P
0 g
s
.599 1.29226 m .54283 1.31139 L .54718 1.30713 L .398 .064 .278 r
F
.4277 1.29226 m .41389 1.31592 L .37225 1.31136 L p .386 .047 .262 r
F P
0 g
s
.37225 1.31136 m .36515 1.31058 L p .37238 1.30847 L .386 .047 .262 r
F P
0 g
s
.4277 1.29226 m .37225 1.31136 L .37238 1.30847 L .386 .047 .262 r
F
.36182 1.30604 m .36515 1.31058 L .37225 1.31136 L p .261 .548 .926 r
F P
0 g
s
.37225 1.31136 m .37248 1.31139 L p .37224 1.31126 L .261 .548 .926 r
F P
0 g
s
.37224 1.31126 m .36182 1.30604 L .37225 1.31136 L .261 .548 .926 r
F
.37224 1.31162 m .37224 1.31126 L p .37211 1.3145 L .763 .623 .059 r
F P
0 g
s
.37224 1.31126 m .3726 1.28899 L p .37219 1.31039 L .763 .623 .059 r
F P
0 g
s
.37225 1.26878 m .36515 1.26808 L p .36832 1.27068 L .381 .04 .256 r
F P
0 g
s
.37202 1.27371 m .37224 1.26891 L .36832 1.27068 L .381 .04 .256 r
F
.37224 1.26891 m .37225 1.26878 L .36832 1.27068 L F
.37905 1.28726 m .37287 1.27873 L p .37248 1.2688 L .269 .551 .927 r
F P
0 g
s
.37225 1.26878 m .37248 1.2688 L p .37287 1.27873 L .269 .551 .927 r
F P
0 g
s
.38907 1.28311 m .37905 1.28726 L .37248 1.2688 L .269 .551 .927 r
F
.3726 1.28899 m .37224 1.26891 L p .38945 1.28344 L .691 .686 .84 r
F P
0 g
s
.37224 1.26891 m .37224 1.26859 L p .37248 1.2688 L .691 .686 .84 r
F P
0 g
s
.37224 1.26891 m .37248 1.2688 L .38945 1.28344 L .691 .686 .84 r
F
.37209 1.27225 m .37224 1.26859 L .37209 1.26622 L .763 .623 .059 r
F
.37209 1.30886 m .37223 1.26908 L .37209 1.27225 L F
.37223 1.26908 m .37224 1.26859 L .37209 1.27225 L F
.38945 1.28344 m .37691 1.2668 L .45947 1.2604 L .691 .686 .84 r
F
.37209 1.2604 m .39108 1.2604 L p .37691 1.2668 L F P
0 g
s
.39108 1.2604 m .45947 1.2604 L p .37691 1.2668 L .691 .686 .84 r
F P
0 g
s
.37224 1.26859 m .37209 1.2604 L p .38945 1.28344 L .691 .686 .84 r
F P
0 g
s
.41389 1.27286 m .38907 1.28311 L .37248 1.2688 L .269 .551 .927 r
F
.45947 1.2604 m .62791 1.2604 L p .40359 1.28552 L .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .45947 1.2604 L .40359 1.28552 L .691 .686 .84 r
F
.37224 1.31162 m .3726 1.28899 L .39587 1.28899 L p .694 .457 .559 r
F P
0 g
s
.39587 1.28899 m .4277 1.29226 L p .37693 1.30713 L .386 .047 .262 r
F P
0 g
s
.39587 1.28899 m .3726 1.28899 L p .3932 1.28668 L .691 .686 .84 r
F P
0 g
s
.41389 1.27286 m .4277 1.29226 L .39587 1.28899 L p .269 .551 .927 r
F P
0 g
s
.41389 1.27286 m .39587 1.28899 L .38907 1.28311 L .269 .551 .927 r
F
.39992 1.29654 m .41389 1.27286 L .37248 1.2688 L p .381 .04 .256 r
F P
0 g
s
.37248 1.2688 m .37225 1.26878 L p .37234 1.26887 L .381 .04 .256 r
F P
0 g
s
.39992 1.29654 m .37248 1.2688 L .37234 1.26887 L .381 .04 .256 r
F
.37211 1.30915 m .37224 1.26859 L .37209 1.30886 L .763 .623 .059 r
F
.37203 1.30798 m .36182 1.30604 L .37224 1.31126 L .261 .548 .926 r
F
.37211 1.3145 m .37224 1.26859 L .37209 1.31488 L .763 .623 .059 r
F
.3726 1.28899 m .37224 1.26891 L p .37212 1.30936 L F P
0 g
s
.37212 1.30936 m .37224 1.26891 L .37224 1.26907 L .763 .623 .059 r
F
.37202 1.27371 m .36515 1.26808 L .37112 1.29353 L .381 .04 .256 r
F
.37149 1.29938 m .3511 1.29143 L .37203 1.30798 L .261 .548 .926 r
F
.37209 1.2604 m .37083 1.25133 L p .37179 1.30413 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .37209 1.30886 L .37179 1.30413 L .763 .623 .059 r
F
.37209 1.30886 m .37209 1.2604 L .37179 1.30413 L F
.37219 1.31039 m .3726 1.28899 L .37212 1.30936 L F
.37112 1.29353 m .3511 1.29143 L p .37149 1.29938 L .261 .548 .926 r
F P
0 g
s
.36515 1.26808 m .3511 1.29143 L .37112 1.29353 L p .381 .04 .256 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.41389 1.31592 m .39992 1.29654 L .37112 1.29353 L p .261 .548 .926 r
F P
0 g
s
.41389 1.31592 m .37112 1.29353 L .37149 1.29938 L .261 .548 .926 r
F
.39992 1.29654 m .37225 1.26878 L .37202 1.27371 L .381 .04 .256 r
F
.37248 1.31139 m .41389 1.31592 L p .37203 1.30798 L .261 .548 .926 r
F P
0 g
s
.37203 1.30798 m .37224 1.31126 L .37248 1.31139 L .261 .548 .926 r
F
.37209 1.31488 m .37211 1.30915 L .37209 1.30886 L .763 .623 .059 r
F
.37224 1.31126 m .37219 1.31039 L .37211 1.3145 L F
.37209 1.3207 m .37211 1.3145 L .37209 1.31488 L F
.37224 1.26891 m .37224 1.26859 L p .37224 1.26907 L F P
0 g
s
.37112 1.29353 m .39992 1.29654 L p .37202 1.27371 L .381 .04 .256 r
F P
0 g
s
.41389 1.31592 m .37149 1.29938 L .37203 1.30798 L .261 .548 .926 r
F
.37211 1.3145 m .37219 1.31039 L .37212 1.30936 L .763 .623 .059 r
F
.37209 1.3207 m .37224 1.31162 L p .37211 1.3145 L F P
0 g
s
.37224 1.26859 m .37209 1.2604 L p .37209 1.26622 L .763 .623 .059 r
F P
0 g
s
.54283 1.2688 m .58611 1.27286 L p .55907 1.28311 L .289 .557 .927 r
F P
0 g
s
.58611 1.27286 m .56574 1.28899 L .55907 1.28311 L .289 .557 .927 r
F
.53732 1.28899 m .55825 1.28238 L .55843 1.28255 L .691 .686 .84 r
F
.62789 1.26135 m .6274 1.28899 L .56574 1.28899 L p F P
0 g
s
.55958 1.295 m .56574 1.28899 L .57513 1.29362 L .694 .457 .559 r
F
.56574 1.28899 m .599 1.29226 L p .54718 1.30713 L .398 .064 .278 r
F P
0 g
s
.58611 1.27286 m .599 1.29226 L .56574 1.28899 L p .289 .557 .927 r
F P
0 g
s
.57309 1.29654 m .58611 1.27286 L .54283 1.2688 L p .393 .057 .272 r
F P
0 g
s
.57309 1.29654 m .54283 1.2688 L .53862 1.27068 L .393 .057 .272 r
F
.53205 1.30604 m .52203 1.29143 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.52203 1.29143 m .53205 1.30604 L p .54699 1.30877 L .281 .554 .927 r
F P
0 g
s
.54148 1.29886 m .52203 1.29143 L .54699 1.30877 L .281 .554 .927 r
F
.52203 1.29143 m .53205 1.27361 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.52203 1.29143 m .57309 1.29654 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.53205 1.27361 m .52203 1.29143 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.54938 1.2604 m .51457 1.2604 L p .52382 1.25967 L .365 .792 .97 r
F P
0 g
s
.52382 1.25967 m .54487 1.25801 L .548 1.25967 L .365 .792 .97 r
F
.52382 1.25967 m .548 1.25967 L .54938 1.2604 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.44479 1.09692 m .50733 1.09692 L p .51462 1.09771 L F P
0 g
s
.50733 1.09692 m .55521 1.09692 L p .51462 1.09771 L .09 0 0 r
F P
0 g
s
.51462 1.09771 m .48479 1.09778 L .48814 1.09741 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .484 1.09787 L .51462 1.09771 L F
.484 1.09787 m .44453 1.09787 L .48479 1.09778 L F
.484 1.09787 m .48479 1.09778 L .51462 1.09771 L F
.48814 1.09741 m .44453 1.09787 L .44479 1.09692 L F
.48479 1.09778 m .44453 1.09787 L .48814 1.09741 L F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.48543 1.2604 m .37209 1.2604 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .47812 1.25666 L .484 1.25967 L .365 .792 .97 r
F
.39284 1.25967 m .484 1.25967 L .48543 1.2604 L F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.25967 L p .48918 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.37209 1.2604 m .37083 1.25133 L .46771 1.25133 L p .365 .792 .97 r
F P
0 g
s
.46771 1.25133 m .46771 1.09965 L p .47971 1.24056 L .997 .814 .539 r
F P
0 g
s
.47971 1.24056 m .48122 1.25825 L .46771 1.25133 L .997 .814 .539 r
F
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L F
.48028 1.24005 m .484 1.29086 L .47971 1.24056 L F
.48028 1.24005 m .47971 1.24056 L .46771 1.09965 L F
.45621 1.25744 m .46771 1.25133 L .47812 1.25666 L .365 .792 .97 r
F
.37209 1.2604 m .46771 1.25133 L .45621 1.25744 L F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48122 1.25825 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.26622 L p .063 .051 .53 r
F P
0 g
s
.47808 1.26098 m .46771 1.29439 L .48371 1.26622 L .063 .051 .53 r
F
.51457 1.2604 m .48543 1.2604 L p .49081 1.25967 L .365 .792 .97 r
F P
0 g
s
.484 1.06663 m .516 1.25967 L .51155 1.25967 L .707 .577 .707 r
F
.516 1.25967 m .516 1.09787 L p .52887 1.25309 L .08 .066 .539 r
F P
0 g
s
.49081 1.25967 m .516 1.25967 L .51457 1.2604 L .365 .792 .97 r
F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.47812 1.25666 m .52512 1.255 L .49081 1.25967 L .365 .792 .97 r
F
.484 1.25967 m .49081 1.25967 L .48543 1.2604 L F
.47812 1.25666 m .49081 1.25967 L .484 1.25967 L F
.49081 1.25967 m .52512 1.255 L .516 1.25967 L F
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L F
.53229 1.25133 m .62917 1.25133 L p .52512 1.255 L .365 .792 .97 r
F P
0 g
s
.62917 1.25133 m .62791 1.2604 L .54938 1.2604 L p .365 .792 .97 r
F P
0 g
s
.54487 1.25801 m .62917 1.25133 L .54938 1.2604 L .365 .792 .97 r
F
.52512 1.255 m .53833 1.25454 L .51457 1.2604 L F
.53833 1.25454 m .62917 1.25133 L .54487 1.25801 L F
.53833 1.25454 m .54487 1.25801 L .51457 1.2604 L F
.53229 1.09965 m .53229 1.25133 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47089 1.24964 L .063 .051 .53 r
F P
0 g
s
.51825 1.09811 m .529 1.24838 L .516 1.09787 L .08 .066 .539 r
F
.58611 1.31592 m .57309 1.29654 L .52203 1.29143 L p .281 .554 .927 r
F P
0 g
s
.529 1.24838 m .53229 1.29439 L .52844 1.24787 L .08 .066 .539 r
F
.529 1.24838 m .52844 1.24787 L .516 1.09787 L F
.46771 1.25133 m .53229 1.25133 L p .47812 1.25666 L .365 .792 .97 r
F P
0 g
s
.47812 1.25666 m .53229 1.25133 L .52512 1.255 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.516 1.25967 m .516 1.29086 L p .51155 1.25967 L .707 .577 .707 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52887 1.25309 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.53229 1.28236 m .53229 1.25133 L p .52091 1.26192 L .998 .815 .53 r
F P
0 g
s
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.54437 1.26218 m .54036 1.25857 L .52604 1.25715 L F
.52377 1.25926 m .52604 1.25715 L .46771 1.25133 L F
.54437 1.26218 m .52604 1.25715 L .52377 1.25926 L F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.52091 1.26192 m .51629 1.29798 L .53229 1.28236 L .998 .815 .53 r
F
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.47468 1.25782 m .48371 1.26622 L .50936 1.26622 L .513 .022 .027 r
F
.48824 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47468 1.25782 m .50936 1.26622 L .52213 1.26079 L .513 .022 .027 r
F
.50936 1.26622 m .51486 1.26755 L .51629 1.26622 L F
.50936 1.26622 m .51629 1.26622 L .52213 1.26079 L F
.54451 1.09826 m .47156 1.10009 L .52783 1.09787 L .09 0 0 r
F
.47156 1.10009 m .46974 1.09988 L .52783 1.09787 L F
.53926 1.09886 m .47257 1.1002 L .54451 1.09826 L F
.53229 1.25133 m .46771 1.25133 L p .54036 1.25857 L .513 .022 .027 r
F P
0 g
s
.46771 1.09965 m .46771 1.29439 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.47257 1.1002 m .44371 1.10079 L .47156 1.10009 L .09 0 0 r
F
.47257 1.1002 m .47156 1.10009 L .54451 1.09826 L F
.52783 1.09787 m .44371 1.10079 L .44453 1.09787 L F
.46771 1.06813 m .484 1.09787 L .47 1.0994 L .997 .814 .539 r
F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L F P
0 g
s
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L .707 .577 .707 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.53229 1.25133 m .53229 1.09965 L p .51999 1.24481 L F P
0 g
s
.53616 1.09921 m .50583 1.10147 L .48087 1.10115 L .09 0 0 r
F
.50583 1.10147 m .49246 1.10246 L .48371 1.10147 L F
.50583 1.10147 m .48371 1.10147 L .48087 1.10115 L F
.51629 1.26622 m .51629 1.10147 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.52581 1.10039 m .49246 1.10246 L .53616 1.09921 L .09 0 0 r
F
.52581 1.10039 m .51629 1.10147 L .50844 1.10147 L F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48918 1.09787 L .707 .577 .707 r
F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L .09 0 0 r
F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.55566 1.09853 m .44324 1.10246 L .45722 1.10051 L .09 0 0 r
F
.45722 1.10051 m .44324 1.10246 L .44371 1.10079 L F
.516 1.06663 m .53229 1.09965 L .51825 1.09811 L .08 .066 .539 r
F
.6395 1.10246 m .57144 1.08458 L .56398 1.08563 L .676 .72 .882 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.55566 1.09853 m .52581 1.10039 L .53616 1.09921 L .09 0 0 r
F
.55566 1.09853 m .55648 1.10147 L .51629 1.10147 L F
.55566 1.09853 m .51629 1.10147 L .52581 1.10039 L F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.55676 1.10246 m .49246 1.10246 L p .50844 1.10147 L .09 0 0 r
F P
0 g
s
.55648 1.10147 m .55676 1.10246 L .50844 1.10147 L .09 0 0 r
F
.48146 1.10121 m .47089 1.24964 L .48371 1.10147 L .063 .051 .53 r
F
.49246 1.10246 m .44324 1.10246 L p .48087 1.10115 L .09 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.47156 1.10009 m .44371 1.10079 L .46974 1.09988 L .09 0 0 r
F
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.44324 1.10246 m .55795 1.10246 L p .56398 1.08563 L .676 .72 .882 r
F P
0 g
s
.55795 1.10246 m .6395 1.10246 L p .56398 1.08563 L .676 .72 .882 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L .732 .598 .026 r
F
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .50936 1.26622 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .50936 1.26622 L .513 .022 .027 r
F
.51866 1.26402 m .51629 1.29798 L .52091 1.26192 L .998 .815 .53 r
F
.51629 1.24284 m .51629 1.29798 L p .51999 1.24481 L F P
0 g
s
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .52213 1.26079 L .513 .022 .027 r
F P
0 g
s
.51904 1.25855 m .51866 1.26402 L .52091 1.26192 L .998 .815 .53 r
F
.53229 1.25133 m .51904 1.25855 L .52091 1.26192 L F
.47089 1.24964 m .47058 1.25401 L .48371 1.24284 L .063 .051 .53 r
F
.47058 1.25401 m .46771 1.29439 L .47808 1.26098 L F
.47058 1.25401 m .47808 1.26098 L .48371 1.24284 L F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L .513 .022 .027 r
F
.54437 1.26218 m .63045 1.26755 L .54036 1.25857 L F
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p F P
0 g
s
.54036 1.25857 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.44964 1.26755 m .48514 1.26755 L p .4614 1.25699 L F P
0 g
s
.4614 1.25699 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.48371 1.26622 m .48371 1.24284 L p .47808 1.26098 L .063 .051 .53 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L .44964 1.26755 L p .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .44964 1.26755 L .4614 1.25699 L .513 .022 .027 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.51999 1.24481 m .51904 1.25855 L .53229 1.25133 L .998 .815 .53 r
F
.53229 1.28979 m .53229 1.28236 L p .52319 1.29124 L F P
0 g
s
.52319 1.29124 m .51629 1.29798 L .53229 1.28979 L .998 .815 .53 r
F
.51629 1.29798 m .53229 1.29439 L .53229 1.28979 L p F P
0 g
s
.58611 1.31592 m .54148 1.29886 L .54699 1.30877 L .281 .554 .927 r
F
.54283 1.31139 m .58611 1.31592 L p .53205 1.30604 L F P
0 g
s
.37209 1.3207 m .37285 1.31157 L .38683 1.31857 L .694 .457 .559 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.41813 .23425 m .39789 .22675 L .359 .22434 L p .289 .763 .934 r
F P
0 g
s
.41813 .23425 m .39789 .22675 L .39789 .39897 L p .996 .813 .545 r
F P
0 g
s
.61378 .17708 m .62254 .17276 L .60903 .17655 L p 0 0 0 r
F P
0 g
s
.60903 .17655 m .60028 .18085 L .61378 .17708 L p 0 0 0 r
F P
0 g
s
.34544 .17708 m .35483 .17276 L .34271 .17655 L p 0 0 0 r
F P
0 g
s
.34271 .17655 m .33334 .18085 L .34544 .17708 L p 0 0 0 r
F P
0 g
s
.60611 .18391 m .61378 .17708 L .60028 .18085 L p 0 0 0 r
F P
0 g
s
.60028 .18085 m .59263 .18765 L .60611 .18391 L p 0 0 0 r
F P
0 g
s
.33723 .18391 m .34544 .17708 L .33334 .18085 L p 0 0 0 r
F P
0 g
s
.33334 .18085 m .32515 .18765 L .33723 .18391 L p 0 0 0 r
F P
0 g
s
.5999 .19297 m .60611 .18391 L .59263 .18765 L p .087 0 .079 r
F P
0 g
s
.59263 .18765 m .58643 .19667 L .5999 .19297 L p .087 0 .079 r
F P
0 g
s
.33058 .19297 m .33723 .18391 L .32515 .18765 L p .021 0 .013 r
F P
0 g
s
.32515 .18765 m .31852 .19667 L .33058 .19297 L p .021 0 .013 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.359 .39718 m .39789 .39897 L .39789 .22675 L p .797 .651 .7 r
F P
0 g
s
.39789 .22675 m .359 .22434 L .359 .39718 L p .797 .651 .7 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59544 .20386 m .5999 .19297 L .58643 .19667 L p .157 0 .296 r
F P
0 g
s
.58643 .19667 m .58197 .20751 L .59544 .20386 L p .157 0 .296 r
F P
0 g
s
.32579 .20386 m .33058 .19297 L .31852 .19667 L p .096 0 .244 r
F P
0 g
s
.31852 .19667 m .31374 .20751 L .32579 .20386 L p .096 0 .244 r
F P
0 g
s
.58065 .2458 m .58429 .25856 L .59776 .25518 L p .294 .37 .771 r
F P
0 g
s
.31233 .2458 m .31623 .25856 L .32829 .25518 L p .254 .347 .766 r
F P
0 g
s
.59292 .2161 m .59544 .20386 L .58197 .20751 L p .208 .068 .46 r
F P
0 g
s
.58197 .20751 m .57946 .21968 L .59292 .2161 L p .208 .068 .46 r
F P
0 g
s
.3231 .2161 m .32579 .20386 L .31374 .20751 L p .152 .014 .425 r
F P
0 g
s
.31374 .20751 m .31105 .21968 L .3231 .2161 L p .152 .014 .425 r
F P
0 g
s
.59776 .25518 m .59411 .24235 L .58065 .2458 L p .294 .37 .771 r
F P
0 g
s
.57901 .23264 m .58065 .2458 L .59411 .24235 L p .273 .282 .687 r
F P
0 g
s
.32829 .25518 m .32437 .24235 L .31233 .2458 L p .254 .347 .766 r
F P
0 g
s
.31057 .23264 m .31233 .2458 L .32437 .24235 L p .228 .251 .676 r
F P
0 g
s
.59247 .22912 m .59292 .2161 L .57946 .21968 L p .245 .183 .586 r
F P
0 g
s
.57946 .21968 m .57901 .23264 L .59247 .22912 L p .245 .183 .586 r
F P
0 g
s
.32262 .22912 m .3231 .2161 L .31105 .21968 L p .195 .141 .565 r
F P
0 g
s
.31105 .21968 m .31057 .23264 L .32262 .22912 L p .195 .141 .565 r
F P
0 g
s
.74033 .79253 m .70039 .75882 L .70739 .8402 L p .882 .449 .124 r
F P
0 g
s
.59411 .24235 m .59247 .22912 L .57901 .23264 L p .273 .282 .687 r
F P
0 g
s
.32437 .24235 m .32262 .22912 L .31057 .23264 L p .228 .251 .676 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.36341 .3687 m .36341 .18607 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.39982 .36517 m .38947 .36617 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.38947 .36617 m .36341 .3687 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.38991 .14037 m .39929 .18443 L .40198 .18093 L .919 .751 .656 r
F
.40148 .19474 m .40184 .18489 L p .39929 .18443 L F P
0 g
s
.40184 .18489 m .40198 .18093 L p .39929 .18443 L .919 .751 .656 r
F P
0 g
s
.36341 .18607 m .38947 .18267 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.39868 .20771 m .40148 .19474 L .41483 .19077 L p .141 .002 .418 r
F P
0 g
s
.39868 .20771 m .40148 .19474 L p .39929 .18443 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .39556 .18376 L .39929 .18443 L .919 .751 .656 r
F
.39556 .18376 m .39868 .20771 L .39929 .18443 L F
.32203 .18336 m .36341 .18607 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.36341 .18607 m .38947 .18267 L p .38947 .22515 L .481 .393 .679 r
F P
0 g
s
.37356 .236 m .38947 .22515 L .38947 .31427 L .481 .393 .679 r
F
.36341 .18607 m .38947 .22515 L .37356 .236 L F
.38947 .22515 m .39368 .21931 L .39942 .21766 L p .018 0 .01 r
F P
0 g
s
.39942 .21766 m .40123 .21713 L p .39982 .2181 L .018 0 .01 r
F P
0 g
s
.38947 .22515 m .39942 .21766 L .39982 .2181 L .018 0 .01 r
F
.36795 .24126 m .37799 .23646 L p .38477 .18182 L .919 .751 .656 r
F P
0 g
s
.38947 .14388 m .38123 .18119 L .38477 .18182 L .919 .751 .656 r
F
.38123 .18119 m .36795 .24126 L .38477 .18182 L F
.38947 .14237 m .38103 .18115 L .38947 .14388 L F
.38103 .18115 m .36795 .24126 L .38123 .18119 L F
.38103 .18115 m .38123 .18119 L .38947 .14388 L F
.29905 .17465 m .32203 .18336 L p .36311 .17794 L .289 .763 .934 r
F P
0 g
s
.4135 .16276 m .41534 .17689 L .40198 .18093 L p .219 .244 .674 r
F P
0 g
s
.40198 .18093 m .40016 .16688 L .4135 .16276 L p .219 .244 .674 r
F P
0 g
s
.40942 .14896 m .4135 .16276 L .40016 .16688 L p .247 .343 .766 r
F P
0 g
s
.40016 .16688 m .39608 .15317 L .40942 .14896 L p .247 .343 .766 r
F P
0 g
s
.40323 .13608 m .40942 .14896 L .39608 .15317 L p .271 .434 .841 r
F P
0 g
s
.40323 .13608 m .4028 .14813 L .40473 .17897 L .921 .752 .656 r
F
.40323 .13608 m .40473 .17897 L .40528 .17907 L F
.39982 .36517 m .39982 .2181 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.40219 .22068 m .4028 .23082 L .39982 .2181 L 0 0 .313 r
F
.4028 .23082 m .41044 .358 L .4028 .25729 L F
.4028 .23082 m .4028 .25729 L .39982 .2181 L F
.40148 .19474 m .40198 .18093 L .41534 .17689 L p .184 .132 .56 r
F P
0 g
s
.41534 .17689 m .41483 .19077 L .40148 .19474 L p .184 .132 .56 r
F P
0 g
s
.41483 .19077 m .41202 .20382 L .39868 .20771 L p .141 .002 .418 r
F P
0 g
s
.39368 .21931 m .39868 .20771 L .41202 .20382 L p .086 0 .237 r
F P
0 g
s
.38947 .31427 m .39667 .22175 L .39982 .36517 L .481 .393 .679 r
F
.41202 .20382 m .41021 .20803 L p .39368 .21931 L .086 0 .237 r
F P
0 g
s
.40123 .21713 m .39368 .21931 L p .41021 .20803 L .086 0 .237 r
F P
0 g
s
.39368 .21931 m .39868 .20771 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.39982 .18132 m .39982 .21856 L p .39667 .22175 L .481 .393 .679 r
F P
0 g
s
.39982 .21856 m .39982 .36517 L p .39667 .22175 L .481 .393 .679 r
F P
0 g
s
.41021 .20803 m .40701 .21547 L .40123 .21713 L p .086 0 .237 r
F P
0 g
s
.40528 .17907 m .40473 .17897 L .40701 .21547 L .921 .752 .656 r
F
.40105 .21944 m .40064 .21899 L .40701 .21547 L .018 0 .01 r
F
.38669 .22903 m .39368 .21931 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.38947 .18267 m .39982 .18132 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.40123 .21713 m .40701 .21547 L p .38947 .22515 L .018 0 .01 r
F P
0 g
s
.41044 .2297 m .41044 .358 L p .40219 .22068 L 0 0 .313 r
F P
0 g
s
.40701 .21547 m .4 .22524 L .38669 .22903 L p .018 0 .01 r
F P
0 g
s
.4028 .22135 m .40701 .21547 L p .40473 .17897 L .921 .752 .656 r
F P
0 g
s
.4028 .14813 m .4028 .17862 L .40473 .17897 L .921 .752 .656 r
F
.4028 .17862 m .4028 .22135 L .40473 .17897 L F
.40198 .18093 m .40016 .16688 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.37799 .23646 m .38669 .22903 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36311 .17794 m .32203 .18336 L .38006 .18098 L .289 .763 .934 r
F
.32203 .18336 m .36341 .18607 L .36341 .3687 L p .802 .655 .7 r
F P
0 g
s
.35699 .2432 m .36795 .24126 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.39982 .18132 m .4028 .17862 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.39336 .17691 m .38006 .18098 L .4028 .17862 L .289 .763 .934 r
F
.41202 .20382 m .41483 .19077 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40701 .21547 m .41202 .20382 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.39982 .18132 m .41044 .17169 L .41044 .2297 L p 0 0 .313 r
F P
0 g
s
.39982 .18132 m .41044 .2297 L .40219 .22068 L 0 0 .313 r
F
.38669 .22903 m .40022 .21922 L .40019 .22002 L .018 0 .01 r
F
.38669 .22903 m .38947 .22515 L p .40022 .21922 L F P
0 g
s
.40093 .19972 m .40219 .22068 L .40024 .21856 L 0 0 .313 r
F
.40093 .19972 m .40024 .21856 L .39982 .2181 L F
.39982 .2181 m .39982 .18132 L p .40093 .19972 L F P
0 g
s
.34558 .24219 m .35699 .2432 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36341 .3687 m .32203 .36668 L .32203 .18336 L p .802 .655 .7 r
F P
0 g
s
.33421 .23823 m .34558 .24219 L p .3728 .17968 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .36803 .17882 L .3728 .17968 L .919 .751 .656 r
F
.36803 .17882 m .33421 .23823 L .3728 .17968 L F
.4028 .14813 m .39875 .17789 L .4017 .17842 L .921 .752 .656 r
F
.38947 .18267 m .39982 .18132 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.40016 .16688 m .39608 .15317 L .38991 .14037 L p .919 .751 .656 r
F P
0 g
s
.37799 .23646 m .38669 .22903 L .4 .22524 L p 0 0 0 r
F P
0 g
s
.4 .22524 m .39129 .2327 L .37799 .23646 L p 0 0 0 r
F P
0 g
s
.4028 .13962 m .39129 .2327 L .4028 .14813 L .921 .752 .656 r
F
.40019 .22002 m .40022 .21922 L .40064 .21899 L .018 0 .01 r
F
.40019 .22002 m .40064 .21899 L .40105 .21944 L F
.4 .22524 m .4028 .22135 L p .4028 .17862 L .921 .752 .656 r
F P
0 g
s
.4028 .14813 m .4017 .17842 L .4028 .17862 L .921 .752 .656 r
F
.4017 .17842 m .4 .22524 L .4028 .17862 L F
.30574 .16764 m .29905 .17465 L p .33889 .17359 L .289 .763 .934 r
F P
0 g
s
.33889 .17359 m .29905 .17465 L .36311 .17794 L .289 .763 .934 r
F
.32203 .36668 m .29905 .3602 L .29905 .17465 L p .997 .814 .54 r
F P
0 g
s
.29905 .17465 m .32203 .18336 L .32203 .36668 L p .997 .814 .54 r
F P
0 g
s
.38991 .14037 m .30574 .19348 L .30574 .21046 L .919 .751 .656 r
F
.29905 .17465 m .29905 .3602 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.38991 .14037 m .30574 .17871 L .30574 .19348 L .919 .751 .656 r
F
.30574 .16764 m .29905 .17465 L p .30478 .21406 L 0 0 .278 r
F P
0 g
s
.30574 .21146 m .30478 .21406 L .30574 .22063 L 0 0 .278 r
F
.30574 .16764 m .30478 .21406 L .30574 .21146 L F
.3136 .22221 m .32339 .23148 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30529 .21083 m .3136 .22221 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.3136 .22221 m .32674 .21832 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.30574 .21146 m .3136 .22221 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.29262 .16938 m .29454 .18381 L p .30574 .17871 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .30574 .16546 L .30574 .17871 L .919 .751 .656 r
F
.30574 .16546 m .29262 .16938 L .30574 .17871 L F
.32339 .23148 m .33421 .23823 L p .38991 .14037 L F P
0 g
s
.36795 .24126 m .37799 .23646 L .39129 .2327 L p 0 0 0 r
F P
0 g
s
.39129 .2327 m .38123 .23752 L .36795 .24126 L p 0 0 0 r
F P
0 g
s
.38123 .23752 m .39129 .2327 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3704 .17275 m .30574 .16764 L .33889 .17359 L .289 .763 .934 r
F
.40323 .13608 m .39038 .17637 L .39434 .17709 L .921 .752 .656 r
F
.39336 .17691 m .36311 .17794 L .38006 .18098 L .289 .763 .934 r
F
.38388 .1752 m .36311 .17794 L .39336 .17691 L F
.39608 .15317 m .38991 .14037 L .40323 .13608 L p .271 .434 .841 r
F P
0 g
s
.3588 .23843 m .37024 .23947 L p .39038 .17637 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .38608 .17559 L .39038 .17637 L .921 .752 .656 r
F
.38608 .17559 m .3588 .23843 L .39038 .17637 L F
.38388 .1752 m .33889 .17359 L .36311 .17794 L .289 .763 .934 r
F
.3704 .17275 m .33889 .17359 L .38388 .1752 L F
.34741 .23444 m .3588 .23843 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.33656 .22764 m .34741 .23444 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.35205 .16943 m .30574 .16764 L .3704 .17275 L .289 .763 .934 r
F
.32674 .21832 m .33656 .22764 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .31886 .20648 L .32674 .21832 L .921 .752 .656 r
F
.31886 .20749 m .32674 .21832 L p .31886 .20648 L F P
0 g
s
.30841 .16484 m .30827 .16774 L p .35205 .16943 L .289 .763 .934 r
F P
0 g
s
.30841 .16484 m .30574 .16764 L p .30574 .21146 L 0 0 .278 r
F P
0 g
s
.32674 .21832 m .31886 .20749 L p .30604 .21065 L .262 .509 .902 r
F P
0 g
s
.30589 .21105 m .32674 .21832 L .30604 .21065 L .262 .509 .902 r
F
.30841 .16484 m .30574 .21146 L .30605 .2106 L 0 0 .278 r
F
.30605 .2106 m .31763 .2071 L p .30834 .20222 L .242 .421 .839 r
F P
0 g
s
.30834 .20222 m .31763 .2071 L .31145 .20366 L .242 .421 .839 r
F
.31763 .2071 m .30605 .2106 L p .31886 .20749 L .262 .509 .902 r
F P
0 g
s
.30604 .21065 m .31886 .20749 L .30605 .2106 L .262 .509 .902 r
F
.30841 .35291 m .30841 .20417 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.31886 .16342 m .30841 .16484 L p .33746 .16679 L .289 .763 .934 r
F P
0 g
s
.33746 .16679 m .30841 .16484 L .35205 .16943 L .289 .763 .934 r
F
.31886 .16342 m .30841 .16484 L p .31145 .20365 L .472 .385 .677 r
F P
0 g
s
.3118 .20385 m .31145 .20365 L .31156 .20517 L .472 .385 .677 r
F
.31886 .16342 m .31145 .20365 L .3118 .20385 L F
.31886 .16342 m .31156 .20517 L .31886 .20749 L F
.30841 .16484 m .30841 .20197 L p .31145 .20365 L F P
0 g
s
.30841 .20197 m .31841 .20686 L .31053 .19422 L .242 .421 .839 r
F
.30834 .20222 m .31145 .20366 L .30841 .20197 L F
.31145 .20366 m .31841 .20686 L .30841 .20197 L F
.31841 .20686 m .31194 .19379 L .31053 .19422 L p F P
0 g
s
.30841 .20197 m .30841 .16484 L p .30626 .20986 L 0 0 .278 r
F P
0 g
s
.30841 .16484 m .30605 .2106 L .30626 .20986 L 0 0 .278 r
F
.30574 .19348 m .29883 .19784 L .30574 .21046 L .919 .751 .656 r
F
.31053 .19422 m .29883 .19784 L p .30834 .20222 L .242 .421 .839 r
F P
0 g
s
.30841 .20417 m .30841 .20197 L p .30625 .21008 L 0 0 .278 r
F P
0 g
s
.30626 .20986 m .30625 .21008 L .30841 .20197 L 0 0 .278 r
F
.30625 .21008 m .30574 .22063 L .30841 .20417 L F
.30605 .2106 m .30529 .21083 L p .30604 .21065 L .262 .509 .902 r
F P
0 g
s
.3136 .22221 m .32339 .23148 L .33656 .22764 L p .276 .591 .947 r
F P
0 g
s
.33656 .22764 m .32674 .21832 L .3136 .22221 L p .276 .591 .947 r
F P
0 g
s
.31886 .20749 m .31156 .20517 L .31886 .29856 L .472 .385 .677 r
F
.31763 .2071 m .31841 .20686 L p .31145 .20366 L .242 .421 .839 r
F P
0 g
s
.31156 .20517 m .31145 .20365 L .30841 .20417 L .472 .385 .677 r
F
.30841 .20197 m .30841 .20417 L p .31145 .20365 L F P
0 g
s
.30626 .20986 m .30605 .2106 L .30625 .21008 L 0 0 .278 r
F
.29883 .19784 m .30529 .21083 L p .30574 .21046 L .919 .751 .656 r
F P
0 g
s
.29883 .19784 m .30529 .21083 L .30605 .2106 L p .242 .421 .839 r
F P
0 g
s
.29883 .19784 m .30605 .2106 L .30834 .20222 L .242 .421 .839 r
F
.30625 .21008 m .30574 .21146 L .30574 .22063 L 0 0 .278 r
F
.30529 .21083 m .30589 .21105 L .30604 .21065 L .262 .509 .902 r
F
.31886 .20749 m .31841 .20686 L .31763 .2071 L p F P
0 g
s
.31886 .29856 m .31156 .20517 L .30841 .35291 L .472 .385 .677 r
F
.30841 .20417 m .30841 .35291 L p .31156 .20517 L F P
0 g
s
.40323 .13608 m .31886 .18941 L .31886 .20648 L .921 .752 .656 r
F
.38991 .14037 m .38947 .14237 L .38947 .14388 L .919 .751 .656 r
F
.30764 .17967 m .31194 .19379 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.39521 .12468 m .40323 .13608 L .38991 .14037 L p .29 .519 .902 r
F P
0 g
s
.38991 .14037 m .3819 .12904 L .39521 .12468 L p .29 .519 .902 r
F P
0 g
s
.29314 .1552 m .29262 .16938 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.2961 .14192 m .29314 .1552 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30135 .13014 m .2961 .14192 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30864 .12039 m .30135 .13014 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.31764 .11309 m .30864 .12039 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.32793 .10855 m .31764 .11309 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.33905 .10696 m .32793 .10855 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.3505 .10836 m .33905 .10696 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36177 .11267 m .3505 .10836 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.37239 .11967 m .36177 .11267 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .3819 .12904 L .37239 .11967 L p .919 .751 .656 r
F P
0 g
s
.3057 .16515 m .30764 .17967 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.34554 .1598 m .3444 .16573 L p .41044 .17169 L .289 .763 .934 r
F P
0 g
s
.41044 .17169 m .31886 .16342 L .33746 .16679 L .289 .763 .934 r
F
.41044 .17169 m .33746 .16679 L .35205 .16943 L F
.32339 .23148 m .33421 .23823 L .34741 .23444 L p .283 .665 .971 r
F P
0 g
s
.34741 .23444 m .33656 .22764 L .32339 .23148 L p .283 .665 .971 r
F P
0 g
s
.34554 .1598 m .31886 .16342 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.31194 .19379 m .31841 .20686 L p .31886 .20648 L .921 .752 .656 r
F P
0 g
s
.31886 .18941 m .31194 .19379 L .31886 .20648 L .921 .752 .656 r
F
.31841 .20686 m .31886 .20749 L p .31886 .20648 L F P
0 g
s
.33421 .23823 m .34558 .24219 L .3588 .23843 L p .279 .726 .96 r
F P
0 g
s
.3588 .23843 m .34741 .23444 L .33421 .23823 L p .279 .726 .96 r
F P
0 g
s
.34554 .34916 m .34554 .1598 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.30841 .35291 m .31886 .35185 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.31886 .35185 m .34554 .34916 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.41044 .17169 m .35205 .16943 L .3704 .17275 L .289 .763 .934 r
F
.37024 .23947 m .38123 .23752 L p .39434 .17709 L .921 .752 .656 r
F P
0 g
s
.39038 .17637 m .37024 .23947 L .39434 .17709 L .921 .752 .656 r
F
.30529 .21083 m .30574 .21146 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.29454 .18381 m .29883 .19784 L p .30574 .19348 L .919 .751 .656 r
F P
0 g
s
.30574 .17871 m .29454 .18381 L .30574 .19348 L .919 .751 .656 r
F
.29905 .3602 m .30574 .35499 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.30574 .35499 m .30841 .35291 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.41044 .17169 m .3704 .17275 L .38388 .1752 L .289 .763 .934 r
F
.39129 .2327 m .4 .22524 L p .4017 .17842 L .921 .752 .656 r
F P
0 g
s
.39875 .17789 m .39129 .2327 L .4017 .17842 L .921 .752 .656 r
F
.4028 .17862 m .41044 .17169 L p .39336 .17691 L .289 .763 .934 r
F P
0 g
s
.40323 .13608 m .4028 .13962 L .4028 .14813 L .921 .752 .656 r
F
.41044 .17169 m .38388 .1752 L .39336 .17691 L .289 .763 .934 r
F
.41044 .358 m .4028 .36316 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.4028 .36316 m .39982 .36517 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.36341 .3687 m .39982 .36517 L .41044 .358 L p .224 .73 .894 r
F P
0 g
s
.32203 .36668 m .36341 .3687 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.29905 .3602 m .32203 .36668 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.38818 .35131 m .41044 .358 L .41044 .17169 L p .999 .815 .525 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.30841 .35291 m .29905 .3602 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.34554 .34916 m .30841 .35291 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.41044 .17169 m .38818 .1627 L .34554 .1598 L p .289 .763 .934 r
F P
0 g
s
.41044 .17169 m .38818 .1627 L .38818 .35131 L p .999 .815 .525 r
F P
0 g
s
.35699 .2432 m .36795 .24126 L .38123 .23752 L p .214 .737 .754 r
F P
0 g
s
.38123 .23752 m .37024 .23947 L .35699 .2432 L p .214 .737 .754 r
F P
0 g
s
.34554 .34916 m .38818 .35131 L .38818 .1627 L p .805 .657 .699 r
F P
0 g
s
.34558 .24219 m .35699 .2432 L .37024 .23947 L p .258 .757 .896 r
F P
0 g
s
.37024 .23947 m .3588 .23843 L .34558 .24219 L p .258 .757 .896 r
F P
0 g
s
.38818 .1627 m .34554 .1598 L .34554 .34916 L p .805 .657 .699 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41044 .358 m .38818 .35131 L .34554 .34916 L p .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64898 .3687 m .60869 .36668 L .60869 .18336 L p .804 .657 .699 r
F P
0 g
s
.60869 .36668 m .58919 .3602 L .58919 .17465 L p 1 .816 .501 r
F P
0 g
s
.58919 .17465 m .60869 .18336 L .60869 .36668 L p 1 .816 .501 r
F P
0 g
s
.70128 .16276 m .70298 .17689 L .68802 .18093 L p .264 .276 .685 r
F P
0 g
s
.68802 .18093 m .68632 .16688 L .70128 .16276 L p .264 .276 .685 r
F P
0 g
s
.68802 .18093 m .68632 .16688 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.58919 .17465 m .60869 .18336 L p .65193 .17794 L .289 .763 .934 r
F P
0 g
s
.67681 .14037 m .68552 .18443 L .68802 .18093 L .929 .759 .649 r
F
.68495 .20771 m .68756 .19474 L p .68552 .18443 L F P
0 g
s
.67681 .14037 m .68205 .18376 L .68552 .18443 L .929 .759 .649 r
F
.68205 .18376 m .68495 .20771 L .68552 .18443 L F
.68031 .21931 m .68495 .20771 L p .68205 .18376 L F P
0 g
s
.67681 .14037 m .6787 .18311 L .68205 .18376 L .929 .759 .649 r
F
.6787 .18311 m .68031 .21931 L .68205 .18376 L F
.60869 .18336 m .64898 .18607 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.64898 .18607 m .67641 .18267 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.67681 .14037 m .67641 .15235 L .68031 .21931 L .929 .759 .649 r
F
.64898 .18607 m .67641 .18267 L p .67641 .22515 L .493 .402 .681 r
F P
0 g
s
.65966 .236 m .67641 .22515 L .67641 .31427 L .493 .402 .681 r
F
.64898 .18607 m .67641 .22515 L .65966 .236 L F
.67641 .22515 m .68031 .21931 L .68674 .21766 L p .084 0 .077 r
F P
0 g
s
.68674 .21766 m .68878 .21713 L p .68729 .2181 L .084 0 .077 r
F P
0 g
s
.67641 .22515 m .68674 .21766 L .68729 .2181 L .084 0 .077 r
F
.68729 .36517 m .68729 .2181 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.69052 .22068 m .69135 .23082 L .68729 .2181 L 0 0 .395 r
F
.69135 .23082 m .70176 .358 L .69135 .25729 L F
.69135 .23082 m .69135 .25729 L .68729 .2181 L F
.67382 .22903 m .67641 .22515 L p .67641 .15235 L .929 .759 .649 r
F P
0 g
s
.67641 .22515 m .68031 .21931 L p .67641 .15235 L .929 .759 .649 r
F P
0 g
s
.66575 .23646 m .67382 .22903 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.64898 .3687 m .64898 .18607 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.65643 .24126 m .66575 .23646 L p .67641 .14388 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .67641 .14237 L .67641 .14388 L .929 .759 .649 r
F
.67641 .14237 m .65643 .24126 L .67641 .14388 L F
.68729 .36517 m .67641 .36617 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.67641 .36617 m .64898 .3687 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.65193 .17794 m .60869 .18336 L .66767 .18098 L .289 .763 .934 r
F
.60869 .18336 m .64898 .18607 L .64898 .3687 L p .804 .657 .699 r
F P
0 g
s
.64626 .2432 m .65643 .24126 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.63567 .24219 m .64626 .2432 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.62511 .23823 m .63567 .24219 L p .66093 .17968 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .6565 .17882 L .66093 .17968 L .929 .759 .649 r
F
.6565 .17882 m .62511 .23823 L .66093 .17968 L F
.69749 .14896 m .70128 .16276 L .68632 .16688 L p .288 .366 .77 r
F P
0 g
s
.68632 .16688 m .68254 .15317 L .69749 .14896 L p .288 .366 .77 r
F P
0 g
s
.69175 .13608 m .69749 .14896 L .68254 .15317 L p .306 .45 .841 r
F P
0 g
s
.69175 .13608 m .69135 .14813 L .69314 .17897 L .931 .76 .648 r
F
.69175 .13608 m .69314 .17897 L .69365 .17907 L F
.69135 .21794 m .69135 .21748 L .69526 .21547 L .084 0 .077 r
F
.67641 .31427 m .68411 .22016 L .68729 .36517 L .493 .402 .681 r
F
.68756 .19474 m .68789 .18489 L p .68552 .18443 L .929 .759 .649 r
F P
0 g
s
.68789 .18489 m .68802 .18093 L p .68552 .18443 L .929 .759 .649 r
F P
0 g
s
.68495 .20771 m .68756 .19474 L .70251 .19077 L p .198 .058 .454 r
F P
0 g
s
.70251 .19077 m .6999 .20382 L .68495 .20771 L p .198 .058 .454 r
F P
0 g
s
.68495 .20771 m .6999 .20382 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68031 .21931 m .68327 .21191 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68327 .21191 m .68495 .20771 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68756 .19474 m .68802 .18093 L .70298 .17689 L p .236 .175 .582 r
F P
0 g
s
.70298 .17689 m .70251 .19077 L .68756 .19474 L p .236 .175 .582 r
F P
0 g
s
.6999 .20382 m .69822 .20803 L p .68031 .21931 L .15 0 .289 r
F P
0 g
s
.69822 .20803 m .69526 .21547 L .68878 .21713 L p .15 0 .289 r
F P
0 g
s
.68878 .21713 m .68031 .21931 L p .69822 .20803 L .15 0 .289 r
F P
0 g
s
.67641 .18267 m .68729 .18132 L p .68398 .22175 L .493 .402 .681 r
F P
0 g
s
.67641 .22905 m .68398 .22175 L .67641 .31427 L .493 .402 .681 r
F
.67641 .18267 m .68398 .22175 L .67641 .22905 L F
.69365 .17907 m .69314 .17897 L .69526 .21547 L .931 .76 .648 r
F
.68878 .21713 m .69526 .21547 L p .68841 .21899 L .084 0 .077 r
F P
0 g
s
.68729 .2181 m .68729 .36517 L p .68411 .22016 L .493 .402 .681 r
F P
0 g
s
.67641 .22515 m .68729 .2181 L .68841 .21899 L .084 0 .077 r
F
.68729 .2181 m .68878 .21713 L .68841 .21899 L F
.69052 .22068 m .70176 .2425 L .69082 .2244 L 0 0 .395 r
F
.68729 .18132 m .69135 .17862 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.69135 .14813 m .69135 .17862 L .69314 .17897 L .931 .76 .648 r
F
.6826 .17691 m .66767 .18098 L .69135 .17862 L .289 .763 .934 r
F
.67382 .22903 m .69135 .21748 L .69135 .21794 L .084 0 .077 r
F
.67382 .22903 m .67641 .22515 L p .69135 .21748 L F P
0 g
s
.69803 .2267 m .70176 .2425 L .69052 .22068 L 0 0 .395 r
F
.69526 .21547 m .68876 .22524 L .67382 .22903 L p .084 0 .077 r
F P
0 g
s
.68729 .18132 m .69135 .19846 L .69052 .22068 L 0 0 .395 r
F
.69135 .19846 m .69135 .22135 L .69052 .22068 L F
.69135 .22135 m .69526 .21547 L p .69314 .17897 L .931 .76 .648 r
F P
0 g
s
.69135 .17862 m .69135 .22135 L .69314 .17897 L .931 .76 .648 r
F
.70298 .17689 m .70128 .16276 L p .69175 .13608 L F P
0 g
s
.70251 .19077 m .70298 .17689 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.6999 .20382 m .70251 .19077 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69526 .21547 m .6999 .20382 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.68729 .18132 m .70176 .17169 L .70176 .2425 L p 0 0 .395 r
F P
0 g
s
.68938 .20676 m .69052 .22068 L .68895 .21942 L 0 0 .395 r
F
.68938 .20676 m .68895 .21942 L .68729 .2181 L F
.68729 .2181 m .68729 .18132 L p .68938 .20676 L F P
0 g
s
.68876 .22524 m .69135 .22135 L p .69135 .14813 L .931 .76 .648 r
F P
0 g
s
.68729 .18132 m .68729 .2181 L p .68411 .22016 L .493 .402 .681 r
F P
0 g
s
.67641 .18267 m .68729 .18132 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.66575 .23646 m .67382 .22903 L .68876 .22524 L p 0 0 0 r
F P
0 g
s
.68876 .22524 m .68067 .2327 L .66575 .23646 L p 0 0 0 r
F P
0 g
s
.68067 .2327 m .68876 .22524 L p .69033 .17842 L .931 .76 .648 r
F P
0 g
s
.69135 .14813 m .68759 .17789 L .69033 .17842 L .931 .76 .648 r
F
.68759 .17789 m .68067 .2327 L .69033 .17842 L F
.62945 .17359 m .58919 .17465 L .65193 .17794 L .289 .763 .934 r
F
.61507 .23148 m .62511 .23823 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60598 .22221 m .61507 .23148 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .59868 .21046 L .60598 .22221 L .929 .759 .649 r
F
.59868 .21146 m .60598 .22221 L p .59868 .21046 L F P
0 g
s
.69135 .13962 m .68067 .2327 L .69135 .14813 L .931 .76 .648 r
F
.59868 .16764 m .58919 .17465 L p .62945 .17359 L .289 .763 .934 r
F P
0 g
s
.58919 .17465 m .58919 .3602 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.59868 .16764 m .58919 .17465 L p .59733 .21406 L 0 0 .367 r
F P
0 g
s
.59868 .21146 m .59733 .21406 L .59868 .22063 L 0 0 .367 r
F
.59868 .16764 m .59733 .21406 L .59868 .21146 L F
.60598 .22221 m .6208 .21832 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.59868 .21146 m .60598 .22221 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.67681 .14037 m .59868 .19348 L .59868 .21046 L .929 .759 .649 r
F
.58829 .18381 m .59227 .19784 L p .67681 .14037 L F P
0 g
s
.5865 .16938 m .58829 .18381 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.68632 .16688 m .68254 .15317 L .67681 .14037 L p .929 .759 .649 r
F P
0 g
s
.65643 .24126 m .66575 .23646 L .68067 .2327 L p 0 0 0 r
F P
0 g
s
.68067 .2327 m .67134 .23752 L .65643 .24126 L p 0 0 0 r
F P
0 g
s
.67134 .23752 m .68067 .2327 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.66115 .23947 m .67134 .23752 L p .6835 .17709 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67983 .17637 L .6835 .17709 L .931 .76 .648 r
F
.6826 .17691 m .65193 .17794 L .66767 .18098 L .289 .763 .934 r
F
.6738 .1752 m .65193 .17794 L .6826 .17691 L F
.67983 .17637 m .66115 .23947 L .6835 .17709 L .931 .76 .648 r
F
.66129 .17275 m .59868 .16764 L .62945 .17359 L .289 .763 .934 r
F
.65054 .23843 m .66115 .23947 L p .67983 .17637 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67584 .17559 L .67983 .17637 L .931 .76 .648 r
F
.67584 .17559 m .65054 .23843 L .67983 .17637 L F
.60248 .16484 m .60228 .16778 L p .64428 .16943 L .289 .763 .934 r
F P
0 g
s
.6738 .1752 m .62945 .17359 L .65193 .17794 L .289 .763 .934 r
F
.66129 .17275 m .62945 .17359 L .6738 .1752 L F
.63997 .23444 m .65054 .23843 L p .67584 .17559 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67141 .17473 L .67584 .17559 L .931 .76 .648 r
F
.67141 .17473 m .63997 .23444 L .67584 .17559 L F
.68254 .15317 m .67681 .14037 L .69175 .13608 L p .306 .45 .841 r
F P
0 g
s
.62991 .22764 m .63997 .23444 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.64428 .16943 m .59868 .16764 L .66129 .17275 L .289 .763 .934 r
F
.6208 .21832 m .62991 .22764 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .61349 .20648 L .6208 .21832 L .931 .76 .648 r
F
.61349 .20749 m .6208 .21832 L p .61349 .20648 L F P
0 g
s
.60598 .22221 m .61507 .23148 L .62991 .22764 L p .303 .599 .949 r
F P
0 g
s
.62991 .22764 m .6208 .21832 L .60598 .22221 L p .303 .599 .949 r
F P
0 g
s
.60248 .16484 m .59868 .16764 L p .59868 .21146 L 0 0 .367 r
F P
0 g
s
.6208 .21832 m .61349 .20749 L p .5991 .21065 L .295 .521 .902 r
F P
0 g
s
.5989 .21105 m .6208 .21832 L .5991 .21065 L .295 .521 .902 r
F
.60248 .16484 m .59868 .21146 L .59913 .2106 L 0 0 .367 r
F
.59913 .2106 m .61219 .2071 L p .60238 .20222 L .282 .439 .841 r
F P
0 g
s
.60238 .20222 m .61219 .2071 L .60568 .20366 L .282 .439 .841 r
F
.61219 .2071 m .59913 .2106 L p .61349 .20749 L .295 .521 .902 r
F P
0 g
s
.5991 .21065 m .61349 .20749 L .59913 .2106 L .295 .521 .902 r
F
.60248 .35291 m .60248 .20417 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.61349 .16342 m .60248 .16484 L p .63075 .16679 L .289 .763 .934 r
F P
0 g
s
.63075 .16679 m .60248 .16484 L .64428 .16943 L .289 .763 .934 r
F
.61349 .16342 m .60248 .16484 L p .60567 .20365 L .484 .395 .68 r
F P
0 g
s
.60604 .20385 m .60567 .20365 L .6058 .20517 L .484 .395 .68 r
F
.61349 .16342 m .60567 .20365 L .60604 .20385 L F
.60248 .20197 m .60248 .16484 L p .59942 .20986 L 0 0 .367 r
F P
0 g
s
.60248 .16484 m .59913 .2106 L .59942 .20986 L 0 0 .367 r
F
.59868 .19348 m .59227 .19784 L .59868 .21046 L .929 .759 .649 r
F
.59227 .19784 m .60238 .20222 L .60248 .20197 L .282 .439 .841 r
F
.60248 .16484 m .60248 .20197 L p .60567 .20365 L .484 .395 .68 r
F P
0 g
s
.60548 .19422 m .59385 .19741 L p .60248 .20197 L .282 .439 .841 r
F P
0 g
s
.59385 .19741 m .59227 .19784 L p .60248 .20197 L .282 .439 .841 r
F P
0 g
s
.61349 .16342 m .60604 .20385 L .61349 .20749 L .484 .395 .68 r
F
.60604 .20385 m .6058 .20517 L .61219 .2071 L F
.60604 .20385 m .61219 .2071 L .61349 .20749 L F
.60248 .20197 m .61307 .20686 L .60548 .19422 L .282 .439 .841 r
F
.60238 .20222 m .60568 .20366 L .60248 .20197 L F
.60568 .20366 m .61307 .20686 L .60248 .20197 L F
.61307 .20686 m .60707 .19379 L .60548 .19422 L p F P
0 g
s
.60248 .20417 m .60248 .20197 L p .5994 .21008 L 0 0 .367 r
F P
0 g
s
.59942 .20986 m .5994 .21008 L .60248 .20197 L 0 0 .367 r
F
.5994 .21008 m .59868 .22063 L .60248 .20417 L F
.59913 .2106 m .59826 .21083 L p .5991 .21065 L .295 .521 .902 r
F P
0 g
s
.61349 .20749 m .6058 .20517 L .61349 .29856 L .484 .395 .68 r
F
.61219 .2071 m .61307 .20686 L p .60568 .20366 L .282 .439 .841 r
F P
0 g
s
.6058 .20517 m .60567 .20365 L .60248 .20417 L .484 .395 .68 r
F
.60248 .20197 m .60248 .20417 L p .60567 .20365 L F P
0 g
s
.59942 .20986 m .59913 .2106 L .5994 .21008 L 0 0 .367 r
F
.59227 .19784 m .59826 .21083 L p .59868 .21046 L .929 .759 .649 r
F P
0 g
s
.59227 .19784 m .59826 .21083 L .59913 .2106 L p .282 .439 .841 r
F P
0 g
s
.59227 .19784 m .59913 .2106 L .60238 .20222 L .282 .439 .841 r
F
.5994 .21008 m .59868 .21146 L .59868 .22063 L 0 0 .367 r
F
.59826 .21083 m .59868 .21146 L p .59868 .21046 L .929 .759 .649 r
F P
0 g
s
.59826 .21083 m .5989 .21105 L .5991 .21065 L .295 .521 .902 r
F
.61349 .20749 m .61307 .20686 L .61219 .2071 L p F P
0 g
s
.61349 .29856 m .6058 .20517 L .60248 .35291 L .484 .395 .68 r
F
.60248 .20417 m .60248 .35291 L p .6058 .20517 L F P
0 g
s
.69175 .13608 m .61349 .18941 L .61349 .20648 L .931 .76 .648 r
F
.60308 .17967 m .60707 .19379 L p .69175 .13608 L F P
0 g
s
.60129 .16515 m .60308 .17967 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.64161 .1598 m .64037 .16594 L p .70176 .17169 L .289 .763 .934 r
F P
0 g
s
.70176 .17169 m .61349 .16342 L .63075 .16679 L .289 .763 .934 r
F
.70176 .17169 m .63075 .16679 L .64428 .16943 L F
.62511 .23823 m .63567 .24219 L .65054 .23843 L p .289 .729 .965 r
F P
0 g
s
.65054 .23843 m .63997 .23444 L .62511 .23823 L p .289 .729 .965 r
F P
0 g
s
.61507 .23148 m .62511 .23823 L .63997 .23444 L p .303 .671 .974 r
F P
0 g
s
.63997 .23444 m .62991 .22764 L .61507 .23148 L p .303 .671 .974 r
F P
0 g
s
.64161 .1598 m .61349 .16342 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.60707 .19379 m .61307 .20686 L p .61349 .20648 L .931 .76 .648 r
F P
0 g
s
.61349 .18941 m .60707 .19379 L .61349 .20648 L .931 .76 .648 r
F
.61307 .20686 m .61349 .20749 L p .61349 .20648 L F P
0 g
s
.63567 .24219 m .64626 .2432 L .66115 .23947 L p .253 .754 .893 r
F P
0 g
s
.66115 .23947 m .65054 .23843 L .63567 .24219 L p .253 .754 .893 r
F P
0 g
s
.64161 .34916 m .64161 .1598 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.60248 .35291 m .61349 .35185 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.61349 .35185 m .64161 .34916 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.70176 .17169 m .64428 .16943 L .66129 .17275 L .289 .763 .934 r
F
.59826 .21083 m .59868 .21146 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.58919 .3602 m .59868 .35499 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.59868 .35499 m .60248 .35291 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.70176 .17169 m .66129 .17275 L .6738 .1752 L .289 .763 .934 r
F
.69135 .17862 m .70176 .17169 L p .6826 .17691 L F P
0 g
s
.69135 .19846 m .69803 .2267 L .69135 .22135 L 0 0 .395 r
F
.70176 .2425 m .70176 .358 L p .69082 .2244 L F P
0 g
s
.70176 .17169 m .6738 .1752 L .6826 .17691 L .289 .763 .934 r
F
.69175 .13608 m .69135 .13962 L .69135 .14813 L .931 .76 .648 r
F
.70176 .358 m .69135 .36316 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.69135 .36316 m .68729 .36517 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.60869 .36668 m .64898 .3687 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.58919 .3602 m .60869 .36668 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64898 .3687 m .68729 .36517 L .70176 .358 L p .224 .73 .894 r
F P
0 g
s
.60248 .35291 m .58919 .3602 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64161 .34916 m .60248 .35291 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64626 .2432 m .65643 .24126 L .67134 .23752 L p .188 .717 .729 r
F P
0 g
s
.67134 .23752 m .66115 .23947 L .64626 .2432 L p .188 .717 .729 r
F P
0 g
s
.70176 .17169 m .6831 .1627 L .64161 .1598 L p .289 .763 .934 r
F P
0 g
s
.64161 .34916 m .6831 .35131 L .6831 .1627 L p .807 .659 .699 r
F P
0 g
s
.6831 .1627 m .64161 .1598 L .64161 .34916 L p .807 .659 .699 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70176 .358 m .6831 .35131 L .64161 .34916 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6831 .35131 m .70176 .358 L .70176 .17169 L p .999 .816 .481 r
F P
0 g
s
.70176 .17169 m .6831 .1627 L .6831 .35131 L p .999 .816 .481 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.39992 1.29654 m .41389 1.27286 L .4277 1.29226 L p .971 .793 .605 r
F P
0 g
s
.4277 1.29226 m .41389 1.31592 L .39992 1.29654 L p .971 .793 .605 r
F P
0 g
s
.57309 1.29654 m .58611 1.27286 L .599 1.29226 L p .978 .799 .593 r
F P
0 g
s
.599 1.29226 m .58611 1.31592 L .57309 1.29654 L p .978 .799 .593 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.68431 .12468 m .69175 .13608 L .67681 .14037 L p .321 .53 .901 r
F P
0 g
s
.67681 .14037 m .66938 .12904 L .68431 .12468 L p .321 .53 .901 r
F P
0 g
s
.58699 .1552 m .5865 .16938 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.58974 .14192 m .58699 .1552 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.59461 .13014 m .58974 .14192 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60138 .12039 m .59461 .13014 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60973 .11309 m .60138 .12039 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.61928 .10855 m .60973 .11309 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.6296 .10696 m .61928 .10855 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.64023 .10836 m .6296 .10696 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.65069 .11267 m .64023 .10836 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.66055 .11967 m .65069 .11267 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .66938 .12904 L .66055 .11967 L p .929 .759 .649 r
F P
0 g
s
.67547 .11525 m .68431 .12468 L .66938 .12904 L p .331 .607 .949 r
F P
0 g
s
.66938 .12904 m .66055 .11967 L .67547 .11525 L p .331 .607 .949 r
F P
0 g
s
.38568 .11525 m .39521 .12468 L .3819 .12904 L p .306 .6 .949 r
F P
0 g
s
.3819 .12904 m .37239 .11967 L .38568 .11525 L p .306 .6 .949 r
F P
0 g
s
.41534 .17689 m .4135 .16276 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.41483 .19077 m .41534 .17689 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.4135 .16276 m .40942 .14896 L .40323 .13608 L p .921 .752 .656 r
F P
0 g
s
.70128 .16276 m .69749 .14896 L .69175 .13608 L p .931 .76 .648 r
F P
0 g
s
.37503 .10819 m .38568 .11525 L .37239 .11967 L p .316 .675 .976 r
F P
0 g
s
.37239 .11967 m .36177 .11267 L .37503 .10819 L p .316 .675 .976 r
F P
0 g
s
.66559 .10819 m .67547 .11525 L .66055 .11967 L p .335 .68 .978 r
F P
0 g
s
.66055 .11967 m .65069 .11267 L .66559 .10819 L p .335 .68 .978 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.30623 .15089 m .3057 .16515 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3092 .13754 m .30623 .15089 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.31446 .1257 m .3092 .13754 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.32177 .1159 m .31446 .1257 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.33079 .10857 m .32177 .1159 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3505 .10836 m .33905 .10696 L .35225 .10243 L p .305 .781 .926 r
F P
0 g
s
.34111 .10402 m .35225 .10243 L .33905 .10696 L p .27 .776 .804 r
F P
0 g
s
.33905 .10696 m .32793 .10855 L .34111 .10402 L p .27 .776 .804 r
F P
0 g
s
.34111 .10402 m .33079 .10857 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.36373 .10385 m .37503 .10819 L .36177 .11267 L p .318 .739 .975 r
F P
0 g
s
.36177 .11267 m .3505 .10836 L .36373 .10385 L p .318 .739 .975 r
F P
0 g
s
.35225 .10243 m .36373 .10385 L .3505 .10836 L p .305 .781 .926 r
F P
0 g
s
.35225 .10243 m .34111 .10402 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.36373 .10385 m .35225 .10243 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.37503 .10819 m .36373 .10385 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.38568 .11525 m .37503 .10819 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .39521 .12468 L .38568 .11525 L p .921 .752 .656 r
F P
0 g
s
.60178 .15089 m .60129 .16515 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.60453 .13754 m .60178 .15089 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.60941 .1257 m .60453 .13754 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.61619 .1159 m .60941 .1257 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.62456 .10857 m .61619 .1159 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65069 .11267 m .64023 .10836 L .65511 .10385 L p .327 .742 .978 r
F P
0 g
s
.64446 .10243 m .65511 .10385 L .64023 .10836 L p .301 .779 .923 r
F P
0 g
s
.64023 .10836 m .6296 .10696 L .64446 .10243 L p .301 .779 .923 r
F P
0 g
s
.63413 .10402 m .64446 .10243 L .6296 .10696 L p .245 .759 .782 r
F P
0 g
s
.6296 .10696 m .61928 .10855 L .63413 .10402 L p .245 .759 .782 r
F P
0 g
s
.63413 .10402 m .62456 .10857 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65511 .10385 m .66559 .10819 L .65069 .11267 L p .327 .742 .978 r
F P
0 g
s
.64446 .10243 m .63413 .10402 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65511 .10385 m .64446 .10243 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.66559 .10819 m .65511 .10385 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.67547 .11525 m .66559 .10819 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .68431 .12468 L .67547 .11525 L p .931 .76 .648 r
F P
0 g
s
.62456 .10857 m .63413 .10402 L .61928 .10855 L p 0 0 0 r
F P
0 g
s
.61928 .10855 m .60973 .11309 L .62456 .10857 L p 0 0 0 r
F P
0 g
s
.33079 .10857 m .34111 .10402 L .32793 .10855 L p 0 0 0 r
F P
0 g
s
.32793 .10855 m .31764 .11309 L .33079 .10857 L p 0 0 0 r
F P
0 g
s
.32177 .1159 m .33079 .10857 L .31764 .11309 L p 0 0 0 r
F P
0 g
s
.31764 .11309 m .30864 .12039 L .32177 .1159 L p 0 0 0 r
F P
0 g
s
.61619 .1159 m .62456 .10857 L .60973 .11309 L p 0 0 0 r
F P
0 g
s
.60973 .11309 m .60138 .12039 L .61619 .1159 L p 0 0 0 r
F P
0 g
s
.31446 .1257 m .32177 .1159 L .30864 .12039 L p 0 0 0 r
F P
0 g
s
.30864 .12039 m .30135 .13014 L .31446 .1257 L p 0 0 0 r
F P
0 g
s
.60941 .1257 m .61619 .1159 L .60138 .12039 L p .035 0 .027 r
F P
0 g
s
.60138 .12039 m .59461 .13014 L .60941 .1257 L p .035 0 .027 r
F P
0 g
s
.3092 .13754 m .31446 .1257 L .30135 .13014 L p .039 0 .197 r
F P
0 g
s
.30135 .13014 m .2961 .14192 L .3092 .13754 L p .039 0 .197 r
F P
0 g
s
.60453 .13754 m .60941 .1257 L .59461 .13014 L p .109 0 .256 r
F P
0 g
s
.59461 .13014 m .58974 .14192 L .60453 .13754 L p .109 0 .256 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.58829 .18381 m .59227 .19784 L .60707 .19379 L p .263 .352 .768 r
F P
0 g
s
.29454 .18381 m .29883 .19784 L .31194 .19379 L p .218 .326 .761 r
F P
0 g
s
.30623 .15089 m .3092 .13754 L .2961 .14192 L p .101 0 .392 r
F P
0 g
s
.2961 .14192 m .29314 .1552 L .30623 .15089 L p .101 0 .392 r
F P
0 g
s
.60178 .15089 m .60453 .13754 L .58974 .14192 L p .164 .025 .433 r
F P
0 g
s
.58974 .14192 m .58699 .1552 L .60178 .15089 L p .164 .025 .433 r
F P
0 g
s
.60707 .19379 m .60308 .17967 L .58829 .18381 L p .263 .352 .768 r
F P
0 g
s
.5865 .16938 m .58829 .18381 L .60308 .17967 L p .238 .257 .679 r
F P
0 g
s
.31194 .19379 m .30764 .17967 L .29454 .18381 L p .218 .326 .761 r
F P
0 g
s
.29262 .16938 m .29454 .18381 L .30764 .17967 L p .187 .221 .665 r
F P
0 g
s
.3057 .16515 m .30623 .15089 L .29314 .1552 L p .149 .102 .545 r
F P
0 g
s
.29314 .1552 m .29262 .16938 L .3057 .16515 L p .149 .102 .545 r
F P
0 g
s
.60129 .16515 m .60178 .15089 L .58699 .1552 L p .206 .15 .57 r
F P
0 g
s
.58699 .1552 m .5865 .16938 L .60129 .16515 L p .206 .15 .57 r
F P
0 g
s
.30764 .17967 m .3057 .16515 L .29262 .16938 L p .187 .221 .665 r
F P
0 g
s
.60308 .17967 m .60129 .16515 L .5865 .16938 L p .238 .257 .679 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool700000;@0oooo1`00003P0?oo
o`00f@3oool5000000L0jl2W1@00002Z0?ooo`D000001`3^`ZD500000=/0oooo003F0?ooo`<00000
4@3[`:L400000:<0oooo1000000@0>k2Y@<00000f03oool00=<0oooo1000000G0>_0Y`800000WP3o
ool5000001D0k/:U0P00003F0?ooo`00d@3oool4000001/0jl2W0P00002J0?ooo`D000006@3^`ZD2
00000=@0oooo003?0?ooo`@000007`3[`:L00`000000oooo0?ooo`2E0?ooo`D000007@3^`ZD00`00
0000oooo0?ooo`3A0?ooo`00c@3oool400000280jl2W00<000000?ooo`3oool0TP3oool6000001l0
k/:U00<000000?ooo`3oool0d03oool00</0oooo1@00000T0>_0Y`800000T03oool600000280k/:U
0P00003@0?ooo`00b@3oool5000002P0jl2W00<000000?ooo`3oool0R`3oool7000002D0k/:U00<0
00000?ooo`3oool0c@3oool00<P0oooo1@00000Z0>_0Y`030000003oool0oooo08T0oooo1`00000W
0>k2Y@030000003oool0oooo0<`0oooo00360?ooo`L00000:`3[`:L00`000000oooo0?ooo`260?oo
o`D000000`0800H00`000000k/:U0>k2Y@0V0>k2Y@030000003oool0oooo0</0oooo00350?ooo`L0
0000;@3[`:L00`000000oooo0?ooo`240?ooo`8000001P0800H00`000000k/:U0>k2Y@0W0>k2Y@03
0000003oool0oooo0</0oooo00340?ooo`P00000;P3[`:L00`000000oooo0?ooo`220?ooo`030000
000800H0200600D0200600<000000>k2Y@3^`ZD0:@3^`ZD00`000000oooo0?ooo`3:0?ooo`00a03o
ool700000300jl2W00<000000?ooo`3oool0P@3oool00`000000200600P01P0400P01P030000003^
`ZD0k/:U02/0k/:U00<000000?ooo`3oool0b@3oool00<<0oooo2000000a0>_0Y`030000003oool0
oooo07l0oooo00<0000000P01P0800H01@0800H00`000000k/:U0>k2Y@0/0>k2Y@030000003oool0
oooo0<P0oooo00320?ooo`P00000<`3[`:L00`000000oooo0?ooo`1n0?ooo`030000000800H02006
00<020060P00000`0>k2Y@030000003oool0oooo0<L0oooo00310?ooo`P00000=@3[`:L00`000000
oooo0?ooo`1l0?ooo`040000000800H0200600P01P<0000000<06`110000003^`ZD0;`3^`ZD00`00
0000oooo0?ooo`370?ooo`00`@3oool4000000<02@0b00<000000>_0Y`3[`:L0=03[`:L00`000000
oooo0?ooo`1k0?ooo`@000000`0K04400`000000k/:U0>k2Y@0`0>k2Y@030000003oool0oooo0<H0
oooo00300?ooo`8000001@0903800`000000jl2W0>_0Y`0e0>_0Y`030000003oool0oooo07X0oooo
0P00000601/0@@030000003^`ZD0k/:U0340k/:U00<000000?ooo`3oool0a@3oool00<00oooo00<0
000000T0<P090380100903800`000000jl2W0>_0Y`0f0>_0Y`030000003oool0oooo07T0oooo00<0
000001/0@@0K0440100K04400`000000k/:U0>k2Y@0c0>k2Y@030000003oool0oooo0<@0oooo002o
0?ooo`030000000903802@0b00@02@0b00<000000>_0Y`3[`:L0>03[`:L00`000000oooo0?ooo`1g
0?ooo`030000000K04406`1100D06`1100<000000>k2Y@3^`ZD0<`3^`ZD00`000000oooo0?ooo`34
0?ooo`00_`3oool00`0000002@0b00T0<P0400T0<P030000003[`:L0jl2W03T0jl2W00<000000?oo
o`3oool0MP3oool00`0000006`1101/0@@0401/0@@030000003^`ZD0k/:U03D0k/:U00<000000?oo
o`3oool0``3oool00;h0oooo00<0000000T0<P0903800`090382000003X0jl2W00<000000>_0Y`00
0000M`3oool00`0000006`1101/0@@0401/0@@800000=03^`ZD2000000030>k2Y@000000oooo0<@0
oooo002n0?ooo`040000000903802@0b00T0<P80000000<06@1T0000003[`:L0?03[`:L00`000000
oooo0?ooo`1d0?ooo`040000000K04406`1101/0@@<0000000<0:@I^0000003^`ZD0<03^`ZD20000
00D0k/:U00<000000?ooo`3oool0`P3oool00;d0oooo00<0000000T0<P0000000P00000301T0I003
0000003[`:L0jl2W03/0jl2W00<000000?ooo`3oool0L`3oool00`0000006`1100000002000000@0
:@I^00<000000>k2Y@3^`ZD0;03^`ZD2000000P0k/:U00<000000?ooo`3oool0`P3oool00;d0oooo
0P00000501T0I0030000003[`:L0jl2W03d0jl2W00<000000?ooo`3oool0LP3oool2000000L0:@I^
00<000000>k2Y@3^`ZD0=`3^`ZD00`000000oooo0?ooo`310?ooo`00_@3oool00`0000006@1T01T0
I00401T0I0030000003[`:L0jl2W03d0jl2W00<000000?ooo`3oool0LP3oool00`000000:@I^02T6
KP0602T6KP030000003^`ZD0k/:U03L0k/:U00<000000?ooo`3oool0`@3oool00;d0oooo00<00000
01T0I00I06@0100I06@00`000000jl2W0>_0Y`0n0>_0Y`030000003oool0oooo0740oooo00<00000
02T6KP0Y1Vh01@0Y1Vh00`000000k/:U0>k2Y@0i0>k2Y@030000003oool0oooo0<00oooo002l0?oo
o`030000000I06@06@1T00D06@1T00<000000>_0Y`3[`:L0>03[`:L00`15KmL0jl2W0>_0Y`030>_0
Y`030000003oool0oooo0700oooo00<0000002T6KP0Y1Vh01P0Y1Vh00`000000k/:U0>k2Y@0i0>k2
Y@030000003oool0oooo0<00oooo002l0?ooo`030000000I06@06@1T00@06@1T00<000000>_0Y`3[
`:L0@03[`:L00`000000oooo0?ooo`1_0?ooo`030000000Y1Vh0:@I^00H0:@I^00<000000>k2Y@3^
`ZD0>P3^`ZD00`000000oooo0?ooo`2o0?ooo`00_03oool00`0000006@1T01T0I00401T0I0030000
003[`:L0jl2W0400jl2W00<000000?ooo`3oool0K`3oool00`000000:@I^02T6KP0602T6KP030000
003^`ZD0k/:U03D0k/:U00<0CW?G0>k2Y@3^`ZD00P3^`ZD00`000000oooo0?ooo`2o0?ooo`00_03o
ool00`0000006@1T01T0I00301T0I0800000@P3[`:L00`000000oooo0?ooo`1_0?ooo`030000000Y
1Vh0:@I^00D0:@I^0P00000g0>k2Y@030000003^`ZD0k/:U0080k/:U00<000000?ooo`3oool0_`3o
ool00;/0oooo00<0000001T0I00I06@00P0I06@20000000302HJR`000000jl2W0440jl2W00<00000
0?ooo`3oool0KP3oool00`000000:@I^02T6KP0302T6KP<0000000<0=2JA0000003^`ZD0=P3^`ZD0
0`19GLD0k/:U0>k2Y@020>k2Y@030000003oool0oooo0;l0oooo002k0?ooo`030000000I06@00000
008000000`0V6X/00`000000jl2W0>_0Y`110>_0Y`030000003oool0oooo06d0oooo00<0000002T6
KP0000000`00000403@VT@030000003^`ZD0k/:U03/0k/:U00<000000?ooo`3oool0_P3oool00;/0
oooo0P00000602HJR`030000003[`:L0jl2W0440jl2W00<000000?ooo`3oool0K@3oool2000000P0
=2JA00<000000>k2Y@3^`ZD0>`3^`ZD00`000000oooo0?ooo`2n0?ooo`00^`3oool00`0000009QZ;
02HJR`0502HJR`030000003[`:L0jl2W0440jl2W00<000000?ooo`3oool0K@3oool00`000000=2JA
03@VT@0703@VT@030000003^`ZD0k/:U03/0k/:U00<000000?ooo`3oool0_P3oool00;/0oooo00<0
000002HJR`0V6X/01@0V6X/00`000000jl2W0>_0Y`110>_0Y`030000003oool0oooo06d0oooo00<0
000003@VT@0d9Y401P0d9Y400`000000k/:U0>k2Y@0l0>k2Y@030000003oool0oooo0;h0oooo002k
0?ooo`030000000V6X/09QZ;00D09QZ;00<000000>_0Y`3[`:L04`3[`:LB000001D0jl2W00<0?eO4
0>_0Y`3[`:L01@3[`:L00`000000oooo0?ooo`1/0?ooo`030000000d9Y40=2JA00H0=2JA00<00000
0>k2Y@3^`ZD04`3^`ZDB00000140k/:U00<0BEg50>k2Y@3^`ZD0103^`ZD00`000000oooo0?ooo`2m
0?ooo`00^`3oool00`0000009QZ;02HJR`0502HJR`030000003[`:L0jl2W00/0jl2W2000000407QR
[@030000003>Z;80cZRb00/0cZRb3`0000060>_0Y`0303mGa03[`:L0jl2W00D0jl2W00<000000?oo
o`3oool0K03oool00`000000=2JA03@VT@0603@VT@030000003^`ZD0k/:U00X0k/:U2@00000407]U
[P030000003>Z;80cZRb00/0cZRb3P0000030>k2Y@0304UMa@3^`ZD0k/:U00@0k/:U00<000000?oo
o`3oool0_@3oool00;/0oooo00<0000002HJR`0V6X/01@0V6X/00`000000jl2W0>_0Y`060>_0Y`D0
0000301hHZd00`000000cZRb0<jX/P0H0<jX/P040000003od8H00000000000`0jl2W00<000000?oo
o`3oool0K03oool00`000000=2JA03@VT@0603@VT@030000003^`ZD0k/:U00D0k/:U1@00000=07]U
[P030000003>Z;80cZRb01P0cZRb0`0000000`19GLD0k/:U0>k2Y@050>k2Y@030000003oool0oooo
0;d0oooo002k0?ooo`030000000V6X/09QZ;00@09QZ;0P0000080>_0Ya40N6:]00<000000<jX/P3>
Z;80603>Z;8010000000om260?o@QP3od8H200000080jl2W00<000000>_0Y`3[`:L01@3[`:L00`00
0000oooo0?ooo`1/0?ooo`030000000d9Y40=2JA00D0=2JA0P0000070>k2YA80NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`02000000H0k/:U00<000000?ooo`3oool0_@3oool00;/0
oooo00<0000002HJR`0V6X/00P0V6X/20000000302lhZP000000jl2W00L0jl2W4@1hHZd00`000000
cZRb0<jX/P0H0<jX/P030000003od8H0om2600<0om260`0000070>_0Y`030000003oool0oooo06`0
oooo00<0000003@VT@0d9Y400P0d9Y430000000303a1[@000000k/:U00H0k/:U4P1kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k0080om1k0P0000040>k2Y@030000003oool0oooo0;d0
oooo002k0?ooo`030000000V6X/00000008000000`0_>:X00`000000jl2W0>_0Y`060>_0Ya40N6:]
00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP060?o@QP8000001@3[`:L00`000000oooo
0?ooo`1/0?ooo`030000000d9Y40000000800000100l@Jd00`000000k/:U0>k2Y@050>k2YA80NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`040?o@N`8000000P3^`ZD00`000000oooo
0?ooo`2m0?ooo`00^`3oool2000000H0;cRZ00<000000>_0Y`3[`:L01P3[`:LA07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H0203od8H2000000@0jl2W00<000000?ooo`3oool0J`3o
ool2000000L0?46]00<000000>k2Y@3^`ZD01@3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/01P3od7/2000000030>k2Y@000000oooo0;d0oooo002k0?ooo`030000000_>:X0
;cRZ00D0;cRZ00<000000>_0Y`3[`:L01P3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02P3od8H200000080jl2W00<000000?ooo`3oool0J`3oool00`000000?46]03a1[@06
03a1[@030000003^`ZD0k/:U00D0k/:U4P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0
om1k00P0om1k0P00002n0?ooo`00^`3oool00`000000;cRZ02lhZP0602lhZP030000003[`:L0jl2W
00D0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000K@3oool00`000000?46]03a1[@0703a1[@030000003^`ZD0k/:U00@0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;/0oooo00<0000002lhZP0_>:X01P0_>:X00`000000jl2W0>_0Y`050>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006d0oooo00<00000
03a1[@0l@Jd01`0l@Jd00`000000k/:U0>k2Y@040>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;80
0`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002k0?ooo`030000000_>:X0;cRZ
00H0;cRZ00<000000>_0Y`3[`:L01@3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H010000000jl2W0>_0Y`00001]0?ooo`030000000l@Jd0?46]00L0?46]00<00000
0>k2Y@3^`ZD0103^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000;cRZ02lhZP0502lhZP030000003[`:L0jl2W
00D0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000KP3oool00`000000?46]03a1[@0603a1[@030000003^`ZD0k/:U00@0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;`0oooo00<0000002lhZP0_>:X0100_>:X2000000L0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600@000000>_0Y`3[`:L00000KP3oool00`000000?46]03a1[@05
03a1[@8000001P3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000;cRZ02lhZP0202lhZP80000000<0=e?20000
003[`:L01P3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H01000
0000jl2W0>_0Y`00001^0?ooo`030000000l@Jd0?46]0080?46]0`0000000`13F/@000000>k2Y@05
0>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0
oooo0;`0oooo002l0?ooo`030000000_>:X0000000800000100gDl800`000000jl2W0>_0Y`040>_0
Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W
000006h0oooo00<0000003a1[@0000000P00000504=Ja0030000003^`ZD0k/:U00<0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;`0oooo0P00000703MC`P030000003[`:L0jl2W00@0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600@000000>_0Y`3[`:L00000KP3oool2000000P0@e[400<00000
0>k2Y@3^`ZD00`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000=e?203MC`P0603MC`P030000003[`:L0jl2W
00@0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000KP3oool00`000000@e[404=Ja00704=Ja0030000003^`ZD0k/:U00<0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;d0oooo00<0000003MC`P0gDl801P0gDl800`000000jl2W0>_0Y`030>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006l0oooo00<00000
04=Ja013F/@01`13F/@00`000000k/:U0>k2Y@020>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;80
0`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002m0?ooo`030000000gDl80=e?2
00H0=e?200<000000>_0Y`3[`:L00`3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H010000000jl2W0>_0Y`00001_0?ooo`0300000013F/@0@e[400L0@e[400<00000
0>k2Y@3^`ZD00P3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_@3oool00`000000=e?203MC`P0603MC`P030000003[`:L0jl2W
00<0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000K`3oool00`000000@e[404=Ja00704=Ja0030000003^`ZD0k/:U0080k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;h0oooo00<0000003MC`P0gDl801P0gDl800`000000jl2W0>_0Y`020>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006l0oooo0P000009
04=Ja0040000003^`ZD0k/:U0>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@
N`090?o@N`030000003oool0oooo0;`0oooo002n0?ooo`030000000gDl80=e?200D0=e?20P000004
0>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0
jl2W000006h0oooo0`00000804=Ja08000000`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000=e?203MC`P03
03MC`P@00000103[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H0
0`000000jl2W0000001_0?ooo`<000001@13F/@5000000<0k/:U4P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0000003MC
`P0000000`00000303e[eP040000003[`:L0jl2W0>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003[`:L0000006h0oooo0`0000000`0005d0000004=Ja005
000000<0B73G0`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool2000000L0?F_F00@000000>_0Y`3[`:L0jl2W4@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000>_0Y`000000KP3oool0
10000000:01;0000000005d3000000L0B73G00<000000>k2Y@3^`ZD04P1kIJh00`000000cZRb0<jX
/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
03e[eP0mJmH01`0mJmH00`000000jl2W0>_0Y`0A07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02`3od8H00`000000jl2W0000001]0?ooo`060000000X04/0:01;0000000005d00000
2P18L=L20>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000mJmH0?F_F00<0?F_F00D0000003e[eP0mJmH0?F_F
000000020>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP800000
KP3oool010000000:01;02P0B`0000020000G@D0B73G00<0000004Q`e`18L=L00P18L=L00`000000
k/:U07]U[P0A07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000
oooo0?ooo`2l0?ooo`00_`3oool2000000@0?F_F00<0000003e[eP0mJmH00P0mJmH00`000000jl2W
07QR[@0@07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H2000006d0oooo
00D0000002P0B`0X04/0:01;000000020000G@0300000018L=L0B73G0080B73G00<0000004Q`e`18
L=L00`18L=L00`3^`ZD0NfF^07]U[P0@07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3o
d7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`000000001703e[eP0303e[eP030000
001hHZd0?F_F0080?F_F00<000000>_0Y`1hHZd0401hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om260`00001/0?ooo`050000000X04/0:01;02P0B`0000000P0005d00`000000
B73G04Q`e`0204Q`e`030000001kIJh0B73G00<0B73G00<0000007]U[P1kIJh0401kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo
00<000000000A`0000000`0mJmH010000000N6:]07QR[@1hHZd203e[eP030000001hHZd0N6:]00l0
N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP<00000J`3oool00`000000
:01;02P0B`03000000<0001M00D0000004Q`e`18L=L0B73G0000000307]U[P<0B73G00<0k/:U07]U
[P1kIJh03`1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00P0mJmH00`0004L0000007QR[@0407QR[@80
0000401hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>RmZ@3X
_JT00000JP3oool300000080=A5e00D000000000G@0005d0001M0000000204Q`e`030000G@000000
NfF^00@0NfF^0P00000A07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool01`00000000170000A`000000?F_F0000A`0000005`1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>RmZ@3X_JT00000
JP3oool00`000000=A5e03DAM@0203DAM@030000000005d0001M0080001M00@0000004Q`e`0005d0
0000601kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3o
ool0_03oool00;l0oooo00L000000000A`0004L000170000000004L0000001L0N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP050000003X_JT0j;fY0>RmZ@000000J03oool0
0`000000=A5e03DAM@0303DAM@030000000005d0001M0080001M00@0000004^5iP0005d00000601k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00L000000000A`0004L000170000000004L0000001L0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP050000003X_JT0j;fY0>RmZ@000000J03oool00`000000
=A5e03DAM@0303DAM@030000000005d0001M00<0001M00<000000000G@000000601kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo
00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb
00<000000?o@QP3od8H02`3od8H01@000000j;fY0>RmZ@3X_JT0000006P0oooo00<0000003DAM@0e
4GD00`0e4GD00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>
Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000
000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om2600<000000>RmZ@3X_JT00P3X_JT00`000000oooo0?ooo`1U0?ooo`030000
000e4GD0=A5e00<0=A5e00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000
003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>
Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY0080j;fY00<000000?ooo`3oool0I03o
ool00`000000=A5e03DAM@0403DAM@030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80
cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000j;fY0>RmZ@020>RmZ@030000003oool0
oooo06@0oooo00<0000003DAM@0e4GD01@0000070000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000>RmZ@3X_JT00`3X_JT00`000000oooo0?ooo`1S0?oo
o`<00000100n;YH00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`03
0000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P03
0000003od8H0om2600/0om2600<000000>RmZ@3X_JT00`3X_JT00`000000oooo0?ooo`1S0?ooo`03
0000000n;YH0?RjF00@0?RjF00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY00@0j;fY00<000000?ooo`3oool0
HP3oool00`000000?RjF03h^UP0403h^UP030000000005d0001M00D0001M00<0000007]U[P1kIJh0
5P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0
_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000j;fY0>RmZ@040>RmZ@030000003o
ool0oooo0680oooo00<0000003h^UP0n;YH0100n;YH00`000000001M0000G@050000G@030000001k
IJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003o
ool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000>RmZ@3X_JT0103X_JT0
0`000000oooo0?ooo`1R0?ooo`030000000n;YH0?RjF00@0?RjF00<000000000G@0005d01@0005d0
0`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]
01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY
00@0j;fY00<000000?ooo`3oool0HP3oool00`000000?RjF03h^UP0403h^UP030000000005d0001M
00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k
00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000
N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000
j;fY0>RmZ@040>RmZ@030000003oool0oooo0680oooo00<0000003h^UP0n;YH0100n;YH00`000000
001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000
om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<00017
00<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om26
0P0000050>RmZ@030000003oool0oooo0680oooo00<0000003h^UP0n;YH01@0000070000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000?k@R`0000000000
103X_JT00`000000oooo0?ooo`1Q0?ooo`<000001015B:l00`000000001M0000G@050000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000?k@R`3nd8/0o]2;
0P0000020>RmZ@030000003oool0oooo0640oooo00<0000004E8[`15B:l01015B:l00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001S0?ooo`0300000015B:l0ADR_00@0ADR_
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@000000>RmZ@3X_JT00000H`3oool00`000000ADR_
04E8[`0404E8[`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`040000003X_JT0j;fY000006<0oooo
00<0000004E8[`15B:l01015B:l00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/010000000j;fY0>Rm
Z@00001T0?ooo`0300000015B:l0ADR_00<0ADR_00<000000000G@0005d01@0005d00`000000NfF^
07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo
0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<0
00000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@0
00000>RmZ@3X_JT00000I03oool00`000000ADR_04E8[`0304E8[`030000000005d0001M00D0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`040000003X_JT0j;fY000006@0oooo00<0000004E8[`15B:l00P15B:l2000000L0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`040000003X_JT0j;fY000006@0oooo00<0000004E8[`0000000P0000000`1;G/D00000
0000G@060000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001T0?ooo`800000101;G/D00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001T0?ooo`030000001;G/D0Bek500<0Bek5
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@000000>RmZ@3X_JT00000I03oool00`000000Bek5
04]Na@0304]Na@030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`040000003X_JT0j;fY000006D0oooo
00<0000004]Na@1;G/D00P1;G/D00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/010000000j;fY0>Rm
Z@00001U0?ooo`030000001;G/D0Bek50080Bek500<000000000G@0005d01@0005d00`000000NfF^
07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo
0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<0
00000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<0
00000>RmZ@000000IP3oool00`000000Bek504]Na@0204]Na@030000000005d0001M00D0001M00<0
000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<0
00000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E
07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`02
0?k@R`030000003X_JT0000006H0oooo00<0000004]Na@1;G/D00P1;G/D00`000000001M0000G@05
0000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`09
0?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR
[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@
R`3nd8/00P3nd8/00`000000j;fY0000001V0?ooo`8000000P1;G/D2000000L0001M00<0000007]U
[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`03
0000003X_JT0000006H0oooo100000000`1?LmL000000000G@060000G@030000001kIJh0NfF^01H0
NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0
oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb
0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo
00<000000000H`1?LmL00P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo00<0
00000000H`0000000P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<0
00000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o
0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H
0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo00<00000
0000H`0006<00P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?oo
o`060000000006<0001S0000001?LmL000001`0005d00`000000NfF^07]U[P0F07]U[P030000003>
Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool0
0`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool0
1P000000001S0000H`0006<0Cg?G000000L0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00@0
00000000H`0006<0001S0P0000070000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80
603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`0300000000
04L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003o
d8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`0300000000
06<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>
Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool0
0`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool0
0`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb
01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo
06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^
01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo
0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000
cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000
oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000
NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000
oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]
00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;
00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000
G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@
N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<00000
07QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<00000
0?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<00000
0000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<00000
0?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000
A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@
QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000
H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX
/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`00
04L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3o
d8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`00
06<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>
Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000
000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000
000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000
003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>
Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3o
ool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80
cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0
oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0
NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0
oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`00
0000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`00
0000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`00
0000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`00
0000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0
N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080
o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0
001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0
om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]
07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;
0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<0
00000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`03
0000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;
0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`02
0000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000
A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000
H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`03
0000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P03
0000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`03
0000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0
IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh0
5P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0
_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003o
ool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001k
IJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003o
ool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/0
0`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d0
0`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]
01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;
0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M
00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k
00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000
N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000
o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000
001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000
om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<00017
00<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om26
00<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000
H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX
/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
0000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<00000
0000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?oo
o`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U
[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?oo
o`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>
Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3o
ool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1k
IJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3o
ool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000
003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000
003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3n
d8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@00
05d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3o
d7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0
N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0
o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0
001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0
om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`00
0000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`00
0000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`00
0000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`00
0000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0
001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0
om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080
001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0
cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`0000000017
0000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om26
0?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S
0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<0
00000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<0
00000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o
0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H
0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V
0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F
07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l
0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?oo
o`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U
[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`03
0000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@03
0000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`03
0000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd0
5@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/0
0P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d0
1@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/0
2@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001h
HZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003n
d8/0o]2;0080o]2;00<000000?ooo`3oool0503oooll000001H0oooo00<000000000H`0006<00P00
06<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>
Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0
001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0
om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`0D000000T0WX6c00<00000
0;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@000000P3oool00`000000001S0000H`02
0000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000
A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H00P3od8HA000001d0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`0K0<RT
/a4000005`1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb0140cZRb3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02d
Tk@09P2dTk@00`000000b:Bc0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000;07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
1@3>Z;8<00000180Q6b_00<0000009j1/`2NPK<04P2NPK=@000001@0b:Bc00<000000=^b[`3K/Zl0
403K/Zl<000001X0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01<0N6:]2P00000H08A/[a/00000D00h
^^@E000001h0fk:_2P00000@0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0;07QR[@P000000`1SD:L0
0`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@000000>c0Y`3/`:L0k<2W2000
00080<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
0000A`0004L00`0004L00`000000N6:]07QR[@0307QR[@P000002`1SD:L00`000000Q6b_08A/[`04
08A/[``00000WP0h^^@<000000H0fk:_00<000000>c0Y`3/`:L02@3/`:L9000000/0om1k00<00000
0?ooo`3oool0_03oool00;l0oooo00@000000000A`0004L000172000000@06=@Y`X00000]P0h^^@7
000001<0k<2W200000040?o@N`030000003oool0oooo0;`0oooo002m0?ooo`H00000401SD:L80000
0<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0He2W00T0
He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?ooo`D00000
1`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<V03jc9P0
1@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D00000[`3o
ool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo002U0?oo
o`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool200000003
0000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`000000080
0000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rji1h0>;[T
100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0001l00<0
000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0om1l0P00
002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000V`3oool0
09P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F0?ooo`80
0000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3000000H0001l
0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`0004/00000
100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool00940oooo
0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000003`a4/0
0P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540>;[T0P00
00050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[TE@0h^^@2
000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h^^@0>;[T
0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=0?ooo`04
0000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?ooo`2;0?oo
o`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000S@3oool0
08d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2000008`0
oooo002<0?ooo`8000007@0h^^@403Vji900>;[T00<0000003Rji00h^^@0/00h^^@2000008`0oooo
002<0?ooo`800000>`0h^^@703Vji6H0>;[T2@2<L[400`000000eZna0=J_/@0=0=J_/J<0>;[T0P00
002<0?ooo`00S03oool00`000000>;[T03Rji01G03Rji0`0>K[T>P0h^^@00`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h^^@0W00h^^@2000008`0oooo002<0?oo
o`030000000h^^@0>;[T07D0>;[T3`0i^^@G03Rji080001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0U@0h^^@00`00
0000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T03Rji02B03Rji0<0>K[T00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg400`3ncg4@03Rji0L0>K[TP`0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T
03Rji02E03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07P0h^^@803Vji6l0>;[T
00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0U00h^^@00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000000h^^@0>;[T0300>;[T2@0i^^AK03Rji0030000003oool0oooo08/0oooo002>
0?ooo`800000U00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00d0>;[T400i^^@V
03Rji0L0>K[TB00h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[T7@0h^^@503Vji3H0>;[T00<000000?oo
o`3oool0SP3oool00940oooo00<0000003Rji00h^^@0T00h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000000h^^@0>;[T04d0>;[T200i^^@C03Rji0@0>K[T900h^^@00`000000oooo0?ooo`2?0?ooo`00
TP3oool200000900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rji0@0>K[T
2P0h^^@203Vji140>;[T0P00002B0?ooo`00U03oool00`000000>;[T03Rji02=03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@0308ec/@00
0000o/ma00H0o/ma00<0000003Rji00h^^@0S@0h^^@00`000000oooo0?ooo`2B0?ooo`00UP3oool2
000008`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji02:03Rji0800000UP3oool0
09P0oooo0P00002:03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0R00h^^@20000
09P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0>;[T08D0
>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T
03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rji003000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@00000O`0h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00Y@3oool5000007X0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000Y@3oool00:X0oooo1@00001e03Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0L`0h^^@500000:X0oooo002_0?ooo`D00000
8P0h^^@2000004`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01^03Rji0D00000
[`3oool00;@0oooo1@00001[03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0J@0h
^^@500000;@0oooo002i0?ooo`D00000IP0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T06@0>;[T1@00002i0?ooo`00_P3oool500000640>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji01O03Rji0D00000_P3oool00<<0oooo1@00001L03Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0?0=J_/@0308ec/@3F[k40000000L0
o/ma00<0000003Rji00h^^@0FP0h^^@500000<<0oooo00380?ooo`D00000E`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k400`2=Lk40eZna
000000070?k?L@030000000h^^@0>;[T05D0>;[T1@0000380?ooo`00c@3oool700000500>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00l0eZna00<0
SG>a0=J_/@0000001`3ncg400`000000>;[T03Rji01>03Rji0L00000c@3oool00=@0oooo2P000016
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0A00h^^@:00000=@0oooo003N0?oo
o`X00000?00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T03X0>;[T2P00003N0?oo
o`00j03oool=000002l0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0d0
0000j03oool00?D0oooo4000000O03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
7@0h^^@@00000?D0oooo003o0?ooo`H0oooo6@00000603Rji003000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
000003Rji00h^^@0100h^^@I00000?l0oooo1P3oool00?l0oooo7`3oool7000000L0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma1`00003o
0?oooal0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00h0eZna00@0SG>a0=J_/@3F[k4000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00h0eZna00@0SG>a0=J_/@3F[k4000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00h0eZna00@0SG>a0=J_/@3F[k4000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0eZna00D0SG>a0=J_/@3F[k40eZna
000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403@3F[k401@2=Lk40eZna0=J_
/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@0508ec/@3F
[k40eZna0=J_/@0000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna00`0eZna00<0SG>a0=J_/@3F[k400P3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40303F[k400`2=Lk40eZna0=J_/@02
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0<0=J_
/@0308ec/@3F[k40eZna0080eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00/0eZna00<0SG>a0=J_/@3F
[k400`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
2`3F[k400`2=Lk40eZna0=J_/@030=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0:0=J_/@0308ec/@3F
[k40eZna00@0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00X0eZna00<0SG>a0=J_/@3F[k40103F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k402P3F[k400`2=Lk40eZna0=J_/@040=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@090=J_/@0308ec/@3F[k40eZna00D0eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna00T0eZna00<0SG>a0=J_/@3F[k401@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k40203F[k400`2=Lk40eZna0=J_/@060=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@080=J_/@0308ec/@3F[k40eZna00H0eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna00L0eZna00<0SG>a0=J_/@3F[k401`3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k401`3F[k400`2=Lk40eZna0=J_/@070=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@060=J_/@0308ec/@3F[k40eZna00P0eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna00H0eZna00<0SG>a0=J_/@3F[k40203F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k401@3F[k400`2=Lk40eZna0=J_/@090=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@040=J_
/@0308ec/@3F[k40eZna00X0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo00330?ooo`<00000
GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00
000A0?ooo`030000001jFJ00NUVP00D00000F@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:d0oooo0`0000000`1kK[X000000000000?0?ooo`030000001jFJ00
NUVP00H0NUVP0`00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool4000000D0Nfjj00<000000?ooo`3oool03@3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05@0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002W0?ooo`8000002@1kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02000005H0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002W0?ooo`030000
001kK[X0Nfjj00P0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@030=J_/@0308ec
/@3F[k40eZna00/0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002X0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000=0?ooo`030000001jFJ00NUVP00P0NUVP00<0
00000?ooo`3oool0E@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:P0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00oooo0?ooo`0;0?ooo`030000001jFJ00
NUVP00P0NUVP00<000000?ooo`3oool0E@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`0;0?oo
o`030000001jFJ00NUVP00L0NUVP0P00001G0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0807]^^P800000303oool00`000000
NUVP07YIX00707YIX0800000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:T0oooo00<0000007]^^P1kK[X01`1kK[X2000000/0oooo00<0000007YIX01jFJ00
201jFJ000`000000oooo0?ooo`1F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i003oool0oooo00T0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1F0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000
oooo00T0oooo00<0000007YIX01jFJ001`1jFJ02000005P0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000
003oool02@3oool00`000000NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X01`1kK[X00`30N@00
00000?ooo`080?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0
1`1kK[X2000000T0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1G0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^
^P0807]^^P030<1i00000000oooo00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0
Nfjj00P0Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX00707YIX0800000F@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^
^P1kK[X01`1kK[X2000000L0oooo00<0000007YIX01jFJ001`1jFJ000`3M_[X000000?ooo`1I0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@020=J_
/@0308ec/@3F[k40eZna00`0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00P0
NUVP00<000000?ooo`3oool0F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`050?ooo`030000
001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00D0oooo00<0
000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000001jFJ00
NUVP00P0NUVP0P00001J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P8000001@3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05T0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002/0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000040?ooo`030000001jFJ00NUVP00L0
NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[03oool2000000T0Nfjj00<0`7T00000003oool00`3oool00`000000NUVP07YIX00707YIX0800000
F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo00<0
000007]^^P1kK[X01`1kK[X2000000<0oooo00<0000007YIX01jFJ00201jFJ02000005/0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000001kK[X0
Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0FP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo00<0000007]^
^P1kK[X0201kK[X200000080oooo00<0000007YIX01jFJ001`1jFJ02000005`0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`8000002@1kK[X01@30N@00
00000?ooo`3oool0000000T0NUVP0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P80000000<0oooo0000001j
FJ002@1jFJ02000005`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj1000000807YIX0030=fn^P000000000005d0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001k
K[X0Nfjj00P0Nfjj0`00000907YIX0800000G@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:h0oooo0P00000907]^^P<000002@1jFJ02000005d0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj
00L0Nfjj0P00000807YIX0040=fn^P1jFJ00b<M6000005d0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000907YI
X0800000GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0
oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00707YIX0800000GP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo0P00000907]^^P030000
001jFJ00NUVP00L0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00/03oool00`000000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00L0NUVP00<0
b<M60000003oool0G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;00oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00507YIX0800000G`3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00000907]^
^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00/03oool2000000T0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`030000
001kK[X0Nfjj00L0Nfjj00<0000007YIX01jFJ001@1jFJ000`38adH000000?ooo`1N0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/@3oool00`000000Nfjj07]^
^P0807]^^P030000001jFJ00NUVP00<0NUVP0`00001O0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[4010000000eZna0=J_/@2=Lk4@0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00/@3oool2000000T0Nfjj00H0000007YIX01jFJ00NUVP
0=fn^P1jFJ0200000600oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002a0?ooo`8000002@1kK[X00`000000NUVP07YIX00307YIX0800000H03oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo00<0000007]^^P1kK[X01`1k
K[X00`000000NUVP07YIX00307YIX0030<S7AP000000oooo05l0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`030000001kK[X0Nfjj00P0Nfjj00@00000
07YIX03M_[X0NUVP0`00001P0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00/P3oool2000000T0Nfjj00@0000007YIX01jFJ00NUVP0P00001Q0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool2000000T0Nfjj00@00000
07YIX01jFJ00NUVP0P00001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00/`3oool00`000000Nfjj07]^^P0707]^^P060000003M_[X0NUVP07YIX038adH00000
H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo00<0
000007]^^P1kK[X0201kK[X00`000000NUVP0000000200000640oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000
001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool2
000000T0Nfjj00@0000007YIX00000000000HP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00;@0oooo00<0000007]^^P1kK[X01`1kK[X010000000NUVP0<S7AP00
001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00]03oool0
0`000000Nfjj07]^^P0807]^^P<00000HP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:h0oooo8`00001C0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`3;0?ooo`00X03oool>000000`0B3^N00<000000?74X`3a
a:<0303aa:<?000004`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`80
000000<0HaME0000003oool05`3oool200000;80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0D@3oool01@000000HaME06<GE@1S5eD0000001D0oooo0`0000000`0n01P0
00000?ooo`2a0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04l0oooo
0P00000506<GE@030000003oool0oooo00h0oooo1000000303h060800000/P3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1>0?ooo`030000001S5eD0HaME00D0HaME00<0
00000?ooo`3oool0303oool2000000L0?P0H0P00002b0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo04`0oooo0P00000906<GE@030000003oool0oooo00/0oooo00<00000
03h0600n01P01P0n01P200000;80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0B`3oool00`000000HaME06<GE@0906<GE@030000003oool0oooo00X0oooo00<0000003h0
600n01P01P0n01P200000;<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0B`3oool00`000000HaME06<GE@0:06<GE@030000003oool0oooo00T0oooo00<0000003h0600n
01P01P0n01P200000;<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
C03oool00`000000HaME06<GE@0906<GE@030000003oool0oooo00T0oooo00<0000003h0600n01P0
1@0n01P300000;<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0C03o
ool00`000000HaME06<GE@0:06<GE@030000003oool0oooo00L0oooo00<0000003h0600n01P01P0n
01P00`000000g<U;0000002c0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo04d0oooo00<0000006<GE@1S5eD02@1S5eD00`000000oooo0?ooo`070?ooo`030000000n01P0
?P0H00H0?P0H00<000000=c9B`000000/`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1=0?ooo`030000001S5eD0HaME00X0HaME00<000000?ooo`3oool01P3oool00`00
0000?P0H03h0600503h060040000003LbD/0g<U;00000;<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0CP3oool00`000000HaME06<GE@0906<GE@030000003oool0oooo
00D0oooo00<0000003h0600n01P01P0n01P00`000000g<U;0000002d0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo04h0oooo00<0000006<GE@1S5eD02P1S5eD00`000000
oooo0?ooo`040?ooo`030000000n01P0?P0H00H0?P0H00<000000=c9B`000000]03oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1?0?ooo`030000001S5eD0HaME00T0HaME
00<000000?ooo`3oool00`3oool00`000000?P0H03h0600603h060040000003LbD/0g<U;00000;@0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0C`3oool00`000000HaME
06<GE@0:06<GE@030000003oool0oooo0080oooo0P00000703h060030000003LbD/000000;D0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0D03oool00`000000HaME06<G
E@0906<GE@030000003oool0oooo0080oooo0`00000503h06080000000<0g<U;0000003oool0]03o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1@0?ooo`030000001S5eD0
HaME00X0HaME00P000000?ooo`00000000000240=P000000hG8O000000@0?P0H00@000000=c9B`3L
bD/00000]@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1A0?ooo`03
0000001S5eD0HaME00T0HaME0P0000030240=P030000003QLQl0hG8O008000000P0n01P00`000000
g<U;0000002f0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0540oooo
00<0000006<GE@1S5eD02@1S5eD00`0000008@0f0240=P020240=P030000003QLQl0hG8O0080hG8O
0`0000000`3LbD/000000?ooo`2e0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0580oooo00<0000006<GE@1S5eD01P1S5eD2000000D08@0f00<000000>5b7`3QLQl00`3Q
LQl010000000g<U;0=c9B`00002f0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0580oooo00<0000006<GE@1S5eD01@1S5eD00`0000008@0f0240=P050240=P030000003Q
LQl0hG8O00@0hG8O0P00002g0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05<0oooo00<0000006<GE@1S5eD00`1S5eD00`0000008@0f0240=P070240=P030000003QLQl0
hG8O00@0hG8O00<000000?ooo`3oool0]@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1C0?ooo`040000001S5eD0HaME06<GE@8000002P0Q03H00`000000hG8O0>5b7`05
0>5b7`800000]@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1D0?oo
o`030000001S5eD0000000`08@0f00<000000>5b7`3QLQl01`3QLQl00`000000oooo0?ooo`2b0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0A`3oooln000005<0oooo0P00000=0240=P030000003QLQl0hG8O00P0hG8O00<000000?ooo`3o
ool0/@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo2`00000900d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
1`3od8H;000004L0oooo0P00000>0240=P030000003QLQl0hG8O00T0hG8O00<000000?ooo`3oool0
/03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0A03oool00`0000008@0f0240=P0>0240=P030000003Q
LQl0hG8O00X0hG8O00<000000?ooo`3oool0[`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0@`3oool0
0`0000008@0f0240=P0?0240=P030000003QLQl0hG8O00/0hG8O0P00002_0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`110?ooo`8000004P0Q03H00`000000hG8O0>5b7`0=0>5b7`030000003oool0oooo
0:`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo0400oooo00<000000240=P0Q03H04P0Q03H00`000000
hG8O0>5b7`0>0>5b7`030000003oool0oooo0:/0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03l0oooo
00<000000240=P0Q03H04`0Q03H00`000000hG8O0>5b7`0?0>5b7`030000003oool0oooo0:X0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo03d0oooo0P00000F0240=P030000003QLQl0hG8O0100hG8O00<0
00000?ooo`3oool0Z@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?03oool00`0000008@0f0240=P0F
0240=P030000003QLQl0hG8O0140hG8O0P00002Y0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0k0?oo
o`030000000Q03H08@0f01L08@0f00<000000>5b7`3QLQl04`3QLQl00`000000oooo0?ooo`2V0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0i0?ooo`8000006`0Q03H00`000000hG8O0>5b7`0C0>5b7`03
0000003oool0oooo0:D0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H0
6`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003o
ool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H0
0`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo
0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000
hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo
00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b
7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<00000
0240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b
7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q
03H06P0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo03T0oooo00<000000240=P0Q03H06P0Q03H00`000000hG8O0>5b7`0E0>5b7`030000
003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06P0Q
03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0
oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`00
0000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0
oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O
0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<0
00000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E
0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240
=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`03
0000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H0
6`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003o
ool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H0
0`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0F0>5b7`030000003oool0oooo
0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000
hG8O0>5b7`0F0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo
00<000000240=P0Q03H0700Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H0700Q03H00`000000hG8O0>5b
7`0E0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<00000
0240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo03X0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b
7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q
03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo03X0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000
003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H06`0Q
03H00`000000hG8O0>5b7`0F0>5b7`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo03X0oooo00<000000240=P0Q03H06P0Q03H00`000000Z;o[0000000G0>5b7`030000003oool0
oooo0:00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H0600Q03H20000
00<0Z;o[0P00000E0>5b7`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0
oooo00<000000240=P0Q03H05`0Q03H00`000000Z;o[0:Roj`050:Roj`030000003QLQl0hG8O0180
hG8O00<000000?ooo`3oool0X03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>P3oool00`0000008@0f
0240=P0F0240=P030000002X_n/0Z;o[00L0Z;o[00<000000>5b7`3QLQl04@3QLQl00`000000oooo
0?ooo`2P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0j0?ooo`030000000Q03H08@0f01@08@0f0P00
000;0:Roj`030000003QLQl0hG8O0100hG8O00<000000?ooo`3oool0X03oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>P3oool00`0000008@0f0240=P0C0240=P8000003@2X_n/00`000000hG8O0>5b7`0?
0>5b7`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240
=P0Q03H04P0Q03H00`000000Z;o[0:Roj`0>0:Roj`8000003`3QLQl00`000000oooo0?ooo`2P0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0j0?ooo`030000000Q03H08@0f01008@0f0P00000C0:Roj`03
0000003QLQl0hG8O00`0hG8O00<000000?ooo`3oool0X03oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>P3oool00`0000008@0f0240=P0?0240=P8000005@2X_n/00`000000hG8O0>5b7`0<0>5b7`030000
003oool0oooo09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H03P0Q
03H00`000000Z;o[0:Roj`0F0:Roj`030000003QLQl0hG8O00/0hG8O00<000000?ooo`3oool0W`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>P3oool00`0000008@0f0240=P0<0240=P8000006P2X_n/2
000000/0hG8O00<000000?ooo`3oool0W`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>P3oool00`00
00008@0f0240=P0;0240=P8000007@2X_n/00`000000hG8O0>5b7`080>5b7`030000003oool0oooo
09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H02P0Q03H2000001l0
Z;o[00<000000>5b7`3QLQl01`3QLQl00`000000oooo0?ooo`2O0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0k0?ooo`030000000Q03H08@0f00L08@0f0P00000R0:Roj`030000003QLQl0hG8O00H0hG8O
00<000000?ooo`3oool0W`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`0000008@0f0240
=P060240=P800000902X_n/2000000H0hG8O00<000000?ooo`3oool0W`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`0000008@0f0240=P050240=P8000009`2X_n/00`000000hG8O0>5b7`03
0>5b7`030000003oool0oooo09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03/0oooo00<000000240
=P0Q03H00`0Q03H3000002T0Z;o[00<000000>5b7`3QLQl00P3QLQl00`000000oooo0?ooo`2O0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000Q03H08@0f00808@0f0P00000/0:Roj`03
0000003QLQl0hG8O0080hG8O00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool0100000008@0f0240=P0Q03H2000002h0Z;o[00D000000>5b7`3QLQl0hG8O0000002P0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000Q03H0000000800000<02X_n/200000003
0>5b7`000000oooo09l0oooo002P0?ooo`0300000018>ih0B3^N00@0B3^N:00000080?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool3000000/0Z;o[900000050:Roj`800000
X03oool009<0oooo5000000B04LjWP030000003aaJ<0lLFS01<0lLFS5`00000`0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo6`00000A05E5X`030000003eb9h0mLRN0100mLRN5000002C0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS0200EDFS00<0m<NP05E5X`1EAJ<01P1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<07P1EAJ<00`3daj00EDFS05E5X`0805E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0L05E5X`030?C7X01EAJ<0
EDFS00X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS01X0EDFS00<0m<NP05E5X`1EAJ<0301EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<06@1EAJ<00`3daj00EDFS05E5X`0=05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0H05E5X`030?C7X01EAJ<0EDFS00h0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01H0EDFS00<0m<NP
05E5X`1EAJ<0401EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0_000001<03@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QRl000000P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75Xc@000004@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
2@00000800D002400000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=
2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@0
00000?o@QP3od8H0om26@02]I7/2000001H0EDFS00<0m<NP05E5X`1EAJ<04P1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003o
d8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]
I7/300d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<20000
0440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000[05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/200d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP2]I7/0@@2]I7/2000001@0EDFS00<0m<NP05E5X`1EAJ<0501EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000om26
0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<0
3@^60000002dTk@0:@2dTk@00`000000om260:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`11
0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000
002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTk@00`000000[FAk0:eTN`110:eTN`80
00004P1EAJ<00`3daj00EDFS05E5X`0F05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000
@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000401EAJ<00`3daj00EDFS05E5X`0H05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2
00000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/20000
02/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`8000003P1EAJ<00`3daj00
EDFS05E5X`0J05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2a0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1M0:eTN`030:jfg`2]I7/0[FAk0580[FAk00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0
I02]I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1_0:eTN`030:jfg`2]I7/0[FAk
0400[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:eTN`2]I7/0MP2]I7/00`2^]]l0[FAk0:eTN`0i0:eTN`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk07d0[FAk00<0[[KO
0:eTN`2]I7/0<P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[FAk0:eTN`240:eTN`030:jfg`2]I7/0[FAk02/0[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0R`2]
I7/00`2^]]l0[FAk0:eTN`0T0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75XkH00000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40
/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]
^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
01<0lLFS5`00002d0:fhhA/000004@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<F0:iUO003
0000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`0502^IG`E05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0B0?75XaL0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00E0:iUO1@0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^
IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04@3aaJ<H0:iUO0030000002]^>40
[KSQ0;80[KSQ00<000000:iUO02^IG`05P2^IG`C05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75
XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS0100lLFS6@2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01L0
[VEl4P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40[KSQ0;00[KSQ
0P00000J0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fh
h@2`0:fhh@8000006P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75XaD0[VEl00<0lLFS
0:iUO02^IG`0102^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0>0?75Xa`0[VEl00<000000:fhh@2]^>40/02]^>42000001/0[VEl401EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<03@3aaJ<M0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000L0:iUO0l0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fhh@2`0:fhh@800000
702^IG`?05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0<0?75Xah0[VEl00<000000:fhh@2]^>40/02]
^>400`000000[VEl0:iUO00L0:iUO0h0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0lLFS7`2^IG`0
0`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0[VEl3@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<02`3aaJ<O0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0:0?75Xb00[VEl00<000000:fhh@2]^>40/02]^>400`000000
[VEl0:iUO00N0:iUO0`0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3a
aJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07`2^IG`;05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00P
0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00P0lLFS8P2^IG`00`000000[KSQ0:fhh@2`0:fh
h@030000002^IG`0[VEl0200[VEl2P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01`3aaJ<S0:iUO003
0000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08@2^IG`905E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00Q0:iUO0T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^
IG`0[VEl00D0[VEl00<0EDFS0:iUO02^IG`06P2^IG`805E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`05
0?75XbD0[VEl00<000000:fhh@2]^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@030000002]^>40
[KSQ0380[KSQ00<000000:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75
XeX0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl
02<0[VEl1`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0103aaJ<o0:iUO0030:fhh@2^IG`0[VEl01T0
[VEl00<0^iT60:fhh@2]^>40@P2]^>401@2^Igh0[KSQ0:fhh@2]^>40000003@0[VEl00<000000:iU
O02^IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0
lLFSCP2^IG`00`2]^>40[VEl0:iUO00;0:iUO0030;^I1P2]^>40[KSQ03/0[KSQ00<0[VMn0:fhh@2]
^>40202]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02@0[VEl1P1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<00`3aaJ=50:iUO0030:fhh@2^IG`0[VEl01@0[VEl00<0^iT60:fhh@2]^>40
=02]^>400`3od8L0[KSQ0:fhh@0?0:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0
9@2^IG`505E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`020?75Xed0[VEl00<0^iT60:fhh@2]^>40;@2]
^>400`3od8L0[KSQ0:fhh@0F0:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`05@2^
IG`00`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSB`2^IG`0
0`2]^>40[VEl0:iUO00?0:iUO0030;^I1P2]^>40[KSQ02H0[KSQ00<0]9>d0:fhh@2]^>407@2]^>40
0`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00@000000?75
X`3aaJ<0lLFSGP2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<00000
0:iUO02^IG`09`2^IG`305E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`1H0:iUO0030:fhh@2^IG`0[VEl
00@0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl
02L0[VEl0`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@03
0000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl
00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl
00<0EDFS0000003eb9h07P3eb9h7000009<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iU
O01O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iU
O00Y0:iUO00305E5X`000000mLRN0180mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<00000
0:iUO02^IG`0G`2^IG`00`2kV@H0000000000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`0
0`000000mLRN0?G8WP040?G8WPd00000YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<00006000000000000I`00002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3o
ool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]
^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]
^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool0
0;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`00
00H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0
[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000
oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<0
00000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fh
hP1P0:fhhP030000003oool0oooo0;L0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h
0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]
^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP03
0000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3o
ool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0
oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000
[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0
[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo
002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<00000
0?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`03
0000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]
^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0
^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80
[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>80
0`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0
oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo
0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<00000
0:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N
0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?oo
o`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80
G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0
^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool2000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>80
0`000000oooo0?ooo`0=0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>80
0`000000oooo0?ooo`2i0?ooo`00^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ0000
0;/0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3o
ool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00k@3ooolo
000000T040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Qcl00000k@3oool0
0>d0oooo00<0000008<51P231@H0?0231@H9010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01P3od8Lo08<51P030000003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D603d0
P`D6200@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700D0om27@0231@H00`000000
oooo0?ooo`3[0?ooo`00k@3oool00`000000P`D608<51P0n08<51PL040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`040?o@Qd40P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0
000008<51P231@H0?`231@H6010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00`3o
d8M208<51P030000003oool0oooo0>/0oooo003/0?ooo`03000000231@H0P`D60480P`D6100@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om270080om27@`231@H00`000000oooo0?ooo`3[
0?ooo`00k03oool00`000000P`D608<51P1208<51P@040f700<000000;BC]02dTk@04P2dTk@01000
0000om270?o@Q`3od8M508<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D6
04<0P`D60`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2704H0P`D600<000000?oo
o`3oool0jP3oool00>`0oooo00<0000008<51P231@H0A0231@H2010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`231@H0AP231@H00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000P`D6
08<51P1508<51P03010=Q`000000]9>d01<0]9>d00<0000008<51P231@H0AP231@H00`000000oooo
0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003Y0?ooo`@00000YP2aLhh00`000000oooo0?ooo`3Z
0?ooo`00j03oool01@000000H@Y1064:@@1Q2T4000000:H0/G>>00<000000?ooo`3oool0jP3oool0
0>P0oooo00D00000064:@@1Q2T40H@Y10000002V0;5cSP030000003oool0oooo0>X0oooo003W0?oo
o`030000001Q2T40H@Y10080H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?oo
o`00i`3oool00`000000H@Y1064:@@02064:@@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3o
ool0jP3oool00>H0oooo00<00000064:@@1Q2T400`1Q2T400`000000/G>>0;5cSP2T0;5cSP030000
003oool0oooo0>X0oooo003U0?ooo`030000001Q2T40H@Y100@0H@Y100<000000;5cSP2aLhh0Y02a
Lhh00`000000oooo0?ooo`3Z0?ooo`00i@3oool00`000000H@Y1064:@@04064:@@030000002aLhh0
/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>@0oooo00<00000064:@@1Q2T401@1Q2T400`00
0000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003T0?ooo`030000001Q2T40H@Y100D0
H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00h`3oool00`000000H@Y1
064:@@06064:@@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>80oooo00<0
0000064:@@1Q2T401`1Q2T400`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003R
0?ooo`030000001Q2T40H@Y100L0H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z
0?ooo`00h@3oool00`000000H@Y1064:@@08064:@@030000002aLhh0/G>>0:@0/G>>00<000000?oo
o`3oool0jP3oool00>40oooo00<00000064:@@1Q2T40201Q2T400`000000/G>>0;5cSP2T0;5cSP03
0000003oool0oooo0>X0oooo003P0?ooo`L000001@1Q2T400`000000/G>>0;5cSP2T0;5cSP030000
003oool0oooo0>X0oooo003Q0?ooo`0300000012S>d0@Xc]00<0@Xc]1P00002V0;5cSP030000003o
ool0oooo0>X0oooo003Q0?ooo`8000002@12S>d00`000000/G>>0;5cSP2T0;5cSP030000003oool0
oooo0>X0oooo003R0?ooo`0300000012S>d0@Xc]00L0@Xc]00<000000;5cSP2aLhh0Y02aLhh00`00
0000oooo0?ooo`3Z0?ooo`00h`3oool00`000000@Xc]04:<k@0604:<k@030000002aLhh0/G>>0:@0
/G>>00<000000?ooo`3oool0jP3oool00>@0oooo00<0000004:<k@12S>d01@12S>fX00000>`0oooo
003T0?ooo`8000001P12S>d00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003U
0?ooo`0300000012S>d0@Xc]00@0@Xc]00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z
0?ooo`00iP3oool00`000000@Xc]04:<k@0304:<k@030000002`/=L0/;3G0:@0/;3G00<000000?oo
o`3oool0jP3oool00>L0oooo00<0000004:<k@12S>d00P12S>d00`000000/;3G0;2`e`2T0;2`e`03
0000003oool0oooo0>X0oooo003W0?ooo`8000000`12S>d00`000000/;3G0;2`e`2T0;2`e`030000
003oool0oooo0>X0oooo003X0?ooo`0500000012S>d0@Xc]04:<k@000000YP2`/=L00`000000oooo
0?ooo`3Z0?ooo`00j@3oool400000:H0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<00000
0;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`
e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3o
ool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03o
ool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0
/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`00
0000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0
oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<0
00000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T
0;2`e`030000003oool0oooo0>X0oooo003/0?ooojP00000k03oool00>`0oooo00<0000005K8m@1F
b?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000E/Se05K8m@2T05K8m@030000
003oool0oooo0>X0oooo003]0?ooo`030000001Fb?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3o
ool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?ooo`00k@3ooonV0000
0>d0oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.67497 .40982 m .64206 .41337 L .64206 .24609 L p .455 .372 .673 r
F P
0 g
s
.64206 .24609 m .67497 .24132 L .67497 .40982 L p .455 .372 .673 r
F P
0 g
s
.64206 .41337 m .60403 .41234 L .60403 .24471 L p .762 .622 .705 r
F P
0 g
s
.60403 .24471 m .64206 .24609 L .64206 .41337 L p .762 .622 .705 r
F P
0 g
s
.67497 .40982 m .67497 .24132 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.6838 .40365 m .68128 .40541 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.68128 .40541 m .67497 .40982 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.68795 .26519 m .69297 .25307 L p .68128 .23784 L .627 .512 .703 r
F P
0 g
s
.64206 .24609 m .67497 .24132 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.63385 .17608 m .67018 .23593 L .67947 .23548 L .627 .512 .703 r
F
.65153 .23683 m .64206 .24609 L .6706 .23591 L .289 .763 .934 r
F
.68128 .27508 m .68795 .26519 L p .68128 .25421 L .627 .512 .703 r
F P
0 g
s
.68128 .25421 m .68795 .26519 L .68128 .23784 L .627 .512 .703 r
F
.67497 .24132 m .68128 .23539 L p .68128 .27508 L 0 0 .305 r
F P
0 g
s
.67749 .28759 m .68128 .27508 L .68128 .35732 L 0 0 .305 r
F
.67497 .24132 m .68128 .27508 L .67749 .28759 L F
.68128 .27508 m .68795 .26519 L .68724 .26433 L p .839 .983 .698 r
F P
0 g
s
.68724 .26433 m .68527 .26192 L p .6838 .26677 L .839 .983 .698 r
F P
0 g
s
.68128 .27508 m .68724 .26433 L .6838 .26677 L .839 .983 .698 r
F
.68128 .35732 m .68302 .27163 L .6838 .40365 L 0 0 .305 r
F
.69297 .25307 m .69545 .24026 L p .68128 .2255 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .67947 .23548 L .68128 .2255 L .627 .512 .703 r
F
.67947 .23548 m .68128 .23539 L .68128 .2255 L F
.68128 .23784 m .69297 .25307 L .68128 .2255 L F
.63385 .17608 m .66201 .23632 L .67018 .23593 L F
.69545 .24026 m .69525 .22733 L p .63385 .17608 L F P
0 g
s
.68961 .24884 m .6921 .23595 L p .68698 .23061 L .627 .512 .703 r
F P
0 g
s
.58855 .23114 m .57468 .24054 L .58106 .24023 L .627 .512 .703 r
F
.58855 .23987 m .60403 .24471 L p .62465 .23813 L .289 .763 .934 r
F P
0 g
s
.57479 .24786 m .57759 .26023 L p .58855 .24384 L .627 .512 .703 r
F P
0 g
s
.58855 .23987 m .60403 .24471 L p .59069 .28168 L .985 .804 .58 r
F P
0 g
s
.58855 .27908 m .59069 .28168 L .58855 .28763 L .985 .804 .58 r
F
.58855 .23987 m .59069 .28168 L .58855 .27908 L F
.58288 .27163 m .58855 .27908 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.58855 .23114 m .57479 .24786 L .58855 .24384 L .627 .512 .703 r
F
.57759 .26023 m .58288 .27163 L p .63385 .17608 L F P
0 g
s
.60403 .24471 m .60403 .41234 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.60403 .24471 m .64206 .24609 L p .65153 .23683 L .289 .763 .934 r
F P
0 g
s
.62465 .23813 m .60403 .24471 L .65153 .23683 L .289 .763 .934 r
F
.58288 .27163 m .59043 .28155 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58238 .23794 m .58855 .23987 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.58238 .40731 m .58238 .27287 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.57759 .26023 m .58023 .26593 L p .58012 .26886 L .765 .382 0 r
F P
0 g
s
.58023 .26593 m .58288 .27163 L .58159 .27034 L p .765 .382 0 r
F P
0 g
s
.58159 .27034 m .58012 .26886 L p .58023 .26593 L .765 .382 0 r
F P
0 g
s
.58238 .27287 m .58238 .27159 L p .58794 .28277 L .985 .804 .58 r
F P
0 g
s
.58288 .27163 m .58414 .27373 L .58238 .27159 L .613 .149 0 r
F
.58012 .26886 m .58159 .27034 L p .58238 .27159 L F P
0 g
s
.58159 .27034 m .58288 .27163 L p .58238 .27159 L .613 .149 0 r
F P
0 g
s
.58238 .27159 m .58238 .23794 L p .5873 .27756 L .985 .804 .58 r
F P
0 g
s
.63385 .17608 m .58855 .23114 L .58855 .24384 L .627 .512 .703 r
F
.59043 .28155 m .59993 .28958 L p .63385 .17608 L F P
0 g
s
.59993 .28958 m .61096 .29535 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.61096 .29535 m .62304 .29861 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.62304 .29861 m .63566 .29921 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.67124 .28531 m .6806 .2761 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.66031 .29242 m .67124 .28531 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.64827 .29712 m .66031 .29242 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63566 .29921 m .64827 .29712 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58238 .23794 m .58855 .23987 L p .62082 .23383 L .289 .763 .934 r
F P
0 g
s
.60478 .23461 m .58238 .23794 L .62082 .23383 L .289 .763 .934 r
F
.5873 .27756 m .58794 .28277 L .58238 .27159 L .985 .804 .58 r
F
.59043 .28155 m .58643 .27755 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.58855 .27908 m .59043 .28155 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.64121 .23284 m .58855 .23987 L .62465 .23813 L .289 .763 .934 r
F
.62082 .23383 m .58855 .23987 L .64121 .23284 L F
.58643 .27755 m .59599 .28562 L p .61132 .23429 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .58855 .22117 L .58855 .23114 L .627 .512 .703 r
F
.57703 .22234 m .5746 .23505 L p .63385 .17608 L F P
0 g
s
.58197 .2103 m .57703 .22234 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58922 .19943 m .58197 .2103 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.59846 .19022 m .58922 .19943 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.6093 .18307 m .59846 .19022 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .62127 .17828 L .6093 .18307 L p .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .62127 .17828 L .61746 .17359 L p .405 .837 .952 r
F P
0 g
s
.61746 .17359 m .63012 .17137 L .63385 .17608 L p .405 .837 .952 r
F P
0 g
s
.63012 .17137 m .60408 .23464 L .61132 .23429 L .627 .512 .703 r
F
.5746 .23505 m .57468 .24054 L p .58855 .23114 L F P
0 g
s
.58855 .22117 m .5746 .23505 L .58855 .23114 L .627 .512 .703 r
F
.63012 .17137 m .58454 .22681 L .58729 .23546 L F
.58454 .22681 m .57701 .23596 L .58454 .23559 L F
.58454 .22681 m .58454 .23559 L .58729 .23546 L F
.58238 .23794 m .58238 .27159 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.58902 .23538 m .58872 .237 L p .60478 .23461 L .289 .763 .934 r
F P
0 g
s
.58454 .23559 m .58238 .23794 L p .58454 .23762 L .289 .763 .934 r
F P
0 g
s
.58454 .23559 m .58238 .23794 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.58238 .27159 m .58238 .27287 L p .58255 .27188 L 0 0 .269 r
F P
0 g
s
.58414 .27373 m .58643 .27755 L .58401 .27421 L .613 .149 0 r
F
.58238 .27159 m .58401 .27421 L .58012 .26886 L F
.58414 .27373 m .58401 .27421 L .58238 .27159 L F
.58794 .28277 m .58855 .28763 L .58238 .27287 L .985 .804 .58 r
F
.58788 .28041 m .58238 .27287 L .58749 .2894 L 0 0 .269 r
F
.59618 .23503 m .58454 .24584 L .58454 .25686 L .627 .512 .703 r
F
.63012 .17137 m .58729 .23546 L .59618 .23503 L F
.58729 .23546 m .58454 .23959 L .59618 .23503 L F
.57479 .24786 m .57759 .26023 L .57351 .25609 L p .87 .585 .06 r
F P
0 g
s
.58454 .23959 m .57351 .25609 L .58454 .24584 L .627 .512 .703 r
F
.58454 .23959 m .58454 .24584 L .59618 .23503 L F
.63012 .17137 m .58454 .25686 L .58643 .27755 L F
.58255 .27188 m .58238 .27287 L .58454 .27583 L 0 0 .269 r
F
.58255 .27188 m .58454 .27583 L .58454 .27506 L F
.57883 .26756 m .58012 .26886 L p .58454 .27494 L .613 .149 0 r
F P
0 g
s
.58454 .27494 m .58643 .27755 L .57883 .26756 L .613 .149 0 r
F
.58454 .26073 m .58255 .27188 L .58454 .27506 L 0 0 .269 r
F
.58454 .26073 m .58238 .27159 L .58255 .27188 L F
.58454 .25981 m .58238 .27159 L .58454 .26073 L F
.58012 .26886 m .57883 .26756 L p .57859 .26613 L .765 .382 0 r
F P
0 g
s
.57759 .26023 m .58012 .26886 L .57859 .26613 L .765 .382 0 r
F
.57883 .26756 m .58454 .27506 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .27506 m .58643 .27755 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .27506 m .58454 .27583 L .58788 .28041 L 0 0 .269 r
F
.59599 .28562 m .60708 .29142 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.60708 .29142 m .61925 .2947 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.65637 .2321 m .62465 .23813 L .65153 .23683 L .289 .763 .934 r
F
.64121 .23284 m .62465 .23813 L .65637 .2321 L F
.61925 .2947 m .63195 .2953 L p .63103 .23333 L .627 .512 .703 r
F P
0 g
s
.63012 .17137 m .62463 .23364 L .63103 .23333 L .627 .512 .703 r
F
.62463 .23364 m .61925 .2947 L .63103 .23333 L F
.68302 .27163 m .6838 .23303 L .6838 .40365 L 0 0 .305 r
F
.68128 .23539 m .6838 .23303 L p .68128 .35732 L F P
0 g
s
.6806 .2761 m .68128 .27508 L p .67018 .23593 L .627 .512 .703 r
F P
0 g
s
.67018 .23593 m .68128 .27508 L .68128 .25421 L .627 .512 .703 r
F
.66201 .23632 m .6806 .2761 L .67018 .23593 L F
.67497 .24132 m .68128 .23539 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.67947 .23548 m .68128 .25421 L .68128 .23784 L .627 .512 .703 r
F
.67018 .23593 m .68128 .25421 L .67947 .23548 L F
.6838 .26677 m .6838 .23303 L p .67904 .27016 L .989 .807 .569 r
F P
0 g
s
.6671 .23158 m .65153 .23683 L .6706 .23591 L .289 .763 .934 r
F
.65637 .2321 m .65153 .23683 L .6671 .23158 L F
.63012 .17137 m .65845 .232 L .66668 .2316 L .627 .512 .703 r
F
.65845 .232 m .67716 .27203 L .66668 .2316 L F
.6838 .23303 m .67785 .23106 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.68128 .23539 m .6838 .23303 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.67947 .23548 m .68128 .23784 L .68128 .23539 L .627 .512 .703 r
F
.67124 .28531 m .6806 .2761 L .67716 .27203 L p .756 .993 .8 r
F P
0 g
s
.6838 .23303 m .67785 .23106 L p .67785 .27101 L .989 .807 .569 r
F P
0 g
s
.67716 .27203 m .6806 .2761 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.67785 .27101 m .67716 .27203 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.67904 .27016 m .67785 .27101 L .67785 .27946 L .989 .807 .569 r
F
.6838 .23303 m .67785 .27101 L .67904 .27016 L F
.68456 .26105 m .67785 .27101 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.6671 .23158 m .6706 .23591 L .67785 .23106 L .289 .763 .934 r
F
.68456 .26105 m .68961 .24884 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.66775 .2813 m .67716 .27203 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .65637 .2321 L .6671 .23158 L .289 .763 .934 r
F
.66775 .2813 m .65674 .28846 L .66031 .29242 L p .649 .969 .874 r
F P
0 g
s
.66031 .29242 m .67124 .28531 L .66775 .2813 L p .649 .969 .874 r
F P
0 g
s
.67716 .27203 m .66775 .2813 L .67124 .28531 L p .756 .993 .8 r
F P
0 g
s
.65674 .28846 m .66775 .2813 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .6626 .39843 L p .67785 .27946 L .989 .807 .569 r
F P
0 g
s
.67716 .27203 m .67785 .27101 L p .66668 .2316 L .627 .512 .703 r
F P
0 g
s
.66668 .2316 m .67785 .27101 L .67785 .25 L .627 .512 .703 r
F
.64649 .17657 m .63385 .17608 L .63012 .17137 L p .236 .716 .934 r
F P
0 g
s
.65864 .17973 m .64649 .17657 L .63385 .17608 L p .627 .512 .703 r
F P
0 g
s
.66977 .18544 m .65864 .17973 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.67937 .19344 m .66977 .18544 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.68703 .20339 m .67937 .19344 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.69241 .21486 m .68703 .20339 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.69525 .22733 m .69241 .21486 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63012 .17137 m .67602 .23115 L .68698 .23061 L .627 .512 .703 r
F
.67602 .23115 m .68961 .24884 L .68698 .23061 L F
.67785 .23106 m .6626 .22601 L p .6671 .23158 L .289 .763 .934 r
F P
0 g
s
.67785 .23106 m .6626 .22601 L p .67785 .27946 L .989 .807 .569 r
F P
0 g
s
.67785 .27101 m .68456 .26105 L p .67785 .25 L .627 .512 .703 r
F P
0 g
s
.64463 .29319 m .65674 .28846 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .64121 .23284 L .65637 .2321 L .289 .763 .934 r
F
.63195 .2953 m .64463 .29319 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.59008 .22957 m .58902 .23538 L p .6626 .22601 L .289 .763 .934 r
F P
0 g
s
.6626 .22601 m .58902 .23538 L .60478 .23461 L .289 .763 .934 r
F
.60408 .23464 m .58643 .27755 L .61132 .23429 L .627 .512 .703 r
F
.59599 .28562 m .58643 .27755 L .59043 .28155 L p 0 .093 .572 r
F P
0 g
s
.59008 .22957 m .58454 .26073 L .58788 .28041 L 0 0 .269 r
F
.58454 .26073 m .58454 .27506 L .58788 .28041 L F
.59008 .22957 m .58454 .25981 L .58454 .26073 L F
.57883 .26756 m .57351 .25609 L .57759 .26023 L p .765 .382 0 r
F P
0 g
s
.57351 .25609 m .57883 .26756 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .24584 m .57351 .25609 L .58454 .25686 L .627 .512 .703 r
F
.57468 .24054 m .57479 .24786 L p .58106 .24023 L F P
0 g
s
.5746 .23505 m .57479 .24786 L .57069 .24364 L p .927 .748 .265 r
F P
0 g
s
.57351 .25609 m .57069 .24364 L .57479 .24786 L p .87 .585 .06 r
F P
0 g
s
.57069 .24364 m .57351 .25609 L p .58729 .23546 L .627 .512 .703 r
F P
0 g
s
.57701 .23596 m .57069 .24364 L .58729 .23546 L .627 .512 .703 r
F
.59008 .22957 m .58454 .23559 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.6626 .22601 m .62082 .23383 L .64121 .23284 L .289 .763 .934 r
F
.6626 .22601 m .60478 .23461 L .62082 .23383 L F
.58238 .27287 m .58238 .40731 L p .58749 .2894 L 0 0 .269 r
F P
0 g
s
.60403 .41234 m .58855 .40874 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.58855 .40874 m .58238 .40731 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.6626 .39843 m .6838 .40365 L .6838 .26677 L p .989 .807 .569 r
F P
0 g
s
.6806 .2761 m .68128 .27508 L p .68456 .26105 L .839 .983 .698 r
F P
0 g
s
.68527 .26192 m .68456 .26105 L p .68128 .27508 L .839 .983 .698 r
F P
0 g
s
.67904 .27016 m .6626 .39843 L .6838 .26677 L .989 .807 .569 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64206 .41337 m .67497 .40982 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.60403 .41234 m .64206 .41337 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.67497 .40982 m .6838 .40365 L .6626 .39843 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.58238 .40731 m .59008 .40107 L .59008 .22957 L p 0 0 .269 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58238 .40731 m .60403 .41234 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.4115 .40982 m .3805 .41337 L .3805 .24609 L p .439 .358 .669 r
F P
0 g
s
.3805 .41337 m .34192 .41234 L .34192 .24471 L p .761 .621 .705 r
F P
0 g
s
.34192 .24471 m .3805 .24609 L .3805 .41337 L p .761 .621 .705 r
F P
0 g
s
.63566 .29921 m .64827 .29712 L .64463 .29319 L p .365 .821 .93 r
F P
0 g
s
.65674 .28846 m .64463 .29319 L .64827 .29712 L p .518 .912 .918 r
F P
0 g
s
.64827 .29712 m .66031 .29242 L .65674 .28846 L p .518 .912 .918 r
F P
0 g
s
.62344 .39734 m .6626 .39843 L .6626 .22601 L p .763 .623 .705 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6769 .93127 m .66235 .92198 L .67668 .91427 L closepath p .783 .577 .623 r
F P
0 g
s
.68266 .91 m .70188 .89629 L p .69105 .91145 L 0 0 .35 r
F P
0 g
s
.70188 .89629 m .67668 .91427 L p .68658 .90477 L .407 .835 .68 r
F P
0 g
s
.69446 .90034 m .70188 .89629 L .68658 .90477 L .407 .835 .68 r
F
.697 .89891 m .70188 .89629 L p .68691 .90446 L F P
0 g
s
.70188 .89629 m .70189 .89663 L p .6769 .93127 L 0 0 .35 r
F P
0 g
s
.68289 .9271 m .6769 .93127 L p .70189 .89663 L 0 0 .35 r
F P
0 g
s
.68693 .90527 m .697 .89891 L p .69937 .90066 L .678 .976 .889 r
F P
0 g
s
.69507 .90756 m .69937 .90066 L .71704 .91374 L .678 .976 .889 r
F
.68693 .90527 m .69937 .90066 L .69507 .90756 L F
.697 .89891 m .70188 .89629 L .70189 .89663 L p .785 .577 .62 r
F P
0 g
s
.70227 .89601 m .70254 .89632 L p .697 .89891 L .678 .976 .889 r
F P
0 g
s
.70254 .89632 m .71704 .91374 L p .697 .89891 L .678 .976 .889 r
F P
0 g
s
.71704 .91374 m .7023 .92303 L .68693 .90527 L p .678 .976 .889 r
F P
0 g
s
.69249 .9117 m .7023 .92303 L p .7023 .91346 L 0 .34 .752 r
F P
0 g
s
.7023 .9134 m .70213 .91337 L .7023 .91346 L 0 .34 .752 r
F
.70213 .91337 m .69249 .9117 L .7023 .91346 L F
.70189 .89663 m .70214 .91371 L .68289 .9271 L p 0 0 .35 r
F P
0 g
s
.70199 .91329 m .69717 .91031 L .69824 .90248 L .785 .577 .62 r
F
.69717 .91031 m .69708 .90434 L .69824 .90248 L F
.69717 .91053 m .68693 .90527 L .697 .89891 L p .614 .44 .623 r
F P
0 g
s
.68691 .90446 m .69446 .90034 L .68658 .90477 L .407 .835 .68 r
F
.6769 .93127 m .67668 .91427 L .68266 .91 L p 0 0 .35 r
F P
0 g
s
.69105 .91145 m .6769 .93127 L .68266 .91 L 0 0 .35 r
F
.67668 .91427 m .66235 .92198 L .68645 .90472 L p .407 .835 .68 r
F P
0 g
s
.68691 .90446 m .67668 .91427 L .68645 .90472 L .407 .835 .68 r
F
.66668 .894 m .6965 .86458 L p .69717 .91053 L .703 .511 .626 r
F P
0 g
s
.68645 .90472 m .68722 .90416 L p .68691 .90446 L .407 .835 .68 r
F P
0 g
s
.65581 .90472 m .66668 .894 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.66235 .92198 m .6769 .93127 L .70214 .91371 L p .132 .507 .91 r
F P
0 g
s
.68722 .90416 m .697 .89891 L p .68733 .90423 L .407 .835 .68 r
F P
0 g
s
.68722 .90416 m .68733 .90423 L p .68691 .90446 L .407 .835 .68 r
F P
0 g
s
.69717 .91053 m .68722 .90416 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.68693 .90527 m .69249 .9117 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.69717 .91053 m .68693 .90527 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.7023 .91331 m .70193 .91325 L .7023 .9134 L 0 .34 .752 r
F
.70193 .91325 m .69249 .9117 L .70213 .91337 L F
.70199 .91329 m .697 .89891 L .70213 .91337 L .785 .577 .62 r
F
.70193 .91325 m .70213 .91337 L .7023 .9134 L 0 .34 .752 r
F
.70189 .89663 m .70213 .91337 L p .697 .89891 L .785 .577 .62 r
F P
0 g
s
.70213 .91337 m .70214 .91371 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.70192 .91311 m .69249 .9117 L .7023 .91331 L 0 .34 .752 r
F
.70214 .91371 m .69717 .91053 L p .66235 .92198 L .132 .507 .91 r
F P
0 g
s
.69717 .91053 m .68722 .90416 L .68645 .90472 L p .132 .507 .91 r
F P
0 g
s
.68645 .90472 m .66235 .92198 L p .69717 .91053 L .132 .507 .91 r
F P
0 g
s
.69442 .90861 m .68722 .90416 L .69705 .90266 L .785 .577 .62 r
F
.69708 .90434 m .69705 .90266 L .69824 .90248 L F
.69442 .90861 m .69705 .90266 L .69708 .90434 L F
.68722 .90416 m .697 .89891 L p .69824 .90248 L F P
0 g
s
.70214 .91371 m .69717 .91053 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.71731 .93075 m .7023 .92303 L .71704 .91374 L closepath p .616 .444 .625 r
F P
0 g
s
.7023 .92303 m .71731 .93075 L .70253 .91344 L p 0 .34 .752 r
F P
0 g
s
.69717 .91053 m .6965 .86458 L .70201 .87824 L .703 .511 .626 r
F
.71731 .93075 m .71704 .91374 L .70227 .89601 L p .908 .711 .21 r
F P
0 g
s
.70228 .89627 m .71731 .93075 L .70227 .89601 L .908 .711 .21 r
F
.69717 .91053 m .70201 .87824 L .70253 .91344 L .703 .511 .626 r
F
.697 .89891 m .70204 .89573 L .70227 .89601 L p .678 .976 .889 r
F P
0 g
s
.70204 .89573 m .7023 .91316 L .70253 .91344 L p .908 .711 .21 r
F P
0 g
s
.70253 .91344 m .71731 .93075 L p .70228 .89627 L .908 .711 .21 r
F P
0 g
s
.70204 .89573 m .70253 .91344 L .70228 .89627 L .908 .711 .21 r
F
.7023 .91331 m .7023 .92303 L .70253 .91344 L 0 .34 .752 r
F
.69767 .94509 m .69717 .91053 L .70253 .91344 L .703 .511 .626 r
F
.72002 .92292 m .70293 .93987 L p .70253 .91344 L F P
0 g
s
.70293 .93987 m .69767 .94509 L p .70253 .91344 L .703 .511 .626 r
F P
0 g
s
.70253 .91344 m .70201 .87824 L .72002 .92292 L .703 .511 .626 r
F
.70227 .89601 m .70204 .89573 L p .70228 .89627 L .908 .711 .21 r
F P
0 g
s
.70253 .91344 m .7023 .91316 L p .7023 .91331 L 0 .34 .752 r
F P
0 g
s
.6965 .86458 m .73836 .90472 L .72002 .92292 L p .703 .511 .626 r
F P
0 g
s
.7023 .91316 m .70192 .91311 L .7023 .91331 L 0 .34 .752 r
F
.69767 .94509 m .66694 .91545 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.66694 .91545 m .65581 .90472 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.69767 .94509 m .66668 .894 L .69717 .91053 L .703 .511 .626 r
F
.7023 .91316 m .69717 .91053 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.7023 .91316 m .69717 .91053 L p .697 .89891 L .614 .44 .623 r
F P
0 g
s
.69717 .91031 m .69442 .90861 L .69708 .90434 L .785 .577 .62 r
F
.697 .89891 m .70204 .89573 L .70204 .89607 L p .614 .44 .623 r
F P
0 g
s
.70204 .89607 m .7023 .91316 L p .697 .89891 L .614 .44 .623 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.3805 .24609 m .4115 .24132 L .4115 .40982 L p .439 .358 .669 r
F P
0 g
s
.31082 .23505 m .3109 .24054 L p .32449 .23114 L .626 .511 .703 r
F P
0 g
s
.3109 .24054 m .311 .24786 L p .31716 .24023 L .626 .511 .703 r
F P
0 g
s
.32449 .23114 m .3109 .24054 L .31716 .24023 L .626 .511 .703 r
F
.32449 .23987 m .34192 .24471 L p .3599 .23813 L .289 .763 .934 r
F P
0 g
s
.311 .24786 m .31375 .26023 L p .32449 .24384 L .626 .511 .703 r
F P
0 g
s
.32449 .23987 m .34192 .24471 L p .32691 .28168 L .974 .795 .601 r
F P
0 g
s
.32449 .27908 m .32691 .28168 L .32449 .28763 L .974 .795 .601 r
F
.32449 .23987 m .32691 .28168 L .32449 .27908 L F
.31893 .27163 m .32449 .27908 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.32449 .23114 m .311 .24786 L .32449 .24384 L .626 .511 .703 r
F
.31375 .26023 m .31893 .27163 L p .36892 .17608 L F P
0 g
s
.31893 .27163 m .32634 .28155 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.31755 .23794 m .32449 .23987 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.31755 .40731 m .31755 .27287 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.31375 .26023 m .31634 .26593 L p .31502 .26886 L .841 .454 0 r
F P
0 g
s
.31634 .26593 m .31893 .27163 L .31711 .27034 L p .841 .454 0 r
F P
0 g
s
.31711 .27034 m .31502 .26886 L p .31634 .26593 L .841 .454 0 r
F P
0 g
s
.31755 .27287 m .31755 .27159 L p .32382 .28277 L .974 .795 .601 r
F P
0 g
s
.31893 .27163 m .31954 .27373 L .31755 .27159 L .698 .226 0 r
F
.31502 .26886 m .31711 .27034 L p .31755 .27159 L F P
0 g
s
.31711 .27034 m .31893 .27163 L p .31755 .27159 L .698 .226 0 r
F P
0 g
s
.31755 .27159 m .31755 .23794 L p .32309 .27756 L .974 .795 .601 r
F P
0 g
s
.36892 .17608 m .32449 .23114 L .32449 .24384 L .626 .511 .703 r
F
.34192 .24471 m .34192 .41234 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.34192 .24471 m .3805 .24609 L p .38626 .23683 L .289 .763 .934 r
F P
0 g
s
.3599 .23813 m .34192 .24471 L .38626 .23683 L .289 .763 .934 r
F
.32634 .28155 m .33565 .28958 L p .3506 .23859 L .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .34355 .23893 L .3506 .23859 L .626 .511 .703 r
F
.34355 .23893 m .32634 .28155 L .3506 .23859 L F
.34647 .29535 m .35833 .29861 L p .36892 .17608 L F P
0 g
s
.35833 .29861 m .3707 .29921 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3805 .24609 m .4115 .24132 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.38626 .23683 m .3805 .24609 L .40496 .23591 L .289 .763 .934 r
F
.4115 .40982 m .4115 .24132 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41701 .40365 m .41544 .40541 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41544 .40541 m .4115 .40982 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41544 .27508 m .42198 .26519 L p .41544 .25421 L .626 .511 .703 r
F P
0 g
s
.41544 .23784 m .42691 .25307 L .41947 .23519 L .626 .511 .703 r
F
.41544 .23539 m .41947 .23519 L .41544 .2255 L F
.41544 .23784 m .41947 .23519 L .41544 .23539 L F
.4115 .24132 m .41544 .23539 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.4115 .24132 m .41544 .23539 L p .41544 .27508 L 0 0 .202 r
F P
0 g
s
.41307 .28759 m .41544 .27508 L .41544 .35732 L 0 0 .202 r
F
.4115 .24132 m .41544 .27508 L .41307 .28759 L F
.41544 .27508 m .42198 .26519 L .42091 .26433 L p .872 .991 .74 r
F P
0 g
s
.42091 .26433 m .41793 .26192 L p .41701 .26677 L .872 .991 .74 r
F P
0 g
s
.41544 .27508 m .42091 .26433 L .41701 .26677 L .872 .991 .74 r
F
.41544 .35732 m .41655 .26929 L .41701 .40365 L 0 0 .202 r
F
.42198 .26519 m .42691 .25307 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42181 .24884 m .4186 .25675 L p .42198 .26519 L .929 .953 .625 r
F P
0 g
s
.41655 .26929 m .41701 .23303 L .41701 .26906 L 0 0 .202 r
F
.41544 .23539 m .41701 .23303 L p .41544 .35732 L F P
0 g
s
.41477 .2761 m .41544 .27508 L p .40455 .23593 L .626 .511 .703 r
F P
0 g
s
.40455 .23593 m .41544 .27508 L .41544 .25421 L .626 .511 .703 r
F
.39654 .23632 m .41477 .2761 L .40455 .23593 L F
.40559 .28531 m .41477 .2761 L p .36892 .17608 L F P
0 g
s
.41701 .26677 m .41701 .23303 L p .41162 .27016 L .979 .799 .592 r
F P
0 g
s
.4186 .25675 m .41685 .26105 L .41793 .26192 L p .929 .953 .625 r
F P
0 g
s
.41793 .26192 m .42198 .26519 L p .4186 .25675 L .929 .953 .625 r
F P
0 g
s
.41656 .27254 m .41701 .26906 L .41701 .40365 L 0 0 .202 r
F
.41655 .26929 m .41701 .26906 L .41656 .27254 L F
.393 .39843 m .41701 .40365 L .41701 .26677 L p .979 .799 .592 r
F P
0 g
s
.41477 .2761 m .41544 .27508 L p .41685 .26105 L .872 .991 .74 r
F P
0 g
s
.41793 .26192 m .41685 .26105 L p .41544 .27508 L .872 .991 .74 r
F P
0 g
s
.40559 .28531 m .41477 .2761 L .40959 .27203 L p .788 .999 .829 r
F P
0 g
s
.40959 .27203 m .41477 .2761 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41496 .2372 m .41544 .23784 L .41544 .23623 L .626 .511 .703 r
F
.41496 .2372 m .41544 .23623 L .41544 .2255 L F
.36892 .17608 m .41496 .2372 L .41544 .2255 L F
.39487 .29242 m .40559 .28531 L p .36892 .17608 L F P
0 g
s
.41701 .23303 m .41027 .24673 L .41162 .27016 L .979 .799 .592 r
F
.36892 .17608 m .39654 .23632 L .40455 .23593 L .626 .511 .703 r
F
.36892 .17608 m .32449 .22117 L .32449 .23114 L F
.3132 .22234 m .31082 .23505 L p .36892 .17608 L F P
0 g
s
.31805 .2103 m .3132 .22234 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.32516 .19943 m .31805 .2103 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.33422 .19022 m .32516 .19943 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.34485 .18307 m .33422 .19022 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.33565 .28958 m .34647 .29535 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .35659 .17828 L .34485 .18307 L p .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .35659 .17828 L .35106 .17359 L p .414 .84 .957 r
F P
0 g
s
.35106 .17359 m .36347 .17137 L .36892 .17608 L p .414 .84 .957 r
F P
0 g
s
.38306 .29712 m .39487 .29242 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3707 .29921 m .38306 .29712 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.36347 .17137 m .40848 .23115 L .41027 .2211 L .625 .51 .703 r
F
.41701 .23303 m .41027 .23106 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.39973 .23158 m .40496 .23591 L .41027 .23106 L .289 .763 .934 r
F
.40848 .23115 m .41027 .23352 L .41027 .23106 L .625 .51 .703 r
F
.40848 .23115 m .41027 .23106 L .41027 .2211 L F
.41544 .23539 m .41701 .23303 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.40848 .23115 m .41027 .25 L .41027 .23352 L .625 .51 .703 r
F
.36347 .17137 m .39932 .2316 L .40848 .23115 L F
.39973 .23158 m .38626 .23683 L .40496 .23591 L .289 .763 .934 r
F
.38921 .2321 m .38626 .23683 L .39973 .23158 L F
.39932 .2316 m .41027 .25 L .40848 .23115 L .625 .51 .703 r
F
.41027 .24673 m .41027 .27101 L .41162 .27016 L .979 .799 .592 r
F
.38921 .2321 m .3599 .23813 L .38626 .23683 L .289 .763 .934 r
F
.36347 .17137 m .39125 .232 L .39193 .23197 L .625 .51 .703 r
F
.31755 .23794 m .32449 .23987 L p .35435 .23383 L .289 .763 .934 r
F P
0 g
s
.36347 .17137 m .39193 .23197 L .39932 .2316 L .625 .51 .703 r
F
.33862 .23461 m .31755 .23794 L .35435 .23383 L .289 .763 .934 r
F
.32309 .27756 m .32382 .28277 L .31755 .27159 L .974 .795 .601 r
F
.32634 .28155 m .32063 .27755 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.32449 .27908 m .32634 .28155 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.37435 .23284 m .32449 .23987 L .3599 .23813 L .289 .763 .934 r
F
.35435 .23383 m .32449 .23987 L .37435 .23284 L F
.33 .28562 m .32063 .27755 L .32634 .28155 L p .506 0 0 r
F P
0 g
s
.32634 .28155 m .33565 .28958 L .33 .28562 L p .506 0 0 r
F P
0 g
s
.32063 .27755 m .33 .28562 L p .34504 .23429 L .625 .51 .703 r
F P
0 g
s
.36347 .17137 m .33794 .23464 L .34504 .23429 L .625 .51 .703 r
F
.32449 .22117 m .31082 .23505 L .32449 .23114 L .626 .511 .703 r
F
.36347 .17137 m .31877 .22681 L .32148 .23546 L .625 .51 .703 r
F
.31877 .22681 m .31139 .23596 L .31877 .23559 L F
.31877 .22681 m .31877 .23559 L .32148 .23546 L F
.31755 .23794 m .31755 .27159 L p .31877 .25981 L 0 0 .16 r
F P
0 g
s
.31877 .23559 m .31755 .23794 L p .33862 .23461 L .289 .763 .934 r
F P
0 g
s
.31877 .23559 m .31755 .23794 L p .31877 .25981 L 0 0 .16 r
F P
0 g
s
.31502 .26886 m .31318 .26756 L p .31329 .26613 L .841 .454 0 r
F P
0 g
s
.31375 .26023 m .31502 .26886 L .31329 .26613 L .841 .454 0 r
F
.311 .24786 m .31375 .26023 L .30796 .25609 L p .93 .641 .168 r
F P
0 g
s
.31318 .26756 m .30796 .25609 L .31375 .26023 L p .841 .454 0 r
F P
0 g
s
.30796 .25609 m .31318 .26756 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.36347 .17137 m .31877 .23959 L .31877 .25686 L .625 .51 .703 r
F
.31877 .23959 m .30796 .25609 L .31877 .25686 L F
.31755 .27159 m .31755 .27287 L p .31765 .27188 L 0 0 .16 r
F P
0 g
s
.31954 .27373 m .32063 .27755 L .31847 .27421 L .698 .226 0 r
F
.31755 .27159 m .31847 .27421 L .31502 .26886 L F
.31954 .27373 m .31847 .27421 L .31755 .27159 L F
.36347 .17137 m .31877 .25686 L .32063 .27755 L .625 .51 .703 r
F
.31877 .27583 m .31755 .27287 L .31877 .27985 L 0 0 .16 r
F
.32382 .28277 m .32449 .28763 L .31755 .27287 L .974 .795 .601 r
F
.31765 .27188 m .31755 .27287 L .32066 .28041 L 0 0 .16 r
F
.31755 .27287 m .31755 .40731 L p .32044 .2894 L F P
0 g
s
.32063 .27755 m .31318 .26756 L .31502 .26886 L p .698 .226 0 r
F P
0 g
s
.31877 .27506 m .32063 .27755 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.33 .28562 m .34088 .29142 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.34088 .29142 m .35281 .2947 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.37435 .23284 m .3599 .23813 L .38921 .2321 L .289 .763 .934 r
F
.35281 .2947 m .36526 .2953 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.40037 .2813 m .40959 .27203 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.38958 .28846 m .40037 .2813 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.3777 .29319 m .38958 .28846 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.36526 .2953 m .3777 .29319 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.32191 .22957 m .32177 .23521 L p .393 .22601 L .289 .763 .934 r
F P
0 g
s
.32191 .22957 m .31877 .23559 L p .32133 .23526 L .289 .763 .934 r
F P
0 g
s
.393 .22601 m .31877 .23559 L .33862 .23461 L .289 .763 .934 r
F
.31082 .23505 m .311 .24786 L .3052 .24364 L p .97 .785 .355 r
F P
0 g
s
.30796 .25609 m .3052 .24364 L .311 .24786 L p .93 .641 .168 r
F P
0 g
s
.3052 .24364 m .30796 .25609 L p .31877 .23959 L .625 .51 .703 r
F P
0 g
s
.32148 .23546 m .31877 .23682 L .31877 .23959 L .625 .51 .703 r
F
.31877 .23682 m .3052 .24364 L .31877 .23959 L F
.31139 .23596 m .3052 .24364 L .32148 .23546 L F
.33794 .23464 m .32063 .27755 L .34504 .23429 L F
.32191 .22957 m .31877 .26073 L .32066 .28041 L 0 0 .16 r
F
.31877 .26073 m .31765 .27188 L .31877 .27506 L F
.31877 .26073 m .31877 .27506 L .32066 .28041 L F
.31877 .26073 m .31755 .27159 L .31765 .27188 L F
.31877 .25981 m .31755 .27159 L .31877 .26073 L F
.31318 .26756 m .31877 .27506 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.32066 .28041 m .31877 .27583 L .32044 .2894 L 0 0 .16 r
F
.31877 .27583 m .31877 .27985 L .32044 .2894 L F
.32191 .22957 m .31877 .25981 L .31877 .26073 L F
.32191 .22957 m .31877 .23559 L p .31877 .25981 L F P
0 g
s
.393 .22601 m .35435 .23383 L .37435 .23284 L .289 .763 .934 r
F
.393 .22601 m .33862 .23461 L .35435 .23383 L F
.39932 .2316 m .41027 .27101 L .41027 .25 L .625 .51 .703 r
F
.39193 .23197 m .41027 .27101 L .39932 .2316 L F
.393 .22601 m .37435 .23284 L .38921 .2321 L .289 .763 .934 r
F
.40959 .27203 m .41027 .27101 L p .39193 .23197 L .625 .51 .703 r
F P
0 g
s
.39125 .232 m .40959 .27203 L .39193 .23197 L .625 .51 .703 r
F
.41027 .27101 m .41685 .26105 L p .41027 .25 L F P
0 g
s
.38306 .29712 m .39487 .29242 L .38958 .28846 L p .541 .919 .931 r
F P
0 g
s
.40037 .2813 m .38958 .28846 L .39487 .29242 L p .678 .976 .894 r
F P
0 g
s
.39487 .29242 m .40559 .28531 L .40037 .2813 L p .678 .976 .894 r
F P
0 g
s
.40959 .27203 m .40037 .2813 L .40559 .28531 L p .788 .999 .829 r
F P
0 g
s
.393 .28185 m .393 .39843 L p .41027 .27946 L .979 .799 .592 r
F P
0 g
s
.41027 .27101 m .40959 .27203 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41162 .27016 m .41027 .27101 L .41027 .27946 L .979 .799 .592 r
F
.41027 .27101 m .393 .28185 L .41027 .27946 L F
.393 .22601 m .38921 .2321 L .39973 .23158 L .289 .763 .934 r
F
.393 .22601 m .393 .28185 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41701 .23303 m .41027 .23106 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41027 .23106 m .393 .22601 L p .39973 .23158 L .289 .763 .934 r
F P
0 g
s
.41027 .23106 m .393 .22601 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41685 .26105 m .42181 .24884 L p .41027 .23352 L .625 .51 .703 r
F P
0 g
s
.41027 .25 m .41685 .26105 L .41027 .23352 L .625 .51 .703 r
F
.42691 .25307 m .42933 .24026 L p .41544 .2255 L .626 .511 .703 r
F P
0 g
s
.42181 .24884 m .42425 .23595 L p .41027 .2211 L .625 .51 .703 r
F P
0 g
s
.41027 .23352 m .42181 .24884 L .41027 .2211 L .625 .51 .703 r
F
.41027 .24673 m .393 .28185 L .41027 .27101 L .979 .799 .592 r
F
.41685 .26105 m .41027 .27101 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41162 .27016 m .393 .39843 L .41701 .26677 L .979 .799 .592 r
F
.34192 .41234 m .32449 .40874 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.32449 .40874 m .31755 .40731 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.59993 .28958 m .61096 .29535 L .60708 .29142 L p 0 .323 .729 r
F P
0 g
s
.61925 .2947 m .60708 .29142 L .61096 .29535 L p 0 .526 .841 r
F P
0 g
s
.61096 .29535 m .62304 .29861 L .61925 .2947 L p 0 .526 .841 r
F P
0 g
s
.63195 .2953 m .61925 .2947 L .62304 .29861 L p .188 .693 .906 r
F P
0 g
s
.62304 .29861 m .63566 .29921 L .63195 .2953 L p .188 .693 .906 r
F P
0 g
s
.6626 .22601 m .62344 .22455 L .59008 .22957 L p .289 .763 .934 r
F P
0 g
s
.59008 .40107 m .62344 .39734 L .62344 .22455 L p .445 .364 .67 r
F P
0 g
s
.59043 .28155 m .59993 .28958 L .59599 .28562 L p 0 .093 .572 r
F P
0 g
s
.60708 .29142 m .59599 .28562 L .59993 .28958 L p 0 .323 .729 r
F P
0 g
s
.62344 .22455 m .59008 .22957 L .59008 .40107 L p .445 .364 .67 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3805 .41337 m .4115 .40982 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.34192 .41234 m .3805 .41337 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.59008 .40107 m .58238 .40731 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.31755 .40731 m .34192 .41234 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.4115 .40982 m .41701 .40365 L .393 .39843 L p .224 .73 .894 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31755 .40731 m .32191 .40107 L .32191 .22957 L p 0 0 .16 r
F P
0 g
s
.33565 .28958 m .34647 .29535 L .34088 .29142 L p 0 .278 .676 r
F P
0 g
s
.35281 .2947 m .34088 .29142 L .34647 .29535 L p 0 .504 .815 r
F P
0 g
s
.34647 .29535 m .35833 .29861 L .35281 .2947 L p 0 .504 .815 r
F P
0 g
s
.36526 .2953 m .35281 .2947 L .35833 .29861 L p .178 .688 .9 r
F P
0 g
s
.393 .22601 m .35326 .22455 L .32191 .22957 L p .289 .763 .934 r
F P
0 g
s
.32191 .40107 m .35326 .39734 L .35326 .22455 L p .428 .35 .666 r
F P
0 g
s
.34088 .29142 m .33 .28562 L .33565 .28958 L p 0 .278 .676 r
F P
0 g
s
.35326 .22455 m .32191 .22957 L .32191 .40107 L p .428 .35 .666 r
F P
0 g
s
.64463 .29319 m .63195 .2953 L .63566 .29921 L p .365 .821 .93 r
F P
0 g
s
.6626 .22601 m .62344 .22455 L .62344 .39734 L p .763 .623 .705 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32191 .40107 m .31755 .40731 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.57069 .24364 m .5705 .23074 L .5746 .23505 L p .927 .748 .265 r
F P
0 g
s
.57703 .22234 m .5746 .23505 L .5705 .23074 L p .939 .868 .446 r
F P
0 g
s
.3052 .24364 m .30501 .23074 L .31082 .23505 L p .97 .785 .355 r
F P
0 g
s
.3132 .22234 m .31082 .23505 L .30501 .23074 L p .972 .888 .516 r
F P
0 g
s
.5705 .23074 m .57295 .21796 L .57703 .22234 L p .939 .868 .446 r
F P
0 g
s
.58197 .2103 m .57703 .22234 L .57295 .21796 L p .914 .947 .599 r
F P
0 g
s
.30501 .23074 m .30741 .21796 L .3132 .22234 L p .972 .888 .516 r
F P
0 g
s
.31805 .2103 m .3132 .22234 L .30741 .21796 L p .941 .955 .649 r
F P
0 g
s
.57295 .21796 m .57792 .20583 L .58197 .2103 L p .914 .947 .599 r
F P
0 g
s
.58922 .19943 m .58197 .2103 L .57792 .20583 L p .859 .989 .724 r
F P
0 g
s
.30741 .21796 m .31229 .20583 L .31805 .2103 L p .941 .955 .649 r
F P
0 g
s
.32516 .19943 m .31805 .2103 L .31229 .20583 L p .885 .991 .758 r
F P
0 g
s
.57792 .20583 m .58522 .19489 L .58922 .19943 L p .859 .989 .724 r
F P
0 g
s
.59846 .19022 m .58922 .19943 L .58522 .19489 L p .779 .998 .821 r
F P
0 g
s
.31229 .20583 m .31944 .19489 L .32516 .19943 L p .885 .991 .758 r
F P
0 g
s
.33422 .19022 m .32516 .19943 L .31944 .19489 L p .804 .999 .844 r
F P
0 g
s
.58522 .19489 m .59452 .18562 L .59846 .19022 L p .779 .998 .821 r
F P
0 g
s
.6093 .18307 m .59846 .19022 L .59452 .18562 L p .676 .975 .893 r
F P
0 g
s
.31944 .19489 m .32856 .18562 L .33422 .19022 L p .804 .999 .844 r
F P
0 g
s
.34485 .18307 m .33422 .19022 L .32856 .18562 L p .701 .978 .908 r
F P
0 g
s
.59452 .18562 m .60542 .17841 L .6093 .18307 L p .676 .975 .893 r
F P
0 g
s
.62127 .17828 m .6093 .18307 L .60542 .17841 L p .551 .922 .937 r
F P
0 g
s
.32856 .18562 m .33925 .17841 L .34485 .18307 L p .701 .978 .908 r
F P
0 g
s
.35659 .17828 m .34485 .18307 L .33925 .17841 L p .571 .927 .947 r
F P
0 g
s
.60542 .17841 m .61746 .17359 L .62127 .17828 L p .551 .922 .937 r
F P
0 g
s
.33925 .17841 m .35106 .17359 L .35659 .17828 L p .571 .927 .947 r
F P
0 g
s
.35833 .29861 m .3707 .29921 L .36526 .2953 L p .178 .688 .9 r
F P
0 g
s
.38132 .17657 m .36892 .17608 L .36347 .17137 L p .227 .712 .929 r
F P
0 g
s
.39324 .17973 m .38132 .17657 L .36892 .17608 L p .626 .511 .703 r
F P
0 g
s
.40415 .18544 m .39324 .17973 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.41357 .19344 m .40415 .18544 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42108 .20339 m .41357 .19344 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42635 .21486 m .42108 .20339 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42914 .22733 m .42635 .21486 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42933 .24026 m .42914 .22733 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3777 .29319 m .36526 .2953 L .3707 .29921 L p .375 .825 .936 r
F P
0 g
s
.3707 .29921 m .38306 .29712 L .3777 .29319 L p .375 .825 .936 r
F P
0 g
s
.63012 .17137 m .64284 .17186 L .64649 .17657 L p .236 .716 .934 r
F P
0 g
s
.65864 .17973 m .64649 .17657 L .64284 .17186 L p .047 .559 .876 r
F P
0 g
s
.36347 .17137 m .37594 .17186 L .38132 .17657 L p .227 .712 .929 r
F P
0 g
s
.39324 .17973 m .38132 .17657 L .37594 .17186 L p .013 .539 .855 r
F P
0 g
s
.38958 .28846 m .3777 .29319 L .38306 .29712 L p .541 .919 .931 r
F P
0 g
s
.64284 .17186 m .65507 .17504 L .65864 .17973 L p .047 .559 .876 r
F P
0 g
s
.66977 .18544 m .65864 .17973 L .65507 .17504 L p 0 .365 .774 r
F P
0 g
s
.37594 .17186 m .38793 .17504 L .39324 .17973 L p .013 .539 .855 r
F P
0 g
s
.40415 .18544 m .39324 .17973 L .38793 .17504 L p 0 .322 .728 r
F P
0 g
s
.6965 .86458 m .70139 .84608 L p .72461 .87504 L 0 .225 .738 r
F P
0 g
s
.70139 .84608 m .70496 .83261 L p .71623 .85695 L 0 .225 .738 r
F P
0 g
s
.71623 .85695 m .72461 .87504 L .70139 .84608 L 0 .225 .738 r
F
.73836 .90472 m .70788 .87549 L p .72461 .87504 L F P
0 g
s
.70788 .87549 m .6965 .86458 L p .72461 .87504 L 0 .225 .738 r
F P
0 g
s
.77017 .87438 m .77017 .89646 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.74034 .87461 m .75114 .87453 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.75114 .87453 m .77017 .87438 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.77017 .87438 m .74034 .87461 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.75401 .87424 m .77017 .87438 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.74865 .87438 m .73196 .89091 L p .70496 .83261 L 0 .225 .738 r
F P
0 g
s
.73315 .89348 m .74865 .87438 L .73836 .90472 L p 0 .225 .738 r
F P
0 g
s
.70139 .8749 m .74034 .87461 L p .74177 .88546 L .347 .283 .642 r
F P
0 g
s
.71437 .91745 m .70139 .8749 L .74177 .88546 L .347 .283 .642 r
F
.69767 .94509 m .73836 .90472 L .7403 .89899 L p .644 .92 .631 r
F P
0 g
s
.7403 .89899 m .74693 .87944 L p .71744 .91874 L .644 .92 .631 r
F P
0 g
s
.71744 .91874 m .69767 .94509 L .7403 .89899 L .644 .92 .631 r
F
.6965 .86458 m .68544 .87549 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.67009 .8722 m .6965 .86458 L .66141 .87944 L .665 .934 .653 r
F
.70496 .83261 m .74865 .87438 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.6672 .87461 m .64101 .87438 L .65952 .87424 L p .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .65772 .87453 L p .65328 .88622 L .954 .779 .626 r
F P
0 g
s
.65772 .87453 m .6672 .87461 L p .66141 .87944 L .954 .779 .626 r
F P
0 g
s
.65328 .88622 m .65772 .87453 L .66141 .87944 L .954 .779 .626 r
F
.66483 .87659 m .66253 .87438 L p .67009 .8722 L .665 .934 .653 r
F P
0 g
s
.65581 .90472 m .66141 .87944 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.68544 .87549 m .65581 .90472 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.66141 .87944 m .65581 .90472 L p .68562 .91163 L 0 .207 .723 r
F P
0 g
s
.68562 .91163 m .65581 .90472 L .70139 .93261 L 0 .207 .723 r
F
.70139 .93261 m .65328 .88622 L .66453 .88358 L .954 .779 .626 r
F
.70139 .8749 m .70139 .93261 L p .66453 .88358 L F P
0 g
s
.65581 .90472 m .69767 .94509 L .70139 .93261 L p 0 .207 .723 r
F P
0 g
s
.70139 .93261 m .69767 .94509 L p .73473 .89368 L .644 .92 .631 r
F P
0 g
s
.73473 .89368 m .69767 .94509 L .74693 .87944 L .644 .92 .631 r
F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.70139 .93261 m .70623 .91641 L p .68562 .91163 L 0 .207 .723 r
F P
0 g
s
.6672 .87461 m .70139 .8749 L p .65328 .88622 L .954 .779 .626 r
F P
0 g
s
.70623 .91641 m .66253 .87438 L .66141 .87944 L p 0 .207 .723 r
F P
0 g
s
.70623 .91641 m .66141 .87944 L .68562 .91163 L 0 .207 .723 r
F
.66253 .87438 m .70496 .83261 L .6965 .86458 L p .665 .934 .653 r
F P
0 g
s
.66253 .87438 m .70496 .83261 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70139 .8749 m .6672 .87461 L p .67977 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .67977 .87438 L .70559 .87438 L .012 .587 .719 r
F
.65952 .87424 m .70996 .87384 L p .6672 .87461 L F P
0 g
s
.70996 .87384 m .75401 .87424 L p .70139 .8749 L .012 .587 .719 r
F P
0 g
s
.74034 .87461 m .70139 .8749 L p .75401 .87424 L .012 .587 .719 r
F P
0 g
s
.70623 .91641 m .66253 .87438 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70559 .87438 m .67977 .87438 L .70996 .87384 L .012 .587 .719 r
F
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.55483 1.09633 m .55502 1.07831 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44517 1.09633 L .36524 1.09633 L p .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.63508 1.08393 m .6913 1.07831 L .70139 1.09633 L .678 .717 .878 r
F
.60506 1.07831 m .63522 1.07831 L .63508 1.08393 L F
.63522 1.07831 m .6913 1.07831 L .63508 1.08393 L F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L .678 .717 .878 r
F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L 0 0 .063 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.5554 1.043 m .63614 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.63614 1.043 m .70347 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.60506 1.07831 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63614 1.043 m .63772 1.04435 L .67151 1.043 L .066 0 0 r
F
.63772 1.04435 m .63806 1.04464 L .64101 1.04449 L F
.63772 1.04435 m .64101 1.04449 L .67151 1.043 L F
.70139 1.09633 m .64101 1.04449 L .64101 .98856 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04449 L p .954 .779 .626 r
F P
0 g
s
.70139 .93261 m .70139 1.04154 L p .66533 .96377 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .66533 .96377 L .70139 1.04154 L .954 .779 .626 r
F
.66533 .96377 m .64101 .87438 L .70139 .93261 L F
.74127 .88169 m .74034 .87461 L .74498 .87801 L .347 .283 .642 r
F
.74127 .88169 m .74498 .87801 L .77017 .89646 L F
.77017 .89646 m .77017 1.10042 L p .74127 .88169 L F P
0 g
s
.74865 .87438 m .70623 .91641 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 1.04449 L p .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63806 1.04464 m .70775 1.04601 L .67151 1.043 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44344 1.15905 m .44461 1.09757 L .44459 1.11724 L F
.63538 1.08458 m .60923 1.09451 L .44497 1.07958 L .682 .404 .495 r
F
.44497 1.07874 m .44497 1.07958 L .43099 1.07831 L F
.63538 1.08458 m .44497 1.07958 L .44497 1.07874 L F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.44461 1.09757 m .44498 1.07831 L .44479 1.09692 L .732 .598 .026 r
F
.44461 1.09757 m .44479 1.09692 L .44459 1.11724 L F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52783 1.09787 m .51885 1.09818 L .516 1.09787 L .09 0 0 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.51434 1.25793 m .54175 1.25635 L .52667 1.25967 L F
.54175 1.25635 m .62917 1.25133 L .54517 1.25817 L F
.54175 1.25635 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.484 1.25967 m .51434 1.25793 L .52667 1.25967 L .365 .792 .97 r
F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.4813 1.25829 m .54018 1.25552 L .484 1.25967 L .365 .792 .97 r
F
.54018 1.25552 m .62917 1.25133 L .54175 1.25635 L F
.54018 1.25552 m .54175 1.25635 L .484 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.45621 1.25744 m .62917 1.25133 L .452 1.25967 L .365 .792 .97 r
F
.58611 1.27286 m .58077 1.29174 L .53867 1.29296 L p .685 .85 .962 r
F P
0 g
s
.53867 1.29296 m .52722 1.29329 L p .53642 1.2901 L .685 .85 .962 r
F P
0 g
s
.58611 1.27286 m .53867 1.29296 L .53642 1.2901 L .685 .85 .962 r
F
.58611 1.27286 m .52722 1.29329 L .52902 1.29028 L F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.52325 1.31785 m .51832 1.29355 L .52722 1.29329 L p .706 .339 .351 r
F P
0 g
s
.52722 1.29329 m .58077 1.29174 L p .53613 1.31201 L .706 .339 .351 r
F P
0 g
s
.53613 1.31201 m .52325 1.31785 L .52722 1.29329 L .706 .339 .351 r
F
.516 1.25967 m .52978 1.28903 L .52722 1.29329 L .08 .066 .539 r
F
.52722 1.29329 m .516 1.29086 L .516 1.26975 L p F P
0 g
s
.516 1.26975 m .516 1.25967 L p .52722 1.29329 L .08 .066 .539 r
F P
0 g
s
.53229 1.26089 m .53229 1.28484 L p .52954 1.25517 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.28484 L .53168 1.28585 L .08 .066 .539 r
F
.53869 1.27417 m .58611 1.27286 L p .52902 1.29028 L .685 .85 .962 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.53229 1.28484 m .53229 1.26089 L p .52429 1.27465 L .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .53229 1.26089 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.26089 L .52954 1.25517 L .08 .066 .539 r
F
.53229 1.26089 m .53229 1.25133 L p .52444 1.27421 L .998 .815 .53 r
F P
0 g
s
.52444 1.27421 m .52429 1.27465 L .53229 1.26089 L .998 .815 .53 r
F
.51832 1.29355 m .52325 1.31785 L .5235 1.31691 L p 0 0 .3 r
F P
0 g
s
.5235 1.31691 m .52826 1.29894 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.51832 1.29355 m .5235 1.31691 L .5235 1.29636 L 0 0 .3 r
F
.53229 1.29439 m .51629 1.29798 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.516 1.29086 m .52722 1.29329 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.52722 1.29329 m .53229 1.29439 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.52902 1.29028 m .51832 1.29355 L .53869 1.27417 L .685 .85 .962 r
F
.53229 1.29439 m .52722 1.29329 L p .52978 1.28903 L .08 .066 .539 r
F P
0 g
s
.53168 1.28585 m .53229 1.28484 L .53229 1.29439 L .08 .066 .539 r
F
.52722 1.29329 m .51832 1.29355 L p .52902 1.29028 L .685 .85 .962 r
F P
0 g
s
.53229 1.29439 m .53229 1.28484 L p .5235 1.29206 L .998 .815 .53 r
F P
0 g
s
.5235 1.29636 m .53229 1.29439 L p .5235 1.29206 L .998 .815 .53 r
F P
0 g
s
.51832 1.29355 m .52325 1.2746 L .52423 1.27457 L p .685 .85 .962 r
F P
0 g
s
.53023 1.28222 m .51832 1.29355 L .52423 1.27457 L .685 .85 .962 r
F
.52325 1.2746 m .51832 1.29355 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.52423 1.27457 m .52325 1.2746 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.52423 1.27457 m .5235 1.27695 L .52429 1.27465 L .998 .815 .53 r
F
.52325 1.2746 m .5235 1.27581 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.5235 1.27364 m .5235 1.27581 L .52423 1.27457 L .998 .815 .53 r
F
.5235 1.27581 m .5235 1.27695 L .52423 1.27457 L F
.51875 1.26758 m .52429 1.27465 L .53229 1.25133 L F
.52423 1.27457 m .53869 1.27417 L p .53023 1.28222 L .685 .85 .962 r
F P
0 g
s
.5235 1.27581 m .52325 1.2746 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.52429 1.27465 m .51629 1.29798 L .53229 1.28484 L .998 .815 .53 r
F
.58077 1.29174 m .58611 1.31592 L .52325 1.31785 L p .706 .339 .351 r
F P
0 g
s
.58077 1.29174 m .58611 1.31592 L .59152 1.29708 L p 0 0 .322 r
F P
0 g
s
.52826 1.29894 m .59152 1.29708 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.5235 1.27581 m .52826 1.29894 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.52826 1.29894 m .5235 1.27581 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.51875 1.26758 m .51629 1.29798 L .5235 1.27695 L .998 .815 .53 r
F
.51875 1.26758 m .5235 1.27695 L .5235 1.27364 L F
.51629 1.29798 m .5235 1.29636 L p .5235 1.29206 L F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.452 1.25967 m .4813 1.25829 L .484 1.25967 L .365 .792 .97 r
F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51875 1.26758 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.53645 1.09918 m .47146 1.10147 L .4687 1.10147 L .09 0 0 r
F
.53616 1.09921 m .47166 1.10147 L .53645 1.09918 L F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .47146 1.10147 L .09 0 0 r
F
.47166 1.10147 m .47146 1.10147 L .53645 1.09918 L F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L .09 0 0 r
F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.55676 1.10246 m .44324 1.10246 L p .53019 1.09942 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L .09 0 0 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.516 1.09787 m .46368 1.10009 L .484 1.09787 L F
.51885 1.09818 m .46368 1.10009 L .516 1.09787 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.47146 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.55566 1.09853 m .53616 1.09921 L .53645 1.09918 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.46771 1.06813 m .47031 1.09869 L .46995 1.09874 L .997 .814 .539 r
F
.47031 1.09869 m .47036 1.09936 L .46995 1.09874 L F
.46995 1.09874 m .47036 1.09936 L .47 1.0994 L F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L .732 .598 .026 r
F
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.35023 1.31785 m .34646 1.29355 L .37134 1.29284 L p .707 .342 .354 r
F P
0 g
s
.37173 1.30072 m .37194 1.27693 L .37151 1.28848 L .763 .623 .059 r
F
.37209 1.3207 m .37209 1.30812 L .37173 1.30072 L F
.37209 1.30812 m .37209 1.2604 L .37173 1.30072 L F
.37074 1.30885 m .35023 1.31785 L .37134 1.29284 L .707 .342 .354 r
F
.37134 1.29284 m .34646 1.29355 L p .37101 1.28602 L .686 .848 .961 r
F P
0 g
s
.37042 1.31724 m .35023 1.31785 L p .37074 1.30885 L .707 .342 .354 r
F P
0 g
s
.37209 1.2604 m .37119 1.25391 L p .37151 1.28848 L .763 .623 .059 r
F P
0 g
s
.37119 1.25391 m .37083 1.25133 L p .37098 1.25943 L .763 .623 .059 r
F P
0 g
s
.37151 1.28848 m .37119 1.25391 L .37098 1.25943 L .763 .623 .059 r
F
.37194 1.27693 m .37209 1.2604 L .37151 1.28848 L F
.34646 1.29355 m .35023 1.2746 L .37042 1.27405 L p .686 .848 .961 r
F P
0 g
s
.37101 1.28602 m .34646 1.29355 L .37042 1.27405 L .686 .848 .961 r
F
.37042 1.27405 m .35023 1.2746 L p .37015 1.28119 L .706 .339 .35 r
F P
0 g
s
.35023 1.2746 m .35405 1.29894 L .36949 1.29849 L p .706 .339 .35 r
F P
0 g
s
.37209 1.3207 m .37173 1.30072 L .37026 1.27833 L .763 .623 .059 r
F
.37209 1.3207 m .37026 1.27833 L .37017 1.28057 L F
.37083 1.25133 m .36989 1.26323 L p .37173 1.30072 L F P
0 g
s
.36989 1.26323 m .36955 1.26755 L p .37173 1.30072 L .763 .623 .059 r
F P
0 g
s
.37042 1.27405 m .41389 1.27286 L p .37101 1.28602 L .686 .848 .961 r
F P
0 g
s
.37015 1.28119 m .35023 1.2746 L .36949 1.29849 L .706 .339 .35 r
F
.36955 1.26755 m .36915 1.29168 L p .37066 1.31103 L .763 .623 .059 r
F P
0 g
s
.36973 1.30339 m .35405 1.29894 L .37042 1.31724 L .685 .851 .962 r
F
.37066 1.31103 m .36915 1.29168 L .36984 1.30551 L .763 .623 .059 r
F
.37209 1.3207 m .37108 1.29966 L .37066 1.31103 L F
.37108 1.29966 m .36955 1.26755 L .37066 1.31103 L F
.41067 1.29729 m .4007 1.29758 L p .40971 1.29174 L .707 .342 .354 r
F P
0 g
s
.37209 1.3207 m .36984 1.30551 L .3708 1.32493 L .763 .623 .059 r
F
.38807 1.30578 m .41389 1.31592 L .37042 1.31724 L p .707 .342 .354 r
F P
0 g
s
.40971 1.29174 m .37042 1.31724 L .37074 1.30885 L .707 .342 .354 r
F
.37134 1.29284 m .40971 1.29174 L p .37074 1.30885 L F P
0 g
s
.40971 1.29174 m .41389 1.31592 L .41812 1.29708 L p 0 0 .263 r
F P
0 g
s
.41389 1.31592 m .41812 1.29708 L .36949 1.29849 L p .685 .851 .962 r
F P
0 g
s
.36949 1.29849 m .35405 1.29894 L p .36973 1.30339 L .685 .851 .962 r
F P
0 g
s
.41389 1.31592 m .36949 1.29849 L .36973 1.30339 L .685 .851 .962 r
F
.35405 1.29894 m .35023 1.31785 L .37042 1.31724 L p F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .3708 1.32493 L .763 .623 .059 r
F P
0 g
s
.36984 1.30551 m .36901 1.29994 L .3708 1.32493 L .763 .623 .059 r
F
.36915 1.29168 m .36901 1.29994 L p .36984 1.30551 L F P
0 g
s
.37042 1.31724 m .41389 1.31592 L p .36973 1.30339 L .685 .851 .962 r
F P
0 g
s
.41389 1.27286 m .40971 1.29174 L .37134 1.29284 L p .686 .848 .961 r
F P
0 g
s
.41389 1.27286 m .37134 1.29284 L .37101 1.28602 L .686 .848 .961 r
F
.36949 1.29849 m .41812 1.29708 L p .37015 1.28119 L .706 .339 .35 r
F P
0 g
s
.37017 1.28057 m .37026 1.27833 L .36955 1.26755 L .763 .623 .059 r
F
.41812 1.29708 m .41389 1.27286 L .40971 1.29174 L p 0 0 .263 r
F P
0 g
s
.41812 1.29708 m .41389 1.27286 L .37042 1.27405 L p .706 .339 .35 r
F P
0 g
s
.41812 1.29708 m .37042 1.27405 L .37015 1.28119 L .706 .339 .35 r
F
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.53869 1.27417 m .52423 1.27457 L p .54185 1.28072 L .705 .336 .346 r
F P
0 g
s
.54185 1.28072 m .52423 1.27457 L .52406 1.27486 L .705 .336 .346 r
F
.59152 1.29708 m .58611 1.27286 L .58077 1.29174 L p 0 0 .322 r
F P
0 g
s
.59152 1.29708 m .58611 1.27286 L .53869 1.27417 L p .705 .336 .346 r
F P
0 g
s
.59152 1.29708 m .53869 1.27417 L .54185 1.28072 L .705 .336 .346 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L .513 .022 .027 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.74865 .87438 m .70623 .91641 L .70139 .93261 L p .644 .92 .631 r
F P
0 g
s
.74865 .87438 m .70139 .93261 L .73473 .89368 L .644 .92 .631 r
F
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.74693 .87944 m .74865 .87438 L p .73473 .89368 L .644 .92 .631 r
F P
0 g
s
.77017 1.10042 m .71437 .91745 L .74177 .88546 L .347 .283 .642 r
F
.5705 .23074 m .57069 .24364 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.57295 .21796 m .5705 .23074 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.30501 .23074 m .3052 .24364 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.30741 .21796 m .30501 .23074 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.57792 .20583 m .57295 .21796 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.31229 .20583 m .30741 .21796 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.65507 .17504 m .66626 .18078 L .66977 .18544 L p 0 .365 .774 r
F P
0 g
s
.67937 .19344 m .66977 .18544 L .66626 .18078 L p 0 .14 .626 r
F P
0 g
s
.38793 .17504 m .39891 .18078 L .40415 .18544 L p 0 .322 .728 r
F P
0 g
s
.41357 .19344 m .40415 .18544 L .39891 .18078 L p 0 .074 .549 r
F P
0 g
s
.58522 .19489 m .57792 .20583 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.31944 .19489 m .31229 .20583 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.59452 .18562 m .58522 .19489 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.32856 .18562 m .31944 .19489 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.66626 .18078 m .67593 .18883 L .67937 .19344 L p 0 .14 .626 r
F P
0 g
s
.68703 .20339 m .67937 .19344 L .67593 .18883 L p 0 0 .437 r
F P
0 g
s
.39891 .18078 m .40839 .18883 L .41357 .19344 L p 0 .074 .549 r
F P
0 g
s
.42108 .20339 m .41357 .19344 L .40839 .18883 L p .649 .181 0 r
F P
0 g
s
.67593 .18883 m .68364 .19885 L .68703 .20339 L p 0 0 .437 r
F P
0 g
s
.69241 .21486 m .68703 .20339 L .68364 .19885 L p .715 .338 0 r
F P
0 g
s
.40839 .18883 m .41595 .19885 L .42108 .20339 L p .649 .181 0 r
F P
0 g
s
.42635 .21486 m .42108 .20339 L .41595 .19885 L p .804 .418 0 r
F P
0 g
s
.60542 .17841 m .59452 .18562 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.33925 .17841 m .32856 .18562 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.68961 .24884 m .68456 .26105 L .68795 .26519 L p .893 .937 .567 r
F P
0 g
s
.68795 .26519 m .69297 .25307 L .68961 .24884 L p .893 .937 .567 r
F P
0 g
s
.42198 .26519 m .42691 .25307 L .42181 .24884 L p .929 .953 .625 r
F P
0 g
s
.68364 .19885 m .68905 .21038 L .69241 .21486 L p .715 .338 0 r
F P
0 g
s
.69525 .22733 m .69241 .21486 L .68905 .21038 L p .831 .55 .003 r
F P
0 g
s
.41595 .19885 m .42125 .21038 L .42635 .21486 L p .804 .418 0 r
F P
0 g
s
.42914 .22733 m .42635 .21486 L .42125 .21038 L p .904 .616 .117 r
F P
0 g
s
.6921 .23595 m .68961 .24884 L .69297 .25307 L p .915 .852 .406 r
F P
0 g
s
.69297 .25307 m .69545 .24026 L .6921 .23595 L p .915 .852 .406 r
F P
0 g
s
.42425 .23595 m .42181 .24884 L .42691 .25307 L p .958 .881 .484 r
F P
0 g
s
.42691 .25307 m .42933 .24026 L .42425 .23595 L p .958 .881 .484 r
F P
0 g
s
.68905 .21038 m .69191 .22294 L .69525 .22733 L p .831 .55 .003 r
F P
0 g
s
.69545 .24026 m .69525 .22733 L .69191 .22294 L p .896 .723 .216 r
F P
0 g
s
.42125 .21038 m .42406 .22294 L .42914 .22733 L p .904 .616 .117 r
F P
0 g
s
.42933 .24026 m .42914 .22733 L .42406 .22294 L p .953 .77 .315 r
F P
0 g
s
.69191 .22294 m .6921 .23595 L .69545 .24026 L p .896 .723 .216 r
F P
0 g
s
.42406 .22294 m .42425 .23595 L .42933 .24026 L p .953 .77 .315 r
F P
0 g
s
.63012 .17137 m .61746 .17359 L .60542 .17841 L p .627 .512 .703 r
F P
0 g
s
.36347 .17137 m .35106 .17359 L .33925 .17841 L p .625 .51 .703 r
F P
0 g
s
.65507 .17504 m .64284 .17186 L .63012 .17137 L p .627 .512 .703 r
F P
0 g
s
.66626 .18078 m .65507 .17504 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.67593 .18883 m .66626 .18078 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.68364 .19885 m .67593 .18883 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.68905 .21038 m .68364 .19885 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.69191 .22294 m .68905 .21038 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6921 .23595 m .69191 .22294 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.38793 .17504 m .37594 .17186 L .36347 .17137 L p .625 .51 .703 r
F P
0 g
s
.39891 .18078 m .38793 .17504 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.40839 .18883 m .39891 .18078 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.41595 .19885 m .40839 .18883 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42125 .21038 m .41595 .19885 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42406 .22294 m .42125 .21038 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42425 .23595 m .42406 .22294 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.35326 .39734 m .393 .39843 L .393 .22601 L p .763 .623 .705 r
F P
0 g
s
.393 .22601 m .35326 .22455 L .35326 .39734 L p .763 .623 .705 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6626 .39843 m .62344 .39734 L .59008 .40107 L p .224 .73 .894 r
F P
0 g
s
.393 .39843 m .35326 .39734 L .32191 .40107 L p .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.40328 .36429 m .36948 .36852 L .36948 .18583 L p .413 .337 .662 r
F P
0 g
s
.36948 .36852 m .32732 .3673 L .32732 .18419 L p .766 .625 .704 r
F P
0 g
s
.32732 .18419 m .36948 .18583 L .36948 .36852 L p .766 .625 .704 r
F P
0 g
s
.29322 .1732 m .29331 .17921 L p .30815 .16886 L .618 .504 .702 r
F P
0 g
s
.29331 .17921 m .29342 .18721 L p .30014 .17884 L .618 .504 .702 r
F P
0 g
s
.30815 .16886 m .29331 .17921 L .30014 .17884 L .618 .504 .702 r
F
.30815 .17841 m .32732 .18419 L p .34682 .17632 L .289 .763 .934 r
F P
0 g
s
.29342 .18721 m .29642 .20072 L p .30815 .18274 L .618 .504 .702 r
F P
0 g
s
.30815 .17841 m .32732 .18419 L p .31081 .22418 L .982 .801 .586 r
F P
0 g
s
.30815 .22127 m .31081 .22418 L .30815 .23062 L .982 .801 .586 r
F
.30815 .17841 m .31081 .22418 L .30815 .22127 L F
.30208 .21315 m .30815 .22127 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.30815 .16886 m .29342 .18721 L .30815 .18274 L .618 .504 .702 r
F
.29642 .20072 m .30208 .21315 L p .35667 .10843 L F P
0 g
s
.30208 .21315 m .31017 .22396 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.30051 .1761 m .30815 .17841 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30051 .36128 m .30051 .21429 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.29642 .20072 m .29925 .20693 L p .29772 .20984 L .826 .439 0 r
F P
0 g
s
.29925 .20693 m .30208 .21315 L .30005 .21161 L p .826 .439 0 r
F P
0 g
s
.30005 .21161 m .29772 .20984 L p .29925 .20693 L .826 .439 0 r
F P
0 g
s
.30051 .21429 m .30051 .2129 L p .30741 .22529 L .982 .801 .586 r
F P
0 g
s
.30208 .21315 m .3027 .21529 L .30051 .2129 L .68 .209 0 r
F
.29772 .20984 m .30005 .21161 L p .30051 .2129 L F P
0 g
s
.30005 .21161 m .30208 .21315 L p .30051 .2129 L .68 .209 0 r
F P
0 g
s
.30051 .2129 m .30051 .1761 L p .3066 .21957 L .982 .801 .586 r
F P
0 g
s
.35667 .10843 m .30815 .16886 L .30815 .18274 L .618 .504 .702 r
F
.32732 .18419 m .32732 .3673 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.32732 .18419 m .36948 .18583 L p .37562 .17477 L .289 .763 .934 r
F P
0 g
s
.34682 .17632 m .32732 .18419 L .37562 .17477 L .289 .763 .934 r
F
.31017 .22396 m .32034 .23269 L p .33666 .17687 L .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .32896 .17729 L .33666 .17687 L .618 .504 .702 r
F
.32896 .17729 m .31017 .22396 L .33666 .17687 L F
.33215 .23895 m .3451 .24246 L p .35667 .10843 L F P
0 g
s
.3451 .24246 m .35862 .24306 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.36948 .18583 m .40328 .18013 L .40328 .36429 L p .413 .337 .662 r
F P
0 g
s
.36948 .18583 m .40328 .18013 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.37562 .17477 m .36948 .18583 L .39606 .17367 L .289 .763 .934 r
F
.40328 .36429 m .40328 .18013 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.4092 .35691 m .40751 .35902 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.40751 .35902 m .40328 .36429 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.40751 .21647 m .41465 .20562 L p .40751 .19364 L .618 .504 .702 r
F P
0 g
s
.40751 .17573 m .42004 .19233 L .41192 .17282 L .618 .504 .702 r
F
.40751 .17305 m .41192 .17282 L .40751 .16223 L F
.40751 .17573 m .41192 .17282 L .40751 .17305 L F
.40328 .18013 m .40751 .17305 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.40328 .18013 m .40751 .17305 L p .40751 .21647 L 0 0 .183 r
F P
0 g
s
.40496 .23048 m .40751 .21647 L .40751 .30642 L 0 0 .183 r
F
.40328 .18013 m .40751 .21647 L .40496 .23048 L F
.40751 .21647 m .41465 .20562 L .41347 .20458 L p .865 .99 .731 r
F P
0 g
s
.41347 .20458 m .41019 .2017 L p .4092 .20715 L .865 .99 .731 r
F P
0 g
s
.40751 .21647 m .41347 .20458 L .4092 .20715 L .865 .99 .731 r
F
.40751 .30642 m .40871 .20982 L .4092 .35691 L 0 0 .183 r
F
.41465 .20562 m .42004 .19233 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41442 .18727 m .4109 .19594 L p .41465 .20562 L .923 .951 .614 r
F P
0 g
s
.40871 .20982 m .4092 .17022 L .4092 .20965 L 0 0 .183 r
F
.40751 .17305 m .4092 .17022 L p .40751 .30642 L F P
0 g
s
.40677 .21758 m .40751 .21647 L p .39561 .17369 L .618 .504 .702 r
F P
0 g
s
.39561 .17369 m .40751 .21647 L .40751 .19364 L .618 .504 .702 r
F
.38685 .17417 m .40677 .21758 L .39561 .17369 L F
.39675 .2277 m .40677 .21758 L p .35667 .10843 L F P
0 g
s
.4092 .20715 m .4092 .17022 L p .40328 .2107 L .986 .805 .576 r
F P
0 g
s
.4109 .19594 m .40899 .20066 L .41019 .2017 L p .923 .951 .614 r
F P
0 g
s
.41019 .2017 m .41465 .20562 L p .4109 .19594 L .923 .951 .614 r
F P
0 g
s
.40872 .2135 m .4092 .20965 L .4092 .35691 L 0 0 .183 r
F
.40871 .20982 m .4092 .20965 L .40872 .2135 L F
.40677 .21758 m .40751 .21647 L p .40899 .20066 L .865 .99 .731 r
F P
0 g
s
.41019 .2017 m .40899 .20066 L p .40751 .21647 L .865 .99 .731 r
F P
0 g
s
.38281 .35065 m .4092 .35691 L .4092 .20715 L p .986 .805 .576 r
F P
0 g
s
.39675 .2277 m .40677 .21758 L .40105 .21271 L p .781 .998 .823 r
F P
0 g
s
.40105 .21271 m .40677 .21758 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40687 .17488 m .40751 .17573 L .40751 .1736 L .618 .504 .702 r
F
.40687 .17488 m .40751 .1736 L .40751 .16223 L F
.35667 .10843 m .40687 .17488 L .40751 .16223 L F
.38502 .23552 m .39675 .2277 L p .35667 .10843 L F P
0 g
s
.4092 .17022 m .40179 .18502 L .40328 .2107 L .986 .805 .576 r
F
.35667 .10843 m .38685 .17417 L .39561 .17369 L .618 .504 .702 r
F
.35667 .10843 m .30815 .15796 L .30815 .16886 L F
.29582 .1593 m .29322 .1732 L p .35667 .10843 L F P
0 g
s
.30112 .14611 m .29582 .1593 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.30888 .1342 m .30112 .14611 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.31877 .12408 m .30888 .1342 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.33038 .1162 m .31877 .12408 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.32034 .23269 m .33215 .23895 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .3432 .11091 L .33038 .1162 L p .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .3432 .11091 L .33706 .1053 L p .412 .839 .956 r
F P
0 g
s
.33706 .1053 m .35062 .1028 L .35667 .10843 L p .412 .839 .956 r
F P
0 g
s
.37213 .24071 m .38502 .23552 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35862 .24306 m .37213 .24071 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35062 .1028 m .39984 .16797 L .40179 .15696 L .617 .504 .702 r
F
.4092 .17022 m .40179 .16786 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.39027 .16849 m .39606 .17367 L .40179 .16786 L .289 .763 .934 r
F
.39984 .16797 m .40179 .17056 L .40179 .16786 L .617 .504 .702 r
F
.39984 .16797 m .40179 .16786 L .40179 .15696 L F
.40751 .17305 m .4092 .17022 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.39984 .16797 m .40179 .18859 L .40179 .17056 L .617 .504 .702 r
F
.35062 .1028 m .38982 .16851 L .39984 .16797 L F
.39027 .16849 m .37562 .17477 L .39606 .17367 L .289 .763 .934 r
F
.37876 .16911 m .37562 .17477 L .39027 .16849 L F
.38982 .16851 m .40179 .18859 L .39984 .16797 L .617 .504 .702 r
F
.40179 .18502 m .40179 .21159 L .40328 .2107 L .986 .805 .576 r
F
.37876 .16911 m .34682 .17632 L .37562 .17477 L .289 .763 .934 r
F
.35062 .1028 m .38099 .16899 L .38174 .16895 L .617 .504 .702 r
F
.30051 .1761 m .30815 .17841 L p .34066 .17118 L .289 .763 .934 r
F P
0 g
s
.35062 .1028 m .38174 .16895 L .38982 .16851 L .617 .504 .702 r
F
.32346 .17212 m .30051 .1761 L .34066 .17118 L .289 .763 .934 r
F
.3066 .21957 m .30741 .22529 L .30051 .2129 L .982 .801 .586 r
F
.31017 .22396 m .30381 .21917 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.30815 .22127 m .31017 .22396 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.36251 .17 m .30815 .17841 L .34682 .17632 L .289 .763 .934 r
F
.34066 .17118 m .30815 .17841 L .36251 .17 L F
.31404 .22796 m .30381 .21917 L .31017 .22396 L p .488 0 0 r
F P
0 g
s
.31017 .22396 m .32034 .23269 L .31404 .22796 L p .488 0 0 r
F P
0 g
s
.30381 .21917 m .31404 .22796 L p .33048 .17174 L .617 .504 .702 r
F P
0 g
s
.35062 .1028 m .32272 .17216 L .33048 .17174 L .617 .504 .702 r
F
.30815 .15796 m .29322 .1732 L .30815 .16886 L .618 .504 .702 r
F
.35062 .1028 m .30178 .16368 L .30473 .17313 L .617 .504 .702 r
F
.30178 .16368 m .29372 .17373 L .30178 .17329 L F
.30178 .16368 m .30178 .17329 L .30473 .17313 L F
.30051 .1761 m .30051 .2129 L p .30178 .19978 L 0 0 .14 r
F P
0 g
s
.30178 .17329 m .30051 .1761 L p .32346 .17212 L .289 .763 .934 r
F P
0 g
s
.30178 .17329 m .30051 .1761 L p .30178 .19978 L 0 0 .14 r
F P
0 g
s
.29772 .20984 m .29567 .20828 L p .29582 .2068 L .826 .439 0 r
F P
0 g
s
.29642 .20072 m .29772 .20984 L .29582 .2068 L .826 .439 0 r
F
.29342 .18721 m .29642 .20072 L .28997 .19576 L p .919 .63 .144 r
F P
0 g
s
.29567 .20828 m .28997 .19576 L .29642 .20072 L p .826 .439 0 r
F P
0 g
s
.28997 .19576 m .29567 .20828 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.35062 .1028 m .30178 .17766 L .30178 .19655 L .617 .504 .702 r
F
.30178 .17766 m .28997 .19576 L .30178 .19655 L F
.30051 .2129 m .30051 .21429 L p .30061 .21319 L 0 0 .14 r
F P
0 g
s
.3027 .21529 m .30381 .21917 L .30147 .21558 L .68 .209 0 r
F
.30051 .2129 m .30147 .21558 L .29772 .20984 L F
.3027 .21529 m .30147 .21558 L .30051 .2129 L F
.35062 .1028 m .30178 .19655 L .30381 .21917 L .617 .504 .702 r
F
.30178 .2173 m .30051 .21429 L .30178 .2217 L 0 0 .14 r
F
.30741 .22529 m .30815 .23062 L .30051 .21429 L .982 .801 .586 r
F
.30061 .21319 m .30051 .21429 L .30374 .22197 L 0 0 .14 r
F
.30051 .21429 m .30051 .36128 L p .30352 .23184 L F P
0 g
s
.30381 .21917 m .29567 .20828 L .29772 .20984 L p .68 .209 0 r
F P
0 g
s
.30178 .21646 m .30381 .21917 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.31404 .22796 m .32594 .23425 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.32594 .23425 m .33897 .23778 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.36251 .17 m .34682 .17632 L .37876 .16911 L .289 .763 .934 r
F
.33897 .23778 m .35258 .23838 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.39096 .2229 m .40105 .21271 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.37916 .23078 m .39096 .2229 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.36618 .23602 m .37916 .23078 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.35258 .23838 m .36618 .23602 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.30504 .16608 m .30489 .17285 L p .38281 .16181 L .289 .763 .934 r
F P
0 g
s
.30504 .16608 m .30178 .17329 L p .3044 .17292 L .289 .763 .934 r
F P
0 g
s
.38281 .16181 m .30178 .17329 L .32346 .17212 L .289 .763 .934 r
F
.29322 .1732 m .29342 .18721 L .28695 .18216 L p .963 .778 .337 r
F P
0 g
s
.28997 .19576 m .28695 .18216 L .29342 .18721 L p .919 .63 .144 r
F P
0 g
s
.28695 .18216 m .28997 .19576 L p .30178 .17766 L .617 .504 .702 r
F P
0 g
s
.30473 .17313 m .30178 .17463 L .30178 .17766 L .617 .504 .702 r
F
.30178 .17463 m .28695 .18216 L .30178 .17766 L F
.29372 .17373 m .28695 .18216 L .30473 .17313 L F
.32272 .17216 m .30381 .21917 L .33048 .17174 L F
.30504 .16608 m .30178 .20079 L .30374 .22197 L 0 0 .14 r
F
.30178 .20079 m .30061 .21319 L .30178 .21646 L F
.30178 .20079 m .30178 .21646 L .30374 .22197 L F
.30178 .20079 m .30051 .2129 L .30061 .21319 L F
.30178 .19978 m .30051 .2129 L .30178 .20079 L F
.29567 .20828 m .30178 .21646 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.30374 .22197 m .30178 .2173 L .30352 .23184 L 0 0 .14 r
F
.30178 .2173 m .30178 .2217 L .30352 .23184 L F
.30504 .16608 m .30178 .19978 L .30178 .20079 L F
.30504 .16608 m .30178 .17329 L p .30178 .19978 L F P
0 g
s
.38281 .16181 m .34066 .17118 L .36251 .17 L .289 .763 .934 r
F
.38281 .16181 m .32346 .17212 L .34066 .17118 L F
.38982 .16851 m .40179 .21159 L .40179 .18859 L .617 .504 .702 r
F
.38174 .16895 m .40179 .21159 L .38982 .16851 L F
.38281 .16181 m .36251 .17 L .37876 .16911 L .289 .763 .934 r
F
.40105 .21271 m .40179 .21159 L p .38174 .16895 L .617 .504 .702 r
F P
0 g
s
.38099 .16899 m .40105 .21271 L .38174 .16895 L .617 .504 .702 r
F
.40179 .21159 m .40899 .20066 L p .40179 .18859 L F P
0 g
s
.37213 .24071 m .38502 .23552 L .37916 .23078 L p .536 .918 .928 r
F P
0 g
s
.39096 .2229 m .37916 .23078 L .38502 .23552 L p .672 .975 .89 r
F P
0 g
s
.38502 .23552 m .39675 .2277 L .39096 .2229 L p .672 .975 .89 r
F P
0 g
s
.40105 .21271 m .39096 .2229 L .39675 .2277 L p .781 .998 .823 r
F P
0 g
s
.38281 .22297 m .38281 .35065 L p .40179 .22084 L .986 .805 .576 r
F P
0 g
s
.40179 .21159 m .40105 .21271 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40328 .2107 m .40179 .21159 L .40179 .22084 L .986 .805 .576 r
F
.40179 .21159 m .38281 .22297 L .40179 .22084 L F
.38281 .16181 m .37876 .16911 L .39027 .16849 L .289 .763 .934 r
F
.38281 .16181 m .38281 .22297 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.4092 .17022 m .40179 .16786 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.40179 .16786 m .38281 .16181 L p .39027 .16849 L .289 .763 .934 r
F P
0 g
s
.40179 .16786 m .38281 .16181 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.40899 .20066 m .41442 .18727 L p .40179 .17056 L .617 .504 .702 r
F P
0 g
s
.40179 .18859 m .40899 .20066 L .40179 .17056 L .617 .504 .702 r
F
.42004 .19233 m .42269 .1783 L p .40751 .16223 L .618 .504 .702 r
F P
0 g
s
.41442 .18727 m .41708 .17314 L p .40179 .15696 L .617 .504 .702 r
F P
0 g
s
.40179 .17056 m .41442 .18727 L .40179 .15696 L .617 .504 .702 r
F
.40179 .18502 m .38281 .22297 L .40179 .21159 L .986 .805 .576 r
F
.40899 .20066 m .40179 .21159 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40328 .2107 m .38281 .35065 L .4092 .20715 L .986 .805 .576 r
F
.32732 .3673 m .30815 .363 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30815 .363 m .30051 .36128 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30051 .36128 m .30504 .35382 L .30504 .16608 L p 0 0 .14 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.36948 .36852 m .40328 .36429 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.32732 .3673 m .36948 .36852 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.30051 .36128 m .32732 .3673 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.32034 .23269 m .33215 .23895 L .32594 .23425 L p 0 .288 .689 r
F P
0 g
s
.33897 .23778 m .32594 .23425 L .33215 .23895 L p 0 .509 .821 r
F P
0 g
s
.33215 .23895 m .3451 .24246 L .33897 .23778 L p 0 .509 .821 r
F P
0 g
s
.35258 .23838 m .33897 .23778 L .3451 .24246 L p .181 .689 .902 r
F P
0 g
s
.38281 .16181 m .33925 .16006 L .30504 .16608 L p .289 .763 .934 r
F P
0 g
s
.30504 .35382 m .33925 .34935 L .33925 .16006 L p .4 .326 .658 r
F P
0 g
s
.32594 .23425 m .31404 .22796 L .32034 .23269 L p 0 .288 .689 r
F P
0 g
s
.33925 .16006 m .30504 .16608 L .30504 .35382 L p .4 .326 .658 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.40328 .36429 m .4092 .35691 L .38281 .35065 L p .224 .73 .894 r
F P
0 g
s
.30504 .35382 m .30051 .36128 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.38281 .35065 m .33925 .34935 L .30504 .35382 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.36618 .23602 m .35258 .23838 L .35862 .24306 L p .373 .824 .935 r
F P
0 g
s
.35862 .24306 m .37213 .24071 L .36618 .23602 L p .373 .824 .935 r
F P
0 g
s
.37916 .23078 m .36618 .23602 L .37213 .24071 L p .536 .918 .928 r
F P
0 g
s
.33925 .34935 m .38281 .35065 L .38281 .16181 L p .767 .627 .704 r
F P
0 g
s
.3451 .24246 m .35862 .24306 L .35258 .23838 L p .181 .689 .902 r
F P
0 g
s
.38281 .16181 m .33925 .16006 L .33925 .34935 L p .767 .627 .704 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65515 .36852 m .61364 .3673 L .61364 .18419 L p .766 .626 .704 r
F P
0 g
s
.58154 .1732 m .58163 .17921 L p .59679 .16886 L .62 .506 .702 r
F P
0 g
s
.58163 .17921 m .58174 .18721 L p .58861 .17884 L .62 .506 .702 r
F P
0 g
s
.59679 .16886 m .58163 .17921 L .58861 .17884 L .62 .506 .702 r
F
.59679 .17841 m .61364 .18419 L p .63629 .17632 L .289 .763 .934 r
F P
0 g
s
.58174 .18721 m .5848 .20072 L p .59679 .18274 L .62 .506 .702 r
F P
0 g
s
.59679 .17841 m .61364 .18419 L p .59913 .22418 L .991 .809 .561 r
F P
0 g
s
.59679 .22127 m .59913 .22418 L .59679 .23062 L .991 .809 .561 r
F
.59679 .17841 m .59913 .22418 L .59679 .22127 L F
.59059 .21315 m .59679 .22127 L p .59199 .21529 L .591 .131 0 r
F P
0 g
s
.59679 .16886 m .58174 .18721 L .59679 .18274 L .62 .506 .702 r
F
.5848 .20072 m .59059 .21315 L p .64636 .10843 L F P
0 g
s
.61364 .18419 m .61364 .3673 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.61364 .18419 m .65515 .18583 L .65515 .36852 L p .766 .626 .704 r
F P
0 g
s
.61364 .18419 m .65515 .18583 L p .66571 .17477 L .289 .763 .934 r
F P
0 g
s
.63629 .17632 m .61364 .18419 L .66571 .17477 L .289 .763 .934 r
F
.59059 .21315 m .59885 .22396 L p .61804 .17729 L .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .60945 .17774 L .61804 .17729 L .62 .506 .702 r
F
.60945 .17774 m .59059 .21315 L .61804 .17729 L F
.6213 .23895 m .63453 .24246 L p .64636 .10843 L F P
0 g
s
.63453 .24246 m .64834 .24306 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.65515 .18583 m .69122 .18013 L .69122 .36429 L p .432 .353 .667 r
F P
0 g
s
.65515 .18583 m .69122 .18013 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.66571 .17477 m .65515 .18583 L .68659 .17367 L .289 .763 .934 r
F
.69122 .36429 m .69122 .18013 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.70111 .35691 m .69829 .35902 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.69829 .35902 m .69122 .36429 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.69829 .21647 m .70559 .20562 L p .69829 .19364 L .62 .506 .702 r
F P
0 g
s
.69829 .17573 m .71109 .19233 L .70279 .17282 L .62 .506 .702 r
F
.69829 .17305 m .70279 .17282 L .69829 .16223 L F
.69829 .17573 m .70279 .17282 L .69829 .17305 L F
.69122 .18013 m .69829 .17305 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.69122 .18013 m .69829 .17305 L p .69829 .21647 L 0 0 .288 r
F P
0 g
s
.69404 .23048 m .69829 .21647 L .69829 .30642 L 0 0 .288 r
F
.69122 .18013 m .69829 .21647 L .69404 .23048 L F
.69829 .21647 m .70559 .20562 L .70484 .20458 L p .829 .979 .687 r
F P
0 g
s
.70484 .20458 m .70276 .2017 L p .70111 .20715 L .829 .979 .687 r
F P
0 g
s
.69829 .21647 m .70484 .20458 L .70111 .20715 L .829 .979 .687 r
F
.69829 .30642 m .70023 .21263 L .70111 .35691 L 0 0 .288 r
F
.70559 .20562 m .71109 .19233 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70023 .21263 m .70111 .17022 L .70111 .35691 L 0 0 .288 r
F
.69829 .17305 m .70111 .17022 L p .69829 .30642 L F P
0 g
s
.69122 .36429 m .65515 .36852 L .65515 .18583 L p .432 .353 .667 r
F P
0 g
s
.67808 .35065 m .70111 .35691 L .70111 .20715 L p .995 .812 .548 r
F P
0 g
s
.69753 .21758 m .69829 .21647 L p .68613 .17369 L .62 .506 .702 r
F P
0 g
s
.68613 .17369 m .69829 .21647 L .69829 .19364 L .62 .506 .702 r
F
.70111 .20715 m .70111 .17022 L p .69594 .2107 L .995 .812 .548 r
F P
0 g
s
.69753 .21758 m .69829 .21647 L p .702 .20066 L .829 .979 .687 r
F P
0 g
s
.70276 .2017 m .702 .20066 L p .69829 .21647 L .829 .979 .687 r
F P
0 g
s
.67718 .17417 m .69753 .21758 L .68613 .17369 L .62 .506 .702 r
F
.68729 .2277 m .69753 .21758 L p .64636 .10843 L F P
0 g
s
.68729 .2277 m .69753 .21758 L .69389 .21271 L p .748 .99 .792 r
F P
0 g
s
.69389 .21271 m .69753 .21758 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.67532 .23552 m .68729 .2277 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70111 .17022 m .69465 .18502 L .69594 .2107 L .995 .812 .548 r
F
.69465 .18502 m .69465 .21159 L .69594 .2107 L F
.69465 .17102 m .69829 .17573 L .69829 .16919 L .62 .506 .702 r
F
.69465 .17102 m .69829 .16919 L .69829 .16223 L F
.64636 .10843 m .69465 .17102 L .69829 .16223 L F
.70111 .17022 m .69465 .16786 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.64636 .10843 m .67718 .17417 L .68613 .17369 L .62 .506 .702 r
F
.64636 .10843 m .59679 .16886 L .59679 .18274 L F
.64636 .10843 m .59679 .15796 L .59679 .16886 L F
.5842 .1593 m .58154 .1732 L p .64636 .10843 L F P
0 g
s
.5896 .14611 m .5842 .1593 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.59753 .1342 m .5896 .14611 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.60764 .12408 m .59753 .1342 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.59885 .22396 m .60924 .23269 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.6195 .1162 m .60764 .12408 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.60924 .23269 m .6213 .23895 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .63259 .11091 L .6195 .1162 L p .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .63259 .11091 L .62851 .1053 L p .402 .836 .951 r
F P
0 g
s
.66019 .1089 m .64636 .10843 L .64237 .1028 L p .238 .717 .935 r
F P
0 g
s
.62851 .1053 m .64237 .1028 L .64636 .10843 L p .402 .836 .951 r
F P
0 g
s
.6735 .11229 m .66019 .1089 L .64636 .10843 L p .62 .506 .702 r
F P
0 g
s
.68568 .11847 m .6735 .11229 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.6962 .12718 m .68568 .11847 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70459 .13802 m .6962 .12718 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.71047 .15053 m .70459 .13802 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.71359 .16416 m .71047 .15053 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.7138 .1783 m .71359 .16416 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.66214 .24071 m .67532 .23552 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64834 .24306 m .66214 .24071 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64237 .1028 m .68241 .16851 L .69265 .16797 L .619 .505 .702 r
F
.68287 .16849 m .68659 .17367 L .69465 .16786 L .289 .763 .934 r
F
.64237 .1028 m .69465 .17056 L .69465 .15696 L .619 .505 .702 r
F
.68287 .16849 m .66571 .17477 L .68659 .17367 L .289 .763 .934 r
F
.64237 .1028 m .6734 .16899 L .67416 .16895 L .619 .505 .702 r
F
.67111 .16911 m .66571 .17477 L .68287 .16849 L .289 .763 .934 r
F
.68241 .16851 m .69465 .21159 L .69465 .18859 L .619 .505 .702 r
F
.64237 .1028 m .67416 .16895 L .68241 .16851 L F
.67416 .16895 m .69465 .21159 L .68241 .16851 L F
.67111 .16911 m .63629 .17632 L .66571 .17477 L .289 .763 .934 r
F
.65452 .17 m .63629 .17632 L .67111 .16911 L F
.68358 .2229 m .69389 .21271 L p .6734 .16899 L .619 .505 .702 r
F P
0 g
s
.64237 .1028 m .66523 .16943 L .6734 .16899 L .619 .505 .702 r
F
.66523 .16943 m .68358 .2229 L .6734 .16899 L F
.59007 .1761 m .59679 .17841 L p .63218 .17118 L .289 .763 .934 r
F P
0 g
s
.61462 .17212 m .59007 .1761 L .63218 .17118 L .289 .763 .934 r
F
.59548 .21996 m .59679 .22106 L .59679 .23062 L .991 .809 .561 r
F
.59007 .1761 m .59679 .22106 L .59548 .21996 L F
.59007 .1761 m .59679 .17841 L p .59679 .22106 L F P
0 g
s
.59007 .36128 m .59007 .21429 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.5848 .20072 m .5877 .20693 L p .58761 .20984 L .744 .363 0 r
F P
0 g
s
.5877 .20693 m .59059 .21315 L .5892 .21161 L p .744 .363 0 r
F P
0 g
s
.5892 .21161 m .58761 .20984 L p .5877 .20693 L .744 .363 0 r
F P
0 g
s
.59007 .21429 m .59007 .2129 L p .59613 .22529 L .991 .809 .561 r
F P
0 g
s
.59059 .21315 m .59199 .21529 L .59007 .2129 L .591 .131 0 r
F
.58761 .20984 m .5892 .21161 L p .59007 .2129 L F P
0 g
s
.5892 .21161 m .59059 .21315 L p .59007 .2129 L .591 .131 0 r
F P
0 g
s
.59007 .2129 m .59007 .1761 L p .59543 .21957 L .991 .809 .561 r
F P
0 g
s
.59679 .15796 m .58154 .1732 L .59679 .16886 L .62 .506 .702 r
F
.64237 .1028 m .61386 .17216 L .62178 .17174 L .619 .505 .702 r
F
.59246 .17329 m .59007 .1761 L p .61462 .17212 L .289 .763 .934 r
F P
0 g
s
.59007 .1761 m .59007 .2129 L p .59246 .19978 L 0 0 .252 r
F P
0 g
s
.59246 .17329 m .59007 .1761 L p .59246 .19978 L 0 0 .252 r
F P
0 g
s
.58154 .1732 m .58174 .18721 L .57731 .18216 L p .913 .737 .242 r
F P
0 g
s
.58039 .19576 m .57731 .18216 L .58174 .18721 L p .853 .569 .034 r
F P
0 g
s
.58174 .18721 m .5848 .20072 L .58039 .19576 L p .853 .569 .034 r
F P
0 g
s
.57731 .18216 m .58039 .19576 L p .59246 .17766 L .619 .505 .702 r
F P
0 g
s
.64237 .1028 m .59246 .16368 L .59246 .17766 L .619 .505 .702 r
F
.59246 .16368 m .57731 .18216 L .59246 .17766 L F
.58761 .20984 m .58622 .20828 L p .58594 .2068 L .744 .363 0 r
F P
0 g
s
.5848 .20072 m .58761 .20984 L .58594 .2068 L .744 .363 0 r
F
.58622 .20828 m .58039 .19576 L .5848 .20072 L p F P
0 g
s
.58039 .19576 m .58622 .20828 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.65452 .17 m .59679 .17841 L .63629 .17632 L .289 .763 .934 r
F
.63218 .17118 m .59679 .17841 L .65452 .17 L F
.61714 .23425 m .63046 .23778 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.63046 .23778 m .64437 .23838 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67152 .23078 m .68358 .2229 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.65826 .23602 m .67152 .23078 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.64437 .23838 m .65826 .23602 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67808 .16181 m .63218 .17118 L .65452 .17 L .289 .763 .934 r
F
.6052 .17262 m .59246 .17766 L .59246 .19655 L .619 .505 .702 r
F
.64237 .1028 m .59548 .17313 L .6052 .17262 L F
.59548 .17313 m .59246 .17766 L .6052 .17262 L F
.59246 .17766 m .58039 .19576 L .59246 .19655 L F
.59543 .21957 m .59613 .22529 L .59007 .2129 L .991 .809 .561 r
F
.59007 .2129 m .59007 .21429 L p .59027 .21319 L 0 0 .252 r
F P
0 g
s
.59199 .21529 m .59454 .21917 L .59188 .21558 L .591 .131 0 r
F
.59007 .2129 m .59188 .21558 L .58761 .20984 L F
.59199 .21529 m .59188 .21558 L .59007 .2129 L F
.59613 .22529 m .59679 .23062 L .59007 .21429 L .991 .809 .561 r
F
.59617 .22197 m .59007 .21429 L .59573 .23184 L 0 0 .252 r
F
.59447 .21842 m .59454 .21917 L p .59199 .21529 L .591 .131 0 r
F P
0 g
s
.59472 .21873 m .59885 .22396 L .59454 .21917 L .591 .131 0 r
F
.59679 .22127 m .59885 .22396 L p .59199 .21529 L F P
0 g
s
.64237 .1028 m .59246 .19655 L .59454 .21917 L .619 .505 .702 r
F
.59027 .21319 m .59007 .21429 L .59617 .22197 L 0 0 .252 r
F
.59454 .21917 m .58622 .20828 L .58761 .20984 L p .591 .131 0 r
F P
0 g
s
.59246 .20079 m .59027 .21319 L .59246 .21646 L 0 0 .252 r
F
.59246 .20079 m .59007 .2129 L .59027 .21319 L F
.59246 .19978 m .59007 .2129 L .59246 .20079 L F
.58622 .20828 m .59246 .21646 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.59246 .21646 m .59454 .21917 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.60499 .22796 m .61714 .23425 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67808 .16181 m .59246 .17329 L .61462 .17212 L .289 .763 .934 r
F
.59454 .21917 m .60499 .22796 L p .62178 .17174 L .619 .505 .702 r
F P
0 g
s
.61386 .17216 m .59454 .21917 L .62178 .17174 L .619 .505 .702 r
F
.60499 .22796 m .59454 .21917 L .59885 .22396 L p 0 .108 .589 r
F P
0 g
s
.59861 .16608 m .59246 .20079 L .59617 .22197 L 0 0 .252 r
F
.59246 .20079 m .59246 .21646 L .59617 .22197 L F
.59861 .16608 m .59833 .17251 L p .67808 .16181 L .289 .763 .934 r
F P
0 g
s
.59861 .16608 m .59246 .17329 L p .59745 .17262 L .289 .763 .934 r
F P
0 g
s
.59861 .16608 m .59246 .19978 L .59246 .20079 L 0 0 .252 r
F
.59861 .16608 m .59246 .17329 L p .59246 .19978 L F P
0 g
s
.59007 .21429 m .59007 .36128 L p .59573 .23184 L 0 0 .252 r
F P
0 g
s
.67808 .16181 m .61462 .17212 L .63218 .17118 L .289 .763 .934 r
F
.67808 .16181 m .65452 .17 L .67111 .16911 L F
.67808 .16181 m .67111 .16911 L .68287 .16849 L F
.69389 .21271 m .69465 .21159 L p .67416 .16895 L .619 .505 .702 r
F P
0 g
s
.6734 .16899 m .69389 .21271 L .67416 .16895 L .619 .505 .702 r
F
.69465 .21159 m .702 .20066 L p .69465 .18859 L F P
0 g
s
.68358 .2229 m .67152 .23078 L .67532 .23552 L p .642 .967 .868 r
F P
0 g
s
.67532 .23552 m .68729 .2277 L .68358 .2229 L p .642 .967 .868 r
F P
0 g
s
.69389 .21271 m .68358 .2229 L .68729 .2277 L p .748 .99 .792 r
F P
0 g
s
.67808 .22297 m .67808 .35065 L p .69465 .22084 L .995 .812 .548 r
F P
0 g
s
.69465 .21159 m .69389 .21271 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.69594 .2107 m .69465 .21159 L .69465 .22084 L .995 .812 .548 r
F
.69465 .21159 m .67808 .22297 L .69465 .22084 L F
.69465 .16786 m .67808 .16181 L p .68287 .16849 L .289 .763 .934 r
F P
0 g
s
.69829 .17305 m .70111 .17022 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.69265 .16797 m .69465 .18859 L .69465 .17056 L .619 .505 .702 r
F
.68241 .16851 m .69465 .18859 L .69265 .16797 L F
.70111 .17022 m .69465 .16786 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.702 .20066 m .70754 .18727 L p .69465 .17056 L .619 .505 .702 r
F P
0 g
s
.69465 .18859 m .702 .20066 L .69465 .17056 L .619 .505 .702 r
F
.67808 .16181 m .67808 .22297 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.69465 .16786 m .67808 .16181 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.69465 .18502 m .67808 .22297 L .69465 .21159 L .995 .812 .548 r
F
.71109 .19233 m .7138 .1783 L p .69829 .16223 L .62 .506 .702 r
F P
0 g
s
.70754 .18727 m .71027 .17314 L p .69465 .15696 L .619 .505 .702 r
F P
0 g
s
.69465 .17056 m .70754 .18727 L .69465 .15696 L .619 .505 .702 r
F
.702 .20066 m .69465 .21159 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.69594 .2107 m .67808 .35065 L .70111 .20715 L .995 .812 .548 r
F
.61364 .3673 m .59679 .363 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.59679 .363 m .59007 .36128 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.59007 .36128 m .59861 .35382 L .59861 .16608 L p 0 0 .252 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61364 .3673 m .65515 .36852 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.59007 .36128 m .61364 .3673 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60924 .23269 m .6213 .23895 L .61714 .23425 L p 0 .333 .74 r
F P
0 g
s
.63046 .23778 m .61714 .23425 L .6213 .23895 L p 0 .531 .846 r
F P
0 g
s
.6213 .23895 m .63453 .24246 L .63046 .23778 L p 0 .531 .846 r
F P
0 g
s
.64437 .23838 m .63046 .23778 L .63453 .24246 L p .19 .694 .908 r
F P
0 g
s
.63453 .24246 m .64834 .24306 L .64437 .23838 L p .19 .694 .908 r
F P
0 g
s
.67808 .16181 m .63522 .16006 L .59861 .16608 L p .289 .763 .934 r
F P
0 g
s
.59861 .35382 m .63522 .34935 L .63522 .16006 L p .42 .343 .664 r
F P
0 g
s
.59885 .22396 m .60924 .23269 L .60499 .22796 L p 0 .108 .589 r
F P
0 g
s
.61714 .23425 m .60499 .22796 L .60924 .23269 L p 0 .333 .74 r
F P
0 g
s
.63522 .16006 m .59861 .16608 L .59861 .35382 L p .42 .343 .664 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59861 .35382 m .59007 .36128 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64834 .24306 m .66214 .24071 L .65826 .23602 L p .362 .82 .929 r
F P
0 g
s
.67152 .23078 m .65826 .23602 L .66214 .24071 L p .513 .91 .914 r
F P
0 g
s
.66214 .24071 m .67532 .23552 L .67152 .23078 L p .513 .91 .914 r
F P
0 g
s
.63522 .34935 m .67808 .35065 L .67808 .16181 L p .768 .627 .704 r
F P
0 g
s
.65826 .23602 m .64437 .23838 L .64834 .24306 L p .362 .82 .929 r
F P
0 g
s
.67808 .16181 m .63522 .16006 L .63522 .34935 L p .768 .627 .704 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.65515 .36852 m .69122 .36429 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.67808 .35065 m .63522 .34935 L .59861 .35382 L p .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.69122 .36429 m .70111 .35691 L .67808 .35065 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.35405 1.29894 m .35023 1.2746 L .34646 1.29355 L p 0 0 .238 r
F P
0 g
s
.34646 1.29355 m .35023 1.31785 L .35405 1.29894 L p 0 0 .238 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.52826 1.29894 m .52325 1.31785 L .58611 1.31592 L p .683 .852 .964 r
F P
0 g
s
.58611 1.31592 m .59152 1.29708 L .52826 1.29894 L p .683 .852 .964 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.28695 .18216 m .28675 .16806 L .29322 .1732 L p .963 .778 .337 r
F P
0 g
s
.29582 .1593 m .29322 .1732 L .28675 .16806 L p .966 .885 .501 r
F P
0 g
s
.57731 .18216 m .57711 .16806 L .58154 .1732 L p .913 .737 .242 r
F P
0 g
s
.5842 .1593 m .58154 .1732 L .57711 .16806 L p .928 .861 .428 r
F P
0 g
s
.28675 .16806 m .28937 .15406 L .29582 .1593 L p .966 .885 .501 r
F P
0 g
s
.30112 .14611 m .29582 .1593 L .28937 .15406 L p .937 .954 .639 r
F P
0 g
s
.57711 .16806 m .57978 .15406 L .5842 .1593 L p .928 .861 .428 r
F P
0 g
s
.5896 .14611 m .5842 .1593 L .57978 .15406 L p .906 .944 .586 r
F P
0 g
s
.28937 .15406 m .2947 .14077 L .30112 .14611 L p .937 .954 .639 r
F P
0 g
s
.30888 .1342 m .30112 .14611 L .2947 .14077 L p .88 .991 .751 r
F P
0 g
s
.57978 .15406 m .58523 .14077 L .5896 .14611 L p .906 .944 .586 r
F P
0 g
s
.59753 .1342 m .5896 .14611 L .58523 .14077 L p .852 .987 .714 r
F P
0 g
s
.58523 .14077 m .59321 .12877 L .59753 .1342 L p .852 .987 .714 r
F P
0 g
s
.60764 .12408 m .59753 .1342 L .59321 .12877 L p .772 .997 .815 r
F P
0 g
s
.2947 .14077 m .30251 .12877 L .30888 .1342 L p .88 .991 .751 r
F P
0 g
s
.31877 .12408 m .30888 .1342 L .30251 .12877 L p .799 .999 .84 r
F P
0 g
s
.30251 .12877 m .31247 .11858 L .31877 .12408 L p .799 .999 .84 r
F P
0 g
s
.33038 .1162 m .31877 .12408 L .31247 .11858 L p .695 .978 .905 r
F P
0 g
s
.59321 .12877 m .60339 .11858 L .60764 .12408 L p .772 .997 .815 r
F P
0 g
s
.6195 .1162 m .60764 .12408 L .60339 .11858 L p .67 .974 .888 r
F P
0 g
s
.31247 .11858 m .32415 .11064 L .33038 .1162 L p .695 .978 .905 r
F P
0 g
s
.3432 .11091 m .33038 .1162 L .32415 .11064 L p .567 .926 .945 r
F P
0 g
s
.60339 .11858 m .61532 .11064 L .6195 .1162 L p .67 .974 .888 r
F P
0 g
s
.63259 .11091 m .6195 .1162 L .61532 .11064 L p .547 .921 .934 r
F P
0 g
s
.32415 .11064 m .33706 .1053 L .3432 .11091 L p .567 .926 .945 r
F P
0 g
s
.61532 .11064 m .62851 .1053 L .63259 .11091 L p .547 .921 .934 r
F P
0 g
s
.37022 .1089 m .35667 .10843 L .35062 .1028 L p .229 .713 .93 r
F P
0 g
s
.38324 .11229 m .37022 .1089 L .35667 .10843 L p .618 .504 .702 r
F P
0 g
s
.39516 .11847 m .38324 .11229 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.40546 .12718 m .39516 .11847 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41367 .13802 m .40546 .12718 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41944 .15053 m .41367 .13802 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.42249 .16416 m .41944 .15053 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.42269 .1783 m .42249 .16416 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35062 .1028 m .36426 .10327 L .37022 .1089 L p .229 .713 .93 r
F P
0 g
s
.38324 .11229 m .37022 .1089 L .36426 .10327 L p .021 .544 .86 r
F P
0 g
s
.64237 .1028 m .6563 .10327 L .66019 .1089 L p .238 .717 .935 r
F P
0 g
s
.6735 .11229 m .66019 .1089 L .6563 .10327 L p .055 .563 .881 r
F P
0 g
s
.36426 .10327 m .37737 .10668 L .38324 .11229 L p .021 .544 .86 r
F P
0 g
s
.39516 .11847 m .38324 .11229 L .37737 .10668 L p 0 .332 .739 r
F P
0 g
s
.6563 .10327 m .66969 .10668 L .6735 .11229 L p .055 .563 .881 r
F P
0 g
s
.68568 .11847 m .6735 .11229 L .66969 .10668 L p 0 .374 .784 r
F P
0 g
s
.28675 .16806 m .28695 .18216 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.28937 .15406 m .28675 .16806 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.57711 .16806 m .57731 .18216 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.57978 .15406 m .57711 .16806 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.2947 .14077 m .28937 .15406 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.58523 .14077 m .57978 .15406 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.37737 .10668 m .38937 .1129 L .39516 .11847 L p 0 .332 .739 r
F P
0 g
s
.40546 .12718 m .39516 .11847 L .38937 .1129 L p 0 .089 .568 r
F P
0 g
s
.66969 .10668 m .68195 .1129 L .68568 .11847 L p 0 .374 .784 r
F P
0 g
s
.6962 .12718 m .68568 .11847 L .68195 .1129 L p 0 .155 .642 r
F P
0 g
s
.30251 .12877 m .2947 .14077 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.59321 .12877 m .58523 .14077 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.60339 .11858 m .59321 .12877 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.31247 .11858 m .30251 .12877 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.38937 .1129 m .39974 .12166 L .40546 .12718 L p 0 .089 .568 r
F P
0 g
s
.41367 .13802 m .40546 .12718 L .39974 .12166 L p .629 .164 0 r
F P
0 g
s
.68195 .1129 m .69255 .12166 L .6962 .12718 L p 0 .155 .642 r
F P
0 g
s
.70459 .13802 m .6962 .12718 L .69255 .12166 L p 0 0 .459 r
F P
0 g
s
.39974 .12166 m .408 .13258 L .41367 .13802 L p .629 .164 0 r
F P
0 g
s
.41944 .15053 m .41367 .13802 L .408 .13258 L p .786 .401 0 r
F P
0 g
s
.69255 .12166 m .70099 .13258 L .70459 .13802 L p 0 0 .459 r
F P
0 g
s
.71047 .15053 m .70459 .13802 L .70099 .13258 L p .692 .318 0 r
F P
0 g
s
.32415 .11064 m .31247 .11858 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.61532 .11064 m .60339 .11858 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.41465 .20562 m .42004 .19233 L .41442 .18727 L p .923 .951 .614 r
F P
0 g
s
.70754 .18727 m .702 .20066 L .70559 .20562 L p .882 .931 .551 r
F P
0 g
s
.70559 .20562 m .71109 .19233 L .70754 .18727 L p .882 .931 .551 r
F P
0 g
s
.408 .13258 m .4138 .14518 L .41944 .15053 L p .786 .401 0 r
F P
0 g
s
.42249 .16416 m .41944 .15053 L .4138 .14518 L p .89 .603 .092 r
F P
0 g
s
.70099 .13258 m .70692 .14518 L .71047 .15053 L p .692 .318 0 r
F P
0 g
s
.71359 .16416 m .71047 .15053 L .70692 .14518 L p .81 .532 0 r
F P
0 g
s
.41708 .17314 m .41442 .18727 L .42004 .19233 L p .951 .876 .468 r
F P
0 g
s
.42004 .19233 m .42269 .1783 L .41708 .17314 L p .951 .876 .468 r
F P
0 g
s
.71027 .17314 m .70754 .18727 L .71109 .19233 L p .901 .842 .385 r
F P
0 g
s
.71109 .19233 m .7138 .1783 L .71027 .17314 L p .901 .842 .385 r
F P
0 g
s
.4138 .14518 m .41688 .1589 L .42249 .16416 L p .89 .603 .092 r
F P
0 g
s
.42269 .1783 m .42249 .16416 L .41688 .1589 L p .942 .761 .294 r
F P
0 g
s
.70692 .14518 m .71006 .1589 L .71359 .16416 L p .81 .532 0 r
F P
0 g
s
.7138 .1783 m .71359 .16416 L .71006 .1589 L p .879 .709 .191 r
F P
0 g
s
.41688 .1589 m .41708 .17314 L .42269 .1783 L p .942 .761 .294 r
F P
0 g
s
.71006 .1589 m .71027 .17314 L .7138 .1783 L p .879 .709 .191 r
F P
0 g
s
.35062 .1028 m .33706 .1053 L .32415 .11064 L p .617 .504 .702 r
F P
0 g
s
.64237 .1028 m .62851 .1053 L .61532 .11064 L p .619 .505 .702 r
F P
0 g
s
.37737 .10668 m .36426 .10327 L .35062 .1028 L p .617 .504 .702 r
F P
0 g
s
.38937 .1129 m .37737 .10668 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.39974 .12166 m .38937 .1129 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.408 .13258 m .39974 .12166 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.4138 .14518 m .408 .13258 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.41688 .1589 m .4138 .14518 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.41708 .17314 m .41688 .1589 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.66969 .10668 m .6563 .10327 L .64237 .1028 L p .619 .505 .702 r
F P
0 g
s
.68195 .1129 m .66969 .10668 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.69255 .12166 m .68195 .1129 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70099 .13258 m .69255 .12166 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70692 .14518 m .70099 .13258 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.71006 .1589 m .70692 .14518 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.71027 .17314 m .71006 .1589 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool=00000:h0oooo3000003K0?oo
o`00fP3oool4000000d0WH6c0P00002X0?ooo`@00000302NPK<300000=P0oooo003F0?ooo`@00000
4`2MPK<300000:40oooo1000000C09j1/`<00000e@3oool00=@0oooo0P00000K09f1/`800000V`3o
ool3000001/0WX6c0P00003B0?ooo`00d@3oool3000001l0WH6c0P00002F0?ooo`<00000802NPK<2
00000=00oooo003?0?ooo`8000002`2MPK<00`000000WH6c09f1/`0F09f1/`<00000T@3oool20000
02D0WX6c0`00003=0?ooo`00c@3oool2000002X0WH6c00<000000?ooo`3oool0R`3oool2000002/0
WX6c00<000000?ooo`3oool0b@3oool00<`0oooo00<0000009f1/`2MPK<0:`2MPK<00`000000oooo
0?ooo`290?ooo`030000002NPK<0WX6c02`0WX6c00<000000?ooo`3oool0b03oool00<X0oooo0P00
000_09f1/`030000003oool0oooo08L0oooo00<0000009j1/`2NPK<0;P2NPK<00`000000oooo0?oo
o`370?ooo`00b03oool200000380WH6c00<000000?ooo`3oool0Q03oool200000380WX6c0P000037
0?ooo`00a`3oool00`000000WH6c09f1/`0>09f1/`0309j1/`2MPK<0WH6c0280WH6c00<000000?oo
o`3oool0PP3oool00`000000WX6c09j1/`0d09j1/`030000003oool0oooo0<@0oooo00360?ooo`03
0000002MPK<0WH6c03D0WH6c00<000000?ooo`3oool0P03oool00`000000WX6c09j1/`0f09j1/`03
0000003oool0oooo0<<0oooo00350?ooo`030000002MPK<0WH6c03L0WH6c00<000000?ooo`3oool0
OP3oool00`000000WX6c09j1/`0h09j1/`030000003oool0oooo0<80oooo00340?ooo`030000002M
PK<0WH6c03T0WH6c00<000000?ooo`3oool0O03oool00`000000WX6c09j1/`0E09j1/`030?ooo`2N
PK<0WX6c0280WX6c00<000000?ooo`3oool0`@3oool00<@0oooo00<0000009f1/`2MPK<0>P2MPK<0
0`000000oooo0?ooo`1j0?ooo`030000002NPK<0WX6c03/0WX6c00<000000?ooo`3oool0`@3oool0
0<<0oooo00<0000009f1/`2MPK<03P2MPK<00`2NPK<0WH6c09f1/`0[09f1/`030000003oool0oooo
07P0oooo00<0000009j1/`2NPK<0?@2NPK<00`000000oooo0?ooo`300?ooo`00`P3oool00`000000
WH6c09f1/`0m09f1/`800000N03oool00`000000WX6c09j1/`0o09j1/`030000003oool0oooo0;l0
oooo00310?ooo`030000002MPK<0WH6c03l0WH6c0P00001f0?ooo`030000002NPK<0WX6c0440WX6c
00<000000?ooo`3oool0_P3oool00<00oooo00<0000009f1/`2MPK<0@@2MPK<00`000000oooo0?oo
o`1c0?ooo`030000002NPK<0WX6c0480WX6c00<000000?ooo`3oool0_P3oool00<00oooo00<00000
09f1/`2MPK<0@P2MPK<00`000000oooo0?ooo`1b0?ooo`030000002NPK<0WX6c01P0WX6c00<0oooo
09j1/`2NPK<0:02NPK<00`000000oooo0?ooo`2m0?ooo`00_`3oool00`000000WH6c09f1/`0>09f1
/`0309j1/`2MPK<0WH6c0380WH6c0P00001b0?ooo`030000002NPK<0WX6c04@0WX6c00<000000?oo
o`3oool0_@3oool00;h0oooo00<0000009f1/`2MPK<0A@2MPK<200000700oooo00<0000009j1/`2N
PK<0AP2NPK<00`000000oooo0?ooo`2l0?ooo`00_@3oool00`000000WH6c09f1/`1609f1/`800000
K`3oool00`000000WX6c09j1/`1709j1/`030000003oool0oooo0;`0oooo002m0?ooo`030000002M
PK<0WH6c04H0WH6c00<000000<UV00000000KP3oool00`000000WX6c09j1/`1809j1/`030000003o
ool0oooo0;/0oooo002l0?ooo`030000002MPK<0WH6c04P0WH6c0P00001]0?ooo`030000002NPK<0
WX6c04T0WX6c00<000000?ooo`3oool0^`3oool00;`0oooo00<0000009f1/`2MPK<03@2MPK<00`2N
PK<0WH6c09f1/`0h09f1/`0300000039IP00000006`0oooo00<0000009j1/`2NPK<0BP2NPK<00`00
0000oooo0?ooo`2j0?ooo`00^`3oool00`000000WH6c09f1/`1:09f1/`0300000039IP00oooo06X0
oooo00<0000009j1/`2NPK<0B`2NPK<00`000000oooo0?ooo`2j0?ooo`00^`3oool00`000000WH6c
09f1/`1:09f1/`0300000039IP00000006X0oooo00<0000009j1/`2NPK<0C02NPK<00`000000oooo
0?ooo`2i0?ooo`00^`3oool00`000000WH6c09f1/`1:09f1/`80000000<0bFH00?ooo`3oool0J03o
ool00`000000WX6c09j1/`1<09j1/`030000003oool0oooo0;T0oooo002j0?ooo`030000002MPK<0
WH6c04/0WH6c00@000000>>J5`0000000000J03oool00`000000WX6c09j1/`1=09j1/`800000^P3o
ool00;X0oooo00<0000009f1/`2MPK<02`2MPK<00`2NPK<0WH6c09f1/`0n09f1/`030000003SVQL0
000006P0oooo00<0000009j1/`2NPK<0CP2NPK<00`000000oooo0?ooo`2h0?ooo`00^P3oool00`00
0000WH6c09f1/`1<09f1/`040000003SVQL0hiXG000006L0oooo00<0000009j1/`2NPK<0CP2NPK<2
00000;T0oooo002i0?ooo`030000002MPK<0WH6c04d0WH6c00@000000>>J5`3SVQL00000IP3oool0
0`000000WX6c09j1/`1?09j1/`800000^@3oool00;T0oooo00<0000009f1/`2MPK<0C@2MPK<01000
0000hiXG0>>J5`00001V0?ooo`030000002NPK<0WX6c04l0WX6c0P00002i0?ooo`00^@3oool00`00
0000WH6c09f1/`1>09f1/`040000003SVQL0hiXG000006D0oooo00<0000009j1/`2NPK<0D02NPK<2
00000;P0oooo002i0?ooo`030000002MPK<0WH6c00P0WH6c00<0WX6c09f1/`2MPK<0@`2MPK<01000
0000hiXG0>>J5`00001U0?ooo`030000002NPK<0WX6c0500WX6c0P00002h0?ooo`00^03oool00`00
0000WH6c09f1/`1?09f1/`040000003SVQL0hiXG000006@0oooo00<0000009j1/`2NPK<06`2NPK<0
0`3oool0WX6c09j1/`0c09j1/`800000^03oool00;P0oooo00<0000009f1/`2MPK<0702MPK<@0000
02<0WH6c0P0000000`3SVQL000000?ooo`1S0?ooo`030000002NPK<0WX6c01l0WX6c4000000R09j1
/`800000^03oool00;P0oooo00<0000009f1/`2MPK<05P2MPK<600000080IU>X00<000000<BP]034
X;@02`34X;@?000001@0WH6c00<000000?72B`0000000P00001S0?ooo`030000002NPK<0WX6c01T0
WX6c1P00000206]GZ@0300000034X;@0a:2d00/0a:2d3`00000C09j1/`<00000]`3oool00;P0oooo
00<0000009f1/`2MPK<04@2MPK<5000000P0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0000000200000140WH6c00D000000?72B`3a`T/0lL9;0000001S0?ooo`030000002NPK<0WX6c01<0
WX6c1P00000806]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S00000000P00000@09j1/`03
0000003Q]C0000000;L0oooo002g0?ooo`030000002MPK<0WH6c00`0WH6c1P00000=06ICZ0030000
0034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<00P3lcY<4000000d0WH6c00D000000?72B`3a`T/0
lL9;0000001R0?ooo`030000002NPK<0WX6c00h0WX6c1P00000>06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`00P3nch`2000000h0WX6c00<000000>6e<0000000]`3oool00;L0oooo
00<0000009f1/`2MPK<02@2MPK<3000001<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`060?c>T`<000002P2MPK<01@000000lL9;0?72B`3a`T/000000680oooo00<0000009j1/`2N
PK<02`2NPK<3000001@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0040?k?S0<0
00002`2NPK<00`000000hKD`0000002g0?ooo`00]`3oool00`000000WH6c09f1/`0809f1/`800000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00T0o<jC00<0000009f1/`2MPK<0
1`2MPK<01@000000lL9;0?72B`3a`T/000000680oooo00<0000009j1/`2NPK<02P2NPK<2000001H0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0070?k?S0030000002NPK<0WX6c00P0
WX6c00<000000>6e<0000000]`3oool00;L0oooo00<0000009f1/`2MPK<0202MPK<2000001D0IU>X
00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0
lL9;0000001R0?ooo`030000002NPK<0WX6c00T0WX6c00<000000000@00000005P1[EjT00`000000
a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<2P2NPK<00`000000hKD`0000002g0?ooo`00
]`3oool00`000000WH6c09f1/`0709f1/`030000000002<0000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0lL9;0000001R0?ooo`03
0000002NPK<0WX6c00P0WX6c00@000000000@000040000005P1[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00P0o/n<2P2NPK<00`000000hKD`0000002g0?ooo`00]`3oool00`000000
WH6c09f1/`0709f1/`030000000002<0000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0lL9;0000001R0?ooo`030000002NPK<0WX6c
00L0WX6c00D000000000@000040000100000000F06]GZ@0300000034X;@0a:2d01P0a:2d00<00000
0?k?S03nch`0203nch`:09j1/`030000003Q]C0000000;L0oooo002g0?ooo`030000002MPK<0WH6c
00L0WH6c0P0002<00`000000IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<02P3lcY<909f1/`8000000P3a`T/00`000000oooo0?ooo`1P0?ooo`030000002NPK<0WX6c
00L0WX6c100004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0203nch`:09j1/`<00000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`03
0000001VDjP0IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0
WH6c00<000000??PM`0000000P00001R0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`:09j1/`<0
0000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`030000001VDjP0IU>X01<0IU>X
00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000??PM`3ch7L0
ln1g0000001R0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000JeNY06]GZ@0D06]GZ@03
00000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`909j1/`040000003Vef80i]MR0000
0;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06ICZ00C06ICZ003
00000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<909f1/`050000003ch7L0ln1g0??P
M`000000HP3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`00
0000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<2@2NPK<010000000i]MR0>KGHP00002g
0?ooo`00]`3oool00`000000WH6c09f1/`0709f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC202MPK<00`000000ln1g0??PM`020??P
M`030000003oool0oooo0600oooo00<0000009j1/`2NPK<01`2NPK<40000@0030000001[EjT0JeNY
01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0T0WX6c00@000000>KG
HP3Vef800000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`030000001VDjP0IU>X
01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`P0WH6c00D000000??P
M`3ch7L0ln1g0000001S0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000JeNY06]GZ@0D
06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`909j1/`040000003Vef80
i]MR00000;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06ICZ00C
06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<809f1/`050000003ch7L0
ln1g0??PM`000000H`3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0501[
EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<01@000000i]MR0>KG
HP3Vef8000000;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06IC
Z00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<809f1/`050000003c
h7L0ln1g0??PM`000000H`3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<010000000i]MR
0>KGHP00002h0?ooo`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP0
4`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC202MPK<01@000000ln1g
0??PM`3ch7L0000006@0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0P0WX6c00@000000>KGHP3V
ef800000^03oool00;P0oooo00<0000009f1/`2MPK<01P2MPK<200008`030000001VDjP0IU>X01<0
IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`P0WH6c00@0k?>M0000003c
h7L00000I@3oool00`000000WX6c09j1/`0609j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`00
0000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<0103QkXd000000>KGHP00002h
0?ooo`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1`2MPK<00`000000k?>M0>ccW@020000
06D0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00<000000>7^S@3QkXd00P00002h0?oo
o`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1`2MPK<01@000000k?>M0>ccW@3/lid00000
06D0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00D000000>7^S@3QkXd0hNj=0000002h
0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1P2MPK<00`000000k?>M0>ccW@020>cc
W@030000003oool0oooo06@0oooo00<0000009j1/`2NPK<01@2NPK<40000@0030000001[EjT0JeNY
01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00D000000>7^
S@3QkXd0hNj=0000002h0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<0000006IC
Z01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1P2MPK<01@00
0000k?>M0>ccW@3/lid0000006L0oooo00<0000009j1/`2NPK<01@2NPK<30000@00309j1/`000000
JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0H0WX6c00D00000
0>7^S@3QkXd0hNj=0000002i0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<00000
06ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1@2MPK<0
0`000000k?>M0>ccW@020>ccW@030000003oool0oooo06D0oooo202NPK<30000@00309j1/`000000
JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0H0WX6c00D00000
0>7^S@3QkXd0hNj=0000002i0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<00000
06ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1@2MPK<0
0`000000k?>M0>ccW@020>ccW@030000003oool0oooo06D0oooo00<0000009j1/`2NPK<01@2NPK<3
0000@00309j1/`000000JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S008
0?k?S0H0WX6c00@000000>7^S@3QkXd00000^P3oool00;X0oooo00<0000009f1/`2MPK<0102MPK<2
00008`030000001VDjP0IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:
0?c>T`@0WH6c00<000000>ccW@3/lid00P3/lid2000006P0oooo00<0000009j1/`2NPK<0102NPK<4
0000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S008
0?k?S0D0WX6c00D000000>7^S@3QkXd0hNj=0000002j0?ooo`00^P3oool00`000000WH6c09f1/`04
09f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0
o<jC00X0o<jC102MPK<2000000<0k?>M0`00001V0?ooo`8000001P2NPK<40000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0D0WX6c00@00000
0>7^S@3QkXd00000^`3oool00;/0oooo00<0000009f1/`2MPK<00`2MPK<200008`030000001VDjP0
IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`<0WH6c00@00000
0=gm^`3MoK/000000P3/lid2000000030<e[00000000oooo06<0oooo00@000000:23/`2PPk<00000
1@2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<
0?k?S0080?k?S0@0WX6c00D000000=Cj[`000000hNj=0000002k0?ooo`00^`3oool00`000000WH6c
09f1/`0309f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00X0o<jC0`2MPK<010000000gOfk0=gm^`3MoK/20000000409n2/`000000cF/00000
06@0oooo00@000000:23/`2PPk<000001@2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<00000
0<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0@0WX6c00@000000=Cj[`0000000000_03o
ool00;`0oooo00<0000009f1/`2MPK<00P2MPK<200008`030000001VDjP0IU>X01<0IU>X00<00000
0<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`80WH6c00<000000=gm^`3MoK/00`3MoK/0
1P000000Wh:c09n2/`000000cF/000000680oooo00<000000:23/`2PPk<00P2PPk<00`000000WX6c
09j1/`0209j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00P0o/n<0`2NPK<01@000000e?Z_0=Cj[`3DnZl000000;`0oooo002l0?ooo`030000
002MPK<0WH6c0080WH6c0P0002<00`000000IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<02P3lcY<209f1/`030000003MoK/000000080gOfk00L0000009n2/`2OP[<0
Wh:c0000003=J`0000000680oooo00<000000:23/`2PPk<00P2PPk<00`000000WX6c09j1/`0209j1
/`@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<
00P0o/n<0P2NPK<01@000000e?Z_0000003DnZl000000;d0oooo002m0?ooo`040000002MPK<0WH6c
09f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0
o<jC00X0o<jC00D0WH6c0000003MoK/0o<jC000000020=gm^`030000002OP[<0Wh:c0080Wh:c0P00
001Q0?ooo`030000002PPk<0X8>c00@0X8>c00@0000009j1/`2NPK<0WX6c100004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01`2NPK<00000
0=Cj[`3nch`000000=Cj[`000000_@3oool00;h0oooo00<0000009f1/`2MPK<00P0002<00`000000
IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<01`2MPK<0
o<jC0?c>T`3lcY<000000=gm^`0000001@2OP[<00`000000cF/00000001P0?ooo`030000002PPk<0
X8>c00D0X8>c00<0000009j1/`2NPK<0100004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0203nch`0102NPK<0o/n<0?k?S03nch`200000;h0oooo002n
0?ooo`80000000@0WH6c00008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003l
cY<0o<jC00X0o<jC00@000000?c>T`3lcY<0o<jC0P00000609n2/`<00000G`3oool00`000000X8>c
0:23/`060:23/`80000000<0WX6c0000@00004000P0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01@000000o/n<0?k?S03nch`000000;l0
oooo002o0?ooo`050000002MPK<0000S00008`0000005@1VDjP00`000000a:2d0<BP]00H0<BP]003
0000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01@2OP[<010000000iidM00000000001N0?oo
o`030000002PPk<0X8>c00L0X8>c00<0000009j1/`0004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`030000003WWAd0000005h0oooo00<000000:23
/`2PPk<01`2PPk<2000000@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo0P0000000`0002<0
000006ICZ00D06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03@3lcY<2000000P0
Wh:c00<000000>NM7@000000G@3oool00`000000X8>c0:23/`080:23/`03000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01P2OP[<00`000000
iidM0000001M0?ooo`030000002PPk<0X8>c00P0X8>c00<000000000@00000000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`040000003WWAd0iidM0000
05`0oooo00<000000:23/`2PPk<0202PPk<01000000000100000@00000020000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0
oooo0;d0oooo00300?ooo`040000000002<0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@0
0`000000o<jC0?c>T`0>0?c>T`030000002PP[<0Wh:c00L0Wh:c00<000000>NM7@000000G03oool0
0`000000X8>c0:23/`080:23/`0700000000040000100000@000000000100000000F06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01@0004T0o/n<0?k?S03nch`000000;l0
oooo00300?ooo`040000003kcIH0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000002OP[<0X8:c00L0Wh:c00<000000>NM7@000000G03oool00`000000
X8>c0:23/`080:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
10000000Wh:c09n2/`2PP[<609n2/`80000000<0iidM0?ooo`3oool0F@3oool00`000000X8>c0:23
/`090:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S
0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<01@000000
Wh:c09n2/`2OP[<0X8:c00D0Wh:c00@000000??5D00000000000FP3oool00`000000X8>c0:23/`09
0:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0a:2d01P0a:2d
00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S0?_=
UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c
09n2/`0209n2/`030?ooo`2OP[<0Wh:c0080Wh:c00@000000??5D03caE000000FP3oool00`000000
X8>c0:23/`090:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
0`000000Wh:c09n2/`0309n2/`050?ooo`2OP[<0Wh:c09n2/`0000000P3caE000`000000oooo0?oo
o`1H0?ooo`030000002PPk<0X8>c00T0X8>c00L000000000@000040000100?g?S`000400000001H0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0
oooo00300?ooo`040000000002<0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00@0oooo09n2/`2OP[<000000P3caE000`00
0000oooo0?ooo`1H0?ooo`030000002PPk<0X8>c00P0X8>c0P0000030000@0030?g?S`0004000000
01H0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo
0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`00
0000o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00D0Wh:c00<0oooo09n2/`0000000P3caE000`00
0000oooo0?ooo`1H0?ooo`030000002PPk<0X8>c00L0X8>c00<000000000A00000001@0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050?ooo`000000llE@
0??5D0000000FP3oool00`000000X8>c0:23/`070:23/`030000000004@0000000D0001000<00000
06]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<00000
0?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H
0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01`2OP[<010000000llE@0??5D000
001J0?ooo`030000002PPk<0X8>c00H0X8>c00@000000000A00004@000001@0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0709n2/`80000000<0llE@0000003oool0
F@3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`030000003ehG/0mN5k00800000
FP3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k0?GQN`00
0000FP3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k0?GQ
N`000000FP3oool00`000000X8>c0:23/`050:23/`@0001400<000000000@00004000`0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k
0?GQN`000000FP3oool00`000000X8>c0:23/`040:23/`030000002PPk<000140080001400<00000
0000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<00000
0?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E
06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`05
09n2/`030000003ehG/0mN5k0080mN5k00<000000?ooo`3oool0F03oool00`000000X8>c0:23/`06
0:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
0`000000Wh:c09n2/`0509n2/`050000003ehG/0mN5k0?GQN`000000F`3oool00`000000X8>c0:23
/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034
X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool0
10000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3l
cY<00`000000Wh:c09n2/`0509n2/`050000003ehG/0mN5k0?GQN`000000G03oool00`000000X8>c
0:23/`050:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03o
ool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<0
3P3lcY<00`000000Wh:c09n2/`0509n2/`8000000P3ehG/00`000000oooo0?ooo`1J0?ooo`030000
002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00<000000>gcW`3]lil00`00001L0?ooo`030000
002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00<000000>gcW`3]lil00P3]lil00`000000oooo
0?ooo`1J0?ooo`030000002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000
001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000
003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00<0Wh:c0P0000040>gcW`030000
003oool0oooo05/0oooo00<000000:23/`2PPk<0102PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<00`2OP[<00`000000kO>O
0>gcW`020>gcW`030000003oool0oooo05`0oooo00<000000:23/`2PPk<0102PPk<30000A0030000
00000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<00000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<0
0`2OP[<00`000000kO>O0>gcW`020>gcW`030000003oool0oooo05`0oooo00<000000:23/`2PPk<0
102PPk<30000A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d
0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0
000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC
00<0000009n2/`2OP[<00P2OP[<00`000000kO>O0>gcW`020>gcW`030000003oool0oooo05h0oooo
00<000000:23/`2PPk<00`2PPk<30000A003000000000400001000<0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0
_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<00P2OP[<00`000000kO>O0>gcW`020>gcW`030000
003oool0oooo05h0oooo00<000000:23/`2PPk<00`2PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00L0000009n2/`2OP[<0Wh:c0000003OoKd00000
00<0kO>O00<000000?ooo`3oool0G`3oool00`000000X8>c0:23/`020:23/`<0001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<01@000000Wh:c09n2/`2OP[<0
00000080gofm0`00001R0?ooo`030000002PPk<0X8>c0080X8>c0`0004@00`00000000100000@003
0000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<
0?k?S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<00000
0<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`040000002OP[<0Wh:c000000D0gofm00<0
00000?ooo`3oool0H@3oool010000000X8>c0:23/`2PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00@0000009n2/`2OP[<00000103OoKd00`000000
oooo0?ooo`1R0?ooo`040000002PPk<0X8>c0:23/`<0001400<000000000@00004000`0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<020000000Wh:c0000003OoKd0n/bG0000003OoKd00000
IP3oool00`000000X8>c0:23/`030000A003000000000400001000<0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0
_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00h0o<jC00<0000009n2/`3jc9L00P3jc9L2000006P0oooo00<000000:23/`0004@0
0P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@0
6034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`0400000000
02<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`800000
0`3jc9L2000006P0oooo00<000000:23/`0004@00P0004@00`00000000100000@0030000@0030000
001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000
003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0
I`3oool2000000<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03o
ool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<0
3P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000A00004@0
0P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@0
6034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`0400000000
02<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`040000
003jc9L0n/bG0?[<U`800000J@3oool00`00000000140000A0020000A003000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000
oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000bOoD0?[<U`020?[<U`030000003oool0oooo06L0
oooo00<000000000A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0
oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`000000
00140000A0020000A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000
a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo
00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0
o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080
001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S
00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000
n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`000000
00100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000
o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0
IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080
n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000
oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0
oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY00<00000
0<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?oo
o`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>
0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P00000000140000A03l
cI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<00000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L0
0P3jc9L00`000000oooo0?ooo`1W0?ooo`060000000004@000140?c=U00004@000001@0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo
06L0oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY00<0
00000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo0030
0?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>
T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P00000000140000
A03lcI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]003
0000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<0
00005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3j
c9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`060000000004@000140?c=U00004@000001@000400
0`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`0
0`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0
a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0
oooo06L0oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P0000000014
0000A03lcI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@0o<fD0080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool05@3oooll000001H0oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00@000000?oo
o`3oool0oooo5000000909j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D
00000080oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0
oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@0
0`000000o<jC0?c>T`060?c>Ta4000007@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0
b:Bc01/0b:Bc4@00000C06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`0
0`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0
a:2d01D0a:2d3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02dTk@09P2dTk@0
0`000000b:Bc0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000706]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S00008`00000E06ICZ00300000034X;@0a:2d00T0a:2d3000000B08A/[`030000002NPK<0
WX6c0180WX6cD000000D0<RT/`030000003K/Zl0fk:_0100fk:_3000000F0<BP]0030000003nch`0
o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP0
0`000000a:2d00000009000001P0Q6b_6`00001@03Rji1D000007P3K/Zl:000000`0a:2d00<00000
0?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000?
06ICZ0P000000`1SD:L00`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@00000
0>c0Y`3/`:L0k<2W200000040<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3o
ool00<00oooo00@0000000008`0002<000001`1VDjP8000000/0He2W00<0000008A/[`24K:l01024
K:l<000009h0>;[T300000060=^b[`030000003/`:L0k<2W00T0k<2W2000000;0?k?S0030000003o
ool0oooo0;d0oooo00300?ooo`030000000002<0000S00P00000401SD:L:00000;H0>;[T1`00000C
0>c0Y`P000000`3nch`00`000000oooo0?ooo`2m0?ooo`00_@3oool600000100He2W2000003:03Rj
i0P00000403/`:L600000;d0oooo002h0?ooo`D000000P0f;9P00`000000He2W06=@Y`0906=@Y`P0
0000fP0h^^@8000000/0k<2W00<000000?[<V03jc9P01@00002h0?ooo`00/`3oool5000000L0=RbH
00<0000006=@Y`1SD:L00P1SD:L700000>X0>;[T200000030>c0Y`030000003jc9P0n/bH00D0n/bH
1000002d0?ooo`00[P3oool5000000X0=RbH1P00003j03Rji0@000002`3jc9P500000:l0oooo002Y
0?ooo`D000002`0f;9P400000?l0>;[T1P0h^^@4000000/0n/bH1@00002Z0?ooo`00Y@3oool40000
00`0=RbH1000003o03Rji0h0>;[T1000000<0?[<V0@00000YP3oool00:<0oooo0P0000000`0007`0
000003H/V00903H/V0@00000o`0h^^@F03Rji0@000002P3jc9P00`000000om1l0000000200000:<0
oooo002P0?ooo`<000000`0007`00`000000=RbH03H/V00403H/V0@00000o`0h^^@N03Rji0@00000
1P3jc9P00`000000om1l0?o@O0020?o@O0<00000X03oool009d0oooo0`0000060000O0030000000f
;9P0=RbH00@00000o`0h^^@V03Rji0@000000P3jc9P00`000000om1l0?o@O0050?o@O0800000WP3o
ool009/0oooo0P0000080000O0@00000o`0h^^@^03Rji0<000002@3od7`3000009/0oooo002H0?oo
o`<00000200007`200000?l0>;[T=P0h^^@3000000P0om1l0`00002H0?ooo`00UP3oool2000000P0
001l0`00003o03Rji3/0>;[T0`0000080?o@O0800000UP3oool009@0oooo0`0000060000O0<00000
o`0h^^A103Rji08000001`3od7`3000009@0oooo002C0?ooo`040000000004/0001;000000@0001l
0P00003o03Rji4H0>;[T0`0000040?o@O0040000003`a4/0l<A;000009<0oooo002A0?ooo`800000
0`0004/00`000000001l0000000200000?l0>;[TB`0h^^@3000000030?o@O0000000l<A;0080l<A;
0P00002A0?ooo`00T03oool00`000000001;0000B`030000B`800000o`0h^^AA03Rji08000001@3`
a4/00`000000oooo0?ooo`2>0?ooo`00SP3oool2000000@0001;0P00003o03Rji5D0>;[T0P000004
0?34B`800000SP3oool008d0oooo00<000000000B`0004/00`0004/00`000000>;[T03Rji03o03Rj
i5L0>;[T00<000000?34B`3`a4/00`3`a4/00`000000oooo0?ooo`2;0?ooo`00S@3oool010000000
001;0000B`0004/200000?l0>;[TF`0h^^@2000000<0l<A;00<000000?ooo`3oool0R`3oool008d0
oooo00@000000000B`0004/00000o`0h^^AO03Rji0040000003`a4/0l<A;000008d0oooo002=0?oo
o`<00000o`0h^^AQ03Rji0<00000S@3oool008`0oooo0P00003o03Rji6D0>;[T0P00002<0?ooo`00
S03oool2000001D0>;[T0P0i^^BJ03Rji0030000000h^^@0>;[T00d0>;[T00<0eZna03Rji00h^^@0
X00h^^@2000008`0oooo002<0?ooo`800000:`0h^^@403Vji6T0>;[T0P0000030000L@/0>;[T2@2<
L[400`000000eZna0=J_/@070=J_/@P0>;[T00<0eZna03Rji00h^^@0WP0h^^@2000008`0oooo002<
0?ooo`030000000h^^@0>;[T03l0>;[T1P0i^^AH03Rji0030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000>;[T03Rji02L03Rji0800000S03oool008`0oooo00<0000003Rj
i00h^^@0V`0h^^@20000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@2M03Rji0030000003oool0oooo08X0oooo002<0?ooo`030000000h^^@0>;[T09P0
>;[T1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg400`3ncg6J03Rji0030000003oool0oooo08X0oooo002<0?ooo`030000000h^^@0>;[T09D0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02E03Rji0030000003oool0oooo08X0oooo
002=0?ooo`030000000h^^@0>;[T0340>;[T3@0i^^AF03Rji003000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
000003Vji00i^^@0U00h^^@00`000000oooo0?ooo`2;0?ooo`00SP3oool2000006H0>;[T6@0i^^@E
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@03@0h^^@@03Vji7D0>;[T0P00002>
0?ooo`00T03oool00`000000>;[T03Rji02A03Rji003000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rj
i00h^^@0;@0h^^@<03Vji5P0>;[T00<000000?ooo`3oool0SP3oool00940oooo00<0000003Rji00h
^^@0T00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T02H0>;[T00<0>K[T03Rji00h
^^@0900h^^@803Vji3/0>;[T00<000000?ooo`3oool0S`3oool00980oooo0P00002@03Rji0030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0K@0h^^@403Vji1d0>;[T0P00002B0?ooo`00U03o
ool00`000000>;[T03Rji02=03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0S@0h
^^@00`000000oooo0?ooo`2B0?ooo`00UP3oool2000008`0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji02:03Rji0800000UP3oool009P0oooo0P00002:03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0800h^^@00`000000>;[T03Rji01U03Rji0800000V03oool009X0
oooo0`00002703Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h^^@3000009X0
oooo002M0?ooo`800000Q@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08<0>;[T
0P00002M0?ooo`00W`3oool2000008<0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i02103Rji0800000W`3oool00:40oooo1000001o03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0O@0h^^@400000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000000h^^@0>;[T07P0>;[T1@00002U0?ooo`00ZP3oool5000005P0>;[T00<0000003Rji00h
^^@06P0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T07<0>;[T1@00002Z0?ooo`00
[`3oool5000002@0>;[T0`00001903Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
B`0h^^@00`000000>;[T03Rji00P03Rji0D00000[`3oool00;@0oooo1@00001[03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0J@0h^^@500000;@0oooo002i0?ooo`D00000IP0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06@0>;[T1@00002i0?ooo`00_P3oool50000
0640>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01O03Rji0D00000_P3oool00<<0
oooo1@00001L03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0FP0h^^@500000<<0
oooo00380?ooo`D00000E`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05D0>;[T
1@0000380?ooo`00c@3oool700000500>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i01>03Rji0L00000c@3oool00=@0oooo2P00001603Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0A00h^^@:00000=@0oooo003N0?ooo`X00000?00h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000000h^^@0>;[T03X0>;[T2P00003N0?ooo`00j03oool=000002l0>;[T00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000>;[T03Rji00]03Rji0d00000j03oool00?D0oooo4000000O03Rji0030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07@0h^^@@00000?D0oooo003o0?ooo`H0oooo6@00
000603Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0100h^^@I00000?l0oooo1P3o
ool00?l0oooo7`3oool7000000L0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma1`00003o0?oooal0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo00330?ooo`<00000GP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00000A
0?ooo`030000001jFJ00NUVP00D00000F@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:d0oooo0`0000000`1kK[X000000000000?0?ooo`030000001jFJ00NUVP
00H0NUVP0`00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00Z@3oool4000000D0Nfjj00<000000?ooo`3oool03@3oool00`000000NUVP07YIX00807YIX003
0000003oool0oooo05@0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002W0?ooo`8000002@1kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02000005H0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002W0?ooo`030000001k
K[X0Nfjj00P0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P07
07]^^P8000003@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj
00P0Nfjj00<0`7T00?ooo`3oool02`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo
05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`03
0000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool00`000000NUVP07YIX00707YIX080
0000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0oooo
00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YIX01jFJ001`1jFJ02000005L0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001k
K[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<00000
07]^^P1kK[X0201kK[X00`30N@00oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<00000
0?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00NUVP
00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YIX01j
FJ001`1jFJ02000005P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0`7T00000003oool0203oool00`000000NUVP
07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000090?ooo`030000001j
FJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`07
0?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo
00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`03
0000001jFJ00NUVP00L0NUVP00<0gKjj0000003oool0F@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X01`1kK[X2000000L0oooo
00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1H0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i0000
0000oooo00D0oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T0
0000003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X20000
00D0oooo00<0000007YIX01jFJ00201jFJ02000005X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`03
0000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0F@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X0201kK[X2000000@0oooo
00<0000007YIX01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002/0?ooo`8000002@1kK[X00`30N@0000000?ooo`030?ooo`030000001j
FJ00NUVP00L0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX008
07YIX0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:d0oooo00<0000007]^^P1kK[X01`1kK[X2000000<0oooo00<0000007YIX01jFJ00201jFJ000`00
0000oooo0?ooo`1J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[@3oool00`000000Nfjj07]^^P0807]^^P8000000P3oool00`000000NUVP07YIX00707YIX080
0000G03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo
0P00000907]^^P050<1i00000000oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj
0P0000000`3oool0000007YIX00907YIX0800000G03oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X4000000P0NUVP00<0
gKjj000000000000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:h0oooo00<0000007]^^P1kK[X0201kK[X3000000T0NUVP0P00001M0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool2000000T0Nfjj0`00000907YI
X0800000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0
oooo00<0000007]^^P1kK[X01`1kK[X2000000P0NUVP00@0gKjj07YIX038adH00000G@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1k
K[X01`1kK[X2000000T0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00L0NUVP
0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3o
ool2000000T0Nfjj00<0000007YIX01jFJ001`1jFJ02000005h0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00L0Nfjj00<00000
07YIX01jFJ001`1jFJ000`38adH000000?ooo`1M0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00/03oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP
00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00/03oool2000000T0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X00`000000NUVP
07YIX00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00;40oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7AP00
0000oooo05h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a
0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ000`1jFJ03000005l0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X01P00
0000NUVP07YIX01jFJ00gKjj07YIX0800000H03oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00001P
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`00
0000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00<0NUVP00<0b<M60000003oool0G`3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo00<0000007]^^P1k
K[X0201kK[X010000000NUVP0=fn^P1jFJ0300000600oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`8000002@1kK[X010000000NUVP07YIX01jFJ020000
0640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`80
00002@1kK[X010000000NUVP07YIX01jFJ0200000640oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`030000001kK[X0Nfjj00L0Nfjj00H000000=fn^P1j
FJ00NUVP0<S7AP00001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00000000800000H@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo0P00000907]^^P04
0000001jFJ00000000000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00]03oool00`000000Nfjj07]^^P0707]^^P04
0000001jFJ00b<M600000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002d0?ooo`030000001kK[X0Nfjj00P0Nfjj0`00001R0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3ooolS000005<0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`h000003018>ih00`000000lLBS0?74
X`0<0?74X`l00000C03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
A`3oooln00000?l0oooo8P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo2`00000900d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H01`3od8H;00000?l0oooo5`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00W0;BC]08000004`3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oo
oaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oo
oaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`2j0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`1F0?ooo`<00000^`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0E@3oool01@000000
/h:O0;>2W`2cPYl000000;X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo05@0oooo00<000000;>2W`2c
PYl00`2cPYl00`000000oooo0?ooo`2g0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1C0?ooo`030000
002cPYl0/h:O00D0/h:O00<000000?ooo`3oool0]P3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0DP3o
ool00`000000/h:O0;>2W`070;>2W`030000003oool0oooo0;D0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0540oooo00<000000;>2W`2cPYl02@2cPYl00`000000oooo0?ooo`2d0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`1@0?ooo`030000002cPYl0/h:O00/0/h:O00<000000?ooo`3oool0/`3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0C`3oool00`000000/h:O0;>2W`0=0;>2W`030000003oool0oooo0;80
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo04h0oooo00<000000;>2W`2cPYl03`2cPYl00`000000oooo
0?ooo`2a0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1=0?ooo`030000002cPYl0/h:O0140/h:O00<0
00000?ooo`3oool0/03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0C03oool00`000000/h:O0;>2W`0C
0;>2W`030000003oool0oooo0:l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04/0oooo00<000000;>2
W`2cPYl05@2cPYl00`000000oooo0?ooo`2^0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1:0?ooo`03
0000002cPYl0/h:O01L0/h:O00<000000?ooo`3oool0[@3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
B03oool2000001/0/h:O0P00002]0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`170?ooo`030000002c
PYl0/h:O01d0/h:O00<000000?ooo`3oool0ZP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0AP3oool0
0`000000/h:O0;>2W`0O0;>2W`030000003oool0oooo0:T0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
04D0oooo00<000000;>2W`2cPYl08@2cPYl00`000000oooo0?ooo`2X0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`140?ooo`030000002cPYl0/h:O02<0/h:O00<000000?ooo`3oool0Y`3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0@`3oool00`000000/h:O0;>2W`0U0;>2W`030000003oool0oooo0:H0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0480oooo00<000000;>2W`2cPYl09`2cPYl00`000000oooo0?oo
o`2U0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`110?ooo`030000002cPYl0/h:O02T0/h:O00<00000
0?ooo`3oool0Y03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0@03oool00`000000/h:O0;>2W`0[0;>2
W`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03l0oooo00<000000;>2W`2c
PYl0;@2cPYl00`000000oooo0?ooo`2R0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000
002cPYl0/h:O02l0/h:O00<000000?ooo`3oool0X@3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?@3o
ool00`000000/h:O0;>2W`0a0;>2W`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0
B3^N00@0B3^N:00000080?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?03oool0
0`000000/h:O0;>2W`060;>2WbP000001@2cPYl00`000000oooo0?ooo`2O0?ooo`00T`3ooolD0000
0180AcZN00<000000?75X`3aaJ<04`3aaJ<G00000300oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3ooolG0000
01D0EDFS00<000000?G8WP3eb9h0403eb9hD000009<0oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0_000001<03@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QRl000000P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75Xc4000000`0=2hH>000000<03@^600<00000
0;BC]02dTk@0:02dTk@D0?o@QPT000002005000Q000002/0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I0
0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`00
0000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@
QP3od8H0om26@02]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eT
N`<03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000:`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000
@@2]I7/200d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2
00000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000om260:eTN`110:eTN`800000:`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`00
0000om260:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480
[FAk00<03@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000[FAk
0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<0
00000;BC]02dTk@0:02dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eT
N`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02d
Tk@0:02dTkA40:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`80
0000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
[FAk0:eTN`2a0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1M0:eTN`030:jfg`2]I7/0[FAk0580[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0I02]I7/00`2^]]l0[FAk0:eTN`1;
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`1_0:eTN`030:jfg`2]I7/0[FAk0400[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0MP2]I7/0
0`2^]]l0[FAk0:eTN`0i0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk07d0[FAk00<0[[KO0:eTN`2]I7/0<P2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`240:eTN`030:jfg`2]I7/0[FAk02/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0R`2]I7/00`2^]]l0[FAk0:eTN`0T0:eT
N`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75XkH0
0000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]
^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40
[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS01<0lLFS5`00002d0:fhhA/00000
4@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<F0:iUO0030000002]^>40[KSQ0;80[KSQ00<0
00000:iUO02^IG`0502^IG`E05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0B0?75XaL0[VEl00<00000
0:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00E0:iUO1@0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl501EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<04@3aaJ<H0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^
IG`05P2^IG`C05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40
/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0100lLFS6@2^
IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01L0[VEl4P1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000J0:iUO140EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006P2^IG`A05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0>0?75XaD0[VEl00<0lLFS0:iUO02^IG`0102^IG`00`000000
[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75Xa`0[VEl
00<000000:fhh@2]^>40/02]^>42000001/0[VEl401EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03@3a
aJ<M0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000L0:iUO0l0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fhh@2`0:fhh@800000702^IG`?05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0<0?75Xah0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00L0:iU
O0h0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0lLFS7`2^IG`00`000000[KSQ0:fhh@2`0:fhh@03
0000002^IG`0[VEl01d0[VEl3@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<O0:iUO0030000
002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0:0?75Xb00[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00N0:iUO0`0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0
[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`07`2^IG`;05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80
[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00P0lLFS8P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0200[VEl
2P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01`3aaJ<S0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`08@2^IG`905E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`060?75Xb@0[VEl00<00000
0:fhh@2]^>40/02]^>400`000000[VEl0:iUO00Q0:iUO0T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl00D0[VEl00<0EDFS0:iU
O02^IG`06P2^IG`805E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XbD0[VEl00<000000:fhh@2]
^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@030000002]^>40[KSQ0380[KSQ00<000000:iUO02^
IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XeX0[VEl00<0^iT60:fhh@2]^>40
AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02<0[VEl1`1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0103aaJ<o0:iUO0030:fhh@2^IG`0[VEl01T0[VEl00<0^iT60:fhh@2]^>40AP2]
^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl00d0[VEl00<0EDFS0:iUO02^IG`0502^
IG`605E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`030?75Xdh0[VEl00<0[KSQ0:iUO02^IG`02`2^IG`0
0`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0902^IG`6
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`030?75XdD0[VEl00<0[KSQ0:iUO02^IG`0502^IG`00`2k
V@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09@2^IG`505E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`020?75Xed0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000
[VEl0:iUO00b0:iUO0030000002^IG`0[VEl01D0[VEl00<0EDFS0:iUO02^IG`03P2^IG`405E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`020?75Xd/0[VEl00<0[KSQ0:iUO02^IG`03`2^IG`00`2kV@H0[KSQ
0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09P2^IG`405E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh010000000lLFS0?75X`3aaJ=N0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0
<P2^IG`00`000000[VEl0:iUO00W0:iUO0<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS05P0[VEl00<0
[KSQ0:iUO02^IG`0102^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<0
00000:iUO02^IG`09`2^IG`305E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`1O0:iUO0030;^I1P2]^>40
[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00X0:iUO080EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool7000001l0AcZN00<000000?75
X`2^IG`0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iU
O02^IG`0:@2^IG`00`1EAJ<000000?G8WP0N0?G8WPL00000T`3oool009X0oooo3000000C04LjWP03
0000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO003
0000002^IG`0[VEl02T0[VEl00<0EDFS0000003eb9h04P3eb9h<000009X0oooo002V0?ooo`d00000
1P17>Yh00`000000[VEl0:iUO01O0:iUO0030;^I1P000000000004L00000=02^IG`00`000000[VEl
0:iUO00Z0:iUO0030000003eb9h0mLRN00@0mLRN3@00002V0?ooo`00/`3ooomZ000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000000001W00000;<0oooo002i0?ooo`030000002]^>80
[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>80
0`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0
oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo
0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<00000
0:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P
0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?oo
o`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo
0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?oo
o`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fh
hP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00
^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003o
ool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`00
0000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`800000G`2]^>800`00
0000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`800000G`2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR
0:fhhP1M0:fhhP030000003oool0oooo00d0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3oool00`000000[KSR
0:fhhP1M0:fhhP030000003oool0oooo0;T0oooo002k0?ooof4000003`3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0=0?ooof400000^`3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`03010=Q`050?o@R@0@3HL040f7010=Q`00
0000502dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00D00000010=Q`0@3HL040f70?o@R@05010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`040000000@3HL040f70?o@R@H040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700H040f7
00<0om290000002dTk@04`2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003]0?ooocl000002@0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27?`00003]0?ooo`00k@3oool00`00
0000P`D608<51P0408<51P0305g:n0231@H0P`D603D0P`D61`0@3HL00`231@H040f70000000D0;BC
]0030000003od8L0om2700H0om27?`231@H00`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000
P`D608<51P0;08<51P0305g:n0231@H0P`D602l0P`D6200@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700D0om27@0231@H00`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000P`D6
08<51P0B08<51P0305g:n0231@H0P`D602T0P`D61`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700@0om27@@231@H00`000000oooo0?ooo`3[0?ooo`00k03oool2000001X0P`D60`1M
b_PT08<51P<040f700@0P`D6010=Q`0@3HL00000502dTk@00`000000om270?o@Q`030?o@Qd80P`D6
00<000000?ooo`3oool0j`3oool00>`0oooo00<0000008<51P231@H080231@H305g:n1l0P`D6100@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om270080om27@`231@H00`000000oooo0?oo
o`3[0?ooo`00k03oool00`000000P`D608<51P0W08<51P<000006@231@H3010=Q`030000002dTk@0
]9>d0180]9>d00@000000?o@Q`3od8L0om27A@231@H00`000000oooo0?ooo`3Z0?ooo`00k03oool0
0`000000P`D608<51P0]08<51PD0/:oG4P231@H2010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L0AP231@H00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000P`D608<51P0d08<5
1PD0/:oG30231@H00`0@3HL000000;BC]00C0;BC]0030000003od8L0P`D601d0P`D61@2`[mLT08<5
1P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D603/0P`D600<0/:oG0000000@
3HL00P0@3HL608<51P030000002dTk@0]9>d0180]9>d00<0000008<51P231@H0:`231@H90;2_ea80
P`D600<000000?ooo`3oool0jP3oool00>`0ooooZ000003/0?ooo`00k03oool00`000000/G>>0;5c
SP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?oo
o`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003P0?ooo`d00000
YP2aLhh00`000000oooo0?ooo`3Z0?ooo`00h03oool00`000000]5II0;AFF@090;AFF@030000002a
Lhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=l0oooo0P00000;0;AFF@030000002aLhh0
/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=l0oooo0P00000;0;AFF@030000002aLhh0/G>>
0:@0/G>>00<000000?ooo`3oool0jP3oool00=l0oooo00<000000000?00000002P2dEUT00`000000
/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003O0?ooo`030000000003`0000000X0]5II
00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00gP3oool010000000000l0000
?000000:0;AFF@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=h0oooo00@0
00000000?00003`000002P2dEUT00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo
003N0?ooo`040000000003`0000l000000X0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo
0?ooo`3Z0?ooo`00gP3oool010000000000l0000?000000:0;AFF@030000002aLhh0/G>>0:@0/G>>
00<000000?ooo`3oool0jP3oool00=d0oooo00D000000000?00003`0000l0000000:0;AFF@030000
002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=d0oooo00D000000000?00003`0000l
0000000:0;AFF@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=d0oooo00<0
00000000?00003`00P0003`00`000000]5II0;AFF@070;AFF@030000002aLhh0/G>>0:@0/G>>00<0
00000?ooo`3oool0jP3oool00=d0oooo00<000000000?00003`00P0003`00`000000]5II0;AFF@07
0;AFF@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=d0oooo00<000000000
?00003`00P0003`00`000000]5II0;AFF@070;AFF@030000002aLhh0/G>>0:@0/G>>00<000000?oo
o`3oool0jP3oool00=h0oooo00@000000000?00003`0000l2`00002V0;5cSP030000003oool0oooo
0>X0oooo003N0?ooo`050000000003`0000l0000?00000002@2_fOJX00000>`0oooo003N0?ooo`05
0000000003`0000l0000?00000002@2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo
0>X0oooo003N0?ooo`050000000003`0000l0000?00000002@2_fOH00`000000/;3G0;2`e`2T0;2`
e`030000003oool0oooo0>X0oooo003N0?ooo`040000000003`0000l000000X0[mWf00<000000;2`
e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00gP3oool010000000000l0000?000000:0:oI
mP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00=l0oooo00<000000000?000
00002P2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003O0?ooo`030000
000003`0000000X0[mWf00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00g`3o
ool00`000000000l0000000:0:oImP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3o
ool00=l0oooo00<000000000?00000002P2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003oool0
oooo0>X0oooo003O0?ooo`8000002`2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo
0>X0oooo003P0?ooo`030000002_fOH0[mWf00T0[mWf00<000000;2`e`2`/=L0Y02`/=L00`000000
oooo0?ooo`3Z0?ooo`00h03oool00`000000[mWf0:oImP040:oImPH00000YP2`/=L00`000000oooo
0?ooo`3Z0?ooo`00h03oool7000000D0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?oo
o`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`
/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000
003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3o
ool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03ooonX0000
0>`0oooo003/0?ooo`030000001Fb?D0E/Se0:@0E/Se00<000000?ooo`3oool0jP3oool00>`0oooo
00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00k@3oool00`000000E/Se05K8
m@2R05K8m@030000003oool0oooo0>/0oooo003]0?ooo`030000001Fb?D0E/Se0:80E/Se00<00000
0?ooo`3oool0j`3oool00>d0ooooYP00003]0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00001\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.67803 .40902 m .6476 .41312 L .6476 .24575 L p .391 .319 .656 r
F P
0 g
s
.6476 .24575 m .67803 .24025 L .67803 .40902 L p .391 .319 .656 r
F P
0 g
s
.59568 .25697 m .59524 .24447 L .61318 .24633 L p .849 .671 .66 r
F P
0 g
s
.61318 .24633 m .61362 .25879 L .59568 .25697 L p .849 .671 .66 r
F P
0 g
s
.61397 .23343 m .61318 .24633 L .59524 .24447 L p .842 .727 .737 r
F P
0 g
s
.59732 .26852 m .59568 .25697 L .61362 .25879 L p .845 .598 .565 r
F P
0 g
s
.61362 .25879 m .61528 .27031 L .59732 .26852 L p .845 .598 .565 r
F P
0 g
s
.6476 .41312 m .60892 .41278 L .60892 .27909 L p .726 .592 .707 r
F P
0 g
s
.60902 .27914 m .6476 .41312 L .60892 .27909 L .726 .592 .707 r
F
.61819 .28552 m .6476 .41312 L .60902 .27914 L F
.61005 .27962 m .60902 .27914 L .60892 .2788 L F
.61819 .28552 m .60902 .27914 L .61005 .27962 L F
.6181 .28041 m .61987 .28418 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.61005 .27962 m .6181 .28041 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.59732 .26852 m .61528 .27031 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.60892 .27909 m .60892 .2788 L p .60902 .27914 L .726 .592 .707 r
F P
0 g
s
.61528 .27031 m .6181 .28041 L .61005 .27962 L p .824 .499 .439 r
F P
0 g
s
.61528 .27031 m .61005 .27962 L .605 .27596 L .824 .499 .439 r
F
.59524 .24447 m .59603 .23154 L .61397 .23343 L p .842 .727 .737 r
F P
0 g
s
.61597 .22065 m .61397 .23343 L .59603 .23154 L p .826 .772 .801 r
F P
0 g
s
.59603 .23154 m .59801 .21872 L .61597 .22065 L p .826 .772 .801 r
F P
0 g
s
.6191 .2085 m .61597 .22065 L .59801 .21872 L p .801 .81 .858 r
F P
0 g
s
.59801 .21872 m .60111 .20654 L .6191 .2085 L p .801 .81 .858 r
F P
0 g
s
.59524 .24447 m .5953 .24626 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.5953 .24626 m .59568 .25697 L p .5969 .24561 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .5953 .24626 L .5969 .24561 L .042 .034 .521 r
F
.61318 .24633 m .61324 .24811 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.61324 .24811 m .61362 .25879 L p .61486 .24746 L .049 .04 .524 r
F P
0 g
s
.6191 .2085 m .61324 .24811 L .61486 .24746 L .049 .04 .524 r
F
.61397 .23343 m .61318 .24633 L p .6191 .2085 L F P
0 g
s
.61362 .25879 m .61528 .27031 L p .61674 .24669 L .049 .04 .524 r
F P
0 g
s
.6191 .2085 m .61486 .24746 L .61674 .24669 L .049 .04 .524 r
F
.61486 .24746 m .61362 .25879 L .61674 .24669 L F
.6476 .24575 m .67803 .24025 L p .65012 .23315 L .289 .763 .934 r
F P
0 g
s
.61528 .27031 m .6181 .28041 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.61987 .24543 m .6476 .24575 L p .63711 .23843 L .289 .763 .934 r
F P
0 g
s
.6181 .28041 m .61987 .28418 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.6476 .24575 m .6476 .30684 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.61987 .24543 m .6476 .24575 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.6476 .30684 m .6476 .41312 L p .61987 .29279 L .726 .592 .707 r
F P
0 g
s
.61819 .28552 m .61987 .28674 L .61987 .29279 L .726 .592 .707 r
F
.61987 .28674 m .6476 .30684 L .61987 .29279 L F
.6191 .2085 m .61987 .28418 L .61987 .22993 L .049 .04 .524 r
F
.60892 .2453 m .61987 .26271 L .61819 .28552 L .726 .592 .707 r
F
.61987 .26271 m .6476 .30684 L .61987 .28674 L F
.61987 .26271 m .61987 .28674 L .61819 .28552 L F
.67803 .24025 m .68252 .23183 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.61987 .21121 m .6264 .24277 L .62854 .2419 L .049 .04 .524 r
F
.61987 .21215 m .63805 .29906 L .61987 .21121 L F
.63214 .2982 m .63805 .29906 L p .61987 .21215 L F P
0 g
s
.61987 .21376 m .63214 .2982 L .61987 .21215 L .049 .04 .524 r
F
.65012 .23315 m .67803 .24025 L .65945 .22936 L .289 .763 .934 r
F
.68252 .40275 m .67803 .40902 L .67803 .24025 L p 0 0 .164 r
F P
0 g
s
.67803 .24025 m .68252 .23183 L .68252 .40275 L p 0 0 .164 r
F P
0 g
s
.68252 .23183 m .66471 .22723 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.6191 .2085 m .66471 .23582 L .66471 .22382 L .049 .04 .524 r
F
.68252 .23183 m .66471 .22723 L p .66471 .26726 L .966 .789 .613 r
F P
0 g
s
.63711 .23843 m .6476 .24575 L .65012 .23315 L .289 .763 .934 r
F
.66117 .2763 m .66551 .2652 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.656 .28558 m .66117 .2763 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66117 .2763 m .66471 .26726 L p .65 .26398 L .764 .849 .915 r
F P
0 g
s
.66117 .2763 m .65 .26398 L .64848 .26458 L .764 .849 .915 r
F
.6191 .2085 m .66471 .24909 L .66471 .23582 L .049 .04 .524 r
F
.66551 .2652 m .66884 .25277 L p .6191 .2085 L F P
0 g
s
.65024 .29264 m .656 .28558 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.64417 .2972 m .65024 .29264 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.62671 .29467 m .63214 .2982 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.62196 .28864 m .62671 .29467 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65761 .22539 m .64634 .22526 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.6191 .2085 m .61987 .21376 L .61987 .21215 L .049 .04 .524 r
F
.6191 .2085 m .61597 .22065 L .61397 .23343 L p F P
0 g
s
.60111 .20654 m .63786 .22875 L .64634 .22526 L .042 .034 .521 r
F
.64634 .22184 m .64634 .22526 L .65089 .22338 L F
.60111 .20654 m .64634 .22526 L .64634 .22184 L F
.63805 .29906 m .64417 .2972 L p .62854 .2419 L .049 .04 .524 r
F P
0 g
s
.6264 .24277 m .63805 .29906 L .62854 .2419 L .049 .04 .524 r
F
.61987 .28418 m .62196 .28864 L p .61987 .22993 L F P
0 g
s
.60892 .2453 m .61987 .24543 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.60892 .2453 m .61987 .24543 L p .61894 .23653 L .289 .763 .934 r
F P
0 g
s
.60111 .20654 m .6238 .23453 L .6296 .23214 L .042 .034 .521 r
F
.64112 .2274 m .65945 .22936 L .64634 .22526 L .289 .763 .934 r
F
.66196 .26484 m .65071 .2637 L p .66471 .26726 L .764 .849 .915 r
F P
0 g
s
.64112 .2274 m .65012 .23315 L .65945 .22936 L .289 .763 .934 r
F
.60111 .20654 m .6296 .23214 L .63786 .22875 L .042 .034 .521 r
F
.61773 .22491 m .63594 .22954 L .64112 .2274 L .289 .763 .934 r
F
.63594 .22954 m .65012 .23315 L .64112 .2274 L F
.65761 .22539 m .64634 .26541 L .64854 .26455 L .726 .593 .707 r
F
.61773 .22491 m .63711 .23843 L .65012 .23315 L .289 .763 .934 r
F
.65761 .22539 m .64634 .22526 L p .64634 .26541 L .726 .593 .707 r
F P
0 g
s
.65044 .25087 m .65256 .23763 L p .64634 .23387 L .042 .034 .521 r
F P
0 g
s
.63786 .22875 m .64634 .24366 L .64634 .23387 L .042 .034 .521 r
F
.64634 .24366 m .65044 .25087 L .64634 .23387 L F
.62866 .23253 m .61987 .24543 L .63711 .23843 L .289 .763 .934 r
F
.61894 .23653 m .61987 .24543 L .62866 .23253 L F
.64283 .27448 m .64714 .26334 L p .6238 .23453 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .61941 .23634 L .6238 .23453 L .042 .034 .521 r
F
.61941 .23634 m .64283 .27448 L .6238 .23453 L F
.61136 .23965 m .60892 .2453 L .61894 .23653 L .289 .763 .934 r
F
.6377 .28379 m .64283 .27448 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61894 .23653 L .62866 .23253 L .289 .763 .934 r
F
.6296 .23214 m .65044 .25087 L .63786 .22875 L .042 .034 .521 r
F
.64874 .2637 m .64854 .26455 L .65 .26398 L .726 .593 .707 r
F
.64874 .2637 m .65071 .2637 L .65267 .26251 L F
.65761 .22539 m .65761 .25949 L p .65969 .26204 L .966 .789 .613 r
F P
0 g
s
.65071 .2637 m .66196 .26484 L p .65761 .25949 L .803 .818 .863 r
F P
0 g
s
.66471 .26726 m .65071 .2637 L .65 .26398 L .764 .849 .915 r
F
.66471 .22723 m .65761 .22539 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.656 .28558 m .66117 .2763 L .64283 .27448 L p .705 .871 .96 r
F P
0 g
s
.64283 .27448 m .66117 .2763 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.64714 .26334 m .64634 .26541 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.64634 .26541 m .64283 .27448 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.63214 .2982 m .63805 .29906 L .6199 .29733 L p .106 0 0 r
F P
0 g
s
.62671 .29467 m .63214 .2982 L .61405 .29647 L p .434 0 0 r
F P
0 g
s
.6199 .29733 m .61405 .29647 L .63214 .2982 L p .106 0 0 r
F P
0 g
s
.62597 .29545 m .6199 .29733 L .63805 .29906 L p .226 .729 .901 r
F P
0 g
s
.63805 .29906 m .64417 .2972 L .62597 .29545 L p .226 .729 .901 r
F P
0 g
s
.632 .29088 m .62597 .29545 L .64417 .2972 L p .465 .842 .987 r
F P
0 g
s
.64417 .2972 m .65024 .29264 L .632 .29088 L p .465 .842 .987 r
F P
0 g
s
.6377 .28379 m .632 .29088 L .65024 .29264 L p .613 .875 .991 r
F P
0 g
s
.65024 .29264 m .656 .28558 L .6377 .28379 L p .613 .875 .991 r
F P
0 g
s
.64283 .27448 m .6377 .28379 L .656 .28558 L p .705 .871 .96 r
F P
0 g
s
.64634 .27408 m .64223 .26701 L .61773 .3976 L .726 .593 .707 r
F
.632 .29088 m .6377 .28379 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60187 .24356 m .60892 .2453 L p .61136 .23965 L .289 .763 .934 r
F P
0 g
s
.60187 .28242 m .60012 .27864 L .6082 .27943 L p .77 .356 .265 r
F P
0 g
s
.605 .27596 m .60892 .2788 L .60012 .27864 L .824 .499 .439 r
F
.6082 .27943 m .60012 .27864 L p .60892 .2788 L F P
0 g
s
.60012 .27864 m .59797 .27086 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.59797 .27086 m .59732 .26852 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.60012 .27864 m .60187 .28242 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60187 .28499 m .6082 .27943 L .60187 .36399 L .96 .784 .62 r
F
.60187 .36399 m .6082 .27943 L .60892 .41278 L F
.60892 .27909 m .60892 .41278 L p .6082 .27943 L F P
0 g
s
.60111 .20654 m .60187 .28242 L .60187 .22802 L .042 .034 .521 r
F
.59568 .25697 m .59732 .26852 L p .60111 .20654 L F P
0 g
s
.59732 .26852 m .60012 .27864 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.58382 .23912 m .60187 .26765 L .59173 .29388 L .96 .784 .62 r
F
.60187 .26765 m .60892 .2788 L .60187 .28499 L F
.60187 .26765 m .60187 .28499 L .59173 .29388 L F
.61005 .27962 m .60776 .28234 L .60761 .28045 L .77 .356 .265 r
F
.60776 .28234 m .60394 .2869 L .60761 .28045 L F
.60394 .2869 m .60187 .28242 L p .60761 .28045 L F P
0 g
s
.60892 .2788 m .60892 .27909 L p .6082 .27943 L .96 .784 .62 r
F P
0 g
s
.6082 .27943 m .61005 .27962 L p .60187 .28242 L .77 .356 .265 r
F P
0 g
s
.62196 .28864 m .62671 .29467 L .60865 .29294 L p .655 .143 .015 r
F P
0 g
s
.59603 .23154 m .59524 .24447 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60892 .2453 m .60892 .2788 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.58382 .23912 m .60187 .24356 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.60187 .24356 m .60892 .2453 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.60892 .26016 m .60892 .2453 L p .611 .25433 L .726 .592 .707 r
F P
0 g
s
.611 .25433 m .61819 .28552 L .60892 .26016 L .726 .592 .707 r
F
.60892 .2788 m .60892 .26016 L p .61819 .28552 L F P
0 g
s
.62196 .28864 m .60394 .2869 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.61987 .28418 m .62196 .28864 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.6149 .28187 m .60394 .2869 L .61005 .27962 L .77 .356 .265 r
F
.60865 .29294 m .60394 .2869 L .62196 .28864 L p .655 .143 .015 r
F P
0 g
s
.61405 .29647 m .60865 .29294 L .62671 .29467 L p .434 0 0 r
F P
0 g
s
.61405 .29647 m .6199 .29733 L p .60187 .2102 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .60187 .2118 L .60187 .2102 L .042 .034 .521 r
F
.60187 .2118 m .61405 .29647 L .60187 .2102 L F
.61005 .27962 m .6082 .27943 L p .60892 .2788 L .824 .499 .439 r
F P
0 g
s
.60865 .29294 m .61405 .29647 L p .60187 .2118 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .60187 .21522 L .60187 .2118 L .042 .034 .521 r
F
.60187 .21522 m .60865 .29294 L .60187 .2118 L F
.60187 .28242 m .60394 .2869 L p .60187 .22802 L F P
0 g
s
.59173 .29388 m .60187 .28499 L .60187 .36399 L .96 .784 .62 r
F
.62597 .29545 m .632 .29088 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61136 .23965 L .61894 .23653 L .289 .763 .934 r
F
.6199 .29733 m .62597 .29545 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61773 .27658 L p .64223 .26701 L .726 .593 .707 r
F P
0 g
s
.61773 .27658 m .61773 .3976 L p .64223 .26701 L .726 .593 .707 r
F P
0 g
s
.66471 .22723 m .65761 .22539 L p .65969 .26204 L .966 .789 .613 r
F P
0 g
s
.66471 .26822 m .65969 .26204 L .66471 .35065 L .966 .789 .613 r
F
.66471 .22723 m .65969 .26204 L .66471 .26822 L F
.65761 .22539 m .64874 .2637 L .65267 .26251 L .726 .593 .707 r
F
.65761 .26101 m .65761 .25949 L p .65267 .26251 L F P
0 g
s
.65761 .25949 m .65761 .22539 L p .65267 .26251 L .726 .593 .707 r
F P
0 g
s
.66551 .2652 m .66884 .25277 L .66865 .25275 L p .803 .818 .863 r
F P
0 g
s
.66865 .25275 m .65062 .25089 L p .65881 .25876 L .803 .818 .863 r
F P
0 g
s
.66551 .2652 m .66865 .25275 L .65881 .25876 L .803 .818 .863 r
F
.65062 .25089 m .65044 .25087 L p .65119 .25159 L F P
0 g
s
.66551 .2652 m .65062 .25089 L .65119 .25159 L .803 .818 .863 r
F
.66551 .2652 m .65876 .25879 L .65761 .25949 L F
.66196 .26484 m .66551 .2652 L p .65761 .25949 L F P
0 g
s
.66471 .35065 m .65969 .26204 L .65761 .39797 L .966 .789 .613 r
F
.65761 .25949 m .65761 .39797 L p .65969 .26204 L F P
0 g
s
.65044 .25087 m .64714 .26334 L .65071 .2637 L p .803 .818 .863 r
F P
0 g
s
.65876 .25879 m .65044 .25087 L .65071 .2637 L .803 .818 .863 r
F
.64874 .2637 m .65 .26398 L .65071 .2637 L .726 .593 .707 r
F
.65267 .26251 m .65071 .2637 L .65761 .26101 L F
.65071 .2637 m .64714 .26334 L p .65 .26398 L .764 .849 .915 r
F P
0 g
s
.64854 .26455 m .64634 .26541 L .64634 .27408 L .726 .593 .707 r
F
.64714 .26334 m .65044 .25087 L p .6296 .23214 L .042 .034 .521 r
F P
0 g
s
.6238 .23453 m .64714 .26334 L .6296 .23214 L .042 .034 .521 r
F
.64634 .22526 m .61773 .22491 L p .64112 .2274 L .289 .763 .934 r
F P
0 g
s
.63786 .22875 m .65256 .23763 L .65089 .22338 L .042 .034 .521 r
F
.64634 .22526 m .61773 .22491 L p .64634 .27408 L .726 .593 .707 r
F P
0 g
s
.65256 .23763 m .6534 .22423 L p .65089 .22338 L .042 .034 .521 r
F P
0 g
s
.61773 .3976 m .65761 .39797 L .65761 .26101 L p .726 .593 .707 r
F P
0 g
s
.64854 .26455 m .61773 .3976 L .65761 .26101 L .726 .593 .707 r
F
.64848 .26458 m .65 .26398 L .64714 .26334 L .764 .849 .915 r
F
.66471 .26726 m .66551 .2652 L .66196 .26484 L p F P
0 g
s
.67575 .277 m .66471 .26726 L .66471 .35065 L .966 .789 .613 r
F
.68252 .23183 m .66471 .26726 L .67575 .277 L F
.66884 .25277 m .67098 .23957 L p .66471 .23582 L .049 .04 .524 r
F P
0 g
s
.66471 .24909 m .66884 .25277 L .66471 .23582 L .049 .04 .524 r
F
.67098 .23957 m .67183 .22621 L p .66929 .22536 L F P
0 g
s
.66471 .22382 m .66587 .22675 L .66929 .22536 L .049 .04 .524 r
F
.66587 .22675 m .67098 .23957 L .66929 .22536 L F
.66471 .23582 m .67098 .23957 L .66471 .22382 L F
.6191 .2085 m .61987 .21215 L .61987 .21121 L F
.60394 .2869 m .60865 .29294 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.58382 .23912 m .60187 .24356 L p .61773 .22491 L .289 .763 .934 r
F P
0 g
s
.61773 .22491 m .60187 .24356 L .61136 .23965 L .289 .763 .934 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.60892 .41278 m .58382 .40818 L .58382 .23912 L p .96 .784 .62 r
F P
0 g
s
.65761 .39797 m .68252 .40275 L .68252 .23183 L p .966 .789 .613 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6476 .41312 m .67803 .40902 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.60892 .41278 m .6476 .41312 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.67803 .40902 m .68252 .40275 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58382 .40818 m .60892 .41278 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.60111 .20654 m .59801 .21872 L .59603 .23154 L p .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .58712 .23067 L .58382 .23912 L p .289 .763 .934 r
F P
0 g
s
.58382 .40818 m .58712 .40189 L .58712 .23067 L p 0 0 .122 r
F P
0 g
s
.58712 .23067 m .58382 .23912 L .58382 .40818 L p 0 0 .122 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.41413 .40902 m .3859 .41312 L .3859 .24575 L p .366 .299 .648 r
F P
0 g
s
.33412 .25697 m .33375 .24447 L .35244 .24633 L p .844 .668 .663 r
F P
0 g
s
.35244 .24633 m .35281 .25879 L .33412 .25697 L p .844 .668 .663 r
F P
0 g
s
.3531 .23343 m .35244 .24633 L .33375 .24447 L p .838 .722 .736 r
F P
0 g
s
.3355 .26852 m .33412 .25697 L .35281 .25879 L p .841 .598 .572 r
F P
0 g
s
.35281 .25879 m .3542 .27031 L .3355 .26852 L p .841 .598 .572 r
F P
0 g
s
.3859 .41312 m .34704 .41278 L .34704 .27909 L p .726 .592 .707 r
F P
0 g
s
.34714 .27914 m .3859 .41312 L .34704 .27909 L .726 .592 .707 r
F
.35635 .28552 m .3859 .41312 L .34714 .27914 L F
.34817 .27962 m .34714 .27914 L .34704 .2788 L F
.35635 .28552 m .34714 .27914 L .34817 .27962 L F
.35656 .28041 m .35804 .28418 L p .35305 .28187 L .772 .367 .285 r
F P
0 g
s
.34817 .27962 m .35656 .28041 L p .35305 .28187 L .772 .367 .285 r
F P
0 g
s
.3355 .26852 m .3542 .27031 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.34704 .27909 m .34704 .2788 L p .34714 .27914 L .726 .592 .707 r
F P
0 g
s
.3542 .27031 m .35656 .28041 L .34817 .27962 L p .821 .504 .452 r
F P
0 g
s
.3542 .27031 m .34817 .27962 L .3431 .27596 L .821 .504 .452 r
F
.33375 .24447 m .33441 .23154 L .3531 .23343 L p .838 .722 .736 r
F P
0 g
s
.35478 .22065 m .3531 .23343 L .33441 .23154 L p .823 .766 .799 r
F P
0 g
s
.33441 .23154 m .33607 .21872 L .35478 .22065 L p .823 .766 .799 r
F P
0 g
s
.3574 .2085 m .35478 .22065 L .33607 .21872 L p .8 .803 .855 r
F P
0 g
s
.33607 .21872 m .33866 .20654 L .3574 .2085 L p .8 .803 .855 r
F P
0 g
s
.33375 .24447 m .33381 .24626 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33381 .24626 m .33412 .25697 L p .33514 .24561 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33381 .24626 L .33514 .24561 L 0 0 .476 r
F
.33441 .23154 m .33375 .24447 L p .33866 .20654 L F P
0 g
s
.33412 .25697 m .3355 .26852 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33783 .27864 m .33604 .27086 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.33604 .27086 m .3355 .26852 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.3355 .26852 m .33783 .27864 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33929 .24356 m .34704 .2453 L p .34722 .23965 L .289 .763 .934 r
F P
0 g
s
.3431 .27596 m .34704 .2788 L .33783 .27864 L .821 .504 .452 r
F
.34624 .27943 m .33783 .27864 L p .34704 .2788 L F P
0 g
s
.33929 .36399 m .34624 .27943 L .34704 .41278 L .949 .775 .632 r
F
.32816 .29388 m .33929 .28499 L .33929 .36399 L F
.33929 .28499 m .34624 .27943 L .33929 .36399 L F
.34704 .27909 m .34704 .41278 L p .34624 .27943 L F P
0 g
s
.33929 .28242 m .33783 .27864 L .34624 .27943 L p .772 .367 .285 r
F P
0 g
s
.33783 .27864 m .33929 .28242 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33929 .28242 L .33929 .22802 L 0 0 .476 r
F
.31947 .23912 m .33929 .26765 L .32816 .29388 L .949 .775 .632 r
F
.33929 .26765 m .34704 .2788 L .33929 .28499 L F
.33929 .26765 m .33929 .28499 L .32816 .29388 L F
.34428 .28359 m .34408 .28091 L p .34817 .27962 L .772 .367 .285 r
F P
0 g
s
.34103 .2869 m .33929 .28242 L p .34091 .28191 L .772 .367 .285 r
F P
0 g
s
.34624 .27943 m .34817 .27962 L p .33929 .28242 L .772 .367 .285 r
F P
0 g
s
.34704 .2453 m .34704 .2788 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.33929 .24356 m .34704 .2453 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.3859 .30684 m .3859 .41312 L p .35804 .29279 L .726 .592 .707 r
F P
0 g
s
.35635 .28552 m .35804 .28674 L .35804 .29279 L .726 .592 .707 r
F
.35804 .28674 m .3859 .30684 L .35804 .29279 L F
.3859 .24575 m .41413 .24025 L p .38338 .23315 L .289 .763 .934 r
F P
0 g
s
.3574 .2085 m .35696 .24595 L .35771 .24558 L 0 0 .48 r
F
.35656 .28041 m .35804 .28418 L p .35771 .24558 L F P
0 g
s
.35696 .24595 m .35656 .28041 L .35771 .24558 L 0 0 .48 r
F
.3574 .2085 m .35771 .24558 L .35804 .22993 L F
.35771 .24558 m .35804 .28418 L .35804 .24543 L F
.35771 .24558 m .35804 .24543 L .35804 .22993 L F
.35244 .24633 m .35281 .25879 L p .3574 .2085 L F P
0 g
s
.3531 .23343 m .35244 .24633 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.35281 .25879 m .3542 .27031 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3542 .27031 m .35656 .28041 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.34704 .2453 m .35804 .24543 L p .35356 .23653 L .289 .763 .934 r
F P
0 g
s
.35804 .24543 m .3859 .24575 L p .37248 .23843 L .289 .763 .934 r
F P
0 g
s
.33866 .20654 m .35102 .23778 L .35395 .23634 L 0 0 .476 r
F
.3859 .24575 m .3859 .30684 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.34704 .2453 m .35804 .24543 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.35804 .24543 m .3859 .24575 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.34704 .2453 m .35804 .26271 L .35635 .28552 L .726 .592 .707 r
F
.35804 .26271 m .3859 .30684 L .35804 .28674 L F
.35804 .26271 m .35804 .28674 L .35635 .28552 L F
.41413 .24025 m .41526 .23183 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.35804 .21057 m .36539 .24186 L .36743 .24087 L 0 0 .48 r
F
.35804 .21121 m .3784 .2972 L .35804 .21057 L F
.3574 .2085 m .35478 .22065 L .3531 .23343 L p F P
0 g
s
.38338 .23315 m .41413 .24025 L .39119 .22936 L .289 .763 .934 r
F
.3859 .24575 m .41413 .24025 L .41413 .40902 L p .366 .299 .648 r
F P
0 g
s
.41526 .23183 m .3956 .22723 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.3574 .2085 m .3956 .23582 L .3956 .22382 L 0 0 .48 r
F
.41526 .23183 m .3956 .22723 L p .3956 .26726 L .954 .779 .627 r
F P
0 g
s
.37248 .23843 m .3859 .24575 L .38338 .23315 L .289 .763 .934 r
F
.39263 .2763 m .39627 .2652 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3883 .28558 m .39263 .2763 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.38348 .29264 m .3883 .28558 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39263 .2763 m .3956 .26726 L p .38012 .26398 L .765 .843 .911 r
F P
0 g
s
.39263 .2763 m .38012 .26398 L .37859 .26458 L .765 .843 .911 r
F
.3574 .2085 m .3956 .24909 L .3956 .23582 L 0 0 .48 r
F
.39627 .2652 m .39906 .25277 L p .3574 .2085 L F P
0 g
s
.37327 .29906 m .3784 .2972 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.36832 .2982 m .37327 .29906 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.36376 .29467 m .36832 .2982 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.35979 .28864 m .36376 .29467 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.38777 .22539 m .37644 .22526 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.33866 .20654 m .36936 .22875 L .37644 .22526 L 0 0 .476 r
F
.37644 .22184 m .37644 .22526 L .38024 .22338 L F
.33866 .20654 m .37644 .22526 L .37644 .22184 L F
.3784 .2972 m .38348 .29264 L p .36743 .24087 L 0 0 .48 r
F P
0 g
s
.36539 .24186 m .3784 .2972 L .36743 .24087 L 0 0 .48 r
F
.35804 .28418 m .35979 .28864 L p .35849 .2452 L F P
0 g
s
.35804 .22993 m .35804 .24543 L .35849 .2452 L 0 0 .48 r
F
.35804 .24543 m .35804 .28418 L .35849 .2452 L F
.36167 .23253 m .35804 .24543 L .37248 .23843 L .289 .763 .934 r
F
.35356 .23653 m .35804 .24543 L .36167 .23253 L F
.37208 .2274 m .39119 .22936 L .37644 .22526 L F
.39257 .26484 m .38083 .2637 L p .3956 .26726 L .765 .843 .911 r
F P
0 g
s
.37208 .2274 m .38338 .23315 L .39119 .22936 L .289 .763 .934 r
F
.38777 .22539 m .37644 .26541 L .37866 .26455 L .726 .593 .707 r
F
.36775 .22954 m .38338 .23315 L .37208 .2274 L .289 .763 .934 r
F
.33866 .20654 m .35761 .23453 L .36246 .23214 L 0 0 .476 r
F
.33866 .20654 m .36246 .23214 L .36936 .22875 L F
.36775 .22954 m .37248 .23843 L .38338 .23315 L .289 .763 .934 r
F
.33866 .20654 m .35395 .23634 L .35761 .23453 L 0 0 .476 r
F
.3477 .22491 m .36167 .23253 L .36775 .22954 L .289 .763 .934 r
F
.36167 .23253 m .37248 .23843 L .36775 .22954 L F
.38777 .22539 m .37644 .22526 L p .37644 .26541 L .726 .593 .707 r
F P
0 g
s
.37351 .27448 m .37644 .26541 L p .35761 .23453 L 0 0 .476 r
F P
0 g
s
.37644 .26541 m .37711 .26334 L p .37644 .26235 L 0 0 .476 r
F P
0 g
s
.35761 .23453 m .37644 .26541 L .37644 .26235 L 0 0 .476 r
F
.35395 .23634 m .37351 .27448 L .35761 .23453 L F
.37711 .26334 m .37986 .25087 L p .37644 .24719 L F P
0 g
s
.36246 .23214 m .37644 .26192 L .37644 .24719 L 0 0 .476 r
F
.37644 .26192 m .37711 .26334 L .37644 .24719 L F
.35761 .23453 m .37711 .26334 L .36246 .23214 L F
.3477 .22491 m .36775 .22954 L .37208 .2274 L .289 .763 .934 r
F
.37885 .26371 m .37866 .26455 L .38012 .26398 L .726 .593 .707 r
F
.37885 .26371 m .38083 .2637 L .38278 .26252 L F
.38777 .22539 m .38777 .25949 L p .39006 .26204 L .954 .779 .627 r
F P
0 g
s
.38083 .2637 m .39257 .26484 L p .38777 .25949 L .802 .811 .859 r
F P
0 g
s
.3956 .26726 m .38083 .2637 L .38012 .26398 L .765 .843 .911 r
F
.3956 .22723 m .38777 .22539 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.3883 .28558 m .39263 .2763 L .37351 .27448 L p .708 .867 .957 r
F P
0 g
s
.37351 .27448 m .39263 .2763 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.37711 .26334 m .37644 .26541 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.37644 .26541 m .37351 .27448 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.36922 .28379 m .37351 .27448 L p .35395 .23634 L 0 0 .476 r
F P
0 g
s
.34722 .23965 m .34704 .2453 L .35356 .23653 L .289 .763 .934 r
F
.35102 .23778 m .36922 .28379 L .35395 .23634 L 0 0 .476 r
F
.36446 .29088 m .36922 .28379 L p .33866 .20654 L F P
0 g
s
.36376 .29467 m .36832 .2982 L .34946 .29647 L p .451 0 0 r
F P
0 g
s
.35436 .29733 m .34946 .29647 L .36832 .2982 L p .119 0 0 r
F P
0 g
s
.36832 .2982 m .37327 .29906 L .35436 .29733 L p .119 0 0 r
F P
0 g
s
.35943 .29545 m .35436 .29733 L .37327 .29906 L p .224 .728 .901 r
F P
0 g
s
.37327 .29906 m .3784 .2972 L .35943 .29545 L p .224 .728 .901 r
F P
0 g
s
.35979 .28864 m .36376 .29467 L .34496 .29294 L p .665 .162 .042 r
F P
0 g
s
.34946 .29647 m .34496 .29294 L .36376 .29467 L p .451 0 0 r
F P
0 g
s
.36446 .29088 m .35943 .29545 L .3784 .2972 L p .469 .843 .988 r
F P
0 g
s
.3784 .2972 m .38348 .29264 L .36446 .29088 L p .469 .843 .988 r
F P
0 g
s
.36922 .28379 m .36446 .29088 L .38348 .29264 L p .618 .874 .99 r
F P
0 g
s
.38348 .29264 m .3883 .28558 L .36922 .28379 L p .618 .874 .99 r
F P
0 g
s
.37351 .27448 m .36922 .28379 L .3883 .28558 L p .708 .867 .957 r
F P
0 g
s
.37644 .27408 m .37231 .26701 L .3477 .3976 L .726 .593 .707 r
F
.3477 .22491 m .35356 .23653 L .36167 .23253 L .289 .763 .934 r
F
.35979 .28864 m .3578 .28846 L p .35724 .28608 L .772 .367 .285 r
F P
0 g
s
.3578 .28846 m .34103 .2869 L p .35724 .28608 L .772 .367 .285 r
F P
0 g
s
.34704 .2788 m .34704 .2453 L p .3558 .28314 L .726 .592 .707 r
F P
0 g
s
.3558 .28314 m .35635 .28552 L .34817 .27962 L .726 .592 .707 r
F
.3558 .28314 m .34817 .27962 L .34704 .2788 L F
.35305 .28187 m .35724 .28608 L .34103 .2869 L .772 .367 .285 r
F
.35804 .28418 m .35979 .28864 L p .35305 .28187 L F P
0 g
s
.34496 .29294 m .34103 .2869 L .35979 .28864 L p .665 .162 .042 r
F P
0 g
s
.35943 .29545 m .36446 .29088 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3477 .22491 m .34722 .23965 L .35356 .23653 L .289 .763 .934 r
F
.35305 .28187 m .34103 .2869 L .34817 .27962 L .772 .367 .285 r
F
.35436 .29733 m .35943 .29545 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.34704 .2788 m .34704 .27909 L p .34624 .27943 L .949 .775 .632 r
F P
0 g
s
.34817 .27962 m .34624 .27943 L p .34704 .2788 L .821 .504 .452 r
F P
0 g
s
.34946 .29647 m .35436 .29733 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3477 .22491 m .3477 .27658 L p .37231 .26701 L .726 .593 .707 r
F P
0 g
s
.34496 .29294 m .34946 .29647 L p .33929 .2118 L 0 0 .476 r
F P
0 g
s
.3477 .27658 m .3477 .3976 L p .37231 .26701 L .726 .593 .707 r
F P
0 g
s
.3956 .22723 m .38777 .22539 L p .39006 .26204 L .954 .779 .627 r
F P
0 g
s
.3956 .26822 m .39006 .26204 L .3956 .35065 L .954 .779 .627 r
F
.3956 .22723 m .39006 .26204 L .3956 .26822 L F
.38777 .22539 m .37885 .26371 L .38278 .26252 L .726 .593 .707 r
F
.38777 .26101 m .38777 .25949 L p .38278 .26252 L F P
0 g
s
.38777 .25949 m .38777 .22539 L p .38278 .26252 L .726 .593 .707 r
F P
0 g
s
.39627 .2652 m .39906 .25277 L .39886 .25275 L p .802 .811 .859 r
F P
0 g
s
.39886 .25275 m .38006 .25089 L p .38897 .25876 L .802 .811 .859 r
F P
0 g
s
.39627 .2652 m .39886 .25275 L .38897 .25876 L .802 .811 .859 r
F
.38006 .25089 m .37986 .25087 L p .38068 .25159 L F P
0 g
s
.39627 .2652 m .38006 .25089 L .38068 .25159 L .802 .811 .859 r
F
.39627 .2652 m .38893 .25879 L .38777 .25949 L F
.39257 .26484 m .39627 .2652 L p .38777 .25949 L F P
0 g
s
.3956 .35065 m .39006 .26204 L .38777 .39797 L .954 .779 .627 r
F
.38777 .25949 m .38777 .39797 L p .39006 .26204 L F P
0 g
s
.37986 .25087 m .37711 .26334 L .38083 .2637 L p .802 .811 .859 r
F P
0 g
s
.38893 .25879 m .37986 .25087 L .38083 .2637 L .802 .811 .859 r
F
.37885 .26371 m .38012 .26398 L .38083 .2637 L .726 .593 .707 r
F
.38278 .26252 m .38083 .2637 L .38777 .26101 L F
.38083 .2637 m .37711 .26334 L p .38012 .26398 L .765 .843 .911 r
F P
0 g
s
.37866 .26455 m .37644 .26541 L .37644 .27408 L .726 .593 .707 r
F
.37986 .25087 m .38164 .23763 L p .36936 .22875 L 0 0 .476 r
F P
0 g
s
.36246 .23214 m .37986 .25087 L .36936 .22875 L 0 0 .476 r
F
.37644 .22526 m .3477 .22491 L p .37208 .2274 L .289 .763 .934 r
F P
0 g
s
.36936 .22875 m .38164 .23763 L .38024 .22338 L 0 0 .476 r
F
.37644 .22526 m .3477 .22491 L p .37644 .27408 L .726 .593 .707 r
F P
0 g
s
.38164 .23763 m .38234 .22423 L p .38024 .22338 L 0 0 .476 r
F P
0 g
s
.3477 .3976 m .38777 .39797 L .38777 .26101 L p .726 .593 .707 r
F P
0 g
s
.37866 .26455 m .3477 .3976 L .38777 .26101 L .726 .593 .707 r
F
.37859 .26458 m .38012 .26398 L .37711 .26334 L .765 .843 .911 r
F
.3956 .26726 m .39627 .2652 L .39257 .26484 L p F P
0 g
s
.40778 .277 m .3956 .26726 L .3956 .35065 L .954 .779 .627 r
F
.41526 .23183 m .3956 .26726 L .40778 .277 L F
.39906 .25277 m .40085 .23957 L p .3956 .23582 L 0 0 .48 r
F P
0 g
s
.3956 .24909 m .39906 .25277 L .3956 .23582 L 0 0 .48 r
F
.40085 .23957 m .40156 .22621 L p .39944 .22536 L F P
0 g
s
.3956 .22382 m .39657 .22675 L .39944 .22536 L 0 0 .48 r
F
.39657 .22675 m .40085 .23957 L .39944 .22536 L F
.3956 .23582 m .40085 .23957 L .3956 .22382 L F
.3574 .2085 m .35804 .21121 L .35804 .21057 L F
.34103 .2869 m .34496 .29294 L p .33929 .21522 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33929 .22802 L .33929 .21522 L 0 0 .476 r
F
.33929 .22802 m .34103 .2869 L .33929 .21522 L F
.33866 .20654 m .33929 .21522 L .33929 .2118 L F
.33929 .21522 m .34496 .29294 L .33929 .2118 L F
.33929 .28242 m .34103 .2869 L p .33929 .22802 L F P
0 g
s
.31947 .23912 m .33929 .24356 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.31947 .23912 m .33929 .24356 L p .3477 .22491 L .289 .763 .934 r
F P
0 g
s
.3477 .22491 m .33929 .24356 L .34722 .23965 L .289 .763 .934 r
F
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61773 .3976 m .58712 .40189 L .58382 .40818 L p .224 .73 .894 r
F P
0 g
s
.68252 .40275 m .65761 .39797 L .61773 .3976 L p .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.34704 .41278 m .31947 .40818 L .31947 .23912 L p .949 .775 .632 r
F P
0 g
s
.41526 .40275 m .41413 .40902 L .41413 .24025 L p 0 0 .042 r
F P
0 g
s
.58712 .40189 m .61773 .3976 L .61773 .22491 L p .378 .309 .652 r
F P
0 g
s
.61773 .22491 m .58712 .23067 L .58712 .40189 L p .378 .309 .652 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3859 .41312 m .41413 .40902 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.34704 .41278 m .3859 .41312 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.31947 .40818 m .34704 .41278 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.33866 .20654 m .33607 .21872 L .33441 .23154 L p 0 0 .476 r
F P
0 g
s
.62323 .19751 m .6191 .2085 L .60111 .20654 L p .765 .84 .909 r
F P
0 g
s
.6282 .18815 m .62323 .19751 L .6191 .2085 L p .049 .04 .524 r
F P
0 g
s
.6338 .18082 m .6282 .18815 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.63979 .17587 m .6338 .18082 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.64593 .17353 m .63979 .17587 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65193 .17395 m .64593 .17353 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65754 .17712 m .65193 .17395 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.6625 .18295 m .65754 .17712 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66658 .19117 m .6625 .18295 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66957 .20145 m .66658 .19117 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.67135 .21331 m .66957 .20145 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.67183 .22621 m .67135 .21331 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.36086 .19751 m .3574 .2085 L .33866 .20654 L p .765 .835 .906 r
F P
0 g
s
.36502 .18815 m .36086 .19751 L .3574 .2085 L p 0 0 .48 r
F P
0 g
s
.3697 .18082 m .36502 .18815 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.37473 .17587 m .3697 .18082 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.37986 .17353 m .37473 .17587 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3849 .17395 m .37986 .17353 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3896 .17712 m .3849 .17395 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39375 .18295 m .3896 .17712 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39716 .19117 m .39375 .18295 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39967 .20145 m .39716 .19117 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.40117 .21331 m .39967 .20145 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.40156 .22621 m .40117 .21331 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.60111 .20654 m .60521 .19551 L .62323 .19751 L p .765 .84 .909 r
F P
0 g
s
.6282 .18815 m .62323 .19751 L .60521 .19551 L p .71 .863 .954 r
F P
0 g
s
.33866 .20654 m .34208 .19551 L .36086 .19751 L p .765 .835 .906 r
F P
0 g
s
.36502 .18815 m .36086 .19751 L .34208 .19551 L p .713 .859 .951 r
F P
0 g
s
.60521 .19551 m .61013 .18611 L .6282 .18815 L p .71 .863 .954 r
F P
0 g
s
.61013 .18611 m .60521 .19551 L .60111 .20654 L p .042 .034 .521 r
F P
0 g
s
.6338 .18082 m .6282 .18815 L .61013 .18611 L p .627 .87 .988 r
F P
0 g
s
.61013 .18611 m .61568 .17875 L .6338 .18082 L p .627 .87 .988 r
F P
0 g
s
.61568 .17875 m .61013 .18611 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.63979 .17587 m .6338 .18082 L .61568 .17875 L p .492 .846 .994 r
F P
0 g
s
.61568 .17875 m .62163 .17378 L .63979 .17587 L p .492 .846 .994 r
F P
0 g
s
.62163 .17378 m .61568 .17875 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64593 .17353 m .63979 .17587 L .62163 .17378 L p .273 .753 .93 r
F P
0 g
s
.62163 .17378 m .62771 .17143 L .64593 .17353 L p .273 .753 .93 r
F P
0 g
s
.62771 .17143 m .62163 .17378 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65193 .17395 m .64593 .17353 L .62771 .17143 L p 0 .536 .731 r
F P
0 g
s
.62771 .17143 m .63367 .17184 L .65193 .17395 L p 0 .536 .731 r
F P
0 g
s
.63367 .17184 m .62771 .17143 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.63923 .17502 m .63367 .17184 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64415 .18085 m .63923 .17502 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64819 .18909 m .64415 .18085 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65117 .1994 m .64819 .18909 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65293 .21129 m .65117 .1994 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.6534 .22423 m .65293 .21129 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.34208 .19551 m .34619 .18611 L .36502 .18815 L p .713 .859 .951 r
F P
0 g
s
.34619 .18611 m .34208 .19551 L .33866 .20654 L p 0 0 .476 r
F P
0 g
s
.3697 .18082 m .36502 .18815 L .34619 .18611 L p .631 .868 .987 r
F P
0 g
s
.34619 .18611 m .35083 .17875 L .3697 .18082 L p .631 .868 .987 r
F P
0 g
s
.35083 .17875 m .34619 .18611 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37473 .17587 m .3697 .18082 L .35083 .17875 L p .496 .847 .994 r
F P
0 g
s
.35083 .17875 m .3558 .17378 L .37473 .17587 L p .496 .847 .994 r
F P
0 g
s
.3558 .17378 m .35083 .17875 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37986 .17353 m .37473 .17587 L .3558 .17378 L p .272 .752 .929 r
F P
0 g
s
.3558 .17378 m .36088 .17143 L .37986 .17353 L p .272 .752 .929 r
F P
0 g
s
.36088 .17143 m .3558 .17378 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3849 .17395 m .37986 .17353 L .36088 .17143 L p 0 .526 .718 r
F P
0 g
s
.36088 .17143 m .36586 .17184 L .3849 .17395 L p 0 .526 .718 r
F P
0 g
s
.36586 .17184 m .36088 .17143 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37051 .17502 m .36586 .17184 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37461 .18085 m .37051 .17502 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37799 .18909 m .37461 .18085 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38047 .1994 m .37799 .18909 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38195 .21129 m .38047 .1994 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38234 .22423 m .38195 .21129 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.41413 .24025 m .41526 .23183 L .41526 .40275 L p 0 0 .042 r
F P
0 g
s
.31947 .40818 m .31939 .40189 L .31939 .23067 L p .71 .58 .003 r
F P
0 g
s
.31939 .23067 m .31947 .23912 L .31947 .40818 L p .71 .58 .003 r
F P
0 g
s
.38777 .39797 m .41526 .40275 L .41526 .23183 L p .954 .779 .627 r
F P
0 g
s
.31939 .40189 m .3477 .3976 L .3477 .22491 L p .351 .287 .644 r
F P
0 g
s
.3477 .22491 m .31939 .23067 L .31947 .23912 L p .289 .763 .934 r
F P
0 g
s
.3477 .22491 m .31939 .23067 L .31939 .40189 L p .351 .287 .644 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41413 .40902 m .41526 .40275 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.3477 .3976 m .31939 .40189 L .31947 .40818 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65754 .17712 m .65193 .17395 L .63367 .17184 L p .389 0 0 r
F P
0 g
s
.3896 .17712 m .3849 .17395 L .36586 .17184 L p .408 0 0 r
F P
0 g
s
.41526 .40275 m .38777 .39797 L .3477 .3976 L p .224 .73 .894 r
F P
0 g
s
.63367 .17184 m .63923 .17502 L .65754 .17712 L p .389 0 0 r
F P
0 g
s
.36586 .17184 m .37051 .17502 L .3896 .17712 L p .408 0 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6625 .18295 m .65754 .17712 L .63923 .17502 L p .635 .107 0 r
F P
0 g
s
.39375 .18295 m .3896 .17712 L .37051 .17502 L p .647 .128 0 r
F P
0 g
s
.684 1.07578 m .66842 1.06807 L .68303 1.06704 L closepath p .64 .136 .035 r
F P
0 g
s
.6886 1.0493 m .70625 .9931 L p .6967 1.02858 L 0 0 .095 r
F P
0 g
s
.70625 .9931 m .68303 1.06704 L p .68811 1.02338 L .855 .879 .855 r
F P
0 g
s
.69103 .99828 m .70029 .99513 L .68811 1.02338 L .855 .879 .855 r
F
.70029 .99513 m .70625 .9931 L .68811 1.02338 L F
.69884 .99457 m .70354 .99364 L .69103 .99828 L F
.70354 .99364 m .70625 .9931 L .704 .99387 L F
.70354 .99364 m .704 .99387 L .69103 .99828 L F
.70136 .99337 m .70625 .9931 L p .69129 .99606 L F P
0 g
s
.70625 .9931 m .70627 .99327 L p .684 1.07578 L 0 0 .095 r
F P
0 g
s
.6896 1.05798 m .684 1.07578 L p .70627 .99327 L 0 0 .095 r
F P
0 g
s
.6914 .99846 m .70136 .99337 L p .70409 1.00173 L .869 .8 .779 r
F P
0 g
s
.70035 1.01626 m .70409 1.00173 L .72475 1.06482 L .869 .8 .779 r
F
.6914 .99846 m .70409 1.00173 L .70035 1.01626 L F
.70136 .99337 m .70625 .9931 L .70627 .99327 L p .628 .114 .004 r
F P
0 g
s
.70661 .99197 m .70693 .99326 L p .70136 .99337 L .869 .8 .779 r
F P
0 g
s
.70693 .99326 m .72475 1.06482 L p .70136 .99337 L .869 .8 .779 r
F P
0 g
s
.70627 .99327 m .70685 .9977 L p .70196 1.0148 L 0 0 .095 r
F P
0 g
s
.72475 1.06482 m .71003 1.07251 L .6914 .99846 L p .869 .8 .779 r
F P
0 g
s
.69809 1.02504 m .71003 1.07251 L p .70864 1.0334 L .438 .526 .85 r
F P
0 g
s
.70183 1.01546 m .69809 1.02504 L .70864 1.0334 L .438 .526 .85 r
F
.70531 .99701 m .70196 1.0148 L .6896 1.05798 L 0 0 .095 r
F
.70627 .99327 m .70196 1.0148 L .70531 .99701 L F
.70786 1.01149 m .70183 1.01546 L .70864 1.0334 L .438 .526 .85 r
F
.70247 1.01384 m .70183 1.01546 L .70786 1.01149 L F
.696 1.03763 m .6896 1.05798 L p .70196 1.0148 L 0 0 .095 r
F P
0 g
s
.70685 .9977 m .70139 1.01778 L .70196 1.0148 L 0 0 .095 r
F
.70139 1.01778 m .696 1.03763 L .70196 1.0148 L F
.684 1.07578 m .68303 1.06704 L .6886 1.0493 L p F P
0 g
s
.6967 1.02858 m .684 1.07578 L .6886 1.0493 L 0 0 .095 r
F
.68303 1.06704 m .66842 1.06807 L .69083 .99618 L p .855 .879 .855 r
F P
0 g
s
.70136 .99337 m .68421 .99452 L .69927 .97691 L .511 .018 .022 r
F
.65947 .99618 m .67017 .991 L p .68421 .99452 L F P
0 g
s
.67017 .991 m .69927 .97691 L p .68421 .99452 L .511 .018 .022 r
F P
0 g
s
.69129 .99606 m .68303 1.06704 L .69083 .99618 L .855 .879 .855 r
F
.706 1.00081 m .70247 1.01384 L .70139 .99365 L .347 .283 .642 r
F
.70139 1.0143 m .70139 .99365 L p .70247 1.01384 L F P
0 g
s
.72593 1.07356 m .71003 1.07251 L .72475 1.06482 L closepath p .398 0 .067 r
F P
0 g
s
.72593 1.07356 m .72475 1.06482 L .70661 .99197 L p .755 .49 0 r
F P
0 g
s
.70663 .9921 m .72593 1.07356 L .70661 .99197 L .755 .49 0 r
F
.7092 1.00578 m .70247 1.01384 L .706 1.00081 L .347 .283 .642 r
F
.70663 .9921 m .70714 .99606 L .72593 1.07356 L .755 .49 0 r
F
.71757 .9848 m .74396 .99618 L p .70687 .99398 L .511 .018 .022 r
F P
0 g
s
.71021 1.01047 m .70247 1.01384 L .7092 1.00578 L .347 .283 .642 r
F
.71021 1.01047 m .72593 1.07356 L p .70714 .99606 L .755 .49 0 r
F P
0 g
s
.70201 1.01852 m .70139 1.01778 L .7032 1.01477 L .347 .283 .642 r
F
.7032 1.01477 m .70139 1.01778 L .70247 1.01384 L F
.71003 1.07251 m .72593 1.07356 L .71021 1.01047 L p .438 .526 .85 r
F P
0 g
s
.70719 .99644 m .71021 1.01047 L .70714 .99606 L .755 .49 0 r
F
.71225 1.00958 m .70139 .99365 L .70271 .99463 L .347 .283 .642 r
F
.72113 1.02351 m .71178 1.00978 L .71225 1.00958 L F
.72099 1.02407 m .71178 1.00978 L .72113 1.02351 L F
.71178 1.00978 m .70139 .99365 L .71225 1.00958 L F
.74396 .99618 m .72562 1.0053 L p .70719 .99644 L .511 .018 .022 r
F P
0 g
s
.70719 .99644 m .70687 .99398 L .74396 .99618 L .511 .018 .022 r
F
.74396 .99618 m .71757 .9848 L p .70921 .91076 L .305 .36 .755 r
F P
0 g
s
.71757 .9848 m .69927 .97691 L .70139 .90907 L p .305 .36 .755 r
F P
0 g
s
.70139 .90907 m .70139 .8749 L p .70602 .89006 L .347 .283 .642 r
F P
0 g
s
.71255 .91149 m .70139 .90907 L .70602 .89006 L .347 .283 .642 r
F
.70139 .90907 m .69927 .97691 L p .69071 .95301 L .945 .896 .747 r
F P
0 g
s
.69629 .91033 m .65352 .88252 L .69409 .87484 L .954 .779 .626 r
F
.65178 .87448 m .69409 .87484 L p .65352 .88252 L F P
0 g
s
.66352 .91843 m .64101 .87438 L .69629 .91033 L .954 .779 .626 r
F
.67711 .91507 m .70139 .90907 L .69071 .95301 L .945 .896 .747 r
F
.70627 .99327 m .70685 .9977 L p .70136 .99337 L .628 .114 .004 r
F P
0 g
s
.70177 .99393 m .70136 .99337 L .70685 .9977 L .628 .114 .004 r
F
.69927 .97691 m .70497 .97937 L p .70139 .99365 L .511 .018 .022 r
F P
0 g
s
.66253 .87438 m .70305 .85625 L .70247 .87477 L p .945 .896 .747 r
F P
0 g
s
.70972 .87484 m .70139 .8749 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70139 .90907 m .70139 .99256 L p .69629 .91033 L .954 .779 .626 r
F P
0 g
s
.69629 .91033 m .69409 .87484 L .70139 .90907 L .954 .779 .626 r
F
.69409 .87484 m .70139 .8749 L .70139 .90907 L p F P
0 g
s
.70247 .87477 m .70305 .85625 L p .70514 .87475 L .305 .36 .755 r
F P
0 g
s
.70305 .85625 m .70845 .87472 L .70514 .87475 L .305 .36 .755 r
F
.77017 .87438 m .70972 .87484 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .74865 .87438 L .77017 .87438 L .012 .587 .719 r
F
.7598 .87429 m .77017 .87438 L p .74865 .87438 L F P
0 g
s
.74865 .87438 m .70835 .87438 L p .70305 .85625 L .305 .36 .755 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 .924 L p .347 .283 .642 r
F P
0 g
s
.74693 .91895 m .74396 .99618 L p .71965 .91303 L .305 .36 .755 r
F P
0 g
s
.71965 .91303 m .74396 .99618 L .70921 .91076 L .305 .36 .755 r
F
.72562 1.0053 m .74396 .99618 L .74693 .91895 L p .948 .9 .745 r
F P
0 g
s
.77017 .924 m .77017 1.10042 L p .73257 .97714 L .347 .283 .642 r
F P
0 g
s
.73257 .97714 m .71255 .91149 L .74693 .91895 L .347 .283 .642 r
F
.73257 .97714 m .74693 .91895 L .77017 .924 L F
.71255 .91149 m .70139 .8749 L .77017 .924 L F
.71312 .89071 m .74865 .87438 L .74693 .91895 L p .305 .36 .755 r
F P
0 g
s
.71312 .89071 m .74693 .91895 L .71965 .91303 L .305 .36 .755 r
F
.70514 .87475 m .71965 .91303 L .70921 .91076 L F
.70845 .87472 m .71965 .91303 L .70514 .87475 L F
.70305 .85625 m .74865 .87438 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.70996 .87384 m .7598 .87429 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.70559 .87438 m .70996 .87384 L .74865 .87438 L F
.66253 .87438 m .70305 .85625 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.64101 .87438 m .70996 .87384 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .69409 .87484 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.69409 .87484 m .64101 .87438 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .70139 .90907 L p .66253 .87438 L .945 .896 .747 r
F P
0 g
s
.70139 .90907 m .70247 .87477 L p .70921 .91076 L .305 .36 .755 r
F P
0 g
s
.70514 .87475 m .70921 .91076 L .70247 .87477 L .305 .36 .755 r
F
.7082 .89298 m .66253 .87438 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.74865 .87438 m .7082 .89298 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.70921 .91076 m .71757 .9848 L .70139 .90907 L .305 .36 .755 r
F
.70706 .99543 m .70384 .9938 L .70687 .99398 L .511 .018 .022 r
F
.70719 .99644 m .70384 .9938 L .70706 .99543 L F
.70719 .99644 m .70139 .99365 L .70384 .9938 L F
.70685 .99485 m .70719 .99644 L .70714 .99606 L .755 .49 0 r
F
.70177 .99393 m .70139 .99365 L .70136 .99337 L .628 .114 .004 r
F
.70139 .99365 m .70647 .99088 L .70687 .99398 L .511 .018 .022 r
F
.70647 .99088 m .71757 .9848 L .70687 .99398 L F
.70139 .99365 m .70497 .97937 L .70647 .99088 L F
.70136 .99337 m .70633 .99084 L .70661 .99197 L p .869 .8 .779 r
F P
0 g
s
.70633 .99084 m .70685 .99485 L p .70714 .99606 L .755 .49 0 r
F P
0 g
s
.70633 .99084 m .70714 .99606 L .70663 .9921 L .755 .49 0 r
F
.70661 .99197 m .70633 .99084 L p .70663 .9921 L F P
0 g
s
.70497 .97937 m .71757 .9848 L p .70647 .99088 L .511 .018 .022 r
F P
0 g
s
.70136 .99337 m .70633 .99084 L .70635 .991 L p .379 0 .039 r
F P
0 g
s
.70635 .991 m .70685 .99485 L p .70136 .99337 L .379 0 .039 r
F P
0 g
s
.74383 1.01405 m .7052 .99449 L .74022 1.00219 L .347 .283 .642 r
F
.74819 1.02833 m .70524 .9955 L .74383 1.01405 L F
.70172 .99373 m .70136 .99337 L .70685 .99485 L .379 0 .039 r
F
.70524 .9955 m .70139 .99256 L .74383 1.01405 L .347 .283 .642 r
F
.77017 1.10042 m .71544 1.01458 L .74819 1.02833 L F
.71544 1.01458 m .70271 .99463 L .7209 1.00811 L F
.71544 1.01458 m .7209 1.00811 L .74819 1.02833 L F
.70786 1.01149 m .71003 1.07251 L .71021 1.01047 L .438 .526 .85 r
F
.77017 1.10042 m .70247 1.01384 L .71178 1.00978 L .347 .283 .642 r
F
.7075 1.00147 m .70247 1.01384 L .70786 1.01149 L .438 .526 .85 r
F
.70733 1.00139 m .70247 1.01384 L .7075 1.00147 L F
.70139 1.09633 m .69265 1.06418 L .70012 1.02455 L .954 .779 .626 r
F
.70139 1.01778 m .70139 1.03123 L p .70012 1.02455 L F P
0 g
s
.70139 1.03123 m .70139 1.09633 L p .70012 1.02455 L .954 .779 .626 r
F P
0 g
s
.77017 1.10042 m .70139 1.09633 L .70139 1.01778 L p .347 .283 .642 r
F P
0 g
s
.70735 1.00156 m .696 1.03763 L p .70685 .9977 L 0 0 .095 r
F P
0 g
s
.696 1.03763 m .70012 1.02455 L p .66977 1.06874 L .486 .481 .777 r
F P
0 g
s
.70676 1.00113 m .70209 1.014 L .70732 1.00139 L .438 .526 .85 r
F
.70209 1.014 m .69809 1.02504 L .70247 1.01384 L F
.70685 .9977 m .70733 1.00139 L p .70177 .99393 L .628 .114 .004 r
F P
0 g
s
.70718 1.00132 m .70177 .99393 L .70733 1.00139 L .628 .114 .004 r
F
.70209 1.014 m .70247 1.01384 L .70749 1.00099 L .438 .526 .85 r
F
.69598 1.01666 m .69809 1.02504 L p .70209 1.014 L F P
0 g
s
.70718 1.00132 m .70206 .9989 L .70139 .99365 L .628 .114 .004 r
F
.70718 1.00132 m .70139 .99365 L .70177 .99393 L F
.70271 .99463 m .70139 .99256 L .74819 1.02833 L .347 .283 .642 r
F
.70271 .99463 m .70139 .99365 L .7022 .99383 L F
.70207 .999 m .70206 .9989 L .70718 1.00132 L .628 .114 .004 r
F
.70139 .99365 m .70139 1.0143 L p .69546 .99866 L .954 .779 .626 r
F P
0 g
s
.69546 .99866 m .6914 .99846 L p .70124 .99379 L .379 0 .039 r
F P
0 g
s
.70207 .999 m .70139 .99365 L .70719 .99644 L .511 .018 .022 r
F
.70207 .999 m .70719 .99644 L .70771 1.00042 L F
.70743 .99928 m .70098 .99356 L .70172 .99373 L .379 0 .039 r
F
.69546 .99866 m .69491 .99721 L .70139 .99365 L .954 .779 .626 r
F
.6914 .99846 m .70098 .99356 L p .70124 .99379 L .379 0 .039 r
F P
0 g
s
.70724 .99911 m .69546 .99866 L .70124 .99379 L .379 0 .039 r
F
.70207 .999 m .69546 .99866 L p .70724 .99911 L F P
0 g
s
.6914 .99846 m .69598 1.01666 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.70743 .99928 m .69546 .99866 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.69546 .99866 m .6914 .99846 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.69129 .99606 m .69884 .99457 L .69103 .99828 L .855 .879 .855 r
F
.69083 .99618 m .69003 .99876 L p .69522 .99886 L .486 .481 .777 r
F P
0 g
s
.70707 1.00026 m .69598 1.01666 L .70209 1.014 L .438 .526 .85 r
F
.70682 1.0002 m .69598 1.01666 L .70707 1.00026 L F
.70139 1.01778 m .69859 1.01653 L .69491 .99721 L .954 .779 .626 r
F
.70139 1.0143 m .70139 1.01778 L p .69491 .99721 L F P
0 g
s
.70207 .999 m .69491 .99721 L .69522 .99886 L .486 .481 .777 r
F
.69491 .99721 m .69083 .99618 L .69522 .99886 L F
.69003 .99876 m .66842 1.06807 L p .69717 1.00907 L F P
0 g
s
.70207 .999 m .69522 .99886 L .69717 1.00907 L .486 .481 .777 r
F
.69522 .99886 m .69003 .99876 L .69717 1.00907 L F
.69869 1.01704 m .66977 1.06874 L .70012 1.02455 L F
.70012 1.02455 m .69859 1.01653 L .70139 1.01778 L .954 .779 .626 r
F
.66842 1.06807 m .66977 1.06874 L p .70735 1.00156 L .486 .481 .777 r
F P
0 g
s
.66977 1.06874 m .684 1.07578 L .696 1.03763 L p .486 .481 .777 r
F P
0 g
s
.70735 1.00156 m .70207 .999 L p .66842 1.06807 L .486 .481 .777 r
F P
0 g
s
.69265 1.06418 m .67708 1.00696 L .69859 1.01653 L .954 .779 .626 r
F
.69265 1.06418 m .69859 1.01653 L .70012 1.02455 L F
.69859 1.01653 m .68085 1.00864 L .69491 .99721 L F
.68085 1.00864 m .68012 1.0053 L .69491 .99721 L F
.70139 1.01778 m .70139 1.0143 L p .70247 1.01384 L .347 .283 .642 r
F P
0 g
s
.70012 1.02455 m .70735 1.00156 L p .69869 1.01704 L .486 .481 .777 r
F P
0 g
s
.70422 1.01594 m .69077 .9962 L .69083 .99618 L .511 .018 .022 r
F
.77017 1.10042 m .70201 1.01852 L .7032 1.01477 L .347 .283 .642 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L F P
0 g
s
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .55502 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .63384 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.63384 1.0217 m .55502 1.07831 L .55468 1.04379 L .682 .404 .495 r
F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63614 1.043 m .67151 1.043 L p .63572 1.05936 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.55483 1.09633 m .63572 1.05936 L .63551 1.06739 L F
.63572 1.05936 m .67151 1.043 L .63551 1.06739 L F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.60506 1.07831 m .6913 1.07831 L .70139 1.09633 L F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.69265 1.06418 m .67703 1.05284 L .67708 1.00696 L .954 .779 .626 r
F
.67704 1.04273 m .65736 1.01775 L .67708 1.00696 L F
.67703 1.05284 m .67151 1.043 L .67704 1.04273 L F
.67151 1.043 m .65736 1.01775 L .67704 1.04273 L F
.67151 1.043 m .69746 1.04516 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.69265 1.06418 m .68599 1.06885 L .67703 1.05284 L .954 .779 .626 r
F
.70139 1.09633 m .68639 1.09735 L p .69265 1.06418 L F P
0 g
s
.68639 1.09735 m .64101 1.10042 L p .69265 1.06418 L .954 .779 .626 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.67151 1.043 m .64101 1.02671 L .65736 1.01775 L .954 .779 .626 r
F
.67703 1.05284 m .66397 1.04337 L .67151 1.043 L F
.66397 1.04337 m .64101 1.02671 L .67151 1.043 L F
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63772 1.04435 m .65515 1.0438 L .63614 1.043 L F
.63806 1.04464 m .64101 1.04449 L .63772 1.04435 L F
.64101 1.04449 m .65515 1.0438 L .63772 1.04435 L F
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .60986 1.04601 L .6333 1.04487 L .066 0 0 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L F
.6395 1.10246 m .63806 1.04502 L .63593 1.05141 L 0 0 .063 r
F
.67703 1.05284 m .64101 1.04449 L .66397 1.04337 L .954 .779 .626 r
F
.64101 1.10042 m .64101 1.04449 L p .67703 1.05284 L F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.68599 1.06885 m .64101 1.10042 L .67703 1.05284 L .954 .779 .626 r
F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63806 1.04502 m .63614 1.043 L .63593 1.05141 L 0 0 .063 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L .066 0 0 r
F
.6395 1.10246 m .63919 1.05309 L .6371 1.00646 L 0 0 .063 r
F
.63919 1.05309 m .63854 .95086 L .63756 .98856 L F
.63919 1.05309 m .63756 .98856 L .6371 1.00646 L F
.55483 1.09633 m .63614 1.043 L .63572 1.05936 L .678 .717 .878 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L 0 0 .026 r
F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.63538 1.08458 m .60923 1.09451 L .43099 1.07831 L .682 .404 .495 r
F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52783 1.09787 m .51885 1.09818 L .516 1.09787 L .09 0 0 r
F
.55468 1.04379 m .55502 1.07831 L .44498 1.07831 L .682 .404 .495 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.55468 1.04379 m .44498 1.07831 L .44502 1.07439 L .682 .404 .495 r
F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.51434 1.25793 m .54175 1.25635 L .52667 1.25967 L F
.54175 1.25635 m .62917 1.25133 L .54517 1.25817 L F
.54175 1.25635 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.484 1.25967 m .51434 1.25793 L .52667 1.25967 L .365 .792 .97 r
F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.4813 1.25829 m .54018 1.25552 L .484 1.25967 L .365 .792 .97 r
F
.54018 1.25552 m .62917 1.25133 L .54175 1.25635 L F
.54018 1.25552 m .54175 1.25635 L .484 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.45621 1.25744 m .62917 1.25133 L .452 1.25967 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.452 1.25967 m .4813 1.25829 L .484 1.25967 L .365 .792 .97 r
F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.53645 1.09918 m .47146 1.10147 L .4687 1.10147 L .09 0 0 r
F
.53616 1.09921 m .47166 1.10147 L .53645 1.09918 L F
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .47146 1.10147 L .09 0 0 r
F
.47166 1.10147 m .47146 1.10147 L .53645 1.09918 L F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L .09 0 0 r
F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.55676 1.10246 m .44324 1.10246 L p .53019 1.09942 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L .09 0 0 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.516 1.09787 m .46368 1.10009 L .484 1.09787 L F
.51885 1.09818 m .46368 1.10009 L .516 1.09787 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.47146 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.55566 1.09853 m .53616 1.09921 L .53645 1.09918 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.46771 1.06813 m .47031 1.09869 L .46995 1.09874 L .997 .814 .539 r
F
.47031 1.09869 m .47036 1.09936 L .46995 1.09874 L F
.46995 1.09874 m .47036 1.09936 L .47 1.0994 L F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.66397 1.04337 m .64101 1.04449 L .64101 1.02671 L .954 .779 .626 r
F
.69239 .99858 m .67129 1.0014 L .69077 .9962 L .511 .018 .022 r
F
.68012 1.0053 m .67129 1.0014 L p .69239 .99858 L F P
0 g
s
.67129 1.0014 m .65947 .99618 L p .70136 .99337 L .511 .018 .022 r
F P
0 g
s
.69927 .97691 m .65947 .99618 L .66141 .91895 L p .945 .896 .747 r
F P
0 g
s
.65947 .99618 m .67546 1.00324 L p .6662 .98194 L .293 .353 .754 r
F P
0 g
s
.67546 1.00324 m .68012 1.0053 L p .6662 .98194 L .293 .353 .754 r
F P
0 g
s
.67227 .96907 m .6662 .98194 L .68012 1.0053 L .293 .353 .754 r
F
.66141 .91895 m .65947 .99618 L p .67227 .96907 L F P
0 g
s
.64101 1.02671 m .64101 .924 L p .67708 1.00696 L .954 .779 .626 r
F P
0 g
s
.64101 .924 m .64101 .87438 L p .65366 .92087 L .954 .779 .626 r
F P
0 g
s
.67708 1.00696 m .64101 .924 L .65366 .92087 L .954 .779 .626 r
F
.67711 .91507 m .69927 .97691 L .66141 .91895 L .945 .896 .747 r
F
.66869 .97611 m .64101 .87438 L .70139 .99256 L .954 .779 .626 r
F
.66141 .91895 m .66253 .87438 L p .67711 .91507 L .945 .896 .747 r
F P
0 g
s
.66253 .87438 m .70139 .90907 L .67711 .91507 L .945 .896 .747 r
F
.7082 .89298 m .66253 .87438 L .66141 .91895 L p .293 .353 .754 r
F P
0 g
s
.70139 .99256 m .66352 .91843 L .69629 .91033 L .954 .779 .626 r
F
.7082 .89298 m .66141 .91895 L .67227 .96907 L .293 .353 .754 r
F
.64101 .87438 m .65178 .87448 L p .65352 .88252 L .954 .779 .626 r
F P
0 g
s
.70996 .87384 m .65289 .87429 L p .64101 1.04449 L .333 .272 .638 r
F P
0 g
s
.65289 .87429 m .64101 .87438 L .64101 .924 L p .333 .272 .638 r
F P
0 g
s
.64101 .924 m .64101 1.04449 L p .65289 .87429 L .333 .272 .638 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.67708 1.00696 m .66869 .97611 L .69155 .98838 L .954 .779 .626 r
F
.70098 .99356 m .70136 .99337 L p .70172 .99373 L .379 0 .039 r
F P
0 g
s
.70207 .999 m .69083 .99618 L .70136 .99337 L .511 .018 .022 r
F
.69083 .99618 m .69154 .99391 L p .69129 .99606 L .855 .879 .855 r
F P
0 g
s
.69154 .99391 m .70136 .99337 L p .69129 .99606 L .855 .879 .855 r
F P
0 g
s
.69154 .99391 m .69083 .99618 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69491 .99721 m .69455 .99537 L .70139 .99365 L .954 .779 .626 r
F
.70207 .999 m .69455 .99537 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69455 .99537 m .69154 .99391 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69491 .99721 m .69424 .99545 L .69455 .99537 L .954 .779 .626 r
F
.69455 .99537 m .69154 .99391 L p .6946 .99536 L .628 .114 .004 r
F P
0 g
s
.69154 .99391 m .70136 .99337 L p .70139 .99365 L .628 .114 .004 r
F P
0 g
s
.70206 .9989 m .6946 .99536 L .70139 .99365 L .628 .114 .004 r
F
.6946 .99536 m .69154 .99391 L .70139 .99365 L F
.70422 1.01594 m .69083 .99618 L .70207 .999 L .511 .018 .022 r
F
.67708 1.00696 m .68406 .998 L .69491 .99721 L .954 .779 .626 r
F
.68406 .998 m .69155 .98838 L .69424 .99545 L F
.68406 .998 m .69424 .99545 L .69491 .99721 L F
.69424 .99545 m .69155 .98838 L .70139 .99365 L F
.70207 .999 m .69455 .99537 L p .70206 .9989 L .628 .114 .004 r
F P
0 g
s
.69455 .99537 m .6946 .99536 L .70206 .9989 L .628 .114 .004 r
F
.70743 .99928 m .70207 .999 L p .70724 .99911 L .379 0 .039 r
F P
0 g
s
.70685 .99485 m .70743 .99928 L p .70172 .99373 L .379 0 .039 r
F P
0 g
s
.74022 1.00219 m .70139 .99256 L .72241 .94381 L .347 .283 .642 r
F
.7052 .99449 m .70139 .99256 L .74022 1.00219 L F
.70139 .99256 m .70139 .90907 L p .72241 .94381 L F P
0 g
s
.72241 .94381 m .70139 .90907 L .71255 .91149 L .347 .283 .642 r
F
.70771 1.00042 m .71021 1.01047 L p .70719 .99644 L .755 .49 0 r
F P
0 g
s
.70743 .99928 m .70676 1.00113 L .70749 1.00099 L .438 .526 .85 r
F
.70676 1.00113 m .70732 1.00139 L .70749 1.00099 L F
.70733 1.00139 m .70735 1.00156 L p .70718 1.00132 L .628 .114 .004 r
F P
0 g
s
.71021 1.01047 m .70771 1.00042 L p .70786 1.01149 L .438 .526 .85 r
F P
0 g
s
.70747 1.00036 m .70786 1.01149 L .70771 1.00042 L .438 .526 .85 r
F
.71178 1.00978 m .71021 1.01047 L .7092 1.00578 L .347 .283 .642 r
F
.70749 1.00099 m .70733 1.00139 L .7075 1.00147 L .438 .526 .85 r
F
.70735 1.00156 m .70207 .999 L p .70718 1.00132 L .628 .114 .004 r
F P
0 g
s
.72562 1.0053 m .70422 1.01594 L p .70207 .999 L .511 .018 .022 r
F P
0 g
s
.70207 .999 m .72395 1.00449 L .72562 1.0053 L .511 .018 .022 r
F
.70139 .99256 m .70139 .99365 L p .66869 .97611 L .954 .779 .626 r
F P
0 g
s
.70139 .99365 m .70139 .99256 L p .7022 .99383 L .347 .283 .642 r
F P
0 g
s
.70422 1.01594 m .7082 .89298 L p .67227 .96907 L .293 .353 .754 r
F P
0 g
s
.70422 1.01594 m .68012 1.0053 L p .69239 .99858 L .511 .018 .022 r
F P
0 g
s
.68012 1.0053 m .70422 1.01594 L p .67227 .96907 L .293 .353 .754 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37209 1.26039 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37209 1.26039 m .37083 1.25133 L p .37121 1.27211 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .37209 1.26039 L .37121 1.27211 L .763 .623 .059 r
F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36868 1.3059 m .36433 1.3007 L .36742 1.29994 L p .823 .35 .073 r
F P
0 g
s
.36742 1.29994 m .36915 1.29952 L p .36904 1.3011 L .823 .35 .073 r
F P
0 g
s
.36904 1.3011 m .36868 1.3059 L .36742 1.29994 L .823 .35 .073 r
F
.37209 1.3207 m .36901 1.29994 L .36955 1.32905 L .763 .623 .059 r
F
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p F P
0 g
s
.36955 1.26755 m .36904 1.29866 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36904 1.29866 m .36901 1.29994 L p .37203 1.3203 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .36904 1.29866 L .37203 1.3203 L .763 .623 .059 r
F
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L F P
0 g
s
.41389 1.27286 m .39481 1.2932 L .36915 1.29952 L p .741 .988 .787 r
F P
0 g
s
.36955 1.26755 m .36904 1.29866 L p .39631 1.27701 L .693 .453 .555 r
F P
0 g
s
.39044 1.27014 m .39631 1.27701 L .403 1.2717 L .693 .453 .555 r
F
.36955 1.26755 m .39631 1.27701 L .39044 1.27014 L F
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.58611 1.27286 m .56651 1.2932 L .54207 1.29994 L p .714 .977 .761 r
F P
0 g
s
.58611 1.27286 m .54207 1.29994 L .54619 1.29661 L .714 .977 .761 r
F
.41389 1.27286 m .36915 1.29952 L .36904 1.29866 L .741 .988 .787 r
F
.41389 1.27286 m .36904 1.29866 L .37162 1.29661 L F
.43308 1.29558 m .41389 1.27286 L .39481 1.2932 L p .519 .424 .687 r
F P
0 g
s
.36433 1.3007 m .38368 1.27999 L .41389 1.27286 L p .741 .988 .787 r
F P
0 g
s
.43308 1.29558 m .41389 1.27286 L .39631 1.27701 L p .82 .344 .063 r
F P
0 g
s
.43308 1.29558 m .39631 1.27701 L .40444 1.28654 L .82 .344 .063 r
F
.36904 1.3011 m .36955 1.32905 L .38823 1.32905 L p .69 .689 .843 r
F P
0 g
s
.36904 1.3011 m .38823 1.32905 L .39631 1.32055 L .69 .689 .843 r
F
.39481 1.2932 m .38489 1.32056 L .37136 1.3046 L .823 .35 .073 r
F
.36915 1.29952 m .39481 1.2932 L p .36868 1.3059 L F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.39481 1.2932 m .41389 1.31592 L .38368 1.32387 L p .823 .35 .073 r
F P
0 g
s
.39481 1.2932 m .41389 1.31592 L .43308 1.29558 L p .519 .424 .687 r
F P
0 g
s
.41389 1.31592 m .43308 1.29558 L .41588 1.29994 L p .734 .985 .78 r
F P
0 g
s
.36901 1.29994 m .36904 1.3011 L p .41057 1.30554 L .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .41057 1.30554 L .41135 1.30471 L .69 .689 .843 r
F
.41389 1.31592 m .41588 1.29994 L .40769 1.30856 L .734 .985 .78 r
F
.56885 1.32219 m .57381 1.32299 L .57341 1.3227 L .69 .689 .843 r
F
.36901 1.29994 m .56863 1.32241 L .56885 1.32219 L F
.56863 1.32241 m .57381 1.32299 L .56885 1.32219 L F
.41135 1.30471 m .41057 1.30554 L .57381 1.32299 L F
.39631 1.32055 m .41389 1.31592 L p .40769 1.30856 L .734 .985 .78 r
F P
0 g
s
.40822 1.32905 m .58215 1.32905 L p .36904 1.3011 L .69 .689 .843 r
F P
0 g
s
.58215 1.32905 m .63045 1.32905 L p .57381 1.32299 L .69 .689 .843 r
F P
0 g
s
.36904 1.3011 m .58215 1.32905 L .57381 1.32299 L .69 .689 .843 r
F
.56651 1.2932 m .58611 1.31592 L .57045 1.32055 L p .812 .329 .035 r
F P
0 g
s
.56651 1.2932 m .57045 1.32055 L .56154 1.31408 L .812 .329 .035 r
F
.56651 1.2932 m .58611 1.31592 L .60583 1.29558 L p .524 .428 .688 r
F P
0 g
s
.57045 1.32055 m .58611 1.31592 L p .58213 1.30856 L .705 .973 .754 r
F P
0 g
s
.54207 1.29994 m .56651 1.2932 L p .56154 1.31408 L .812 .329 .035 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.58611 1.31592 m .60583 1.29558 L .59053 1.29994 L p .705 .973 .754 r
F P
0 g
s
.59053 1.29994 m .54207 1.29994 L p .57875 1.31202 L .69 .689 .843 r
F P
0 g
s
.59053 1.29994 m .57921 1.30317 L p .58213 1.30856 L .705 .973 .754 r
F P
0 g
s
.58611 1.31592 m .59053 1.29994 L .58213 1.30856 L .705 .973 .754 r
F
.63045 1.32905 m .63099 1.29994 L .59053 1.29994 L p .69 .689 .843 r
F P
0 g
s
.57875 1.31202 m .63045 1.32905 L .59053 1.29994 L .69 .689 .843 r
F
.41588 1.29994 m .36901 1.29994 L p .4245 1.30612 L F P
0 g
s
.60583 1.29558 m .58611 1.27286 L .56651 1.2932 L p .524 .428 .688 r
F P
0 g
s
.403 1.2717 m .39643 1.27716 L .55161 1.29223 L .693 .453 .555 r
F
.403 1.2717 m .55161 1.29223 L .55389 1.29039 L F
.57045 1.27701 m .58611 1.27286 L p .54619 1.29661 L .714 .977 .761 r
F P
0 g
s
.41588 1.29994 m .43308 1.29558 L p .40444 1.28654 L .82 .344 .063 r
F P
0 g
s
.41588 1.29994 m .59053 1.29994 L p .39643 1.27716 L .693 .453 .555 r
F P
0 g
s
.59053 1.29994 m .60583 1.29558 L p .57879 1.28654 L .809 .323 .024 r
F P
0 g
s
.59053 1.29994 m .63099 1.29994 L p .58677 1.29565 L .693 .453 .555 r
F P
0 g
s
.39643 1.27716 m .59053 1.29994 L .58677 1.29565 L .693 .453 .555 r
F
.54207 1.29994 m .41588 1.29994 L p .52524 1.31733 L .69 .689 .843 r
F P
0 g
s
.40822 1.26755 m .55563 1.28899 L .57045 1.27701 L .693 .453 .555 r
F
.58215 1.26755 m .56216 1.26755 L p .57045 1.27701 L F P
0 g
s
.56216 1.26755 m .40822 1.26755 L p .57045 1.27701 L .693 .453 .555 r
F P
0 g
s
.60583 1.29558 m .58611 1.27286 L .57045 1.27701 L p .809 .323 .024 r
F P
0 g
s
.403 1.2717 m .63099 1.29994 L .40822 1.26755 L .693 .453 .555 r
F
.5592 1.27999 m .56429 1.2817 L p .53931 1.3007 L .714 .977 .761 r
F P
0 g
s
.54619 1.29661 m .53931 1.3007 L .57045 1.27701 L .714 .977 .761 r
F
.60583 1.29558 m .57045 1.27701 L .57879 1.28654 L .809 .323 .024 r
F
.55563 1.28899 m .63099 1.29994 L .58215 1.26755 L .693 .453 .555 r
F
.57045 1.27701 m .5592 1.27999 L p .57879 1.28654 L .809 .323 .024 r
F P
0 g
s
.55389 1.29039 m .55161 1.29223 L .63099 1.29994 L .693 .453 .555 r
F
.5592 1.27999 m .57921 1.30317 L .59053 1.29994 L p .809 .323 .024 r
F P
0 g
s
.57879 1.28654 m .5592 1.27999 L .59053 1.29994 L .809 .323 .024 r
F
.36901 1.29994 m .41588 1.29994 L p .39643 1.27716 L .693 .453 .555 r
F P
0 g
s
.40444 1.28654 m .39148 1.28245 L .41588 1.29994 L .82 .344 .063 r
F
.36904 1.29866 m .36901 1.29994 L p .403 1.2717 L .693 .453 .555 r
F P
0 g
s
.38368 1.27999 m .40315 1.30317 L .41588 1.29994 L p .82 .344 .063 r
F P
0 g
s
.39148 1.28245 m .38368 1.27999 L .41588 1.29994 L .82 .344 .063 r
F
.4245 1.30612 m .52524 1.31733 L .41588 1.29994 L .69 .689 .843 r
F
.52524 1.31733 m .63045 1.32905 L .54207 1.29994 L F
.54207 1.29994 m .53931 1.3007 L p .54407 1.29787 L .714 .977 .761 r
F P
0 g
s
.54619 1.29661 m .54207 1.29994 L .54407 1.29787 L .714 .977 .761 r
F
.57045 1.32055 m .5592 1.32387 L p .56154 1.31408 L .812 .329 .035 r
F P
0 g
s
.57921 1.30317 m .5592 1.32387 L .57045 1.32055 L p .705 .973 .754 r
F P
0 g
s
.58213 1.30856 m .57921 1.30317 L .57045 1.32055 L .705 .973 .754 r
F
.41588 1.29994 m .40315 1.30317 L p .40769 1.30856 L .734 .985 .78 r
F P
0 g
s
.57341 1.3227 m .57381 1.32299 L .63045 1.32905 L .69 .689 .843 r
F
.5592 1.32387 m .53931 1.3007 L .54207 1.29994 L p .812 .329 .035 r
F P
0 g
s
.56154 1.31408 m .5592 1.32387 L .54207 1.29994 L .812 .329 .035 r
F
.40315 1.30317 m .38368 1.32387 L .39631 1.32055 L p .734 .985 .78 r
F P
0 g
s
.40769 1.30856 m .40315 1.30317 L .39631 1.32055 L .734 .985 .78 r
F
.38823 1.32905 m .40822 1.32905 L p .39631 1.32055 L .69 .689 .843 r
F P
0 g
s
.36913 1.30645 m .36868 1.3059 L p .36912 1.30568 L .823 .35 .073 r
F P
0 g
s
.37136 1.3046 m .36913 1.30645 L .36912 1.30568 L .823 .35 .073 r
F
.38368 1.32387 m .36913 1.30645 L p .37136 1.3046 L F P
0 g
s
.38489 1.32056 m .38368 1.32387 L .37136 1.3046 L .823 .35 .073 r
F
.63099 1.29994 m .63045 1.26755 L .58215 1.26755 L p .693 .453 .555 r
F P
0 g
s
.40822 1.26755 m .36955 1.26755 L p .403 1.2717 L .693 .453 .555 r
F P
0 g
s
.37162 1.29661 m .36904 1.29866 L .36896 1.2981 L .741 .988 .787 r
F
.39631 1.27701 m .38368 1.27999 L p .40444 1.28654 L .82 .344 .063 r
F P
0 g
s
.36896 1.2981 m .36904 1.29866 L .36433 1.3007 L .741 .988 .787 r
F
.36915 1.29952 m .36742 1.29994 L p .36904 1.29866 L F P
0 g
s
.36742 1.29994 m .36433 1.3007 L p .36904 1.29866 L .741 .988 .787 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L F P
0 g
s
.63806 1.04502 m .6371 1.00646 L .63614 1.043 L 0 0 .063 r
F
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.5554 1.043 m .6333 1.04487 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L 0 0 .063 r
F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.68085 1.00864 m .67708 1.00696 L .68012 1.0053 L .954 .779 .626 r
F
.70743 .99928 m .70682 1.0002 L .70707 1.00026 L .438 .526 .85 r
F
.70771 1.00042 m .70719 .99644 L .72395 1.00449 L .511 .018 .022 r
F
.70685 .99485 m .70743 .99928 L .70771 1.00042 L p .755 .49 0 r
F P
0 g
s
.70685 .99485 m .70771 1.00042 L .70719 .99644 L .755 .49 0 r
F
.70422 1.01594 m .72562 1.0053 L p .72602 1.00307 L .948 .9 .745 r
F P
0 g
s
.72309 .9558 m .70422 1.01594 L .72602 1.00307 L .948 .9 .745 r
F
.70771 1.00042 m .70743 .99928 L p .70747 1.00036 L .438 .526 .85 r
F P
0 g
s
.74865 .87438 m .7082 .89298 L .70422 1.01594 L p .948 .9 .745 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.74865 .87438 m .72309 .9558 L .72602 1.00307 L .948 .9 .745 r
F
.74693 .91895 m .74865 .87438 L p .72562 1.0053 L F P
0 g
s
.77017 1.10042 m .72099 1.02407 L .72113 1.02351 L .347 .283 .642 r
F
.63923 .17502 m .64415 .18085 L .6625 .18295 L p .635 .107 0 r
F P
0 g
s
.37051 .17502 m .37461 .18085 L .39375 .18295 L p .647 .128 0 r
F P
0 g
s
.66658 .19117 m .6625 .18295 L .64415 .18085 L p .766 .338 .234 r
F P
0 g
s
.39716 .19117 m .39375 .18295 L .37461 .18085 L p .769 .351 .256 r
F P
0 g
s
.64415 .18085 m .64819 .18909 L .66658 .19117 L p .766 .338 .234 r
F P
0 g
s
.66957 .20145 m .66658 .19117 L .64819 .18909 L p .826 .492 .423 r
F P
0 g
s
.37461 .18085 m .37799 .18909 L .39716 .19117 L p .769 .351 .256 r
F P
0 g
s
.39967 .20145 m .39716 .19117 L .37799 .18909 L p .824 .498 .437 r
F P
0 g
s
.65256 .23763 m .65044 .25087 L .66884 .25277 L p .83 .779 .804 r
F P
0 g
s
.66884 .25277 m .67098 .23957 L .65256 .23763 L p .83 .779 .804 r
F P
0 g
s
.38164 .23763 m .37986 .25087 L .39906 .25277 L p .827 .773 .801 r
F P
0 g
s
.39906 .25277 m .40085 .23957 L .38164 .23763 L p .827 .773 .801 r
F P
0 g
s
.64819 .18909 m .65117 .1994 L .66957 .20145 L p .826 .492 .423 r
F P
0 g
s
.67135 .21331 m .66957 .20145 L .65117 .1994 L p .85 .598 .557 r
F P
0 g
s
.37799 .18909 m .38047 .1994 L .39967 .20145 L p .824 .498 .437 r
F P
0 g
s
.40117 .21331 m .39967 .20145 L .38047 .1994 L p .846 .598 .564 r
F P
0 g
s
.6534 .22423 m .65256 .23763 L .67098 .23957 L p .847 .732 .737 r
F P
0 g
s
.67098 .23957 m .67183 .22621 L .6534 .22423 L p .847 .732 .737 r
F P
0 g
s
.38234 .22423 m .38164 .23763 L .40085 .23957 L p .842 .727 .737 r
F P
0 g
s
.40085 .23957 m .40156 .22621 L .38234 .22423 L p .842 .727 .737 r
F P
0 g
s
.65117 .1994 m .65293 .21129 L .67135 .21331 L p .85 .598 .557 r
F P
0 g
s
.67183 .22621 m .67135 .21331 L .65293 .21129 L p .854 .674 .657 r
F P
0 g
s
.38047 .1994 m .38195 .21129 L .40117 .21331 L p .846 .598 .564 r
F P
0 g
s
.40156 .22621 m .40117 .21331 L .38195 .21129 L p .849 .671 .66 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.40614 .36334 m .37538 .36823 L .37538 .18543 L p .334 .273 .638 r
F P
0 g
s
.31883 .19772 m .31844 .18408 L .33888 .18629 L p .855 .674 .657 r
F P
0 g
s
.33888 .18629 m .33928 .19989 L .31883 .19772 L p .855 .674 .657 r
F P
0 g
s
.3396 .17219 m .33888 .18629 L .31844 .18408 L p .847 .732 .737 r
F P
0 g
s
.32032 .21027 m .31883 .19772 L .33928 .19989 L p .85 .598 .557 r
F P
0 g
s
.33928 .19989 m .34079 .2124 L .32032 .21027 L p .85 .598 .557 r
F P
0 g
s
.37538 .36823 m .33292 .36782 L .33292 .2218 L p .727 .594 .707 r
F P
0 g
s
.33303 .22185 m .37538 .36823 L .33292 .2218 L .727 .594 .707 r
F
.3431 .22883 m .37538 .36823 L .33303 .22185 L F
.33416 .22237 m .33303 .22185 L .33292 .22148 L F
.3431 .22883 m .33303 .22185 L .33416 .22237 L F
.34334 .22331 m .34494 .22736 L p .33949 .22484 L .767 .342 .241 r
F P
0 g
s
.33416 .22237 m .34334 .22331 L p .33949 .22484 L .767 .342 .241 r
F P
0 g
s
.32032 .21027 m .34079 .2124 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.33292 .2218 m .33292 .22148 L p .33303 .22185 L .727 .594 .707 r
F P
0 g
s
.34079 .2124 m .34334 .22331 L .33416 .22237 L p .826 .493 .425 r
F P
0 g
s
.34079 .2124 m .33416 .22237 L .32862 .21837 L .826 .493 .425 r
F
.31844 .18408 m .31915 .16993 L .3396 .17219 L p .847 .732 .737 r
F P
0 g
s
.34141 .15814 m .3396 .17219 L .31915 .16993 L p .83 .779 .804 r
F P
0 g
s
.31915 .16993 m .32094 .15584 L .34141 .15814 L p .83 .779 .804 r
F P
0 g
s
.34425 .14475 m .34141 .15814 L .32094 .15584 L p .803 .817 .862 r
F P
0 g
s
.32094 .15584 m .32374 .1424 L .34425 .14475 L p .803 .817 .862 r
F P
0 g
s
.31844 .18408 m .3185 .18604 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.3185 .18604 m .31883 .19772 L p .31994 .18525 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .3185 .18604 L .31994 .18525 L 0 0 .449 r
F
.31915 .16993 m .31844 .18408 L p .32374 .1424 L F P
0 g
s
.31883 .19772 m .32032 .21027 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32094 .15584 L .31915 .16993 L p 0 0 .449 r
F P
0 g
s
.32284 .22121 m .3209 .2128 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.3209 .2128 m .32032 .21027 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.32032 .21027 m .32284 .22121 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32442 .18281 m .33292 .18488 L p .33299 .17815 L .289 .763 .934 r
F P
0 g
s
.32862 .21837 m .33292 .22148 L .32284 .22121 L .826 .493 .425 r
F
.33205 .22216 m .32284 .22121 L p .33292 .22148 L F P
0 g
s
.32442 .31439 m .33205 .22216 L .33292 .36782 L .959 .783 .621 r
F
.31219 .23756 m .32442 .22807 L .32442 .31439 L F
.32442 .22807 m .33205 .22216 L .32442 .31439 L F
.33292 .2218 m .33292 .36782 L p .33205 .22216 L F P
0 g
s
.32442 .22527 m .32284 .22121 L .33205 .22216 L p .767 .342 .241 r
F P
0 g
s
.32284 .22121 m .32442 .22527 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32442 .22527 L .32442 .16584 L 0 0 .449 r
F
.30264 .17751 m .32442 .20913 L .31219 .23756 L .959 .783 .621 r
F
.32442 .20913 m .33292 .22148 L .32442 .22807 L F
.32442 .20913 m .32442 .22807 L .31219 .23756 L F
.32983 .22662 m .32962 .22372 L p .33416 .22237 L .767 .342 .241 r
F P
0 g
s
.32629 .23008 m .32442 .22527 L p .32617 .22475 L .767 .342 .241 r
F P
0 g
s
.33205 .22216 m .33416 .22237 L p .32442 .22527 L .767 .342 .241 r
F P
0 g
s
.33292 .18488 m .33292 .22148 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.32442 .18281 m .33292 .18488 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.37538 .25215 m .37538 .36823 L p .34494 .23677 L .727 .594 .707 r
F P
0 g
s
.3431 .22883 m .34494 .23016 L .34494 .23677 L .727 .594 .707 r
F
.34494 .23016 m .37538 .25215 L .34494 .23677 L F
.37538 .18543 m .40614 .17886 L p .3724 .17036 L .289 .763 .934 r
F P
0 g
s
.34425 .14475 m .34377 .18566 L .34459 .18523 L 0 0 .454 r
F
.34425 .14475 m .34459 .18523 L .34494 .16812 L F
.34459 .18523 m .34494 .22736 L .34494 .18504 L F
.34459 .18523 m .34494 .18504 L .34494 .16812 L F
.33888 .18629 m .33928 .19989 L p .34425 .14475 L F P
0 g
s
.3396 .17219 m .33888 .18629 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.33928 .19989 m .34079 .2124 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34079 .2124 m .34334 .22331 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34494 .18504 m .37538 .18543 L p .36057 .17668 L .289 .763 .934 r
F P
0 g
s
.34425 .14475 m .34141 .15814 L .3396 .17219 L p 0 0 .454 r
F P
0 g
s
.32374 .1424 m .34027 .17419 L .34424 .17203 L 0 0 .449 r
F
.34334 .22331 m .34494 .22736 L p .34459 .18523 L 0 0 .454 r
F P
0 g
s
.34377 .18566 m .34334 .22331 L .34459 .18523 L 0 0 .454 r
F
.37538 .18543 m .37538 .25215 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.33292 .18488 m .34494 .18504 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.34494 .18504 m .37538 .18543 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.36057 .17668 m .37538 .18543 L .3724 .17036 L .289 .763 .934 r
F
.38195 .21129 m .38234 .22423 L .40156 .22621 L p .849 .671 .66 r
F P
0 g
s
.37538 .18543 m .40614 .17886 L .40614 .36334 L p .334 .273 .638 r
F P
0 g
s
.40614 .17886 m .40726 .16878 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.34494 .14545 m .36507 .17428 L .37032 .17148 L 0 0 .454 r
F
.34494 .14573 m .365 .17432 L .34494 .14545 L F
.365 .17432 m .36507 .17428 L .34494 .14545 L F
.38567 .20378 m .38567 .20377 L .34494 .14545 L F
.40726 .16878 m .38567 .16327 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.3724 .17036 m .40614 .17886 L .38088 .16583 L .289 .763 .934 r
F
.40726 .16878 m .38567 .16327 L p .38567 .20711 L .965 .788 .614 r
F P
0 g
s
.39906 .21805 m .38567 .20711 L .38567 .29843 L .965 .788 .614 r
F
.40726 .16878 m .38567 .20711 L .39906 .21805 L F
.38245 .21715 m .38641 .20482 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37774 .22751 m .38245 .21715 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37251 .23546 m .37774 .22751 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38245 .21715 m .38567 .20711 L p .36869 .20333 L .763 .856 .919 r
F P
0 g
s
.38245 .21715 m .36869 .20333 L .36701 .20398 L .763 .856 .919 r
F
.39138 .17653 m .39216 .16186 L p .38947 .1609 L 0 0 .454 r
F P
0 g
s
.34425 .14475 m .38947 .17524 L .38947 .1609 L 0 0 .454 r
F
.38947 .17524 m .39138 .17653 L .38947 .1609 L F
.38943 .19108 m .39138 .17653 L p .34425 .14475 L F P
0 g
s
.34494 .20392 m .37538 .25215 L .34494 .23016 L .727 .594 .707 r
F
.36699 .24067 m .37251 .23546 L p .34494 .14697 L 0 0 .454 r
F P
0 g
s
.34425 .14475 m .34494 .14766 L .34494 .14697 L 0 0 .454 r
F
.34494 .14766 m .36699 .24067 L .34494 .14697 L F
.33292 .18488 m .34494 .20392 L .3431 .22883 L .727 .594 .707 r
F
.34494 .20392 m .34494 .23016 L .3431 .22883 L F
.36143 .24294 m .36699 .24067 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.35607 .24222 m .36143 .24294 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.35114 .23857 m .35607 .24222 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34684 .23217 m .35114 .23857 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37707 .16107 m .36466 .16091 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.32374 .1424 m .35697 .16509 L .36466 .16091 L 0 0 .449 r
F
.36466 .15717 m .36466 .16091 L .36879 .15866 L F
.32374 .1424 m .36466 .16091 L .36466 .15717 L F
.34494 .16812 m .34494 .18064 L .34533 .18131 L 0 0 .454 r
F
.34494 .18064 m .34494 .22736 L .34533 .18131 L F
.34494 .22736 m .34684 .23217 L p .34533 .18131 L F P
0 g
s
.34095 .17381 m .34494 .18504 L .3469 .18399 L .289 .763 .934 r
F
.33984 .17442 m .34494 .18504 L .34095 .17381 L F
.33292 .18488 m .34494 .18504 L p .33984 .17442 L F P
0 g
s
.35682 .22537 m .36147 .21497 L p .34027 .17419 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .3371 .17591 L .34027 .17419 L 0 0 .449 r
F
.33299 .17815 m .33292 .18488 L .33984 .17442 L .289 .763 .934 r
F
.3371 .17591 m .35682 .22537 L .34027 .17419 L 0 0 .449 r
F
.33316 .16049 m .33984 .17442 L .34095 .17381 L .289 .763 .934 r
F
.35993 .16348 m .38088 .16583 L .36466 .16091 L F
.38234 .20439 m .36947 .20303 L p .38567 .20711 L .763 .856 .919 r
F P
0 g
s
.365 .17432 m .38567 .20378 L .36507 .17428 L 0 0 .454 r
F
.32374 .1424 m .34949 .16917 L .35697 .16509 L 0 0 .449 r
F
.35993 .16348 m .3724 .17036 L .38088 .16583 L .289 .763 .934 r
F
.32374 .1424 m .34424 .17203 L .34949 .16917 L 0 0 .449 r
F
.33316 .16049 m .35523 .16604 L .35993 .16348 L .289 .763 .934 r
F
.35523 .16604 m .3724 .17036 L .35993 .16348 L F
.38641 .20482 m .38943 .19108 L p .37032 .17148 L 0 0 .454 r
F P
0 g
s
.36507 .17428 m .38641 .20482 L .37032 .17148 L 0 0 .454 r
F
.37707 .16107 m .36466 .20489 L .36709 .20395 L .728 .594 .707 r
F
.33316 .16049 m .36057 .17668 L .3724 .17036 L .289 .763 .934 r
F
.37707 .16107 m .36466 .16091 L p .36466 .20489 L .728 .594 .707 r
F P
0 g
s
.36538 .20259 m .36837 .1888 L p .36466 .18493 L 0 0 .449 r
F P
0 g
s
.34864 .16963 m .3469 .18399 L .36057 .17668 L .289 .763 .934 r
F
.34949 .16917 m .36466 .20106 L .36466 .18493 L 0 0 .449 r
F
.36466 .20106 m .36538 .20259 L .36466 .18493 L F
.34095 .17381 m .3469 .18399 L .34864 .16963 L .289 .763 .934 r
F
.34424 .17203 m .36538 .20259 L .34949 .16917 L 0 0 .449 r
F
.37707 .16107 m .36709 .20395 L .36947 .20303 L .728 .594 .707 r
F
.37707 .16107 m .37707 .19842 L p .37959 .20127 L .965 .788 .614 r
F P
0 g
s
.36947 .20303 m .38234 .20439 L p .37707 .19842 L .805 .825 .867 r
F P
0 g
s
.38567 .20711 m .36947 .20303 L .36869 .20333 L .763 .856 .919 r
F
.38567 .16327 m .37707 .16107 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.37774 .22751 m .38245 .21715 L .36147 .21497 L p .702 .876 .963 r
F P
0 g
s
.36147 .21497 m .38245 .21715 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36538 .20259 m .36466 .20489 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36466 .20489 m .36147 .21497 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36147 .21497 m .36538 .20259 L p .34424 .17203 L 0 0 .449 r
F P
0 g
s
.34027 .17419 m .36147 .21497 L .34424 .17203 L 0 0 .449 r
F
.35166 .23335 m .35682 .22537 L p .32374 .1424 L F P
0 g
s
.35114 .23857 m .35607 .24222 L .33542 .24016 L p .415 0 0 r
F P
0 g
s
.34071 .24087 m .33542 .24016 L .35607 .24222 L p .091 0 0 r
F P
0 g
s
.35607 .24222 m .36143 .24294 L .34071 .24087 L p .091 0 0 r
F P
0 g
s
.33542 .24016 m .33054 .2365 L .35114 .23857 L p .415 0 0 r
F P
0 g
s
.34621 .23858 m .34071 .24087 L .36143 .24294 L p .227 .73 .902 r
F P
0 g
s
.36143 .24294 m .36699 .24067 L .34621 .23858 L p .227 .73 .902 r
F P
0 g
s
.34684 .23217 m .35114 .23857 L .33054 .2365 L p .643 .122 0 r
F P
0 g
s
.35166 .23335 m .34621 .23858 L .36699 .24067 L p .459 .841 .986 r
F P
0 g
s
.36699 .24067 m .37251 .23546 L .35166 .23335 L p .459 .841 .986 r
F P
0 g
s
.35682 .22537 m .35166 .23335 L .37251 .23546 L p .608 .877 .991 r
F P
0 g
s
.37251 .23546 m .37774 .22751 L .35682 .22537 L p .608 .877 .991 r
F P
0 g
s
.36147 .21497 m .35682 .22537 L .37774 .22751 L p .702 .876 .963 r
F P
0 g
s
.36466 .21438 m .36013 .20664 L .33316 .34966 L .728 .594 .707 r
F
.34684 .23217 m .34466 .23194 L p .34406 .2294 L .767 .342 .241 r
F P
0 g
s
.34466 .23194 m .32629 .23008 L p .34406 .2294 L .767 .342 .241 r
F P
0 g
s
.33292 .22148 m .33292 .18488 L p .3425 .22623 L .727 .594 .707 r
F P
0 g
s
.3425 .22623 m .3431 .22883 L .33416 .22237 L .727 .594 .707 r
F
.3425 .22623 m .33416 .22237 L .33292 .22148 L F
.33949 .22484 m .34406 .2294 L .32629 .23008 L .767 .342 .241 r
F
.34494 .22736 m .34684 .23217 L p .33949 .22484 L F P
0 g
s
.33054 .2365 m .32629 .23008 L .34684 .23217 L p .643 .122 0 r
F P
0 g
s
.34621 .23858 m .35166 .23335 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33316 .16049 m .33299 .17815 L .33984 .17442 L .289 .763 .934 r
F
.33949 .22484 m .32629 .23008 L .33416 .22237 L .767 .342 .241 r
F
.34071 .24087 m .34621 .23858 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33292 .22148 m .33292 .2218 L p .33205 .22216 L .959 .783 .621 r
F P
0 g
s
.33416 .22237 m .33205 .22216 L p .33292 .22148 L .826 .493 .425 r
F P
0 g
s
.33542 .24016 m .34071 .24087 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33316 .16049 m .33316 .21709 L p .36013 .20664 L .728 .594 .707 r
F P
0 g
s
.33054 .2365 m .33542 .24016 L p .32442 .14812 L 0 0 .449 r
F P
0 g
s
.33316 .21709 m .33316 .34966 L p .36013 .20664 L .728 .594 .707 r
F P
0 g
s
.38567 .16327 m .37707 .16107 L p .37959 .20127 L .965 .788 .614 r
F P
0 g
s
.38567 .20816 m .37959 .20127 L .38567 .29843 L .965 .788 .614 r
F
.38567 .16327 m .37959 .20127 L .38567 .20816 L F
.37707 .19842 m .37707 .16107 L p .36947 .20303 L .728 .594 .707 r
F P
0 g
s
.38567 .20378 m .38641 .20482 L .38567 .20377 L 0 0 .454 r
F
.38641 .20482 m .38943 .19108 L .36859 .18882 L p .805 .825 .867 r
F P
0 g
s
.36859 .18882 m .36837 .1888 L p .36928 .1896 L .805 .825 .867 r
F P
0 g
s
.38641 .20482 m .36859 .18882 L .36928 .1896 L .805 .825 .867 r
F
.38641 .20482 m .37834 .19765 L .37707 .19842 L F
.38234 .20439 m .38641 .20482 L p .37707 .19842 L F P
0 g
s
.38567 .29843 m .37959 .20127 L .37707 .3501 L .965 .788 .614 r
F
.37707 .19842 m .37707 .3501 L p .37959 .20127 L F P
0 g
s
.37707 .20008 m .37707 .19842 L p .36947 .20303 L .728 .594 .707 r
F P
0 g
s
.36837 .1888 m .36538 .20259 L .36947 .20303 L p .805 .825 .867 r
F P
0 g
s
.37834 .19765 m .36837 .1888 L .36947 .20303 L .805 .825 .867 r
F
.36947 .20303 m .36538 .20259 L p .36869 .20333 L .763 .856 .919 r
F P
0 g
s
.36709 .20395 m .36466 .20489 L .36466 .21438 L .728 .594 .707 r
F
.36837 .1888 m .3703 .1742 L p .35697 .16509 L 0 0 .449 r
F P
0 g
s
.34949 .16917 m .36837 .1888 L .35697 .16509 L 0 0 .449 r
F
.33316 .16049 m .34095 .17381 L .34864 .16963 L .289 .763 .934 r
F
.36466 .16091 m .33316 .16049 L p .35993 .16348 L F P
0 g
s
.35697 .16509 m .3703 .1742 L .36879 .15866 L 0 0 .449 r
F
.36466 .16091 m .33316 .16049 L p .36466 .21438 L .728 .594 .707 r
F P
0 g
s
.3703 .1742 m .37107 .15948 L p .36879 .15866 L 0 0 .449 r
F P
0 g
s
.33316 .34966 m .37707 .3501 L .37707 .20008 L p .728 .594 .707 r
F P
0 g
s
.36709 .20395 m .33316 .34966 L .37707 .20008 L .728 .594 .707 r
F
.36701 .20398 m .36869 .20333 L .36538 .20259 L .763 .856 .919 r
F
.38567 .20711 m .38641 .20482 L .38234 .20439 L p F P
0 g
s
.34425 .14475 m .34494 .14573 L .34494 .14545 L 0 0 .454 r
F
.32629 .23008 m .33054 .2365 L p .32442 .15184 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32442 .16584 L .32442 .15184 L 0 0 .449 r
F
.32442 .16584 m .32629 .23008 L .32442 .15184 L F
.32374 .1424 m .32442 .15184 L .32442 .14812 L F
.32442 .15184 m .33054 .2365 L .32442 .14812 L F
.32442 .22527 m .32629 .23008 L p .32442 .16584 L F P
0 g
s
.30264 .17751 m .32442 .18281 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.30264 .17751 m .32442 .18281 L p .33316 .16049 L .289 .763 .934 r
F P
0 g
s
.33316 .16049 m .32442 .18281 L .33299 .17815 L .289 .763 .934 r
F
.33292 .36782 m .30264 .36233 L .30264 .17751 L p .959 .783 .621 r
F P
0 g
s
.30264 .36233 m .30231 .35481 L .30231 .1674 L p .717 .586 .01 r
F P
0 g
s
.30231 .1674 m .30264 .17751 L .30264 .36233 L p .717 .586 .01 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.33292 .36782 m .37538 .36823 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.30264 .36233 m .33292 .36782 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.65293 .21129 m .6534 .22423 L .67183 .22621 L p .854 .674 .657 r
F P
0 g
s
.40726 .35584 m .40614 .36334 L .40614 .17886 L p 0 0 .035 r
F P
0 g
s
.30231 .35481 m .33316 .34966 L .33316 .16049 L p .316 .258 .632 r
F P
0 g
s
.33316 .16049 m .30231 .1674 L .30264 .17751 L p .289 .763 .934 r
F P
0 g
s
.33316 .16049 m .30231 .1674 L .30231 .35481 L p .316 .258 .632 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37538 .36823 m .40614 .36334 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.40614 .36334 m .40726 .35584 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.33316 .34966 m .30231 .35481 L .30264 .36233 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40614 .17886 m .40726 .16878 L .40726 .35584 L p 0 0 .035 r
F P
0 g
s
.37707 .3501 m .40726 .35584 L .40726 .16878 L p .965 .788 .614 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.40726 .35584 m .37707 .3501 L .33316 .34966 L p .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60449 .19772 m .60401 .18408 L .62357 .18629 L p .86 .677 .654 r
F P
0 g
s
.62357 .18629 m .62406 .19989 L .60449 .19772 L p .86 .677 .654 r
F P
0 g
s
.62445 .17219 m .62357 .18629 L .60401 .18408 L p .852 .738 .737 r
F P
0 g
s
.6063 .21027 m .60449 .19772 L .62406 .19989 L p .855 .597 .549 r
F P
0 g
s
.62406 .19989 m .62589 .2124 L .6063 .21027 L p .855 .597 .549 r
F P
0 g
s
.66121 .36823 m .61897 .36782 L .61897 .2218 L p .727 .594 .707 r
F P
0 g
s
.61908 .22185 m .66121 .36823 L .61897 .2218 L .727 .594 .707 r
F
.6291 .22883 m .66121 .36823 L .61908 .22185 L F
.6202 .22237 m .61908 .22185 L .61897 .22148 L F
.6291 .22883 m .61908 .22185 L .6202 .22237 L F
.62898 .22331 m .63092 .22736 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.6202 .22237 m .62898 .22331 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.6063 .21027 m .62589 .2124 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.61897 .2218 m .61897 .22148 L p .61908 .22185 L .727 .594 .707 r
F P
0 g
s
.62589 .2124 m .62898 .22331 L .6202 .22237 L p .828 .487 .409 r
F P
0 g
s
.62589 .2124 m .6202 .22237 L .61469 .21837 L .828 .487 .409 r
F
.60401 .18408 m .60488 .16993 L .62445 .17219 L p .852 .738 .737 r
F P
0 g
s
.62665 .15814 m .62445 .17219 L .60488 .16993 L p .833 .786 .806 r
F P
0 g
s
.60488 .16993 m .60706 .15584 L .62665 .15814 L p .833 .786 .806 r
F P
0 g
s
.63008 .14475 m .62665 .15814 L .60706 .15584 L p .805 .823 .866 r
F P
0 g
s
.60706 .15584 m .61046 .1424 L .63008 .14475 L p .805 .823 .866 r
F P
0 g
s
.60401 .18408 m .60408 .18604 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.60408 .18604 m .60449 .19772 L p .60584 .18525 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .60408 .18604 L .60584 .18525 L .001 .001 .5 r
F
.62357 .18629 m .62364 .18824 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.62364 .18824 m .62406 .19989 L p .62542 .18746 L .009 .007 .504 r
F P
0 g
s
.63008 .14475 m .62364 .18824 L .62542 .18746 L .009 .007 .504 r
F
.62445 .17219 m .62357 .18629 L p .63008 .14475 L F P
0 g
s
.62406 .19989 m .62589 .2124 L p .62749 .18655 L .009 .007 .504 r
F P
0 g
s
.63008 .14475 m .62542 .18746 L .62749 .18655 L .009 .007 .504 r
F
.62542 .18746 m .62406 .19989 L .62749 .18655 L F
.66121 .18543 m .69459 .17886 L p .66425 .17036 L .289 .763 .934 r
F P
0 g
s
.62589 .2124 m .62898 .22331 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63092 .18504 m .66121 .18543 L p .6499 .17668 L .289 .763 .934 r
F P
0 g
s
.62898 .22331 m .63092 .22736 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.66121 .18543 m .66121 .25215 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.63092 .18504 m .66121 .18543 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.66121 .25215 m .66121 .36823 L p .63092 .23677 L .727 .594 .707 r
F P
0 g
s
.6291 .22883 m .63092 .23016 L .63092 .23677 L .727 .594 .707 r
F
.63092 .23016 m .66121 .25215 L .63092 .23677 L F
.63008 .14475 m .63092 .22736 L .63092 .16812 L .009 .007 .504 r
F
.61897 .18488 m .63092 .20392 L .6291 .22883 L .727 .594 .707 r
F
.63092 .20392 m .66121 .25215 L .63092 .23016 L F
.63092 .20392 m .63092 .23016 L .6291 .22883 L F
.69459 .17886 m .69975 .16878 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63092 .14766 m .63811 .18187 L .64047 .18083 L .009 .007 .504 r
F
.63092 .1487 m .65094 .24294 L .63092 .14766 L F
.64444 .24222 m .65094 .24294 L p .63092 .1487 L F P
0 g
s
.63092 .15045 m .64444 .24222 L .63092 .1487 L .009 .007 .504 r
F
.66425 .17036 m .69459 .17886 L .67455 .16583 L .289 .763 .934 r
F
.69459 .36334 m .66121 .36823 L .66121 .18543 L p .363 .296 .647 r
F P
0 g
s
.66121 .18543 m .69459 .17886 L .69459 .36334 L p .363 .296 .647 r
F P
0 g
s
.69975 .35584 m .69459 .36334 L .69459 .17886 L p 0 0 .158 r
F P
0 g
s
.69459 .17886 m .69975 .16878 L .69975 .35584 L p 0 0 .158 r
F P
0 g
s
.69975 .16878 m .68036 .16327 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63008 .14475 m .68036 .17268 L .68036 .15954 L .009 .007 .504 r
F
.69975 .16878 m .68036 .16327 L p .68036 .20711 L .976 .797 .597 r
F P
0 g
s
.6499 .17668 m .66121 .18543 L .66425 .17036 L .289 .763 .934 r
F
.67645 .21715 m .68126 .20482 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67074 .22751 m .67645 .21715 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67645 .21715 m .68036 .20711 L p .6643 .20333 L .763 .862 .923 r
F P
0 g
s
.67645 .21715 m .6643 .20333 L .66263 .20398 L .763 .862 .923 r
F
.63008 .14475 m .68036 .18722 L .68036 .17268 L .009 .007 .504 r
F
.68126 .20482 m .68493 .19108 L p .63008 .14475 L F P
0 g
s
.66439 .23546 m .67074 .22751 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65769 .24067 m .66439 .23546 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63845 .23857 m .64444 .24222 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63323 .23217 m .63845 .23857 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67264 .16107 m .66029 .16091 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63008 .14475 m .63092 .1487 L .63092 .14766 L .009 .007 .504 r
F
.63008 .14475 m .63092 .15045 L .63092 .1487 L F
.63008 .14475 m .62665 .15814 L .62445 .17219 L p F P
0 g
s
.61046 .1424 m .65093 .16509 L .66029 .16091 L .001 .001 .5 r
F
.66029 .15717 m .66029 .16091 L .66532 .15866 L F
.61046 .1424 m .66029 .16091 L .66029 .15717 L F
.65094 .24294 m .65769 .24067 L p .64047 .18083 L .009 .007 .504 r
F P
0 g
s
.63811 .18187 m .65094 .24294 L .64047 .18083 L .009 .007 .504 r
F
.63092 .22736 m .63323 .23217 L p .63092 .16812 L F P
0 g
s
.61897 .18488 m .63092 .18504 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.61897 .18488 m .63092 .18504 L p .63008 .17442 L .289 .763 .934 r
F P
0 g
s
.61046 .1424 m .63543 .17203 L .64182 .16917 L .001 .001 .5 r
F
.65453 .16348 m .67455 .16583 L .66029 .16091 L .289 .763 .934 r
F
.67737 .20439 m .66508 .20303 L p .68036 .20711 L .763 .862 .923 r
F P
0 g
s
.65453 .16348 m .66425 .17036 L .67455 .16583 L .289 .763 .934 r
F
.61046 .1424 m .64182 .16917 L .65093 .16509 L .001 .001 .5 r
F
.62897 .16049 m .64881 .16604 L .65453 .16348 L .289 .763 .934 r
F
.64881 .16604 m .66425 .17036 L .65453 .16348 L F
.62897 .16049 m .6499 .17668 L .66425 .17036 L F
.67264 .16107 m .66029 .16091 L p .66029 .20489 L .728 .594 .707 r
F P
0 g
s
.66482 .1888 m .66717 .1742 L p .65093 .16509 L .001 .001 .5 r
F P
0 g
s
.64182 .16917 m .66482 .1888 L .65093 .16509 L .001 .001 .5 r
F
.67264 .16107 m .66029 .20489 L .66271 .20395 L .728 .594 .707 r
F
.66293 .203 m .66271 .20395 L .6643 .20333 L F
.66293 .203 m .66508 .20303 L .66725 .2017 L F
.67264 .16107 m .67264 .19842 L p .6749 .20127 L .976 .797 .597 r
F P
0 g
s
.66508 .20303 m .67737 .20439 L p .67264 .19842 L .807 .833 .87 r
F P
0 g
s
.68036 .20711 m .66508 .20303 L .6643 .20333 L .763 .862 .923 r
F
.68036 .16327 m .67264 .16107 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.67074 .22751 m .67645 .21715 L .65642 .21497 L p .698 .88 .965 r
F P
0 g
s
.65642 .21497 m .67645 .21715 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.66118 .20259 m .66029 .20489 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.66029 .20489 m .65642 .21497 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.64079 .16963 m .63092 .18504 L .6499 .17668 L .289 .763 .934 r
F
.61046 .1424 m .63059 .17419 L .63444 .17247 L .001 .001 .5 r
F
.63008 .17442 m .63092 .18504 L .64079 .16963 L .289 .763 .934 r
F
.61046 .1424 m .66029 .20489 L .66029 .20154 L .001 .001 .5 r
F
.62173 .17815 m .61897 .18488 L .63008 .17442 L .289 .763 .934 r
F
.65076 .22537 m .65642 .21497 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .63008 .17442 L .64079 .16963 L .289 .763 .934 r
F
.65642 .21497 m .66029 .20489 L p .63444 .17247 L .001 .001 .5 r
F P
0 g
s
.63059 .17419 m .65642 .21497 L .63444 .17247 L .001 .001 .5 r
F
.66029 .20489 m .66118 .20259 L p .66029 .20154 L F P
0 g
s
.64444 .24222 m .65094 .24294 L .63114 .24087 L p .078 0 0 r
F P
0 g
s
.6113 .22527 m .60937 .22121 L .61818 .22216 L p .764 .329 .217 r
F P
0 g
s
.61469 .21837 m .61897 .22148 L .60937 .22121 L .828 .487 .409 r
F
.61818 .22216 m .60937 .22121 L p .61897 .22148 L F P
0 g
s
.60937 .22121 m .60701 .2128 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.60701 .2128 m .6063 .21027 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.60937 .22121 m .6113 .22527 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.6113 .22807 m .61818 .22216 L .6113 .31439 L .971 .792 .606 r
F
.6113 .31439 m .61818 .22216 L .61897 .36782 L F
.61897 .2218 m .61897 .36782 L p .61818 .22216 L F P
0 g
s
.61046 .1424 m .6113 .22527 L .6113 .16584 L .001 .001 .5 r
F
.60449 .19772 m .6063 .21027 L p .61046 .1424 L F P
0 g
s
.6063 .21027 m .60937 .22121 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.59163 .17751 m .6113 .20913 L .60026 .23756 L .971 .792 .606 r
F
.6113 .20913 m .61897 .22148 L .6113 .22807 L F
.6113 .20913 m .6113 .22807 L .60026 .23756 L F
.6202 .22237 m .6178 .22517 L .61763 .22321 L .764 .329 .217 r
F
.6178 .22517 m .61358 .23008 L .61763 .22321 L F
.61358 .23008 m .6113 .22527 L p .61763 .22321 L F P
0 g
s
.61897 .22148 m .61897 .2218 L p .61818 .22216 L .971 .792 .606 r
F P
0 g
s
.61818 .22216 m .6202 .22237 L p .6113 .22527 L .764 .329 .217 r
F P
0 g
s
.62469 .24016 m .62424 .23707 L .63845 .23857 L p .397 0 0 r
F P
0 g
s
.6113 .18281 m .61897 .18488 L p .62173 .17815 L .289 .763 .934 r
F P
0 g
s
.60488 .16993 m .60401 .18408 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.61897 .18488 m .61897 .22148 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.59163 .17751 m .6113 .18281 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.6113 .18281 m .61897 .18488 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.61897 .20012 m .61897 .18488 L p .62361 .20501 L .727 .594 .707 r
F P
0 g
s
.62361 .20501 m .6291 .22883 L .61897 .20012 L .727 .594 .707 r
F
.61897 .22148 m .61897 .20012 L p .6291 .22883 L F P
0 g
s
.63323 .23217 m .61358 .23008 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.63092 .22736 m .63323 .23217 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.62551 .22484 m .61358 .23008 L .6202 .22237 L .764 .329 .217 r
F
.61875 .2365 m .61358 .23008 L .63323 .23217 L p .631 .1 0 r
F P
0 g
s
.63323 .23217 m .63845 .23857 L .61875 .2365 L p .631 .1 0 r
F P
0 g
s
.63845 .23857 m .64444 .24222 L .62469 .24016 L p .397 0 0 r
F P
0 g
s
.63114 .24087 m .62469 .24016 L .64444 .24222 L p .078 0 0 r
F P
0 g
s
.62469 .24016 m .63114 .24087 L p .6113 .14636 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .6113 .14812 L .6113 .14636 L .001 .001 .5 r
F
.6113 .14812 m .62469 .24016 L .6113 .14636 L F
.6202 .22237 m .61818 .22216 L p .61897 .22148 L .828 .487 .409 r
F P
0 g
s
.61875 .2365 m .62469 .24016 L p .6113 .14812 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .6113 .15184 L .6113 .14812 L .001 .001 .5 r
F
.6113 .15184 m .61875 .2365 L .6113 .14812 L F
.6113 .22527 m .61358 .23008 L p .6113 .16584 L F P
0 g
s
.60026 .23756 m .6113 .22807 L .6113 .31439 L .971 .792 .606 r
F
.63782 .23858 m .63114 .24087 L .65094 .24294 L p .229 .73 .903 r
F P
0 g
s
.65094 .24294 m .65769 .24067 L .63782 .23858 L p .229 .73 .903 r
F P
0 g
s
.64446 .23335 m .63782 .23858 L .65769 .24067 L p .454 .84 .984 r
F P
0 g
s
.65769 .24067 m .66439 .23546 L .64446 .23335 L p .454 .84 .984 r
F P
0 g
s
.65076 .22537 m .64446 .23335 L .66439 .23546 L p .602 .879 .992 r
F P
0 g
s
.66439 .23546 m .67074 .22751 L .65076 .22537 L p .602 .879 .992 r
F P
0 g
s
.65642 .21497 m .65076 .22537 L .67074 .22751 L p .698 .88 .965 r
F P
0 g
s
.66029 .21438 m .65579 .20664 L .62897 .34966 L .728 .594 .707 r
F
.64446 .23335 m .65076 .22537 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.63782 .23858 m .64446 .23335 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .62173 .17815 L .63008 .17442 L .289 .763 .934 r
F
.63543 .17203 m .66118 .20259 L .64182 .16917 L .001 .001 .5 r
F
.63114 .24087 m .63782 .23858 L p .61046 .1424 L F P
0 g
s
.62897 .16049 m .62897 .21709 L p .65579 .20664 L .728 .594 .707 r
F P
0 g
s
.62897 .21709 m .62897 .34966 L p .65579 .20664 L .728 .594 .707 r
F P
0 g
s
.68036 .16327 m .67264 .16107 L p .6749 .20127 L .976 .797 .597 r
F P
0 g
s
.68036 .20816 m .6749 .20127 L .68036 .29843 L .976 .797 .597 r
F
.68036 .16327 m .6749 .20127 L .68036 .20816 L F
.67264 .16107 m .66293 .203 L .66725 .2017 L .728 .594 .707 r
F
.67264 .20008 m .67264 .19842 L p .66725 .2017 L F P
0 g
s
.67264 .19842 m .67264 .16107 L p .66725 .2017 L .728 .594 .707 r
F P
0 g
s
.68126 .20482 m .68493 .19108 L .68473 .19105 L p .807 .833 .87 r
F P
0 g
s
.68473 .19105 m .66503 .18882 L p .67395 .19762 L .807 .833 .87 r
F P
0 g
s
.68126 .20482 m .68473 .19105 L .67395 .19762 L .807 .833 .87 r
F
.66503 .18882 m .66482 .1888 L p .66564 .1896 L F P
0 g
s
.68126 .20482 m .66503 .18882 L .66564 .1896 L .807 .833 .87 r
F
.68126 .20482 m .6739 .19765 L .67264 .19842 L F
.67737 .20439 m .68126 .20482 L p .67264 .19842 L F P
0 g
s
.68036 .29843 m .6749 .20127 L .67264 .3501 L .976 .797 .597 r
F
.67264 .19842 m .67264 .3501 L p .6749 .20127 L F P
0 g
s
.66482 .1888 m .66118 .20259 L .66508 .20303 L p .807 .833 .87 r
F P
0 g
s
.6739 .19765 m .66482 .1888 L .66508 .20303 L .807 .833 .87 r
F
.66293 .203 m .6643 .20333 L .66508 .20303 L .728 .594 .707 r
F
.66725 .2017 m .66508 .20303 L .67264 .20008 L F
.66508 .20303 m .66118 .20259 L p .6643 .20333 L .763 .862 .923 r
F P
0 g
s
.66271 .20395 m .66029 .20489 L .66029 .21438 L .728 .594 .707 r
F
.66118 .20259 m .66482 .1888 L p .64182 .16917 L .001 .001 .5 r
F P
0 g
s
.66029 .16091 m .62897 .16049 L p .65453 .16348 L .289 .763 .934 r
F P
0 g
s
.65093 .16509 m .66717 .1742 L .66532 .15866 L .001 .001 .5 r
F
.66029 .16091 m .62897 .16049 L p .66029 .21438 L .728 .594 .707 r
F P
0 g
s
.66717 .1742 m .6681 .15948 L p .66532 .15866 L .001 .001 .5 r
F P
0 g
s
.62897 .34966 m .67264 .3501 L .67264 .20008 L p .728 .594 .707 r
F P
0 g
s
.66271 .20395 m .62897 .34966 L .67264 .20008 L .728 .594 .707 r
F
.66263 .20398 m .6643 .20333 L .66118 .20259 L .763 .862 .923 r
F
.68036 .20711 m .68126 .20482 L .67737 .20439 L p F P
0 g
s
.69238 .21805 m .68036 .20711 L .68036 .29843 L .976 .797 .597 r
F
.69975 .16878 m .68036 .20711 L .69238 .21805 L F
.68493 .19108 m .6873 .17653 L p .68036 .17268 L .009 .007 .504 r
F P
0 g
s
.68036 .18722 m .68493 .19108 L .68036 .17268 L .009 .007 .504 r
F
.6873 .17653 m .68824 .16186 L p .68544 .16104 L F P
0 g
s
.68036 .15954 m .68165 .1627 L .68544 .16104 L .009 .007 .504 r
F
.68165 .1627 m .6873 .17653 L .68544 .16104 L F
.68036 .17268 m .6873 .17653 L .68036 .15954 L F
.61358 .23008 m .61875 .2365 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.59163 .17751 m .6113 .18281 L p .62897 .16049 L .289 .763 .934 r
F P
0 g
s
.62897 .16049 m .6113 .18281 L .62173 .17815 L .289 .763 .934 r
F
.61897 .36782 m .59163 .36233 L .59163 .17751 L p .971 .792 .606 r
F P
0 g
s
.61046 .1424 m .60706 .15584 L .60488 .16993 L p .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .59535 .1674 L .59163 .17751 L p .289 .763 .934 r
F P
0 g
s
.59163 .36233 m .59535 .35481 L .59535 .1674 L p 0 0 .115 r
F P
0 g
s
.59535 .1674 m .59163 .17751 L .59163 .36233 L p 0 0 .115 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59535 .35481 m .62897 .34966 L .62897 .16049 L p .348 .284 .643 r
F P
0 g
s
.62897 .16049 m .59535 .1674 L .59535 .35481 L p .348 .284 .643 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61897 .36782 m .66121 .36823 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.59163 .36233 m .61897 .36782 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.62897 .34966 m .59535 .35481 L .59163 .36233 L p .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.66121 .36823 m .69459 .36334 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67264 .3501 m .69975 .35584 L .69975 .16878 L p .976 .797 .597 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.69459 .36334 m .69975 .35584 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.69975 .35584 m .67264 .3501 L .62897 .34966 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.40315 1.30317 m .38368 1.27999 L .36433 1.3007 L p .515 .42 .686 r
F P
0 g
s
.36433 1.3007 m .38368 1.32387 L .40315 1.30317 L p .515 .42 .686 r
F P
0 g
s
.57921 1.30317 m .5592 1.27999 L .53931 1.3007 L p .52 .425 .687 r
F P
0 g
s
.53931 1.3007 m .5592 1.32387 L .57921 1.30317 L p .52 .425 .687 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.34799 .13256 m .34425 .14475 L .32374 .1424 L p .764 .847 .913 r
F P
0 g
s
.35249 .12211 m .34799 .13256 L .34425 .14475 L p 0 0 .454 r
F P
0 g
s
.35757 .11385 m .35249 .12211 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.36301 .10816 m .35757 .11385 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.36859 .10533 m .36301 .10816 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37405 .10551 m .36859 .10533 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37915 .10873 m .37405 .10551 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38366 .11488 m .37915 .10873 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38737 .12371 m .38366 .11488 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39011 .13483 m .38737 .12371 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39173 .14774 m .39011 .13483 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39216 .16186 m .39173 .14774 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.63463 .13256 m .63008 .14475 L .61046 .1424 L p .764 .853 .917 r
F P
0 g
s
.64009 .12211 m .63463 .13256 L .63008 .14475 L p .009 .007 .504 r
F P
0 g
s
.64625 .11385 m .64009 .12211 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65286 .10816 m .64625 .11385 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65963 .10533 m .65286 .10816 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.66625 .10551 m .65963 .10533 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67245 .10873 m .66625 .10551 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67793 .11488 m .67245 .10873 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68243 .12371 m .67793 .11488 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68575 .13483 m .68243 .12371 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68772 .14774 m .68575 .13483 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68824 .16186 m .68772 .14774 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.32374 .1424 m .32743 .13016 L .34799 .13256 L p .764 .847 .913 r
F P
0 g
s
.35249 .12211 m .34799 .13256 L .32743 .13016 L p .708 .867 .957 r
F P
0 g
s
.61046 .1424 m .61496 .13016 L .63463 .13256 L p .764 .853 .917 r
F P
0 g
s
.64009 .12211 m .63463 .13256 L .61496 .13016 L p .705 .872 .96 r
F P
0 g
s
.32743 .13016 m .33188 .11967 L .35249 .12211 L p .708 .867 .957 r
F P
0 g
s
.33188 .11967 m .32743 .13016 L .32374 .1424 L p 0 0 .449 r
F P
0 g
s
.35757 .11385 m .35249 .12211 L .33188 .11967 L p .622 .872 .989 r
F P
0 g
s
.33188 .11967 m .3369 .11138 L .35757 .11385 L p .622 .872 .989 r
F P
0 g
s
.3369 .11138 m .33188 .11967 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36301 .10816 m .35757 .11385 L .3369 .11138 L p .487 .846 .993 r
F P
0 g
s
.3369 .11138 m .34227 .10566 L .36301 .10816 L p .487 .846 .993 r
F P
0 g
s
.34227 .10566 m .3369 .11138 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36859 .10533 m .36301 .10816 L .34227 .10566 L p .275 .753 .931 r
F P
0 g
s
.34227 .10566 m .34778 .10281 L .36859 .10533 L p .275 .753 .931 r
F P
0 g
s
.34778 .10281 m .34227 .10566 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37405 .10551 m .36859 .10533 L .34778 .10281 L p 0 .547 .745 r
F P
0 g
s
.34778 .10281 m .35317 .10298 L .37405 .10551 L p 0 .547 .745 r
F P
0 g
s
.35317 .10298 m .34778 .10281 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.35822 .10621 m .35317 .10298 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36267 .11237 m .35822 .10621 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36634 .12121 m .36267 .11237 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36904 .13237 m .36634 .12121 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37064 .14532 m .36904 .13237 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37107 .15948 m .37064 .14532 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.61496 .13016 m .62038 .11967 L .64009 .12211 L p .705 .872 .96 r
F P
0 g
s
.62038 .11967 m .61496 .13016 L .61046 .1424 L p .001 .001 .5 r
F P
0 g
s
.64625 .11385 m .64009 .12211 L .62038 .11967 L p .617 .874 .99 r
F P
0 g
s
.62038 .11967 m .62649 .11138 L .64625 .11385 L p .617 .874 .99 r
F P
0 g
s
.62649 .11138 m .62038 .11967 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65286 .10816 m .64625 .11385 L .62649 .11138 L p .483 .845 .992 r
F P
0 g
s
.62649 .11138 m .63303 .10566 L .65286 .10816 L p .483 .845 .992 r
F P
0 g
s
.63303 .10566 m .62649 .11138 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65963 .10533 m .65286 .10816 L .63303 .10566 L p .276 .754 .932 r
F P
0 g
s
.63303 .10566 m .63974 .10281 L .65963 .10533 L p .276 .754 .932 r
F P
0 g
s
.63974 .10281 m .63303 .10566 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66625 .10551 m .65963 .10533 L .63974 .10281 L p 0 .558 .757 r
F P
0 g
s
.63974 .10281 m .64631 .10298 L .66625 .10551 L p 0 .558 .757 r
F P
0 g
s
.64631 .10298 m .63974 .10281 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65245 .10621 m .64631 .10298 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65788 .11237 m .65245 .10621 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66234 .12121 m .65788 .11237 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66563 .13237 m .66234 .12121 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66758 .14532 m .66563 .13237 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.6681 .15948 m .66758 .14532 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.37915 .10873 m .37405 .10551 L .35317 .10298 L p .368 0 0 r
F P
0 g
s
.67245 .10873 m .66625 .10551 L .64631 .10298 L p .347 0 0 r
F P
0 g
s
.35317 .10298 m .35822 .10621 L .37915 .10873 L p .368 0 0 r
F P
0 g
s
.64631 .10298 m .65245 .10621 L .67245 .10873 L p .347 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.38366 .11488 m .37915 .10873 L .35822 .10621 L p .621 .083 0 r
F P
0 g
s
.67793 .11488 m .67245 .10873 L .65245 .10621 L p .607 .059 0 r
F P
0 g
s
.35822 .10621 m .36267 .11237 L .38366 .11488 L p .621 .083 0 r
F P
0 g
s
.65245 .10621 m .65788 .11237 L .67793 .11488 L p .607 .059 0 r
F P
0 g
s
.38737 .12371 m .38366 .11488 L .36267 .11237 L p .762 .323 .207 r
F P
0 g
s
.68243 .12371 m .67793 .11488 L .65788 .11237 L p .758 .307 .18 r
F P
0 g
s
.36267 .11237 m .36634 .12121 L .38737 .12371 L p .762 .323 .207 r
F P
0 g
s
.39011 .13483 m .38737 .12371 L .36634 .12121 L p .829 .486 .406 r
F P
0 g
s
.65788 .11237 m .66234 .12121 L .68243 .12371 L p .758 .307 .18 r
F P
0 g
s
.68575 .13483 m .68243 .12371 L .66234 .12121 L p .831 .479 .389 r
F P
0 g
s
.3703 .1742 m .36837 .1888 L .38943 .19108 L p .834 .786 .807 r
F P
0 g
s
.38943 .19108 m .39138 .17653 L .3703 .1742 L p .834 .786 .807 r
F P
0 g
s
.66717 .1742 m .66482 .1888 L .68493 .19108 L p .838 .794 .809 r
F P
0 g
s
.68493 .19108 m .6873 .17653 L .66717 .1742 L p .838 .794 .809 r
F P
0 g
s
.36634 .12121 m .36904 .13237 L .39011 .13483 L p .829 .486 .406 r
F P
0 g
s
.39173 .14774 m .39011 .13483 L .36904 .13237 L p .855 .597 .548 r
F P
0 g
s
.66234 .12121 m .66563 .13237 L .68575 .13483 L p .831 .479 .389 r
F P
0 g
s
.68772 .14774 m .68575 .13483 L .66563 .13237 L p .86 .597 .539 r
F P
0 g
s
.37107 .15948 m .3703 .1742 L .39138 .17653 L p .852 .738 .737 r
F P
0 g
s
.39138 .17653 m .39216 .16186 L .37107 .15948 L p .852 .738 .737 r
F P
0 g
s
.6681 .15948 m .66717 .1742 L .6873 .17653 L p .857 .744 .738 r
F P
0 g
s
.6873 .17653 m .68824 .16186 L .6681 .15948 L p .857 .744 .738 r
F P
0 g
s
.36904 .13237 m .37064 .14532 L .39173 .14774 L p .855 .597 .548 r
F P
0 g
s
.39216 .16186 m .39173 .14774 L .37064 .14532 L p .86 .678 .654 r
F P
0 g
s
.66563 .13237 m .66758 .14532 L .68772 .14774 L p .86 .597 .539 r
F P
0 g
s
.68824 .16186 m .68772 .14774 L .66758 .14532 L p .866 .681 .65 r
F P
0 g
s
.37064 .14532 m .37107 .15948 L .39216 .16186 L p .86 .678 .654 r
F P
0 g
s
.66758 .14532 m .6681 .15948 L .68824 .16186 L p .866 .681 .65 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool800000;<0oooo2000003O0?oo
o`00g03oool2000000D0001b0P0000000`1N000000000000000400000:/0oooo0P0000050000O`80
00000P1H000500000=T0oooo003K0?ooo`03000000000780001b00L0001b1000000305h000@00000
Y@3oool2000000T0001o1@00000205P000@00000e@3oool00=X0oooo00<000000000LP0007802@00
07800`000000WQD009hE00060000000305h00000000000000:80oooo00<000000000O`0007l02`00
07l00`000000V`l009/?000800000=<0oooo003I0?ooo`03000000000780001b00X0001b00<00000
09hE002N5@001P2N5@04000009l0oooo0P00000?0000O`030000002K3`00V`l000D0V`l01000003A
0?ooo`00f03oool00`000000001b0000LP0<0000LP030000002N5@00WQD000T0WQD000<000000?oo
o`3oool0V`3oool00`000000001o0000O`0@0000O`030000002K3`00V`l000P0V`l000<000000?oo
o`3oool0cP3oool00=L0oooo00<000000000LP0007803P000784000000L0WQD000<000000?ooo`3o
ool0VP3oool00`000000001o0000O`0B0000O`<000001`2K3`000`000000oooo0?ooo`3>0?ooo`00
eP3oool00`000000001b0000LP0?0000LP0400000033DS@0`e8d0<=B=0H000000P2N5@000`000000
oooo0?ooo`2H0?ooo`030000000007l0001o01<0001o00<000000<9>;P32CRh01P00000209/?0003
0000003oool0oooo0<d0oooo003F0?ooo`03000000000780001b0100001b00<000000<=B=033DS@0
1P33DS@4000009T0oooo5`0007l00`000000`Th^0<9>;P050<9>;P@00000cP3oool00=D0oooo00<0
00000000LP0007804@0007800`000000`e8d0<=B=0090<=B=0030000003oool0oooo09H0oooo00<0
00000000O`0007l05@0007l00`000000`Th^0<9>;P090<9>;P030000003oool0oooo0</0oooo003E
0?ooo`03000000000780001b0140001b00<000000<=B=033DS@02P33DS@00`000000oooo0?ooo`2E
0?oooaP0001o00<000000<9>;P32CRh02@32CRh00`000000oooo0?ooo`3;0?ooo`00e03oool00`00
0000001b0000LP0C0000LP0300000033DS@0`e8d00T0`e8d00<000000?ooo`3oool0U03oool00`00
0000001o0000O`0G0000O`0300000032CRh0`Th^00T0`Th^00<000000?ooo`3oool0bP3oool00=@0
oooo5P000787000000H0`e8d00<000000?ooo`3oool0TP3oool00`000000001o0000O`0H0000O`L0
00001@32CRh00`000000oooo0?ooo`3:0?ooo`00d`3oool00`000000001b0000LP0D0000LP030000
003DO6L0e7aW00@0e7aW1`00002D0?oooa/0001o00<000000=AjH`3DNV<0103DNV<700000</0oooo
003C0?oooaP0001b00<000000=AlI`3DO6L02@3DO6L00`000000oooo0?ooo`2A0?ooo`0300000000
07l0001o01X0001o00<000000=AjH`3DNV<02@3DNV<00`000000oooo0?ooo`390?ooo`00dP3oool0
0`000000001b0000LP0F0000LP030000003DO6L0e7aW00T0e7aW00<000000?ooo`3oool0T@3ooolM
0000O`030000003DNV<0e7YS00T0e7YS00<000000?ooo`3oool0b@3oool00=80oooo00<000000000
LP0007805P0007800`000000e7aW0=AlI`0:0=AlI`030000003oool0oooo08l0oooo00<000000000
O`0007l06`0007l00`000000e7YS0=AjH`0:0=AjH`030000003oool0oooo0<P0oooo003A0?ooo`03
000000000780001b01L0001b00<000000=AlI`3DO6L02P3DO6L00`000000oooo0?ooo`2?0?oooah0
001o00<000000=AjH`3DNV<02P3DNV<00`000000oooo0?ooo`380?ooo`00d@3oool00`000000001b
0000LP0H0000LP030000003DO6L0e7aW00T0e7aW00<000000?ooo`3oool0SP3oool00`000000001o
0000O`0M0000O`030000003DNV<0e7YS00T0e7YS00<000000?ooo`3oool0b03oool00=40oooo00<0
00000000LP00078060000784000000P0e7aW00<000000?ooo`3oool0SP3ooolP0000O`@00000203D
NV<00`000000oooo0?ooo`380?ooo`00d03oool00`000000001b0000LP0I0000LP040000003JV8`0
fYR<0=ZHS0H000000`3DO6L00`000000oooo0?ooo`2<0?ooo`030000000007l0001o01h0001o00@0
00000=bHR@3LV8T0g9R91P0000030=AjH`030000003oool0oooo0<L0oooo003@0?ooo`0300000000
0780001b01T0001b00<000000=ZHS03JV8`01`3JV8`4000008h0oooo8@0007l00`000000g9R90=bH
R@070=bHR@@00000b@3oool00=00oooo00<000000000LP0007806@0007800`000000fYR<0=ZHS00:
0=ZHS0030000003oool0oooo08/0oooo00<000000000O`0007l0800007l00`000000g9R90=bHR@09
0=bHR@030000003oool0oooo0<L0oooo003@0?oooa`0001b00<000000=ZHS03JV8`02P3JV8`00`00
0000oooo0?ooo`2;0?ooob<0001o00<000000=bHR@3LV8T02@3LV8T00`000000oooo0?ooo`370?oo
o`00c`3oool00`000000001b0000LP0K0000LP030000003JV8`0fYR<00T0fYR<00<000000?ooo`3o
ool0RP3oool00`000000001o0000O`0Q0000O`030000003LV8T0g9R900X0g9R900<000000?ooo`3o
ool0aP3oool00<l0oooo7P0007800`000000fYR<0=ZHS0090=ZHS0030000003oool0oooo08X0oooo
900007l00`000000g9R90=bHR@0:0=bHR@030000003oool0oooo0<H0oooo003?0?oooah0001b00<0
00000=ZHS03JV8`02P3JV8`00`000000oooo0?ooo`290?ooo`030000000007l0001o0280001o00<0
00000=bHR@3LV8T02@3LV8T00`000000oooo0?ooo`360?ooo`00c`3ooolN0000LP@000002@3JV8`0
0`000000oooo0?ooo`290?ooo`030000000007l0001o0280001o100000080=bHR@030000003oool0
oooo0<H0oooo003>0?ooo`03000000000780001b00H0001b00<0cM7L0000LP0007804`0007801000
0000g:fW0=b]Y`3L[JL6000000<0fYR<00<000000?ooo`3oool0R03oool00`000000001o0000O`08
0000O`030<kBg@0007l0001o01P0001o00@000000=f^YP3M[ZH0gJjV1P0000030=bHR@030000003o
ool0oooo0<D0oooo003>0?ooo`03000000000780001b01`0001b00<000000=b]Y`3L[JL01`3L[JL4
000008X0oooo00<000000000O`0007l02`0007l00`020H40001o0000O`0E0000O`030000003M[ZH0
gJjV00L0gJjV100000370?ooo`00cP3oool00`000000001b0000LP0;0000LP030000M0000780001b
00h0001b00<000000=b]Y`3L[JL02P3L[JL00`000000oooo0?ooo`280?ooo`030000000007l0001o
00h0001o00<00P610000O`0007l04P0007l00`000000gJjV0=f^YP0:0=f^YP030000003oool0oooo
0<D0oooo003>0?ooo`03000000000780001b00h0001b00<0001d0000LP0007802`0007800`000000
g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08P0oooo00<000000000O`0007l04P0007l00`020H40
001o0000O`0>0000O`030000003M[ZH0gJjV00X0gJjV00<000000?ooo`3oool0a@3oool00<d0oooo
00<000000000LP0007804P0007800`0007@0001b0000LP080000LP030000003L[JL0g:fW00X0g:fW
00<000000?ooo`3oool0Q`3oool010000000001o0000O`3>d]dE0000O`030081P@0007l0001o00/0
001o00<000000=f^YP3M[ZH02P3M[ZH00`000000oooo0?ooo`350?ooo`00c@3oool00`000000001b
0000LP0D0000LP030000M0000780001b00H0001b00<000000=b]Y`3L[JL02P3L[JL00`000000oooo
0?ooo`270?ooo`040000000007l0001o0<kBgAP0001o00<00P610000O`0007l0200007l00`000000
gJjV0=f^YP0:0=f^YP030000003oool0oooo0<D0oooo003=0?ooo`03000000000780001b01L0001b
00<0001d0000LP0007800`0007800`000000g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08L0oooo
00@000000000O`0007l000006`0007l20081P@H0001o00<000000=f^YP3M[ZH02P3M[ZH00`000000
oooo0?ooo`350?ooo`00c@3oool010000000e<O=0000LP3DaldH0000LP80001d0P0007800`000000
g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08L0oooo00@000000000O`0007l0eLW>7P0007l20081
P@<0001o00<000000=f^YP3M[ZH02P3M[ZH00`000000oooo0?ooo`350?ooo`00c@3oool010000000
e<O=0000LP3DaldK0000LP030000M00000000000008000002@3L[JL00`000000oooo0?ooo`270?oo
o`040000000007l0001o0=G9cR40001o0P020H44000000T0gJjV00<000000?ooo`3oool0a@3oool0
0<d0oooo00@000000000LP000780e<O=0P00078G000000<0001b00@000000=Zl_03J_;`0f[bl1P00
00030=b]Y`030000003oool0oooo08L0oooo00@000000000O`0007l0eLW>200007lG000000@0001o
00@000000=^n_03K_[`0fkjl1P0000030=f^YP030000003oool0oooo0<D0oooo003=0?ooo`H00000
0P1@@Z400`000000^YRd0;ZH]00A0;ZH]0@0001b00<000000=Zl_03J_;`01`3J_;`4000008T0oooo
00<000000000O`0007l00`0007l600000080FDRT00<000000;ZH]02jV;@04@2jV;@50000O`030000
003K_[`0fkjl00L0fkjl100000370?ooo`00b@3oool5000000L0D4:Q00<000000;ZH]02jV;@04@2j
V;@40000LP030000003J_;`0f[bl00X0f[bl00<000000?ooo`3oool0QP3oool00`000000001o0000
0004000000P0FDRT00<000000;ZH]02jV;@04@2jV;@50000O`030000003K_[`0fkjl00X0fkjl00<0
00000?ooo`3oool0a@3oool00<@0oooo1@00000<0512X@030000002jV;@0^YRd0140^YRd10000780
0`000000f[bl0=Zl_00:0=Zl_0<00000PP3oool6000000d0FDRT00<000000;ZH]02jV;@04@2jV;@5
0000O`030000003K_[`0fkjl00X0fkjl00<000000?ooo`3oool0a@3oool00<40oooo0`00000A0512
X@030000002jV;@0^YRd0140^YRd0`0007800`000000f[bl0=Zl_00;0=Zl_0030000003gbId0mlVM
00D00000NP3oool3000001<0FDRT00<000000;ZH]02jV;@04@2jV;@40000O`030000003K_[`0fkjl
00/0fkjl1@0000330?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140
^YRd0`0007800`000000f[bl0=Zl_00;0=Zl_0030000003gbId0mlVM00D0mlVM0`00001g0?ooo`03
0000001IB:@0FDRT01<0FDRT00<000000;ZH]02jV;@04@2jV;@40000O`030000003K_[`0fkjl00/0
fkjl00<000000?W<V03ic9P00P3ic9P300000<00oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@04@2jV;@30000LP030000003J_;`0f[bl00/0f[bl00<000000?O9W@3gbId0
1`3gbId00`000000oooo0?ooo`1d0?ooo`8000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o
00<000000=^n_03K_[`02P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LP030000003J
_;`0f[bl00/0f[bl00<000000?O9W@3gbId01`3gbId00`000000oooo0?ooo`1d0?ooo`8000005@1I
B:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<000000=^n_03K_[`02P3K_[`00`000000nLbH0?W<
V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@04@2jV;@30000LP030000003J_;`0f[bl00/0f[bl00<000000?O9W@3gbId01`3gbId0
0`000000oooo0?ooo`1d0?ooo`8000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<00000
0=^n_03K_[`02P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LPL000001`3J_;`00`00
0000mlVM0?O9W@060?O9W@800000MP3oool2000001D0FDRT00<000000;ZH]02jV;@04@2jV;@40000
O`L000001P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`03
0000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LP030000003EbLh0eLW>00@0
eLW>200000080?O9W@800000M@3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140
^YRd100007l00`000000e/_?0=K;c`040=K;c`L000001`3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd0`0007800`000000eLW>
0=G9cP0;0=G9cP030000003gbId0mlVM00H0mlVM0P00001e0?ooo`030000000001d0000001D0FDRT
00<000000;ZH]02jV;@04@2jV;@40000O`030000003Fbll0e/_?00X0e/_?00<000000?W<V03ic9P0
1@3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd0140^YRd0`0007800`000000eLW>0=G9cP0;0=G9cP030000003gbId0mlVM00L0mlVM00<0
00000?ooo`3oool0L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd1000
07l00`000000e/_?0=K;c`0:0=K;c`030000003ic9P0nLbH00D0nLbH00<000000?ooo`3oool0_P3o
ool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A0;ZH]0<0001b00<00000
0=G9cP3EbLh02`3EbLh00`000000mlVM0?O9W@070?O9W@030000003oool0oooo07<0oooo00<00000
00007@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<000000=K;c`3Fbll02P3Fbll0
0`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@04@2jV;@20000LP030000003EbLh0eLW>00`0eLW>00<000000?O9
W@3gbId01`3gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH
]02jV;@04@2jV;@30000O`030000003Fbll0e/_?00/0e/_?00<000000?W<V03ic9P01@3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140
^YRd0P0007800`000000eLW>0=G9cP0;0=G9cP030000003gbId0mlVM00P0mlVM00<000000?ooo`3o
ool0L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0`0007l00`000000
e/_?0=K;c`0:0=K;c`030000003ic9P0nLbH00H0nLbH00<000000?ooo`3oool0_P3oool00<40oooo
00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A0;ZH]080001b00<000000=G9cP3EbLh0
2`3EbLh00`000000mlVM0?O9W@080?O9W@030000003oool0oooo07<0oooo00<0000000007@000000
5@1IB:@00`000000^YRd0;ZH]00A0;ZH]0<0001o00<000000=K;c`3Fbll02P3Fbll00`000000nLbH
0?W<V0060?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@04@2jV;@20000LP030000003EbLh0eLW>00/0eLW>00<000000?O9W@3gbId0203g
bId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2j
V;@30000O`030000003Fbll0e/_?00X0e/_?00<000000?W<V03ic9P01P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd0P000784
000000X0eLW>00<000000?O9W@3gbId0203gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0
000001D0FDRT00<000000;ZH]02jV;@04@2jV;@30000O`@000002@3Fbll00`000000nLbH0?W<V006
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@04@2jV;@20000LP040000003>dmd0c]?M0<kCg@L000000`3EbLh00`000000mlVM0?O9W@08
0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00A
0;ZH]0<0001o00@000000<kEgP3>eMh0c]GN1P0000030=K;c`030000003ic9P0nLbH00H0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A
0;ZH]080001b00<000000<kCg@3>dmd0203>dmd4000000X0mlVM00<000000?ooo`3oool0L`3oool0
0`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0`0007l00`000000c]GN0<kEgP07
0<kEgP@00000203ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512
X@030000002jV;@0^YRd0140^YRd00<0001b0000003>dmd03@3>dmd00`000000mlVM0?O9W@080?O9
W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH
]080001o00<000000<kEgP3>eMh02`3>eMh00`000000nLbH0?W<V0060?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@00`000780
00000<kCg@0<0<kCg@030000003gbId0mlVM00T0mlVM00<000000?ooo`3oool0L`3oool00`000000
000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0P0007l00`000000c]GN0<kEgP0;0<kEgPT0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00A0;ZH]0030000LP000000c]?M00`0c]?M00<000000?O9W@3gbId02@3gbId00`000000oooo
0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@20000O`030000
003>eMh0c]GN00X0c]GN00<000000?W<V03ic9P01`3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3o
ool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd00<0001b0000003>dmd01P3>
dmd00`3gbId0c]?M0<kCg@030<kCg@030000003gbId0mlVM00T0mlVM00<000000?ooo`3oool0L`3o
ool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0P0007l00`000000c]GN0<kE
gP0:0<kEgPX0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z40
0`000000^YRd0;ZH]00A0;ZH]0030000003>dmd0c]?M00@0c]?M00<0^YRd0000003>dmd01@3>dmd0
0`000000mlVM0?O9W@090?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@0
0`000000^YRd0;ZH]00A0;ZH]0030000O`000000c]GN00@0c]GN00<0^YRd0000003>eMh01@3>eMh:
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@04@2jV;@00`000000c]?M0<kCg@020<kCg@<0^YRd00<000000?O9W@3>dmd00`3>dmd00`00
0000mlVM0?O9W@0:0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00B0;ZH]0030000003>eMh0c]GN00@0^YRd00<000000?W<V03>eMh00`3>eMh00`00
0000nLbH0?W<V0080?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140
D4:Q00<000000;ZH]02jV;@04@2jV;@4000000@0^YRd00<000000?O9W@3gbId00`3>dmd00`000000
mlVM0?O9W@0:0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000
^YRd0;ZH]00A0;ZH]0040000O`0000000000000000@0^YRd00<000000?W<V03ic9P00`3>eMh;0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@04@2jV;@00`000000^YRd0;ZH]0050;ZH]0030000003gbId0mlVM00@00000303gbId00`000000
oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@00`000000
`mc/0;ZH]0050;ZH]0030000003ic9P0nLbH00<000002`3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd00h0^YRd00<0001b0;ZH]02jV;@0
202jV;@01@000000mlVM0?O9W@3gbId0`m_[00800000303gbId00`000000oooo0?ooo`1c0?ooo`03
0000000001d0000001D0FDRT00<000000;ZH]02jV;@03P2jV;@00`0007l0^YRd0;ZH]0080;ZH]006
0000003ic9P0nLbH0?W<V033g>`000002`3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`00
0000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId00P3gbId00`00
0000mlVM0?O9W@0;0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0080
mlVM00<000000?O9W@3gbId02`3gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0
FDRT00<000000;ZH]02jV;@04P2jV;@00`33g>`0^YRd0;ZH]0040;ZH]0030000003ic9P0nLbH00h0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000000M
0000000E05U8Y0030000002jV;@0^YRd0180^YRd00<0`mc/0;ZH]02jV;@0102jV;@00`000000nLbH
0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<0
000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I
0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000000M0000000E
05U8Y0030000002jV;@0^YRd0140^YRd00<0`mc/0;ZH]02jV;@01@2jV;@00`000000nLbH0?W<V00>
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<000000000
7@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0030000002jV;@0^YRd00D0^YRd00<000000?W<
V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@03
0000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`03
0000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@00`2bhOL0^YRd0;ZH]0050;ZH]003
0000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z40
4@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0
L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@0
0`000000^YRd0;ZH]00@0;ZH]0030;;Qm`2jV;@0^YRd00H0^YRd00<000000?W<V03ic9P03P3ic9P0
0`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd
01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d00000
01D0FDRT00<000000;ZH]02jV;@0402jV;@00`2bhOL0^YRd0;ZH]0060;ZH]0030000003ic9P0nLbH
00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000
^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000
000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000
oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd
00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH
]00?0;ZH]00309[Qo@2jV;@0^YRd00L0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<00000
0?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@03`2jV;@00`2JhOd0^YRd0;ZH]0070;ZH]0030000003ic9P0nLbH00h0nLbH00<00000
0?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH
]0030000003gbId0mlVM0100mlVM0`00001`0?ooo`@0000000<0000M0000001IB:@0501IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100
mlVM00<000000?C7X03daj000`00001]0?ooo`060000001PCjH0H4nV0000000001d000005@1IB:@0
0`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool0
0<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM
0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Z0?ooo`8000000P1PCjH00`00
0000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0
^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06X0
oooo0P000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@03P2jV;@00`000000
^YRd0;ZH]0080;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo
00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM
00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV
00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00>0;ZH]00307CGn`2jV;@0^YRd00P0^YRd
00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512
X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7
X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000
000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<00000
0?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<00000
00007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<00000
0?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512
X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId01P000000m<NP0?C7X03daj00
GDbU000006/0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd00d0^YRd00<000000;ZH]02jV;@02@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@060000003daj00m<NP05e<Y@3daj000000
J`3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@0
6@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@
@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003d
aj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00GDbU0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@060?O9
W@0305E5X`3gbId0mlVM00L0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?oo
o`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH
]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@
@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03d
aj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@00
00005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3o
ool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000
003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000
000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000
003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@
@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3d
aj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1I
B:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3o
ool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0
mlVM0100mlVM00<0000005e<Y@3daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l0
00000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0
nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`00
0000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM00D0mlVM00<0EDFS0?O9W@3gbId0203gbId00`00
0000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`00
0000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0
^YRd00<000000?O9W@3gbId01@3gbId00`1EAJ<0mlVM0?O9W@080?O9W@030000003daj00m<NP0080
m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0
FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0
oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM
0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O
00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH
0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<0
00000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<0
00000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo0031
0?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@
0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002
061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?oo
o`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH
]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`03
0000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@040?O9W@03
05E5X`3gbId0mlVM00T0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`03
0000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]003
0000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z40
4@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM00@0mlVM00<0EDFS0?O9W@3gbId0
2@3gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`000000
0P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003o
ool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool0
0`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId0
0`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH0
0`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P0
0`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd
01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo
06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd
01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000
D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000
m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000
000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000
oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd
00<000000?O9W@3gbId00`3gbId00`1EAJ<0mlVM0?O9W@0:0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@030?O9W@0305E5X`3gbId0mlVM00X0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?oo
o`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH
]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<00000
0512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<00000
0?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<00000
00007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<00000
0?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH
]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?oo
o`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH
]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@
@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03d
aj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@00
00005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3o
ool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000
003gbId0mlVM0080mlVM00<0EDFS0?O9W@3gbId02`3gbId00`000000m<NP0?C7X0020?C7X0030000
003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000
002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3o
ool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId00P3g
bId00`1EAJ<0mlVM0?O9W@0;0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3o
ool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2j
V;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40
D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@020?O9W@0305E5X`3gbId0
mlVM00/0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l0
00000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0
nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`00
0000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`00
0000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100
mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080
H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo
0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd
0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<0
00000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<0
00000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0
000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I
0;ZH]0050000003gbId0mlVM0?O9W@1EAJ<03P3gbId00`000000m<NP0?C7X0020?C7X0030000003o
ool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool0
0`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00D000000?O9W@3gbId0mlVM05E5
X`0>0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9
W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?
YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3o
ool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02j
V;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000
001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000
003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000
000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000
003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2j
V;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3o
ool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2j
V;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40
D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@010000000mlVM0?O9W@1EAJ<?0?O9W@030000003d
aj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM05E5X`0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9
W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?
YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3o
ool05P3oooll000001L0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y003
0000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0
403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo0080oooo5000000909j1/`030000
002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D000000<0oooo00<0000000007`000000
0P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId02@3gbIdA000001d0WX6c00<000000;BC]02dTk@09P2d
Tk@00`000000b:Bc0<RT/`0K0<RT/a4000003`1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003i
c9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z40
0`000000^YRd0;ZH]00I0;ZH]0`000001P24K:l00`000000WX6c09j1/`0U09j1/`030000002dTk@0
]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`040=^b[``000000`1IB:@0
0`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool0
0<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00=0;ZH]0`000004P24K:l00`00
0000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b[`0@0=^b[``000004`2jV;@00`00
0000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140
D4:Q00<000000;ZH]02jV;@00`2jV;@:000001P0Q6b_6`00001@03Rji1D000007P3K/Zl:000000T0
^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q
0512X@0?0512X@P000000`1SD:L00`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_
00@000000>c0Y`3/`:L0k<2W200000000`2jV;@000000?W<V00?0?W<V0030000003oool0oooo0;h0
oooo00310?ooo`030000001@@Z40D4:Q00L0D4:Q2000000;06=@Y`0300000024K:l0Q6b_00@0Q6b_
3000002N03Rji0`000001P3K/Zl00`000000k<2W0>c0Y`090>c0Y`P000002P3ic9P00`000000oooo
0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0000000700000100He2W2P00002f03Rji0L000004`3/
`:L800000080nLbH00<000000?ooo`3oool0_P3oool00;d0oooo1P00000@06=@Y`P00000bP0h^^@8
00000100k<2W1P00002m0?ooo`00^03oool500000080=RbH00<0000006=@Y`1SD:L02@1SD:L80000
0=X0>;[T2000000;0>c0Y`030000003jc9P0n/bH00D00000^03oool00;<0oooo1@00000703H/V003
0000001SD:L0He2W0080He2W1`00003Z03Rji0P000000`3/`:L00`000000n/bH0?[<V0050?[<V0@0
0000]03oool00:h0oooo1@00000:03H/V0H00000nP0h^^@4000000/0n/bH1@00002_0?ooo`00Z@3o
ool5000000/0=RbH1000003o03Rji0H0>;[T1000000;0?[<V0D00000ZP3oool00:D0oooo1000000<
03H/V0@00000o`0h^^@>03Rji0@00000303jc9P400000:H0oooo002S0?ooo`80000000<0001l0000
000f;9P02@0f;9P400000?l0>;[T5P0h^^@4000000X0n/bH00<000000?o@O00000000P00002S0?oo
o`00X03oool3000000<0001l00<0000003H/V00f;9P0100f;9P400000?l0>;[T7P0h^^@4000000H0
n/bH00<000000?o@O03od7`00P3od7`300000:00oooo002M0?ooo`<000001P0007`00`000000=RbH
03H/V00400000?l0>;[T9P0h^^@400000080n/bH00<000000?o@O03od7`01@3od7`2000009h0oooo
002K0?ooo`800000200007`400000?l0>;[T;P0h^^@3000000T0om1l0`00002K0?ooo`00V03oool3
000000P0001l0P00003o03Rji3H0>;[T0`0000080?o@O0<00000V03oool009H0oooo0P0000080000
O0<00000o`0h^^@k03Rji0<00000203od7`2000009H0oooo002D0?ooo`<000001P0007`300000?l0
>;[T@@0h^^@2000000L0om1l0`00002D0?ooo`00T`3oool010000000001;0000B`0000040000O080
0000o`0h^^A603Rji0<00000103od7`010000000l<A;0?34B`00002C0?ooo`00T@3oool2000000<0
001;00<000000000O00000000P00003_03Rji0030000000h^^@0>;[T05P0>;[T0`0000000`3od7`0
00000?34B`020?34B`800000T@3oool00900oooo00<000000000B`0004/00`0004/200000?l0>;[T
D@0h^^@2000000D0l<A;00<000000?ooo`3oool0SP3oool008h0oooo0P0000040000B`800000o`0h
^^AE03Rji0800000103`a4/2000008h0oooo002=0?ooo`030000000004/0001;00<0001;00<00000
03Rji00h^^@0o`0h^^AG03Rji0030000003`a4/0l<A;00<0l<A;00<000000?ooo`3oool0R`3oool0
08d0oooo00@000000000B`0004/0001;0P00003o03Rji5/0>;[T0P0000030?34B`030000003oool0
oooo08/0oooo002=0?ooo`040000000004/0001;00000?l0>;[TG`0h^^@010000000l<A;0?34B`00
002=0?ooo`00S@3oool300000?l0>;[TH@0h^^@3000008d0oooo002<0?ooo`800000o`0h^^AU03Rj
i0800000S03oool008`0oooo0P00000E03Rji080>K[TVP0h^^@00`000000>;[T03Rji00=03Rji003
0=J_/@0h^^@0>;[T0:00>;[T0P00002<0?ooo`00S03oool2000002/0>;[T100i^^AY03Rji0800000
0`00074;03Rji0T0S7:a00<000000=J_/@3F[k401`3F[k4803Rji0030=J_/@0h^^@0>;[T09h0>;[T
0P00002<0?ooo`00S03oool00`000000>;[T03Rji00o03Rji0H0>K[TF00h^^@00`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h^^@0W00h^^@2000008`0oooo002<
0?ooo`030000000h^^@0>;[T09/0>;[T0P0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg40W@0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`00
0000>;[T03Rji02H03Rji0D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00<0o/maVP0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000
>;[T03Rji02E03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0U@0h^^@00`000000
oooo0?ooo`2:0?ooo`00S@3oool00`000000>;[T03Rji00a03Rji0d0>K[TEP0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000i^^@0>K[T09@0>;[T00<000000?ooo`3oool0R`3oool008h0oooo0P00
001V03Rji1T0>K[T5@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00d0>;[T400i
^^Ae03Rji0800000SP3oool00900oooo00<0000003Rji00h^^@0T@0h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T02d0>;[T300i^^AH03Rji0030000003oool0oooo08h0oooo002A0?oo
o`030000000h^^@0>;[T0900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00V03Rj
i00303Vji00h^^@0>;[T02@0>;[T200i^^@k03Rji0030000003oool0oooo08l0oooo002B0?ooo`80
0000T00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06d0>;[T100i^^@M03Rji080
0000TP3oool009@0oooo00<0000003Rji00h^^@0S@0h^^@00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
000h^^@0>;[T08d0>;[T00<000000?ooo`3oool0TP3oool009H0oooo0P00002<03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0RP0h^^@2000009H0oooo002H0?ooo`800000RP0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08P0>;[T0P00002H0?ooo`00VP3oool30000
08L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02503Rji0<00000VP3oool009d0
oooo0P00002503Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0P`0h^^@2000009d0
oooo002O0?ooo`800000P`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T0840>;[T
0P00002O0?ooo`00X@3oool4000007l0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i01m03Rji0@00000X@3oool00:D0oooo1@00001j03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0N00h^^@500000:D0oooo002Z0?ooo`D00000M@0h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000000h^^@0>;[T07<0>;[T1@00002Z0?ooo`00[`3oool500000700>;[T00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000>;[T03Rji01^03Rji0D00000[`3oool00;@0oooo1@00001[03Rji0030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0J@0h^^@500000;@0oooo002i0?ooo`D00000IP0h
^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06@0>;[T1@00002i0?ooo`00_P3oool5
00000640>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01O03Rji0D00000_P3oool0
0<<0oooo1@00001L03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0FP0h^^@50000
0<<0oooo00380?ooo`D00000E`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05D0
>;[T1@0000380?ooo`00c@3oool700000500>;[T00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T
03Rji01>03Rji0L00000c@3oool00=@0oooo2P00001603Rji003000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
000003Rji00h^^@0A00h^^@:00000=@0oooo003N0?ooo`X00000?00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T03X0>;[T2P00003N0?ooo`00j03oool=000002l0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0d00000j03oool00?D0oooo4000000O03Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07@0h^^@@00000?D0oooo003o0?ooo`H0oooo
6@00000603Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0100h^^@I00000?l0oooo
1P3oool00?l0oooo7`3oool7000000L0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma1`00003o0?oooal0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo00330?ooo`<00000
GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00
000A0?ooo`030000001jFJ00NUVP00D00000F@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:d0oooo0`0000000`1kK[X000000000000?0?ooo`030000001jFJ00
NUVP00H0NUVP0`00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool4000000D0Nfjj00<000000?ooo`3oool03@3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05@0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002W0?ooo`8000002@1kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02000005H0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002W0?ooo`030000
001kK[X0Nfjj00P0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^
^P0707]^^P8000003@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0
Nfjj00P0Nfjj00<0`7T00?ooo`3oool02`3oool00`000000NUVP07YIX00807YIX0030000003oool0
oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?oo
o`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool00`000000NUVP07YIX00707YI
X0800000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0
oooo00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YIX01jFJ001`1jFJ02000005L0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000
001kK[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0
EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0
000007]^^P1kK[X0201kK[X00`30N@00oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<0
00000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00
NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YI
X01jFJ001`1jFJ02000005P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0`7T00000003oool0203oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000090?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?oo
o`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000
oooo00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?oo
o`030000001jFJ00NUVP00L0NUVP00<0gKjj0000003oool0F@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X01`1kK[X2000000L0
oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1H0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i
00000000oooo00D0oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0
`7T00000003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2
000000D0oooo00<0000007YIX01jFJ00201jFJ02000005X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?oo
o`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0F@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X0201kK[X2000000@0
oooo00<0000007YIX01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002/0?ooo`8000002@1kK[X00`30N@0000000?ooo`030?ooo`030000
001jFJ00NUVP00L0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YI
X00807YIX0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:d0oooo00<0000007]^^P1kK[X01`1kK[X2000000<0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00[@3oool00`000000Nfjj07]^^P0807]^^P8000000P3oool00`000000NUVP07YIX00707YI
X0800000G03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0
oooo0P00000907]^^P050<1i00000000oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00L0
Nfjj0P0000000`3oool0000007YIX00907YIX0800000G03oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X4000000P0NUVP
00<0gKjj000000000000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:h0oooo00<0000007]^^P1kK[X0201kK[X3000000T0NUVP0P00001M0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool2000000T0Nfjj0`000009
07YIX0800000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000P0NUVP00@0gKjj07YIX038adH00000G@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^
^P1kK[X01`1kK[X2000000T0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00L0
NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[`3oool2000000T0Nfjj00<0000007YIX01jFJ001`1jFJ02000005h0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0
000007YIX01jFJ001`1jFJ000`38adH000000?ooo`1M0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/03oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00
NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/03oool2000000T0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X00`000000
NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00;40oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7
AP000000oooo05h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002a0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ000`1jFJ03000005l0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X0
1P000000NUVP07YIX01jFJ00gKjj07YIX0800000H03oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00
001P0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool0
0`000000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00<0NUVP00<0b<M60000003oool0G`3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo00<0000007]^
^P1kK[X0201kK[X010000000NUVP0=fn^P1jFJ0300000600oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`8000002@1kK[X010000000NUVP07YIX01jFJ02
00000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?oo
o`8000002@1kK[X010000000NUVP07YIX01jFJ0200000640oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`030000001kK[X0Nfjj00L0Nfjj00H000000=fn
^P1jFJ00NUVP0<S7AP00001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00/`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00000000800000H@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo0P00000907]^
^P040000001jFJ00000000000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00]03oool00`000000Nfjj07]^^P0707]^
^P040000001jFJ00b<M600000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002d0?ooo`030000001kK[X0Nfjj00P0Nfjj0`00001R0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3ooolS000005<0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`h000003018>ih00`000000lLBS
0?74X`0<0?74X`l00000C03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0A`3oooln00000?l0oooo8P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo2`00000900d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H01`3od8H;00000?l0oooo5`3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00W0;BC]08000004`3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0E03oool300000;d0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0580oooo0P00000307`000800000^`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0D03oool20000
00L0O0000`00002h0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1>0?ooo`800000301l000200000;H0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo04`0oooo0P00000@07`000<00000/`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0BP3oool2000001D0O0000P00002a0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`17
0?ooo`<000006@1l000300000:h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04D0oooo0P00000O07`0
00800000[03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0@`3oool2000002<0O0000`00002Y0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`110?ooo`800000:01l000200000:L0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03l0oooo0P00000/07`000<00000Y03oool00:00oooo00<0000004PkWP18>ih01018>ihX
000000P0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`8000001P1l000X
000000<0O0000P00002R0?ooo`00T`3ooolD00000180AcZN00<000000?75X`3aaJ<04`3aaJ<G0000
0300oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0;P3ooolJ00000180EDFS00<000000?G8WP3eb9h0403eb9hD0000
09<0oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0_000001<03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QRl000000P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75Xc4000000`0=2hH>000000<03@^600<000000;BC]02dTk@0:02dTk@D0?o@QPT000002005000Q
000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC
]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om26
0?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;
QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2000002/0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440
[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000[05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/200d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00
00110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260:eTN`110:eTN`800000:`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@0
0`000000om260:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<20000
0480[FAk00<03@^60000002dTk@0:@2dTk@00`000000om260:eTN`110:eTN`800000:`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000
[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk
00<03@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTk@00`000000[FAk0:eT
N`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<00000
0;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<20000
04<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b
0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2
000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2a0:eTN`800000:`1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1M0:eTN`030:jfg`2]I7/0[FAk0580[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:eTN`2]I7/0I02]I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1_0:eTN`030:jf
g`2]I7/0[FAk0400[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0MP2]I7/00`2^]]l0[FAk0:eTN`0i0:eTN`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk07d0
[FAk00<0[[KO0:eTN`2]I7/0<P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`240:eTN`030:jfg`2]I7/0[FAk02/0[FAk00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0R`2]I7/00`2^]]l0[FAk0:eTN`0T0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk
0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75XkH00000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fh
h@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS01<0lLFS5`00002d0:fhhA/000004@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3a
aJ<F0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`0502^IG`E05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0B0?75XaL0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00E
0:iUO1@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fh
h@030000002^IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04@3aaJ<H0:iUO003
0000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05P2^IG`C05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS0100lLFS6@2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^
IG`0[VEl01L0[VEl4P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40
[KSQ0;00[KSQ0P00000J0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`00
0000[KSQ0:fhh@2`0:fhh@8000006P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75XaD0
[VEl00<0lLFS0:iUO02^IG`0102^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0>0?75Xa`0[VEl00<000000:fhh@2]^>40/02]^>42000001/0[VEl
401EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03@3aaJ<M0:iUO0030000002]^>40[KSQ0;00[KSQ0P00
000L0:iUO0l0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fhh@2`
0:fhh@800000702^IG`?05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0<0?75Xah0[VEl00<000000:fh
h@2]^>40/02]^>400`000000[VEl0:iUO00L0:iUO0h0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0
lLFS7`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0[VEl3@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<02`3aaJ<O0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`0
7@2^IG`=05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0:0?75Xb00[VEl00<000000:fhh@2]^>40/02]
^>400`000000[VEl0:iUO00N0:iUO0`0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`0
0`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07`2^IG`;05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]^>40/02]^>400`000000
[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00P0lLFS8P2^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl0200[VEl2P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01`3a
aJ<S0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08@2^IG`905E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00Q
0:iUO0T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fh
h@030000002^IG`0[VEl00D0[VEl00<0EDFS0:iUO02^IG`06P2^IG`805E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`050?75XbD0[VEl00<000000:fhh@2]^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@03
0000002]^>40[KSQ0380[KSQ00<000000:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`050?75XeX0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000
002^IG`0[VEl02<0[VEl1`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0103aaJ<o0:iUO0030:fhh@2^
IG`0[VEl01T0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^
IG`0[VEl00d0[VEl00<0EDFS0:iUO02^IG`0502^IG`605E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`03
0?75Xdh0[VEl00<0[KSQ0:iUO02^IG`02`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0
[VEl0380[VEl00<000000:iUO02^IG`0902^IG`605E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`030?75
XdD0[VEl00<0[KSQ0:iUO02^IG`0502^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl
0380[VEl00<000000:iUO02^IG`09@2^IG`505E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`020?75Xed0
[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl01D0
[VEl00<0EDFS0:iUO02^IG`03P2^IG`405E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`020?75Xd/0[VEl
00<0[KSQ0:iUO02^IG`03`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl
00<000000:iUO02^IG`09P2^IG`405E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh010000000lLFS0?75X`3aaJ=N0:iUO0030;^I
1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00W0:iUO0<0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS05P0[VEl00<0[KSQ0:iUO02^IG`0102^IG`00`2kV@H0[KSQ0:fh
h@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09`2^IG`305E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`1O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`0
0`000000[VEl0:iUO00X0:iUO080EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool7000001l0AcZN00<000000?75X`2^IG`0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fh
h@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:@2^IG`00`1EAJ<000000?G8WP0N0?G8
WPL00000T`3oool009X0oooo3000000C04LjWP030000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]
^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0EDFS0000003e
b9h04P3eb9h<000009X0oooo002V0?ooo`d000001P17>Yh00`000000[VEl0:iUO01O0:iUO0030;^I
1P000000000004L00000=02^IG`00`000000[VEl0:iUO00Z0:iUO0030000003eb9h0mLRN00@0mLRN
3@00002V0?ooo`00/`3ooomZ000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000000
001W00000;<0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`00
0000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0
oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fh
hP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<0
00000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?oo
o`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000
002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3o
ool0]`3oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]
^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]
^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool0
0;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`00
00H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0
[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000
oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<0
00000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fh
hP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h
0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]
^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP03
0000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3o
ool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0
oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000
[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0
[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo
002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<00000
0?ooo`3oool0^03oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`03
0000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]
^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0
^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80
[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>80
0`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`800000G`2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000
[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`800000G`2]^>800`000000
oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP030000003oool0oooo00d0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool03@3oool00`000000[KSR0:fhhP1M0:fhhP030000003oool0oooo0;T0oooo
002k0?ooof4000003`3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0=0?ooof400000^`3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`03010=Q`050?o@R@0@3HL040f7010=Q`000000502dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3o
d8T040f7010=Q`02010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00D0
0000010=Q`0@3HL040f70?o@R@05010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`040000000@3HL040f70?o@
R@H040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3o
ool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700H040f700<0om290000002dTk@04`2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003]0?ooocl000002@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om27?`00003]0?ooo`00k@3oool00`000000P`D608<51P0408<51P0305g:n0231@H0P`D6
03D0P`D61`0@3HL00`231@H040f70000000D0;BC]0030000003od8L0om2700H0om27?`231@H00`00
0000oooo0?ooo`3[0?ooo`00k@3oool00`000000P`D608<51P0;08<51P0305g:n0231@H0P`D602l0
P`D6200@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700D0om27@0231@H00`000000
oooo0?ooo`3[0?ooo`00k@3oool00`000000P`D608<51P0B08<51P0305g:n0231@H0P`D602T0P`D6
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700@0om27@@231@H00`000000oooo
0?ooo`3[0?ooo`00k@3oool00`000000P`D608<51P0H08<51P<0GL[h90231@H3010=Q`0408<51P0@
3HL040f7000001@0]9>d00<000000?o@Q`3od8L00`3od8M208<51P030000003oool0oooo0>/0oooo
003/0?ooo`03000000231@H0P`D60200P`D60`1Mb_PO08<51P@040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`020?o@Qd<0P`D600<000000?ooo`3oool0j`3oool00>`0oooo00<00000
08<51P231@H09`231@H3000001T0P`D60`0@3HL00`000000]9>d0;BC]00B0;BC]0040000003od8L0
om270?o@QdD0P`D600<000000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0;@231@H5
0;2_ea80P`D60P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2704H0P`D600<00000
0?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0=0231@H50;2_e``0P`D600<040f70000
002dTk@04`2dTk@00`000000om2708<51P0M08<51PD0/:oG90231@H00`000000oooo0?ooo`3Z0?oo
o`00k03oool00`000000P`D608<51P0k08<51P030;2_e`00000040f7008040f71P231@H00`000000
]9>d0;BC]00B0;BC]003000000231@H0P`D602/0P`D62@2`[mLB08<51P030000003oool0oooo0>X0
oooo003/0?ooo`03000000231@H0P`D60480P`D61000001A08<51Ph00000k03oool00>`0oooo00<0
00000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0:
0;5cSP030;2_e`2aLhh0/G>>09L0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5c
SP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP03
0000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0
jP3oool00>`0oooo00<000000;5cSP2aLhh03@2aLhh2000006h0/G>>0P00000U0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>00T0/G>>100000020=5H46X0/G>>10000002
0<mB1RD0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh01P2aLhh30000
00L0dEP@IP2aLhh3000000L0ce86902aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/G>>0;5cSP050;5cSP0300000023Jjl0000000T0dEP@I02aLhh00`000000QFb_000000090<mB1R<0
/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0102aLhh01@000000Pf^_
08=[[`23Jjl000000080dEP@00<0/G>>0=5H403AF1000`3AF11S0;5cSP0500000025K:l0QFb_08E/
[`000000203?DPHS0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>00<0
/G>>00<0000008=[[`23Jjl00P23Jjl00`000000dEP@0=5H40070=5H4640/G>>00<0000008E/[`25
K:l00`25K:l00`000000ce860<mB1P060<mB1R80/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;5cSP2aLhh00`2aLhh00`000000Pf^_08=[[`0308=[[`030000003AF100dEP@00L0dEP@
H02aLhh00`000000QFb_08E/[`0308E/[`030000003?DPH0ce8600L0ce868@2aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP020;5cSP0300000023Jjl0Pf^_00D0Pf^_00<0
00000=5H403AF1001P3AF11@0;5cSP030?o@Q`2aLhh0/G>>00`0/G>>00<0000008E/[`25K:l01@25
K:l00`000000ce860<mB1P060<mB1R40/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00D00000
0;5cSP2aLhh0/G>>0000000908=[[`030000003AF100dEP@00H0dEP@E`2aLhh00`000000/G>>0;5c
SP030;5cSP0300000025K:l0QFb_00L0QFb_00<000000<mB1P3?DPH01P3?DPHP0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`040000002aLhh0/G>>000000/0Pf^_00<000000=5H403AF1001P3A
F11K0;5cSP0300000025K:l0QFb_00T0QFb_00<000000<mB1P3?DPH01P3?DPHO0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0000000`0Pf^_00<000000=5H403AF1001`3AF11I
0;5cSP0300000025K:l0QFb_00/0QFb_00<000000<mB1P3?DPH01P3?DPHN0;5cSP030000003oool0
oooo0>X0oooo003/0?ooo`8000003P23Jjl00`000000dEP@0=5H40070=5H45L0/G>>00<0000008E/
[`25K:l03@25K:l00`000000ce860<mB1P060<mB1Qd0/G>>00<000000?ooo`3oool0jP3oool00>`0
oooo00<0000008=[[`23Jjl03P23Jjl00`000000dEP@0=5H40070=5H45D0/G>>00<0000008E/[`25
K:l03`25K:l00`000000ce860<mB1P060<mB1Q`0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00<0000008=[[`23Jjl03`23Jjl00`000000dEP@0=5H40070=5H45@0/G>>00<0000008E/[`25K:l0
4025K:l00`000000ce860<mB1P060<mB1Q/0/G>>00<000000?ooo`3oool0jP3oool00>/0oooo00<0
000008=[[`23Jjl04@23Jjl00`000000dEP@0=5H40070=5H4580/G>>00<0000008E/[`25K:l04@25
K:l00`000000ce860<mB1P070<mB1QX0/G>>00<000000?ooo`3oool0jP3oool00>X0oooo00<00000
08=[[`23Jjl04P23Jjl00`000000dEP@0=5H40060=5H45<000005@25K:l00`000000ce860<mB1P05
0<mB1Q`00000k03oool00>T0oooo00<0000008=[[`23Jjl05023Jjl010000000dEP@0=5H403AF104
000000030;_la`2`/=L0/;3G04h0/;3G00<0000008E/[`25K:l05@25K:l00`000000ce860<mB1P04
000000030;Ci`@2`/=L0/;3G01P0/;3G00<000000?ooo`3oool0jP3oool00>X0oooo00<0000008=[
[`23Jjl05023Jjl3000000@0^oc7DP2`/=L00`000000QFb_08E/[`0E08E/[`800000102dnL4K0;2`
e`030000003oool0oooo0>X0oooo003Z0?ooo`8000005023Jjl00`000000^oc70;_la`040;_lae@0
/;3G00<0000008E/[`25K:l04`25K:l00`000000]?W10;Ci`@030;Ci`A`0/;3G00<000000?ooo`3o
ool0jP3oool00>/0oooo0P00000B08=[[`030000002ko<L0^oc700@0^oc7EP2`/=L00`000000QFb_
08E/[`0A08E/[`030000002dnL40]?W100<0]?W17@2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03o
ool00`000000Pf^_08=[[`0?08=[[`030000002ko<L0^oc700@0^oc7E`2`/=L00`000000QFb_08E/
[`0@08E/[`030000002dnL40]?W100<0]?W17P2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool2
000000l0Pf^_00<000000;_la`2ko<L0102ko<LM0;2`e`030;5dS`2`/=L0/;3G03T0/;3G00<00000
08E/[`25K:l03P25K:l00`000000]?W10;Ci`@030;Ci`Al0/;3G00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;2`e`0000003@23Jjl00`000000^oc70;_la`040;_labL0/;3G00<0/GB?0;2`
e`2`/=L0<@2`/=L00`000000QFb_08E/[`0<08E/[`030000002dnL40]?W100<0]?W1802`/=L00`00
0000oooo0?ooo`3Z0?ooo`00k03oool010000000/;3G0;2`e`00000;08=[[`030000002ko<L0^oc7
00@0^oc7<@2`/=L20;5dSbX0/;3G00<0000008E/[`25K:l02P25K:l00`000000]?W10;Ci`@030;Ci
`B40/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00D000000;2`e`2`/=L0/;3G0000000:08=[
[`030000002ko<L0^oc700<0^oc7>P2`/=L30;5dSb80/;3G00<0000008E/[`25K:l02025K:l00`00
0000]?W10;Ci`@030;Ci`B80/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`
/=L00P2`/=L00`000000Pf^_08=[[`0608=[[`030000002ko<L0^oc700<0^oc7A02`/=L30;5dSaX0
/;3G00<0000008E/[`25K:l01P25K:l00`000000]?W10;Ci`@030;Ci`B<0/;3G00<000000?ooo`3o
ool0jP3oool00>`0oooo00<000000;2`e`2`/=L00`2`/=L00`000000Pf^_08=[[`0408=[[`030000
002ko<L0^oc700<0^oc7CP2`/=L30;5dSa80/;3G00<0000008E/[`25K:l01025K:l00`000000]?W1
0;Ci`@030;Ci`B@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L00`2`
/=L00`000000Pf^_08=[[`0308=[[`030000002ko<L0^oc700<0^oc7E`2`/=L40;5dS`T0/;3G00<0
000008E/[`25K:l00`25K:l00`000000]?W10;Ci`@030;Ci`BD0/;3G00<000000?ooo`3oool0jP3o
ool00>`0oooo00<000000;2`e`2`/=L0102`/=L01@000000Pf^_08=[[`23Jjl0000000@0^oc70P00
001P0;2`e`<000000P2`/=L01@000000QFb_08E/[`25K:l0000000@0]?W10P00000U0;2`e`030000
003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G00D0/;3G00@0000008=[[`000000^oc7
1000001X0;2`e`0400000025K:l000000;Ci`@@000009`2`/=L00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000/;3G0;2`e`060;2`e`<00000K@2`/=L3000000L0/;3G0`262`dQ0;2`e`030000
003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G08T0/;3G0P262`dI0;2`e`030000003o
ool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0980/;3G0P262`d@0;2`e`030000003oool0
oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G09/0/;3G00<0QP/=0;2`e`2`/=L01P2`/=L00`00
0000oooo0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003/0?ooo`030000001Fb?D0E/Se0:@0E/Se
00<000000?ooo`3oool0jP3oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?oo
o`3Z0?ooo`00k@3oool00`000000E/Se05K8m@2R05K8m@030000003oool0oooo0>/0oooo003]0?oo
o`030000001Fb?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3oool00>d0ooooYP00003]0?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00001\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.6141 .41312 m .6141 .24575 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.65296 .41278 m .64196 .41287 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.64196 .41287 m .6141 .41312 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.6469 .2622 m .64196 .26081 L .64196 .25948 L .999 .816 .48 r
F
.64719 .23713 m .64756 .24995 L .6469 .2622 L p F P
0 g
s
.6469 .2622 m .64756 .24995 L .66625 .24811 L p .531 .394 .639 r
F P
0 g
s
.64756 .24995 m .64719 .23713 L .66588 .23525 L p .54 .462 .716 r
F P
0 g
s
.66588 .23525 m .66625 .24811 L .64756 .24995 L p .54 .462 .716 r
F P
0 g
s
.6458 .22426 m .64719 .23713 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.64344 .21188 m .6458 .22426 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.66625 .24811 m .66559 .26039 L .6469 .2622 L p .531 .394 .639 r
F P
0 g
s
.64522 .27336 m .6469 .2622 L .66559 .26039 L p .513 .309 .541 r
F P
0 g
s
.65296 .41278 m .65296 .27986 L p .66071 .31485 L .316 .258 .632 r
F P
0 g
s
.65296 .27986 m .65296 .27839 L p .6533 .27998 L .316 .258 .632 r
F P
0 g
s
.6533 .27998 m .66071 .31485 L .65296 .27986 L .316 .258 .632 r
F
.65928 .2826 m .66071 .29106 L .65411 .28027 L F
.65928 .2826 m .65411 .28027 L .6577 .28155 L F
.66071 .29106 m .66071 .31485 L .65296 .27839 L F
.6577 .28155 m .66134 .28121 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.64541 .27334 m .66374 .2716 L p .65214 .27784 L .48 .2 .41 r
F P
0 g
s
.66287 .27215 m .65217 .27786 L .66374 .2716 L .48 .2 .41 r
F
.65217 .27786 m .6426 .28297 L .65214 .27784 L F
.65217 .27786 m .65214 .27784 L .66374 .2716 L F
.66559 .26039 m .66396 .27136 L p .64522 .27336 L .513 .309 .541 r
F P
0 g
s
.66396 .27136 m .66393 .27158 L .66374 .2716 L p .513 .309 .541 r
F P
0 g
s
.66374 .2716 m .64522 .27336 L p .66396 .27136 L .513 .309 .541 r
F P
0 g
s
.64817 .28183 m .64968 .28121 L .64911 .28736 L .688 .562 .707 r
F
.64196 .28438 m .6426 .28297 L .64623 .28263 L p .422 .05 .224 r
F P
0 g
s
.6426 .28297 m .64522 .27336 L .64541 .27334 L p .48 .2 .41 r
F P
0 g
s
.65214 .27784 m .6426 .28297 L .64541 .27334 L .48 .2 .41 r
F
.6141 .24575 m .64196 .24543 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.61652 .17355 m .6216 .17392 L p .64211 .2455 L .999 .816 .48 r
F P
0 g
s
.6141 .24575 m .64196 .24543 L p .58474 .23183 L .289 .763 .934 r
F P
0 g
s
.58474 .23183 m .64196 .24543 L .63395 .24154 L .289 .763 .934 r
F
.6469 .2622 m .64099 .24495 L .64211 .2455 L .999 .816 .48 r
F
.64099 .24495 m .61652 .17355 L .64211 .2455 L F
.6469 .2622 m .64196 .21668 L .64344 .21188 L F
.63624 .19063 m .64021 .20051 L p .64525 .24702 L F P
0 g
s
.6469 .2622 m .64459 .2467 L .64525 .24702 L .999 .816 .48 r
F
.64459 .2467 m .63624 .19063 L .64525 .24702 L F
.64719 .23713 m .6458 .22426 L .6645 .22234 L p .544 .522 .782 r
F P
0 g
s
.6645 .22234 m .66588 .23525 L .64719 .23713 L p .544 .522 .782 r
F P
0 g
s
.63168 .18268 m .63624 .19063 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62673 .17702 m .63168 .18268 L p .64386 .24635 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .64305 .24595 L .64386 .24635 L .999 .816 .48 r
F
.64305 .24595 m .62673 .17702 L .64386 .24635 L F
.6216 .17392 m .62673 .17702 L p .6469 .2622 L F P
0 g
s
.6117 .17594 m .61652 .17355 L p .64099 .24495 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .63958 .24427 L .64099 .24495 L .999 .816 .48 r
F
.63958 .24427 m .6117 .17594 L .64099 .24495 L F
.60737 .18102 m .6117 .17594 L p .63958 .24427 L F P
0 g
s
.6469 .2622 m .63773 .24337 L .63958 .24427 L .999 .816 .48 r
F
.63773 .24337 m .60737 .18102 L .63958 .24427 L F
.60373 .1886 m .60737 .18102 L p .6469 .2622 L F P
0 g
s
.58474 .23183 m .63395 .24154 L .61933 .23446 L .289 .763 .934 r
F
.60094 .19833 m .60373 .1886 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.59915 .20979 m .60094 .19833 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.58474 .23183 m .61319 .23148 L .60881 .22936 L .289 .763 .934 r
F
.6044 .22723 m .58474 .23183 L p .60881 .22936 L F P
0 g
s
.58474 .23183 m .61933 .23446 L .61319 .23148 L .289 .763 .934 r
F
.59844 .22245 m .59915 .20979 L p .6044 .21555 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .6044 .22735 L .6044 .21555 L .999 .816 .48 r
F
.6645 .22234 m .66588 .23525 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.66217 .20992 m .6645 .22234 L .6458 .22426 L p .542 .577 .839 r
F P
0 g
s
.66217 .20992 m .6645 .22234 L p .66517 .24576 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66458 .24547 L .66517 .24576 L .999 .816 .476 r
F
.66458 .24547 m .66217 .20992 L .66517 .24576 L F
.65296 .2453 m .66071 .24356 L p .61933 .23446 L .289 .763 .934 r
F P
0 g
s
.66588 .23525 m .66625 .24811 L .66559 .26039 L p .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .21473 L .66217 .20992 L .999 .816 .476 r
F
.6458 .22426 m .64344 .21188 L .66217 .20992 L p .542 .577 .839 r
F P
0 g
s
.65897 .19851 m .66217 .20992 L .64344 .21188 L p .535 .629 .891 r
F P
0 g
s
.65897 .19851 m .66071 .2047 L p .66071 .21473 L .999 .816 .476 r
F P
0 g
s
.66071 .2047 m .66217 .20992 L p .66071 .21473 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66351 .26501 L .66322 .26446 L .999 .816 .476 r
F
.66351 .26501 m .66071 .27127 L .66322 .26446 L F
.66322 .26446 m .66071 .27127 L .66071 .26876 L F
.66559 .26039 m .66071 .26876 L .66071 .26666 L F
.64344 .21188 m .64021 .20051 L .65897 .19851 L p .535 .629 .891 r
F P
0 g
s
.65504 .1886 m .65897 .19851 L .64021 .20051 L p .519 .68 .939 r
F P
0 g
s
.65504 .1886 m .65897 .19851 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.64021 .20051 m .63624 .19063 L .65504 .1886 L p .519 .68 .939 r
F P
0 g
s
.65054 .18062 m .65504 .1886 L .63624 .19063 L p .489 .73 .978 r
F P
0 g
s
.65054 .18062 m .65504 .1886 L p .6633 .24484 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66259 .24449 L .6633 .24484 L .999 .816 .476 r
F
.66259 .24449 m .65054 .18062 L .6633 .24484 L F
.63624 .19063 m .63168 .18268 L .65054 .18062 L p .489 .73 .978 r
F P
0 g
s
.64564 .17494 m .65054 .18062 L .63168 .18268 L p .434 .77 .997 r
F P
0 g
s
.64564 .17494 m .65054 .18062 L p .66259 .24449 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66178 .24409 L .66259 .24449 L .999 .816 .476 r
F
.66178 .24409 m .64564 .17494 L .66259 .24449 L F
.61933 .23446 m .64643 .23652 L .61319 .23148 L .289 .763 .934 r
F
.63168 .18268 m .62673 .17702 L .64564 .17494 L p .434 .77 .997 r
F P
0 g
s
.64057 .17182 m .64564 .17494 L .62673 .17702 L p .331 .777 .96 r
F P
0 g
s
.64057 .17182 m .64564 .17494 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65296 .2453 m .66071 .24356 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.61933 .23446 m .66071 .24356 L .64643 .23652 L .289 .763 .934 r
F
.62673 .17702 m .6216 .17392 L .64057 .17182 L p .331 .777 .96 r
F P
0 g
s
.63554 .17144 m .64057 .17182 L .6216 .17392 L p .154 .695 .797 r
F P
0 g
s
.63554 .17144 m .64057 .17182 L p .66085 .24363 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65974 .24309 L .66085 .24363 L .999 .816 .476 r
F
.65974 .24309 m .63554 .17144 L .66085 .24363 L F
.61319 .23148 m .63565 .23121 L .60881 .22936 L .289 .763 .934 r
F
.63078 .17383 m .63554 .17144 L p .65974 .24309 L .999 .816 .476 r
F P
0 g
s
.65835 .2424 m .63078 .17383 L .65974 .24309 L .999 .816 .476 r
F
.64021 .20051 m .64196 .20667 L p .64196 .21668 L .999 .816 .48 r
F P
0 g
s
.64196 .20667 m .64344 .21188 L p .64196 .21668 L .999 .816 .48 r
F P
0 g
s
.62649 .17892 m .63078 .17383 L p .65835 .2424 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65652 .2415 L .65835 .2424 L .999 .816 .476 r
F
.65652 .2415 m .62649 .17892 L .65835 .2424 L F
.61223 .22539 m .6044 .22723 L p .62548 .2262 L .289 .763 .934 r
F P
0 g
s
.65652 .2415 m .62356 .18761 L .62649 .17892 L .999 .816 .476 r
F
.65393 .24022 m .62356 .18767 L .65652 .2415 L F
.62356 .18767 m .62289 .18651 L .62356 .18761 L F
.62356 .18767 m .62356 .18761 L .65652 .2415 L F
.60881 .22936 m .62792 .2274 L .6044 .22723 L .289 .763 .934 r
F
.62792 .2274 m .62548 .2262 L .6044 .22723 L F
.60881 .22936 m .63278 .2298 L .62792 .2274 L F
.63565 .23121 m .63278 .2298 L .60881 .22936 L F
.6141 .41312 m .58587 .40902 L .58587 .24025 L p .931 .76 .648 r
F P
0 g
s
.58587 .24025 m .6141 .24575 L .6141 .41312 L p .931 .76 .648 r
F P
0 g
s
.58474 .23183 m .58587 .24025 L .6141 .24575 L p .289 .763 .934 r
F P
0 g
s
.58587 .40902 m .58474 .40275 L .58474 .23183 L p .748 .611 .042 r
F P
0 g
s
.58474 .23183 m .58587 .24025 L .58587 .40902 L p .748 .611 .042 r
F P
0 g
s
.58474 .23183 m .58474 .40275 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.64196 .25948 m .6044 .25007 L .6044 .23881 L .999 .816 .48 r
F
.6044 .22723 m .58474 .23183 L p .60156 .26953 L .299 .244 .627 r
F P
0 g
s
.6044 .26705 m .60156 .26953 L .6044 .2759 L .299 .244 .627 r
F
.6044 .22723 m .60156 .26953 L .6044 .26705 L F
.60625 .2733 m .60284 .26176 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6104 .28314 m .60625 .2733 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.60625 .2733 m .62539 .27146 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.6044 .26705 m .60625 .2733 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.64196 .26081 m .6044 .2502 L .64196 .25948 L .999 .816 .48 r
F
.6044 .2502 m .60033 .24905 L .6044 .25007 L F
.6044 .2502 m .6044 .25007 L .64196 .25948 L F
.59883 .23575 m .59844 .22245 L p .6469 .2622 L F P
0 g
s
.60284 .26176 m .60033 .24905 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.61223 .22539 m .6044 .22723 L p .6044 .26705 L .299 .244 .627 r
F P
0 g
s
.60495 .26657 m .6044 .26705 L .6044 .26968 L .299 .244 .627 r
F
.61223 .22539 m .6044 .26705 L .60495 .26657 L F
.62539 .27146 m .62356 .2652 L p .61142 .26092 L .525 .629 .897 r
F P
0 g
s
.6134 .26073 m .61142 .26092 L p .62356 .2652 L .525 .629 .897 r
F P
0 g
s
.62539 .27146 m .61142 .26092 L .60795 .26396 L .525 .629 .897 r
F
.6151 .29087 m .6104 .28314 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62014 .29616 m .6151 .29087 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62527 .29881 m .62014 .29616 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6303 .29872 m .62527 .29881 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.63498 .29594 m .6303 .29872 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.63914 .29061 m .63498 .29594 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.64196 .28699 m .64911 .28736 L .64196 .29507 L .688 .562 .707 r
F
.6426 .28297 m .63914 .29061 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .64522 .27336 L .6426 .28297 L p .999 .816 .48 r
F P
0 g
s
.6481 .28144 m .64874 .28515 L .64196 .28531 L .688 .562 .707 r
F
.64623 .28263 m .6426 .28297 L p .66287 .27215 L .48 .2 .41 r
F P
0 g
s
.64196 .24543 m .65296 .2453 L p .64968 .28121 L .688 .562 .707 r
F P
0 g
s
.64196 .24543 m .64968 .28121 L .64817 .28183 L .688 .562 .707 r
F
.6577 .28155 m .65411 .28027 L .65296 .27839 L .316 .258 .632 r
F
.64196 .36551 m .64975 .28041 L .65296 .41278 L .688 .562 .707 r
F
.65296 .27839 m .65296 .41278 L p .64975 .28041 L F P
0 g
s
.66393 .27158 m .66134 .28121 L .64623 .28263 L p .48 .2 .41 r
F P
0 g
s
.66393 .27158 m .64623 .28263 L .66287 .27215 L .48 .2 .41 r
F
.64196 .28531 m .64874 .28515 L .64196 .28699 L .688 .562 .707 r
F
.64196 .24543 m .6481 .28144 L .64196 .28531 L F
.64874 .28515 m .64911 .28736 L .64196 .28699 L F
.64196 .29507 m .64911 .28736 L .64196 .36551 L F
.63498 .29594 m .63914 .29061 L .65792 .28887 L p .315 0 0 r
F P
0 g
s
.6151 .29087 m .62014 .29616 L .63912 .29442 L p .408 .766 .995 r
F P
0 g
s
.63912 .29442 m .63414 .2891 L .6151 .29087 L p .408 .766 .995 r
F P
0 g
s
.6104 .28314 m .6151 .29087 L .63414 .2891 L p .472 .73 .983 r
F P
0 g
s
.63414 .2891 m .62949 .28134 L .6104 .28314 L p .472 .73 .983 r
F P
0 g
s
.60625 .2733 m .6104 .28314 L .62949 .28134 L p .507 .681 .945 r
F P
0 g
s
.62949 .28134 m .62539 .27146 L .60625 .2733 L p .507 .681 .945 r
F P
0 g
s
.62356 .34904 m .61556 .26168 L .61223 .39797 L .688 .561 .707 r
F
.61223 .22539 m .61223 .25992 L p .61556 .26168 L F P
0 g
s
.62356 .22526 m .61223 .22539 L p .62548 .2262 L .289 .763 .934 r
F P
0 g
s
.64643 .23652 m .64308 .23487 L .61319 .23148 L .289 .763 .934 r
F
.61319 .23148 m .64308 .23487 L .63565 .23121 L F
.63395 .24154 m .65296 .2453 L .61933 .23446 L F
.6303 .29872 m .63498 .29594 L .65381 .29421 L p .134 0 0 r
F P
0 g
s
.65381 .29421 m .64917 .297 L .6303 .29872 L p .134 0 0 r
F P
0 g
s
.62014 .29616 m .62527 .29881 L .6442 .29708 L p .289 .76 .939 r
F P
0 g
s
.65792 .28887 m .65381 .29421 L .63498 .29594 L p .315 0 0 r
F P
0 g
s
.6442 .29708 m .63912 .29442 L .62014 .29616 L p .289 .76 .939 r
F P
0 g
s
.62356 .22526 m .61223 .22539 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62201 .25989 m .61504 .25641 L .61223 .25992 L .534 .576 .843 r
F
.61142 .26092 m .6134 .26073 L p .61223 .25992 L F P
0 g
s
.61556 .26168 m .61223 .25992 L .6134 .26073 L .688 .561 .707 r
F
.6134 .26073 m .62201 .25989 L p .61223 .25992 L .534 .576 .843 r
F P
0 g
s
.61223 .25992 m .61223 .26022 L p .6134 .26073 L .688 .561 .707 r
F P
0 g
s
.61223 .26022 m .61223 .39797 L p .61556 .26168 L .688 .561 .707 r
F P
0 g
s
.62356 .2652 m .62201 .25989 L .6134 .26073 L p .525 .629 .897 r
F P
0 g
s
.61223 .22539 m .6044 .26968 L .6056 .26819 L .299 .244 .627 r
F
.61223 .39797 m .61223 .22539 L p .6044 .2759 L F P
0 g
s
.61142 .26092 m .60284 .26176 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.60033 .24905 m .60284 .26176 L .61142 .26092 L p .534 .576 .843 r
F P
0 g
s
.61504 .25641 m .60033 .24905 L .61142 .26092 L .534 .576 .843 r
F
.6056 .26819 m .6044 .26968 L .6044 .2759 L .299 .244 .627 r
F
.60284 .26176 m .6044 .26705 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.60033 .24905 m .59883 .23575 L p .6044 .23881 L .999 .816 .48 r
F P
0 g
s
.6044 .25007 m .60033 .24905 L .6044 .23881 L .999 .816 .48 r
F
.62014 .19627 m .62289 .18651 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.64196 .24543 m .65296 .2453 L p .63395 .24154 L .289 .763 .934 r
F P
0 g
s
.61836 .20776 m .62014 .19627 L p .66071 .2535 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .25495 L .66071 .2535 L .999 .816 .476 r
F
.66134 .28121 m .66071 .28262 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.65296 .2453 m .66071 .25977 L .65928 .2826 L .316 .258 .632 r
F
.65296 .24632 m .65296 .2453 L p .65317 .24656 L F P
0 g
s
.65317 .24656 m .65928 .2826 L .65296 .24632 L .316 .258 .632 r
F
.65296 .27839 m .65296 .24632 L p .65928 .2826 L F P
0 g
s
.65296 .2453 m .65296 .27839 L p .64975 .28041 L .688 .562 .707 r
F P
0 g
s
.66071 .25495 m .61836 .20776 L .66071 .2535 L .999 .816 .476 r
F
.66374 .2716 m .66393 .27158 L p .66287 .27215 L .48 .2 .41 r
F P
0 g
s
.66071 .25977 m .66071 .28356 L .65928 .2826 L .316 .258 .632 r
F
.62201 .25989 m .61953 .24714 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62539 .27146 m .62201 .25989 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62949 .28134 m .62539 .27146 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.63414 .2891 m .62949 .28134 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.63914 .29061 m .64196 .28438 L p .6577 .28155 L .422 .05 .224 r
F P
0 g
s
.64623 .28263 m .6577 .28155 L p .64196 .28438 L .422 .05 .224 r
F P
0 g
s
.65792 .28887 m .63914 .29061 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.65924 .2821 m .63914 .29061 L .6577 .28155 L .422 .05 .224 r
F
.63912 .29442 m .63414 .2891 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65381 .29421 m .64917 .297 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65792 .28887 m .65381 .29421 L p .66071 .2744 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .27851 L .66071 .2744 L .999 .816 .476 r
F
.65928 .2826 m .66071 .28356 L .66071 .29106 L .316 .258 .632 r
F
.66071 .28262 m .65792 .28887 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.66071 .27851 m .65792 .28887 L .66071 .2744 L .999 .816 .476 r
F
.68053 .29681 m .68053 .40818 L p .66071 .29106 L .316 .258 .632 r
F P
0 g
s
.66071 .28356 m .68053 .29681 L .66071 .29106 L .316 .258 .632 r
F
.66134 .28121 m .65792 .28887 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66393 .27158 L .66134 .28121 L p .999 .816 .476 r
F P
0 g
s
.66071 .25977 m .68053 .29681 L .66071 .28356 L .316 .258 .632 r
F
.61766 .22046 m .61836 .20776 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62792 .2274 m .6523 .22491 L .62548 .2262 L .289 .763 .934 r
F
.6523 .22491 m .62356 .22526 L p .62548 .2262 L F P
0 g
s
.68061 .23067 m .6523 .22491 L p .62792 .2274 L .289 .763 .934 r
F P
0 g
s
.63278 .2298 m .68061 .23067 L .62792 .2274 L .289 .763 .934 r
F
.63565 .23121 m .68061 .23067 L .63278 .2298 L F
.64643 .23652 m .68053 .23912 L .64308 .23487 L F
.68053 .23912 m .68061 .23067 L p .63565 .23121 L F P
0 g
s
.64308 .23487 m .68053 .23912 L .63565 .23121 L .289 .763 .934 r
F
.66071 .24356 m .68053 .23912 L p .64643 .23652 L F P
0 g
s
.61805 .23379 m .61766 .22046 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.61953 .24714 m .61805 .23379 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62527 .29881 m .6303 .29872 L .64917 .297 L p .096 .653 .744 r
F P
0 g
s
.64917 .297 m .6442 .29708 L .62527 .29881 L p .096 .653 .744 r
F P
0 g
s
.6523 .22491 m .62356 .22526 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.64917 .297 m .6442 .29708 L p .66071 .26876 L .999 .816 .476 r
F P
0 g
s
.66071 .27127 m .64917 .297 L .66071 .26876 L .999 .816 .476 r
F
.6442 .29708 m .63912 .29442 L p .66071 .26666 L F P
0 g
s
.66071 .26876 m .6442 .29708 L .66071 .26666 L .999 .816 .476 r
F
.6523 .3976 m .6523 .22491 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.61223 .39797 m .62356 .39786 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62356 .39786 m .6523 .3976 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62289 .18651 m .62356 .1851 L p .62356 .18761 L .999 .816 .476 r
F P
0 g
s
.62356 .1851 m .62649 .17892 L p .62356 .18761 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65393 .24022 L .65652 .2415 L .999 .816 .476 r
F
.66559 .26039 m .65835 .2424 L .65974 .24309 L F
.68053 .23912 m .68053 .29681 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.66071 .24356 m .68053 .23912 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.6044 .22735 m .59844 .22245 L .6044 .21555 L .999 .816 .48 r
F
.58474 .40275 m .6044 .39933 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.6044 .39933 m .61223 .39797 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.66071 .29106 m .68053 .40818 L .66071 .31485 L .316 .258 .632 r
F
.68053 .40818 m .66071 .41149 L p .66071 .31485 L F P
0 g
s
.66071 .41149 m .65296 .41278 L p .66071 .31485 L .316 .258 .632 r
F P
0 g
s
.68061 .40189 m .68053 .40818 L .68053 .23912 L p 0 0 .003 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6141 .41312 m .65296 .41278 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.65296 .41278 m .68053 .40818 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.68053 .40818 m .68061 .40189 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.68053 .23912 m .68061 .23067 L .68061 .40189 L p 0 0 .003 r
F P
0 g
s
.6523 .3976 m .68061 .40189 L .68061 .23067 L p .936 .764 .644 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58474 .40275 m .58587 .40902 L .6141 .41312 L p .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.3524 .41312 m .3524 .24575 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.39108 .41278 m .38013 .41287 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.38013 .41287 m .3524 .41312 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.38603 .2622 m .38013 .25948 L .38013 .25815 L .999 .816 .524 r
F
.38638 .23713 m .38682 .24995 L .38603 .2622 L p F P
0 g
s
.38603 .2622 m .38682 .24995 L .40476 .24811 L p .523 .385 .635 r
F P
0 g
s
.38682 .24995 m .38638 .23713 L .40432 .23525 L p .533 .457 .716 r
F P
0 g
s
.40432 .23525 m .40476 .24811 L .38682 .24995 L p .533 .457 .716 r
F P
0 g
s
.38472 .22426 m .38638 .23713 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3819 .21188 m .38472 .22426 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.40476 .24811 m .40397 .26039 L .38603 .2622 L p .523 .385 .635 r
F P
0 g
s
.38403 .27336 m .38603 .2622 L .40397 .26039 L p .503 .297 .533 r
F P
0 g
s
.38421 .27334 m .40181 .2716 L p .39033 .27784 L .469 .183 .396 r
F P
0 g
s
.40094 .27215 m .39036 .27786 L .40181 .2716 L .469 .183 .396 r
F
.39036 .27786 m .3809 .28297 L .39033 .27784 L F
.39036 .27786 m .39033 .27784 L .40181 .2716 L F
.40397 .26039 m .40203 .27136 L p .38403 .27336 L .503 .297 .533 r
F P
0 g
s
.40203 .27136 m .40199 .27158 L .40181 .2716 L p .503 .297 .533 r
F P
0 g
s
.40181 .2716 m .38403 .27336 L p .40203 .27136 L .503 .297 .533 r
F P
0 g
s
.39033 .27784 m .3809 .28297 L .38421 .27334 L .469 .183 .396 r
F
.38481 .24732 m .38013 .21668 L .3819 .21188 L .999 .816 .524 r
F
.38603 .2622 m .38406 .24702 L .38481 .24732 L F
.38406 .24702 m .38013 .21668 L .38481 .24732 L F
.3524 .24575 m .38013 .24543 L p .31748 .23183 L .289 .763 .934 r
F P
0 g
s
.37329 .19063 m .37804 .20051 L p .38406 .24702 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38327 .2467 L .38406 .24702 L .999 .816 .524 r
F
.38327 .2467 m .37329 .19063 L .38406 .24702 L F
.38638 .23713 m .38472 .22426 L .40268 .22234 L p .537 .52 .784 r
F P
0 g
s
.40268 .22234 m .40432 .23525 L .38638 .23713 L p .537 .52 .784 r
F P
0 g
s
.36786 .18268 m .37329 .19063 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.36195 .17702 m .36786 .18268 L p .3824 .24635 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38143 .24595 L .3824 .24635 L .999 .816 .524 r
F
.38143 .24595 m .36195 .17702 L .3824 .24635 L F
.35583 .17392 m .36195 .17702 L p .38603 .2622 L F P
0 g
s
.31748 .23183 m .38013 .24543 L .37056 .24154 L .289 .763 .934 r
F
.3524 .24575 m .38013 .24543 L p .38013 .28438 L .688 .562 .707 r
F P
0 g
s
.36298 .29146 m .38013 .28438 L .38013 .36551 L .688 .562 .707 r
F
.3524 .24575 m .38013 .28438 L .36298 .29146 L F
.34976 .17355 m .35583 .17392 L p .38013 .24498 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38013 .2478 L .38013 .24498 L .999 .816 .524 r
F
.38013 .2478 m .34976 .17355 L .38013 .24498 L F
.344 .17594 m .34976 .17355 L p .37897 .24495 L F P
0 g
s
.38603 .2622 m .37729 .24427 L .37897 .24495 L .999 .816 .524 r
F
.37729 .24427 m .344 .17594 L .37897 .24495 L F
.33883 .18102 m .344 .17594 L p .37729 .24427 L F P
0 g
s
.38603 .2622 m .37508 .24337 L .37729 .24427 L .999 .816 .524 r
F
.37508 .24337 m .33883 .18102 L .37729 .24427 L F
.33449 .1886 m .33883 .18102 L p .38603 .2622 L F P
0 g
s
.31748 .23183 m .37056 .24154 L .35312 .23446 L .289 .763 .934 r
F
.33116 .19833 m .33449 .1886 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.32902 .20979 m .33116 .19833 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.31748 .23183 m .34578 .23148 L .34055 .22936 L .289 .763 .934 r
F
.33529 .22723 m .31748 .23183 L p .34055 .22936 L F P
0 g
s
.31748 .23183 m .35312 .23446 L .34578 .23148 L .289 .763 .934 r
F
.32817 .22245 m .32902 .20979 L p .33529 .21555 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .33529 .22735 L .33529 .21555 L .999 .816 .524 r
F
.40268 .22234 m .40432 .23525 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39988 .20992 m .40268 .22234 L .38472 .22426 L p .536 .576 .842 r
F P
0 g
s
.39988 .20992 m .40268 .22234 L p .40347 .24576 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40276 .24547 L .40347 .24576 L .999 .816 .521 r
F
.40276 .24547 m .39988 .20992 L .40347 .24576 L F
.39108 .2453 m .39813 .24356 L p .35312 .23446 L .289 .763 .934 r
F P
0 g
s
.40432 .23525 m .40476 .24811 L .40397 .26039 L p .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .21473 L .39988 .20992 L .999 .816 .521 r
F
.38472 .22426 m .3819 .21188 L .39988 .20992 L p .536 .576 .842 r
F P
0 g
s
.39606 .19851 m .39988 .20992 L .3819 .21188 L p .528 .629 .895 r
F P
0 g
s
.39606 .19851 m .39813 .2047 L p .39813 .21473 L .999 .816 .521 r
F P
0 g
s
.39813 .2047 m .39988 .20992 L p .39813 .21473 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40071 .26506 L .40034 .26429 L .999 .816 .521 r
F
.40071 .26506 m .39813 .26876 L .40034 .26429 L F
.40034 .26429 m .39813 .26876 L .39813 .26666 L F
.3819 .21188 m .37804 .20051 L .39606 .19851 L p .528 .629 .895 r
F P
0 g
s
.39135 .1886 m .39606 .19851 L .37804 .20051 L p .512 .681 .942 r
F P
0 g
s
.39135 .1886 m .39606 .19851 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.37804 .20051 m .37329 .19063 L .39135 .1886 L p .512 .681 .942 r
F P
0 g
s
.38595 .18062 m .39135 .1886 L .37329 .19063 L p .483 .73 .98 r
F P
0 g
s
.38595 .18062 m .39135 .1886 L p .40124 .24484 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40038 .24449 L .40124 .24484 L .999 .816 .521 r
F
.40038 .24449 m .38595 .18062 L .40124 .24484 L F
.37329 .19063 m .36786 .18268 L .38595 .18062 L p .483 .73 .98 r
F P
0 g
s
.3801 .17494 m .38595 .18062 L .36786 .18268 L p .429 .769 .997 r
F P
0 g
s
.3801 .17494 m .38595 .18062 L p .40038 .24449 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39942 .24409 L .40038 .24449 L .999 .816 .521 r
F
.39942 .24409 m .3801 .17494 L .40038 .24449 L F
.35312 .23446 m .38104 .23652 L .34578 .23148 L .289 .763 .934 r
F
.36786 .18268 m .36195 .17702 L .3801 .17494 L p .429 .769 .997 r
F P
0 g
s
.37403 .17182 m .3801 .17494 L .36195 .17702 L p .33 .777 .959 r
F P
0 g
s
.37403 .17182 m .3801 .17494 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39108 .2453 m .39813 .24356 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.35312 .23446 m .39813 .24356 L .38104 .23652 L .289 .763 .934 r
F
.36195 .17702 m .35583 .17392 L .37403 .17182 L p .33 .777 .959 r
F P
0 g
s
.368 .17144 m .37403 .17182 L .35583 .17392 L p .163 .702 .805 r
F P
0 g
s
.368 .17144 m .37403 .17182 L p .39831 .24363 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39698 .24309 L .39831 .24363 L .999 .816 .521 r
F
.39698 .24309 m .368 .17144 L .39831 .24363 L F
.34578 .23148 m .36813 .23121 L .34055 .22936 L .289 .763 .934 r
F
.37804 .20051 m .38013 .20667 L p .38013 .21668 L .999 .816 .524 r
F P
0 g
s
.38013 .20667 m .3819 .21188 L p .38013 .21668 L .999 .816 .524 r
F P
0 g
s
.3623 .17383 m .368 .17144 L p .39698 .24309 L .999 .816 .521 r
F P
0 g
s
.39531 .2424 m .3623 .17383 L .39698 .24309 L .999 .816 .521 r
F
.35717 .17892 m .3623 .17383 L p .40397 .26039 L F P
0 g
s
.39312 .2415 m .35366 .18761 L .35717 .17892 L .999 .816 .521 r
F
.39002 .24022 m .35366 .18767 L .39312 .2415 L F
.35366 .18767 m .35286 .18651 L .35366 .18761 L F
.35366 .18767 m .35366 .18761 L .39312 .2415 L F
.34239 .22539 m .33529 .22723 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.34055 .22936 m .36469 .2298 L .35888 .2274 L .289 .763 .934 r
F
.36813 .23121 m .36469 .2298 L .34055 .22936 L F
.34055 .22936 m .35888 .2274 L .33529 .22723 L F
.34956 .19627 m .35286 .18651 L p .39002 .24022 L .999 .816 .521 r
F P
0 g
s
.38517 .23822 m .34956 .19627 L .39002 .24022 L .999 .816 .521 r
F
.38104 .23652 m .37702 .23487 L .34578 .23148 L .289 .763 .934 r
F
.34578 .23148 m .37702 .23487 L .36813 .23121 L F
.3524 .41312 m .32197 .40902 L .32197 .24025 L p .92 .752 .656 r
F P
0 g
s
.32197 .24025 m .3524 .24575 L .3524 .41312 L p .92 .752 .656 r
F P
0 g
s
.32197 .40902 m .31748 .40275 L .31748 .23183 L p .852 .696 .164 r
F P
0 g
s
.31748 .23183 m .32197 .24025 L .32197 .40902 L p .852 .696 .164 r
F P
0 g
s
.31748 .23183 m .31748 .40275 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.31748 .23183 m .32197 .24025 L .3524 .24575 L p .289 .763 .934 r
F P
0 g
s
.38603 .2622 m .33529 .2502 L .33529 .23881 L .999 .816 .524 r
F
.35888 .2274 m .35597 .2262 L .33529 .22723 L .289 .763 .934 r
F
.33529 .22723 m .31748 .23183 L p .33272 .26953 L .259 .212 .613 r
F P
0 g
s
.33529 .26705 m .33272 .26953 L .33529 .2759 L .259 .212 .613 r
F
.33529 .22723 m .33272 .26953 L .33529 .26705 L F
.3375 .2733 m .33342 .26176 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.34246 .28314 m .3375 .2733 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3375 .2733 m .35585 .27146 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33529 .26705 m .3375 .2733 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.32865 .23575 m .32817 .22245 L p .33529 .22735 L .999 .816 .524 r
F P
0 g
s
.38013 .25815 m .33529 .23864 L .33529 .22735 L .999 .816 .524 r
F
.33529 .23864 m .32865 .23575 L .33529 .22735 L F
.38013 .25948 m .32865 .23575 L .38013 .25815 L F
.33342 .26176 m .33043 .24905 L p .38603 .2622 L F P
0 g
s
.34239 .22539 m .33529 .22723 L p .33529 .26705 L .259 .212 .613 r
F P
0 g
s
.33579 .26657 m .33529 .26705 L .33529 .26968 L .259 .212 .613 r
F
.34239 .22539 m .33529 .26705 L .33579 .26657 L F
.35585 .27146 m .35366 .2652 L p .34166 .26092 L .518 .629 .9 r
F P
0 g
s
.34355 .26073 m .34166 .26092 L p .35366 .2652 L .518 .629 .9 r
F P
0 g
s
.35585 .27146 m .34166 .26092 L .33851 .26396 L .518 .629 .9 r
F
.34807 .29087 m .34246 .28314 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.35407 .29616 m .34807 .29087 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.36021 .29881 m .35407 .29616 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3662 .29872 m .36021 .29881 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3718 .29594 m .3662 .29872 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.34807 .29087 m .35407 .29616 L .37229 .29442 L p .401 .765 .994 r
F P
0 g
s
.37229 .29442 m .36633 .2891 L .34807 .29087 L p .401 .765 .994 r
F P
0 g
s
.34246 .28314 m .34807 .29087 L .36633 .2891 L p .465 .73 .984 r
F P
0 g
s
.36633 .2891 m .36077 .28134 L .34246 .28314 L p .465 .73 .984 r
F P
0 g
s
.3375 .2733 m .34246 .28314 L .36077 .28134 L p .499 .682 .948 r
F P
0 g
s
.36077 .28134 m .35585 .27146 L .3375 .2733 L p .499 .682 .948 r
F P
0 g
s
.35366 .34904 m .3457 .26168 L .34239 .39797 L .688 .561 .707 r
F
.34239 .22539 m .34239 .25992 L p .3457 .26168 L F P
0 g
s
.35366 .22526 m .34239 .22539 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.37056 .24154 m .39108 .2453 L .35312 .23446 L .289 .763 .934 r
F
.35366 .22526 m .34239 .22539 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35181 .25989 m .34494 .25641 L .34239 .25992 L .527 .575 .846 r
F
.34166 .26092 m .34355 .26073 L p .34239 .25992 L F P
0 g
s
.3457 .26168 m .34239 .25992 L .34355 .26073 L .688 .561 .707 r
F
.34355 .26073 m .35181 .25989 L p .34239 .25992 L .527 .575 .846 r
F P
0 g
s
.34239 .25992 m .34239 .26022 L p .34355 .26073 L .688 .561 .707 r
F P
0 g
s
.34239 .26022 m .34239 .39797 L p .3457 .26168 L .688 .561 .707 r
F P
0 g
s
.35366 .2652 m .35181 .25989 L .34355 .26073 L p .518 .629 .9 r
F P
0 g
s
.34239 .22539 m .33529 .26968 L .33638 .26819 L .259 .212 .613 r
F
.34239 .39797 m .34239 .22539 L p .33529 .2759 L F P
0 g
s
.34166 .26092 m .33342 .26176 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33043 .24905 m .33342 .26176 L .34166 .26092 L p .527 .575 .846 r
F P
0 g
s
.34494 .25641 m .33043 .24905 L .34166 .26092 L .527 .575 .846 r
F
.33638 .26819 m .33529 .26968 L .33529 .2759 L .259 .212 .613 r
F
.33342 .26176 m .33529 .26705 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33043 .24905 m .32865 .23575 L p .33529 .23881 L .999 .816 .524 r
F P
0 g
s
.33529 .2502 m .33043 .24905 L .33529 .23881 L .999 .816 .524 r
F
.37677 .29061 m .3718 .29594 L p .38603 .2622 L F P
0 g
s
.3809 .28297 m .37677 .29061 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38403 .27336 L .3809 .28297 L p .999 .816 .524 r
F P
0 g
s
.38438 .28263 m .3809 .28297 L p .40094 .27215 L .469 .183 .396 r
F P
0 g
s
.38013 .24543 m .39108 .2453 L p .38788 .28041 L .688 .562 .707 r
F P
0 g
s
.38625 .28144 m .38788 .28041 L .38725 .28736 L .688 .562 .707 r
F
.38013 .24543 m .38788 .28041 L .38625 .28144 L F
.38013 .28438 m .3809 .28297 L .38438 .28263 L p .406 .026 .202 r
F P
0 g
s
.3809 .28297 m .38403 .27336 L .38421 .27334 L p .469 .183 .396 r
F P
0 g
s
.38013 .24543 m .38725 .28736 L .38013 .29507 L .688 .562 .707 r
F
.39108 .41278 m .39108 .27986 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.39108 .27986 m .39108 .27839 L p .39139 .27998 L .279 .228 .62 r
F P
0 g
s
.39139 .27998 m .39813 .31485 L .39108 .27986 L .279 .228 .62 r
F
.39889 .28121 m .39679 .2821 L .39584 .28172 L .406 .026 .202 r
F
.39683 .2826 m .39813 .29106 L .39139 .27998 L .279 .228 .62 r
F
.39813 .29106 m .39813 .31485 L .39139 .27998 L F
.39539 .28155 m .39139 .27998 L .39108 .27839 L F
.39683 .2826 m .39139 .27998 L .39539 .28155 L F
.38013 .36551 m .38788 .28041 L .39108 .41278 L .688 .562 .707 r
F
.39108 .27839 m .39108 .41278 L p .38788 .28041 L F P
0 g
s
.38438 .28263 m .39539 .28155 L p .38013 .28438 L .406 .026 .202 r
F P
0 g
s
.39584 .28172 m .38013 .28438 L .39539 .28155 L .406 .026 .202 r
F
.38875 .2822 m .38438 .28263 L p .39163 .27808 L .469 .183 .396 r
F P
0 g
s
.40199 .27158 m .38875 .2822 L .39163 .27808 L .469 .183 .396 r
F
.40199 .27158 m .39889 .28121 L .38875 .2822 L p F P
0 g
s
.39539 .28155 m .39889 .28121 L p .39584 .28172 L .406 .026 .202 r
F P
0 g
s
.40199 .27158 m .38438 .28263 L .40094 .27215 L .469 .183 .396 r
F
.39108 .27839 m .39108 .2453 L p .39675 .28208 L .279 .228 .62 r
F P
0 g
s
.39675 .28208 m .39539 .28155 L .39108 .27839 L .279 .228 .62 r
F
.37677 .29061 m .38013 .28438 L p .39584 .28172 L .406 .026 .202 r
F P
0 g
s
.39675 .28208 m .39683 .2826 L .39539 .28155 L .279 .228 .62 r
F
.40397 .26039 m .39813 .27127 L .39813 .26876 L .999 .816 .521 r
F
.39108 .2453 m .39813 .25977 L .39686 .28212 L .279 .228 .62 r
F
.39675 .28208 m .39686 .28212 L .39683 .2826 L F
.39108 .2453 m .39686 .28212 L .39675 .28208 L F
.38013 .29507 m .38725 .28736 L .38013 .36551 L .688 .562 .707 r
F
.39479 .28887 m .37677 .29061 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39889 .28121 m .39813 .28262 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39813 .25977 m .39813 .28356 L .39683 .2826 L .279 .228 .62 r
F
.41618 .29681 m .41618 .40818 L p .39813 .29106 L F P
0 g
s
.39683 .2826 m .39813 .28356 L .39813 .29106 L .279 .228 .62 r
F
.39813 .28356 m .41618 .29681 L .39813 .29106 L F
.40181 .2716 m .40199 .27158 L p .40094 .27215 L .469 .183 .396 r
F P
0 g
s
.39889 .28121 m .39813 .28262 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39813 .28262 m .39479 .28887 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39813 .28262 m .39479 .28887 L p .39813 .27851 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .28262 L .39813 .27851 L .999 .816 .521 r
F
.38013 .24543 m .39108 .2453 L p .37056 .24154 L .289 .763 .934 r
F P
0 g
s
.39108 .2453 m .39108 .27839 L p .38788 .28041 L .688 .562 .707 r
F P
0 g
s
.34744 .20776 m .34956 .19627 L p .39813 .2535 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .25495 L .39813 .2535 L .999 .816 .521 r
F
.39813 .25495 m .34744 .20776 L .39813 .2535 L F
.35181 .25989 m .34883 .24714 L p .40397 .26039 L F P
0 g
s
.35585 .27146 m .35181 .25989 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36077 .28134 m .35585 .27146 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36633 .2891 m .36077 .28134 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.37229 .29442 m .36633 .2891 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39099 .28456 m .37677 .29061 L .39141 .28379 L .406 .026 .202 r
F
.39099 .28456 m .39141 .28379 L .39584 .28172 L F
.39679 .2821 m .39099 .28456 L .39584 .28172 L F
.3718 .29594 m .37677 .29061 L .39479 .28887 L p .295 0 0 r
F P
0 g
s
.39479 .28887 m .38987 .29421 L .3718 .29594 L p .295 0 0 r
F P
0 g
s
.3662 .29872 m .3718 .29594 L .38987 .29421 L p .115 0 0 r
F P
0 g
s
.38987 .29421 m .38432 .297 L .3662 .29872 L p .115 0 0 r
F P
0 g
s
.38987 .29421 m .38432 .297 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39479 .28887 m .38987 .29421 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40199 .27158 L .39889 .28121 L p .999 .816 .521 r
F P
0 g
s
.39813 .25977 m .41618 .29681 L .39813 .28356 L .279 .228 .62 r
F
.38432 .297 m .37837 .29708 L p .39813 .26876 L .999 .816 .521 r
F P
0 g
s
.39813 .27127 m .38432 .297 L .39813 .26876 L .999 .816 .521 r
F
.39813 .29106 m .41618 .40818 L .39813 .31485 L .279 .228 .62 r
F
.3466 .22046 m .34744 .20776 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.35888 .2274 m .38227 .22491 L .35597 .2262 L .289 .763 .934 r
F
.40397 .26039 m .38517 .23822 L .39002 .24022 L .999 .816 .521 r
F
.38227 .22491 m .35366 .22526 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.41288 .23067 m .38227 .22491 L p .35888 .2274 L .289 .763 .934 r
F P
0 g
s
.36469 .2298 m .41288 .23067 L .35888 .2274 L .289 .763 .934 r
F
.36813 .23121 m .41288 .23067 L .36469 .2298 L F
.38104 .23652 m .41618 .23912 L .37702 .23487 L F
.41618 .23912 m .41288 .23067 L p .36813 .23121 L F P
0 g
s
.37702 .23487 m .41618 .23912 L .36813 .23121 L .289 .763 .934 r
F
.34707 .23379 m .3466 .22046 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.34883 .24714 m .34707 .23379 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36021 .29881 m .3662 .29872 L .38432 .297 L p .105 .66 .753 r
F P
0 g
s
.38432 .297 m .37837 .29708 L .36021 .29881 L p .105 .66 .753 r
F P
0 g
s
.35407 .29616 m .36021 .29881 L .37837 .29708 L p .288 .759 .938 r
F P
0 g
s
.37837 .29708 m .37229 .29442 L .35407 .29616 L p .288 .759 .938 r
F P
0 g
s
.38227 .22491 m .35366 .22526 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.39813 .24356 m .41618 .23912 L p .38104 .23652 L .289 .763 .934 r
F P
0 g
s
.37837 .29708 m .37229 .29442 L p .39813 .26666 L .999 .816 .521 r
F P
0 g
s
.39813 .26876 m .37837 .29708 L .39813 .26666 L .999 .816 .521 r
F
.38227 .3976 m .38227 .22491 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.34239 .39797 m .35366 .39786 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35366 .39786 m .38227 .3976 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35286 .18651 m .35366 .1851 L p .35366 .18761 L .999 .816 .521 r
F P
0 g
s
.35366 .1851 m .35717 .17892 L p .35366 .18761 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39002 .24022 L .39312 .2415 L .999 .816 .521 r
F
.40397 .26039 m .39531 .2424 L .39698 .24309 L F
.41618 .23912 m .41618 .29681 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.39813 .24356 m .41618 .23912 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.33529 .22735 m .32817 .22245 L .33529 .21555 L .999 .816 .524 r
F
.31748 .40275 m .33529 .39933 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.33529 .39933 m .34239 .39797 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.41618 .40818 m .39813 .41149 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.39813 .41149 m .39108 .41278 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.41288 .40189 m .41618 .40818 L .41618 .23912 L p .818 .668 .122 r
F P
0 g
s
.68061 .23067 m .6523 .22491 L .6523 .3976 L p .936 .764 .644 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3524 .41312 m .39108 .41278 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.31748 .40275 m .32197 .40902 L .3524 .41312 L p .224 .73 .894 r
F P
0 g
s
.39108 .41278 m .41618 .40818 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.68061 .40189 m .6523 .3976 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.41618 .23912 m .41288 .23067 L .41288 .40189 L p .818 .668 .122 r
F P
0 g
s
.38227 .3976 m .41288 .40189 L .41288 .23067 L p .926 .756 .652 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41618 .40818 m .41288 .40189 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.6523 .3976 m .61223 .39797 L .58474 .40275 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6216 .17392 m .61652 .17355 L .63554 .17144 L p .154 .695 .797 r
F P
0 g
s
.35583 .17392 m .34976 .17355 L .368 .17144 L p .163 .702 .805 r
F P
0 g
s
.61652 .17355 m .6117 .17594 L .63078 .17383 L p .078 0 0 r
F P
0 g
s
.63078 .17383 m .63554 .17144 L .61652 .17355 L p .078 0 0 r
F P
0 g
s
.34976 .17355 m .344 .17594 L .3623 .17383 L p .057 0 0 r
F P
0 g
s
.3623 .17383 m .368 .17144 L .34976 .17355 L p .057 0 0 r
F P
0 g
s
.38227 .3976 m .34239 .39797 L .31748 .40275 L p .224 .73 .894 r
F P
0 g
s
.41288 .40189 m .38227 .3976 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.6117 .17594 m .60737 .18102 L .62649 .17892 L p .276 0 0 r
F P
0 g
s
.62649 .17892 m .63078 .17383 L .6117 .17594 L p .276 0 0 r
F P
0 g
s
.344 .17594 m .33883 .18102 L .35717 .17892 L p .254 0 0 r
F P
0 g
s
.35717 .17892 m .3623 .17383 L .344 .17594 L p .254 0 0 r
F P
0 g
s
.41288 .23067 m .38227 .22491 L .38227 .3976 L p .926 .756 .652 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60737 .18102 m .60373 .1886 L .62289 .18651 L p .398 .015 .191 r
F P
0 g
s
.62289 .18651 m .62649 .17892 L .60737 .18102 L p .398 .015 .191 r
F P
0 g
s
.33883 .18102 m .33449 .1886 L .35286 .18651 L p .381 0 .166 r
F P
0 g
s
.35286 .18651 m .35717 .17892 L .33883 .18102 L p .381 0 .166 r
F P
0 g
s
.60373 .1886 m .60094 .19833 L .62014 .19627 L p .465 .178 .392 r
F P
0 g
s
.62014 .19627 m .62289 .18651 L .60373 .1886 L p .465 .178 .392 r
F P
0 g
s
.33449 .1886 m .33116 .19833 L .34956 .19627 L p .452 .159 .375 r
F P
0 g
s
.34956 .19627 m .35286 .18651 L .33449 .1886 L p .452 .159 .375 r
F P
0 g
s
.60094 .19833 m .59915 .20979 L .61836 .20776 L p .502 .295 .532 r
F P
0 g
s
.61836 .20776 m .62014 .19627 L .60094 .19833 L p .502 .295 .532 r
F P
0 g
s
.33116 .19833 m .32902 .20979 L .34744 .20776 L p .492 .282 .523 r
F P
0 g
s
.34744 .20776 m .34956 .19627 L .33116 .19833 L p .492 .282 .523 r
F P
0 g
s
.59883 .23575 m .60033 .24905 L .61953 .24714 L p .537 .519 .784 r
F P
0 g
s
.62201 .25989 m .61953 .24714 L .60033 .24905 L p .534 .576 .843 r
F P
0 g
s
.32865 .23575 m .33043 .24905 L .34883 .24714 L p .529 .516 .786 r
F P
0 g
s
.35181 .25989 m .34883 .24714 L .33043 .24905 L p .527 .575 .846 r
F P
0 g
s
.59915 .20979 m .59844 .22245 L .61766 .22046 L p .522 .385 .635 r
F P
0 g
s
.61766 .22046 m .61836 .20776 L .59915 .20979 L p .522 .385 .635 r
F P
0 g
s
.32902 .20979 m .32817 .22245 L .3466 .22046 L p .514 .376 .631 r
F P
0 g
s
.3466 .22046 m .34744 .20776 L .32902 .20979 L p .514 .376 .631 r
F P
0 g
s
.59844 .22245 m .59883 .23575 L .61805 .23379 L p .533 .457 .716 r
F P
0 g
s
.61953 .24714 m .61805 .23379 L .59883 .23575 L p .537 .519 .784 r
F P
0 g
s
.32817 .22245 m .32865 .23575 L .34707 .23379 L p .525 .452 .716 r
F P
0 g
s
.34883 .24714 m .34707 .23379 L .32865 .23575 L p .529 .516 .786 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .7082 .85514 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.74865 .87438 m .7082 .85514 L .70881 .87398 L p .948 .647 .432 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.75791 .87448 m .70139 .8749 L p .74865 .87438 L F P
0 g
s
.70559 .87438 m .70881 .87398 L .77017 .87438 L .012 .587 .719 r
F
.70996 .87384 m .71752 .87391 L p .70881 .87398 L F P
0 g
s
.71752 .87391 m .77017 .87438 L p .70881 .87398 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70305 .89315 m .74865 .87438 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70698 1.0175 m .70305 .89315 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.77017 1.02671 m .77017 .924 L p .73961 1.01195 L .96 .784 .62 r
F P
0 g
s
.72453 1.04899 m .77017 .924 L .75797 .92105 L .96 .784 .62 r
F
.71783 1.0746 m .72531 1.05309 L .72453 1.04899 L F
.72531 1.05309 m .77017 .924 L .72453 1.04899 L F
.77017 1.10042 m .77017 1.02671 L p .72769 1.06558 L F P
0 g
s
.71783 1.0746 m .7306 1.0809 L .72769 1.06558 L .96 .784 .62 r
F
.7306 1.0809 m .77017 1.10042 L .72769 1.06558 L F
.71431 1.00257 m .71493 .99856 L p .71524 1.00018 L 0 0 .367 r
F P
0 g
s
.73175 1.00816 m .70698 1.0175 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.71291 1.01526 m .73175 1.00816 L p .73026 1.00744 L .468 .815 .998 r
F P
0 g
s
.71524 1.00018 m .71468 1.00379 L .73026 1.00744 L .468 .815 .998 r
F
.71468 1.00379 m .71291 1.01526 L .73026 1.00744 L F
.70923 1.00251 m .71431 1.00257 L .71468 1.00379 L p .855 .518 .414 r
F P
0 g
s
.70305 .89315 m .74865 .87438 L .75038 .91922 L p .302 .134 .481 r
F P
0 g
s
.70305 .89315 m .75038 .91922 L .73963 .97056 L .302 .134 .481 r
F
.75038 .91922 m .74865 .87438 L p .73478 .91545 L .948 .647 .432 r
F P
0 g
s
.71559 .99868 m .71931 .98274 L .70996 .99764 L .96 .784 .62 r
F
.71172 1.01571 m .71291 1.01526 L p .71247 1.01268 L .468 .815 .998 r
F P
0 g
s
.7082 .85514 m .66253 .87438 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70881 .87398 m .7082 .85514 L p .70265 .87403 L .29 .123 .473 r
F P
0 g
s
.70559 .87438 m .66253 .87438 L .70881 .87398 L .012 .587 .719 r
F
.70139 .8749 m .65178 .87448 L p .70559 .87438 L F P
0 g
s
.65178 .87448 m .66253 .87438 L .70559 .87438 L .012 .587 .719 r
F
.66253 .87438 m .70305 .89315 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70305 .89315 m .70698 1.0175 L p .66253 .87438 L .946 .648 .442 r
F P
0 g
s
.64101 .924 m .64101 1.04449 L p .67409 .96263 L .333 .272 .638 r
F P
0 g
s
.70698 1.0175 m .68501 1.00816 L p .66253 .87438 L .946 .648 .442 r
F P
0 g
s
.66367 .91922 m .66253 .87438 L p .68501 1.00816 L .946 .648 .442 r
F P
0 g
s
.67409 .96263 m .69423 .91277 L .66367 .91922 L .333 .272 .638 r
F
.67409 .96263 m .66367 .91922 L .64101 .924 L F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.68665 1.06543 m .67644 1.04823 L .6578 1.04524 L F
.70345 1.05256 m .7046 1.04733 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .69229 1.1036 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.69229 1.1036 m .70996 1.10469 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .68565 1.08458 L .68 .398 .487 r
F P
0 g
s
.63981 1.07786 m .70996 1.10469 L .63901 1.04601 L .68 .398 .487 r
F
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52783 1.09787 m .51885 1.09818 L .516 1.09787 L .09 0 0 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.51434 1.25793 m .54175 1.25635 L .52667 1.25967 L F
.54175 1.25635 m .62917 1.25133 L .54517 1.25817 L F
.54175 1.25635 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.484 1.25967 m .51434 1.25793 L .52667 1.25967 L .365 .792 .97 r
F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.4813 1.25829 m .54018 1.25552 L .484 1.25967 L .365 .792 .97 r
F
.54018 1.25552 m .62917 1.25133 L .54175 1.25635 L F
.54018 1.25552 m .54175 1.25635 L .484 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.45621 1.25744 m .62917 1.25133 L .452 1.25967 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.452 1.25967 m .4813 1.25829 L .484 1.25967 L .365 .792 .97 r
F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62791 1.26039 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.26039 m .62917 1.25133 L p .62879 1.27211 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62791 1.26039 L .62879 1.27211 L 0 0 .059 r
F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.63104 1.30212 m .63096 1.3011 L .63567 1.3007 L .112 0 .073 r
F
.63085 1.29952 m .63258 1.29994 L p .63096 1.3011 L F P
0 g
s
.63258 1.29994 m .63567 1.3007 L p .63096 1.3011 L .112 0 .073 r
F P
0 g
s
.62882 1.30156 m .63088 1.30002 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .63088 1.30002 L .63091 1.30043 L 0 0 .059 r
F
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.63045 1.32905 m .63096 1.3011 L p .60369 1.32055 L .69 .689 .843 r
F P
0 g
s
.597 1.32532 m .60956 1.32672 L .60369 1.32055 L .69 .689 .843 r
F
.60956 1.32672 m .63045 1.32905 L .60369 1.32055 L F
.61632 1.32387 m .58611 1.31592 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.6289 1.29994 m .63045 1.26755 L .63096 1.29866 L 0 0 .059 r
F
.63132 1.29606 m .63567 1.3007 L .63258 1.29994 L p 0 .297 .787 r
F P
0 g
s
.63258 1.29994 m .63085 1.29952 L p .63096 1.29866 L 0 .297 .787 r
F P
0 g
s
.63096 1.29866 m .63132 1.29606 L .63258 1.29994 L 0 .297 .787 r
F
.63079 1.29994 m .63096 1.29866 L .63099 1.29994 L 0 0 .059 r
F
.6289 1.29994 m .63096 1.29866 L .63079 1.29994 L F
.63096 1.29866 m .63045 1.26755 L .61177 1.26755 L p .693 .453 .555 r
F P
0 g
s
.61177 1.26755 m .59178 1.26755 L p .60369 1.27701 L .693 .453 .555 r
F P
0 g
s
.60369 1.27701 m .63096 1.29866 L .61177 1.26755 L .693 .453 .555 r
F
.60521 1.29321 m .60519 1.2932 L p .60522 1.29321 L 0 .297 .787 r
F P
0 g
s
.60522 1.29321 m .63132 1.29606 L .60521 1.29321 L 0 .297 .787 r
F
.63085 1.29952 m .60521 1.29321 L p .63132 1.29606 L F P
0 g
s
.624 1.29783 m .63085 1.29952 L p .63001 1.29982 L .112 0 .073 r
F P
0 g
s
.58611 1.31592 m .624 1.29783 L .63001 1.29982 L .112 0 .073 r
F
.58611 1.31592 m .60519 1.2932 L .624 1.29783 L p F P
0 g
s
.58611 1.31592 m .63085 1.29952 L .63104 1.30212 L .112 0 .073 r
F
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.43349 1.2932 m .41389 1.27286 L .42955 1.27701 L p 0 .267 .761 r
F P
0 g
s
.43349 1.2932 m .42955 1.27701 L .43846 1.28421 L 0 .267 .761 r
F
.56692 1.29558 m .58611 1.31592 L .60519 1.2932 L p .855 .698 .687 r
F P
0 g
s
.56692 1.29558 m .58611 1.31592 L .60369 1.32055 L p 0 .289 .78 r
F P
0 g
s
.56692 1.29558 m .60369 1.32055 L .59556 1.31198 L 0 .289 .78 r
F
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.45793 1.29994 m .43349 1.2932 L p .43846 1.28421 L 0 .267 .761 r
F P
0 g
s
.41389 1.31592 m .43349 1.2932 L .45793 1.29994 L p .076 0 .035 r
F P
0 g
s
.44611 1.30853 m .597 1.32532 L .45793 1.29994 L .69 .689 .843 r
F
.45793 1.29994 m .46069 1.3007 L p .45381 1.30294 L .076 0 .035 r
F P
0 g
s
.41389 1.31592 m .45793 1.29994 L .45381 1.30294 L .076 0 .035 r
F
.58412 1.29994 m .56692 1.29558 L p .59556 1.31198 L 0 .289 .78 r
F P
0 g
s
.58412 1.29994 m .597 1.32532 L .60357 1.32042 L .69 .689 .843 r
F
.63099 1.29994 m .58412 1.29994 L p .60357 1.32042 L F P
0 g
s
.63088 1.30002 m .63099 1.29994 L p .63091 1.30043 L 0 0 .059 r
F P
0 g
s
.63096 1.3011 m .63099 1.29994 L p .597 1.32532 L .69 .689 .843 r
F P
0 g
s
.61632 1.32387 m .59685 1.30317 L .58412 1.29994 L p 0 .289 .78 r
F P
0 g
s
.59556 1.31198 m .61632 1.32387 L .58412 1.29994 L 0 .289 .78 r
F
.60519 1.2932 m .58611 1.27286 L .56692 1.29558 L p .855 .698 .687 r
F P
0 g
s
.53645 1.09918 m .47146 1.10147 L .4687 1.10147 L .09 0 0 r
F
.53616 1.09921 m .47166 1.10147 L .53645 1.09918 L F
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L F P
0 g
s
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L F
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L F
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.29653 1.043 m .29225 1.04601 L .36099 1.04601 L p F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36099 1.04601 m .29225 1.04601 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36032 1.07254 m .29225 1.04601 L .35951 1.10469 L .68 .398 .487 r
F
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.3605 1.10246 m .35851 1.02865 L .3605 .95121 L p .767 .626 .063 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44284 1.10469 m .36099 1.04601 L .36032 1.07254 L .68 .398 .487 r
F
.3605 1.04653 m .3605 .95121 L .36159 1.02223 L .767 .626 .063 r
F
.36099 1.04601 m .36159 1.02223 L .36194 1.04502 L F
.3605 1.04653 m .36159 1.02223 L .36099 1.04601 L F
.35951 1.10469 m .44284 1.10469 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L F P
0 g
s
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.35899 .98856 m .35899 .87438 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.29225 1.04601 m .29004 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.32488 1.04601 m .35899 .98856 L .30737 1.04679 L F
.29004 1.10469 m .35951 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .47146 1.10147 L .09 0 0 r
F
.47166 1.10147 m .47146 1.10147 L .53645 1.09918 L F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L .09 0 0 r
F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L F P
0 g
s
.55676 1.10246 m .44324 1.10246 L p .53019 1.09942 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L .09 0 0 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.516 1.09787 m .46368 1.10009 L .484 1.09787 L F
.51885 1.09818 m .46368 1.10009 L .516 1.09787 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.47146 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.55566 1.09853 m .53616 1.09921 L .53645 1.09918 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.59496 1.09076 m .61173 1.08458 L .57144 1.08458 L .676 .72 .882 r
F
.6395 1.10246 m .61173 1.08458 L .59496 1.09076 L F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .66674 1.01586 L .64101 1.04449 L .333 .272 .638 r
F
.66674 1.01586 m .69838 .9119 L .65042 1.02274 L F
.66674 1.01586 m .65042 1.02274 L .64101 1.04449 L F
.68501 1.00816 m .70698 1.0175 L p .70923 1.00251 L .468 .815 .998 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 1.03682 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70186 .99895 m .70923 1.00251 L p .70227 1.00088 L .872 .62 .556 r
F P
0 g
s
.71431 1.00257 m .71493 .99856 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70923 1.00251 m .71431 1.00257 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70996 .99764 m .70963 .99983 L .71493 .99856 L .593 .916 .975 r
F
.71084 1.00289 m .71172 1.01571 L .71247 1.01268 L .468 .815 .998 r
F
.70996 .99764 m .71047 1.0028 L .71084 1.00289 L F
.71047 1.0028 m .71172 1.01571 L .71084 1.00289 L F
.70698 1.0175 m .71172 1.01571 L p .70996 .99764 L F P
0 g
s
.71431 1.00257 m .71524 1.00018 L .7147 1.00367 L 0 0 .367 r
F
.71797 1.01454 m .71431 1.00257 L p .7173 1.011 L F P
0 g
s
.70996 .99764 m .71291 1.01526 L .71524 1.00018 L .468 .815 .998 r
F
.70923 1.00251 m .71468 1.00379 L .71441 1.00485 L .855 .518 .414 r
F
.70923 1.00251 m .71439 1.005 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.7147 1.00367 m .71524 1.00018 L .7173 1.011 L 0 0 .367 r
F
.73321 1.01578 m .73666 1.00258 L .70996 .99764 L .96 .784 .62 r
F
.75797 .92105 m .74849 .91876 L .70996 .99764 L F
.70881 .87398 m .70996 .90945 L p .74865 .87438 L .948 .647 .432 r
F P
0 g
s
.70996 .99764 m .74849 .91876 L .7394 .91657 L .96 .784 .62 r
F
.71004 .99631 m .7394 .91657 L .71465 .91059 L F
.70996 .99764 m .7394 .91657 L .71004 .99631 L F
.70227 1.00088 m .68501 1.00816 L .70923 1.00251 L .468 .815 .998 r
F
.6578 1.04524 m .70996 1.03682 L .70265 1.00262 L .333 .272 .638 r
F
.71493 .99856 m .71547 .99502 L p .71 .99738 L .593 .916 .975 r
F P
0 g
s
.71547 .99502 m .7155 .99487 L .71 .99738 L p .593 .916 .975 r
F P
0 g
s
.71 .99738 m .70996 .99764 L .71493 .99856 L .593 .916 .975 r
F
.73666 1.00258 m .71931 .98274 L .71559 .99868 L .96 .784 .62 r
F
.73666 1.00258 m .75797 .92105 L .71931 .98274 L F
.75352 .99995 m .73515 .99192 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.75352 .99995 m .73175 1.00816 L p .73369 .9989 L .302 .134 .481 r
F P
0 g
s
.75352 .99995 m .73505 .99188 L p .71558 .99794 L .468 .815 .998 r
F P
0 g
s
.71587 .99609 m .71558 .99794 L .73505 .99188 L .468 .815 .998 r
F
.71493 .99856 m .7155 .99487 L p .71573 .99699 L 0 0 .367 r
F P
0 g
s
.71493 .99856 m .71573 .99699 L .71543 .99894 L 0 0 .367 r
F
.73175 1.00816 m .75352 .99995 L p .71558 .99794 L .468 .815 .998 r
F P
0 g
s
.71493 .99856 m .71543 .99894 L .71524 1.00018 L 0 0 .367 r
F
.70996 .99764 m .71524 1.00018 L .71558 .99794 L .468 .815 .998 r
F
.71524 1.00018 m .73175 1.00816 L .71558 .99794 L F
.71524 1.00018 m .716 .99938 L .71559 1.00203 L 0 0 .367 r
F
.71543 .99894 m .716 .99938 L .71524 1.00018 L F
.71543 .99894 m .71573 .99699 L .716 .99938 L F
.7155 .99487 m .71 .99738 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.71233 .98195 m .70996 .99764 L .71558 .99794 L .468 .815 .998 r
F
.7155 .99487 m .71587 .99609 L p .71573 .99699 L 0 0 .367 r
F P
0 g
s
.71769 .98429 m .71233 .98195 L p .71524 .99623 L .468 .815 .998 r
F P
0 g
s
.71524 .99623 m .71558 .99794 L .71587 .99609 L .468 .815 .998 r
F
.71587 .99609 m .7155 .99487 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.71524 .99623 m .71587 .99609 L .71769 .98429 L .468 .815 .998 r
F
.728 1.03569 m .73321 1.01578 L .71835 1.00418 L .96 .784 .62 r
F
.71555 .99746 m .71171 .99741 L .71439 1.005 L .327 .684 .979 r
F
.66243 1.03003 m .70265 1.00262 L .70227 1.00088 L .333 .272 .638 r
F
.66243 1.03003 m .70227 1.00088 L .6843 .95815 L F
.6578 1.04524 m .70265 1.00262 L .66243 1.03003 L F
.6843 .95815 m .70227 1.00088 L .68949 .94112 L F
.74865 .87438 m .70996 .90945 L .73478 .91545 L .948 .647 .432 r
F
.70996 .90945 m .70996 .99557 L p .71632 .87956 L .96 .784 .62 r
F P
0 g
s
.70996 .99557 m .70996 .99764 L p .71012 .99473 L .96 .784 .62 r
F P
0 g
s
.71012 .99473 m .71632 .87956 L .70996 .99557 L .96 .784 .62 r
F
.70996 .90945 m .70881 .87398 L p .69564 .91248 L .29 .123 .473 r
F P
0 g
s
.70996 .99764 m .70996 .90945 L p .70186 .99895 L .333 .272 .638 r
F P
0 g
s
.70996 .90945 m .70996 .87384 L p .70763 .90995 L .333 .272 .638 r
F P
0 g
s
.70186 .99895 m .70996 .90945 L .70763 .90995 L .333 .272 .638 r
F
.71 .99738 m .70959 .99757 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.68949 .94112 m .70186 .99895 L .70996 .87384 L .333 .272 .638 r
F
.6989 .99752 m .70186 .99895 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.71 .99738 m .6989 .99752 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.70186 .99895 m .70923 1.00251 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.70186 .99895 m .70227 1.00088 L .70996 .99764 L .333 .272 .638 r
F
.70202 1.00082 m .68501 1.00816 L .70227 1.00088 L .468 .815 .998 r
F
.6989 .99752 m .70186 .99895 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.70186 .99895 m .70227 1.00088 L .69878 1.00006 L .872 .62 .556 r
F
.69216 1.0013 m .68501 1.00816 L .70202 1.00082 L .468 .815 .998 r
F
.6983 .99995 m .6989 .99752 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.6983 .99995 m .70202 1.00082 L .71 .99738 L .468 .815 .998 r
F
.69216 1.0013 m .70202 1.00082 L .6983 .99995 L F
.68565 1.08458 m .70996 1.10469 L .69803 1.08458 L .68 .398 .487 r
F
.68565 1.08458 m .69803 1.08458 L .67512 1.04601 L F
.68665 1.06543 m .70345 1.05256 L .67644 1.04823 L .333 .272 .638 r
F
.69488 1.08618 m .67916 1.07879 L .6983 .99995 L p .872 .62 .556 r
F P
0 g
s
.69878 1.00006 m .69488 1.08618 L .6983 .99995 L .872 .62 .556 r
F
.71439 1.005 m .70503 1.04397 L p .69878 1.00006 L F P
0 g
s
.70923 1.00251 m .71439 1.005 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.71439 1.005 m .71441 1.00485 L p .71013 1.02208 L .731 .724 .198 r
F P
0 g
s
.70996 1.10469 m .728 1.03569 L .71798 1.01454 L .96 .784 .62 r
F
.71441 1.00485 m .71094 1.0186 L .71013 1.02208 L .731 .724 .198 r
F
.70845 1.02973 m .71439 1.005 L p .71013 1.02208 L F P
0 g
s
.71013 1.02208 m .70996 1.02279 L .70845 1.02973 L .731 .724 .198 r
F
.70996 1.10469 m .71798 1.01454 L .71094 1.0186 L .96 .784 .62 r
F
.70996 1.01917 m .70996 1.02279 L p .71094 1.0186 L F P
0 g
s
.70996 1.02279 m .70996 1.10469 L p .71094 1.0186 L .96 .784 .62 r
F P
0 g
s
.71238 1.01291 m .70923 1.00251 L .71266 1.01181 L .855 .518 .414 r
F
.70293 1.00243 m .70923 1.00251 L p .71238 1.01291 L F P
0 g
s
.70293 1.00243 m .71238 1.01291 L .71049 1.02041 L .855 .518 .414 r
F
.71013 1.02208 m .71056 1.02012 L .71005 1.02242 L .731 .724 .198 r
F
.71432 1.00481 m .71426 1.00478 L .71439 1.005 L .327 .684 .979 r
F
.70923 1.00251 m .71441 1.00485 L .71266 1.01181 L .855 .518 .414 r
F
.71088 1.01864 m .71094 1.0186 L .71093 1.01841 L .96 .784 .62 r
F
.71088 1.01864 m .71093 1.01841 L .70996 .99764 L F
.70996 .99764 m .70996 1.01917 L p .71088 1.01864 L F P
0 g
s
.71094 1.0186 m .7139 1.00593 L .70996 .99764 L .96 .784 .62 r
F
.7151 1.00516 m .71797 1.01454 L p .71266 1.01181 L .855 .518 .414 r
F P
0 g
s
.71441 1.00485 m .7151 1.00516 L .71266 1.01181 L .855 .518 .414 r
F
.71248 .9996 m .70996 .99764 L .71426 1.00478 L .327 .684 .979 r
F
.71248 .9996 m .71426 1.00478 L .71432 1.00481 L F
.71441 1.00485 m .71493 1.00151 L p .71094 1.0186 L .731 .724 .198 r
F P
0 g
s
.71468 1.00379 m .7151 1.00516 L p .71441 1.00485 L .855 .518 .414 r
F P
0 g
s
.71798 1.01454 m .71835 1.00418 L .70996 .99764 L .96 .784 .62 r
F
.72098 1.02088 m .71981 1.01348 L .71798 1.01454 L F
.71981 1.01348 m .71835 1.00418 L .71798 1.01454 L F
.71783 1.0746 m .77017 1.02671 L .73961 1.01195 L F
.71797 1.01454 m .73912 1.08369 L p .71442 1.01659 L .855 .518 .414 r
F P
0 g
s
.71266 1.01181 m .71797 1.01454 L .71442 1.01659 L .855 .518 .414 r
F
.70996 .99764 m .70227 1.00088 L .70923 1.00251 L .468 .815 .998 r
F
.7096 .99789 m .70516 1.00091 L .70963 .99983 L .593 .916 .975 r
F
.71 .99738 m .70202 1.00082 L .70996 .99764 L .468 .815 .998 r
F
.70959 .99757 m .7096 .99789 L .70996 .99764 L .593 .916 .975 r
F
.7096 .99789 m .70963 .99983 L .70996 .99764 L F
.70227 1.00088 m .70265 1.00262 L .70996 .99764 L .333 .272 .638 r
F
.69878 1.00006 m .70503 1.04397 L .69622 1.05672 L .872 .62 .556 r
F
.69904 1.00239 m .70923 1.00251 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70996 1.03682 m .70996 1.01917 L p .70265 1.00262 L .333 .272 .638 r
F P
0 g
s
.70503 1.04397 m .69488 1.08618 L p .69622 1.05672 L .872 .62 .556 r
F P
0 g
s
.71005 1.02242 m .69598 1.07885 L .70721 1.03459 L .731 .724 .198 r
F
.70996 1.02279 m .70721 1.03459 L .70845 1.02973 L F
.71005 1.02242 m .70721 1.03459 L .70996 1.02279 L F
.69598 1.07885 m .69488 1.08618 L .70845 1.02973 L p F P
0 g
s
.71005 1.02242 m .71049 1.02041 L .69598 1.07885 L .731 .724 .198 r
F
.70778 1.03115 m .69904 1.00239 L p .70962 1.02384 L .855 .518 .414 r
F P
0 g
s
.70996 1.01917 m .70996 .99764 L p .70293 1.00243 L .333 .272 .638 r
F P
0 g
s
.70265 1.00262 m .70996 1.01917 L .70293 1.00243 L .333 .272 .638 r
F
.70077 1.05893 m .69598 1.07885 L p .71049 1.02041 L .731 .724 .198 r
F P
0 g
s
.71554 .99753 m .71229 .99848 L .71464 1.00142 L .482 .308 .568 r
F
.71561 .99615 m .71225 .99741 L .71555 .99746 L F
.71 .99738 m .70959 .99757 L p .70996 .99764 L .593 .916 .975 r
F P
0 g
s
.71169 .99736 m .70996 .99764 L .71248 .9996 L .327 .684 .979 r
F
.70959 .99757 m .70942 .99848 L .71225 .99741 L .482 .308 .568 r
F
.71037 .99739 m .71225 .99741 L .71561 .99615 L F
.71143 .9974 m .71 .99738 L .70996 .99764 L .327 .684 .979 r
F
.70959 .99757 m .71225 .99741 L .71037 .99739 L .482 .308 .568 r
F
.71169 .99736 m .71 .99738 L p .71143 .9974 L .327 .684 .979 r
F P
0 g
s
.71558 .99731 m .71171 .99741 L .71555 .99746 L .327 .684 .979 r
F
.70202 1.00082 m .70227 1.00088 L .70996 .99764 L .468 .815 .998 r
F
.70959 .99757 m .69904 1.00239 L p .70516 1.00091 L .593 .916 .975 r
F P
0 g
s
.70959 .99757 m .70516 1.00091 L .7096 .99789 L .593 .916 .975 r
F
.71225 .99741 m .69904 1.00239 L .71554 .99753 L .482 .308 .568 r
F
.71555 .99746 m .71554 .99753 L .71574 .99747 L F
.71225 .99741 m .71554 .99753 L .71555 .99746 L F
.71493 1.00151 m .71555 .99746 L p .71058 1.02003 L .731 .724 .198 r
F P
0 g
s
.71555 .99746 m .71558 .99731 L p .71534 .99836 L .731 .724 .198 r
F P
0 g
s
.71555 .99746 m .71534 .99836 L .71058 1.02003 L .731 .724 .198 r
F
.71094 1.0186 m .71058 1.02003 L .71013 1.02208 L F
.71493 1.00151 m .71058 1.02003 L .71094 1.0186 L F
.69904 1.00239 m .70293 1.00243 L p .71049 1.02041 L .855 .518 .414 r
F P
0 g
s
.71056 1.02012 m .71049 1.02041 L .71005 1.02242 L .731 .724 .198 r
F
.71013 1.02208 m .71058 1.02003 L .71056 1.02012 L F
.71013 1.02208 m .71005 1.02242 L .70996 1.02279 L F
.70962 1.02384 m .71049 1.02041 L .72536 1.05577 L .855 .518 .414 r
F
.69904 1.00239 m .71049 1.02041 L .70962 1.02384 L F
.69904 1.00239 m .70778 1.03115 L p .71464 1.00142 L .482 .308 .568 r
F P
0 g
s
.71229 .99848 m .69904 1.00239 L .71464 1.00142 L .482 .308 .568 r
F
.71515 .99908 m .70077 1.05893 L p .71049 1.02041 L .731 .724 .198 r
F P
0 g
s
.71155 1.10458 m .77017 1.10042 L p .71783 1.0746 L .96 .784 .62 r
F P
0 g
s
.72375 1.08378 m .70778 1.03115 L p .72536 1.05577 L .855 .518 .414 r
F P
0 g
s
.70962 1.02384 m .72536 1.05577 L .70778 1.03115 L .855 .518 .414 r
F
.73912 1.08369 m .73711 1.0837 L p .72536 1.05577 L F P
0 g
s
.73711 1.0837 m .72375 1.08378 L p .72536 1.05577 L .855 .518 .414 r
F P
0 g
s
.71049 1.02041 m .71238 1.01291 L .72536 1.05577 L .855 .518 .414 r
F
.71363 1.01705 m .71238 1.01291 L .71389 1.0169 L F
.71238 1.01291 m .71266 1.01181 L .73912 1.08369 L F
.71094 1.0186 m .71798 1.01454 L .7139 1.00593 L .96 .784 .62 r
F
.72536 1.05577 m .71363 1.01705 L .73912 1.08369 L .855 .518 .414 r
F
.71363 1.01705 m .71389 1.0169 L .73912 1.08369 L F
.71559 1.00203 m .71582 1.00051 L .71635 1.00602 L 0 0 .367 r
F
.71582 1.00051 m .716 .99938 L .71635 1.00602 L F
.71635 1.00602 m .716 .99938 L .7173 1.011 L F
.71574 .99747 m .71554 .99753 L .72375 1.08378 L .482 .308 .568 r
F
.71056 1.02012 m .71466 1.00133 L .71049 1.02041 L .731 .724 .198 r
F
.71466 1.00133 m .71464 1.00142 L .71049 1.02041 L F
.71056 1.02012 m .71534 .99836 L .71466 1.00133 L F
.71058 1.02003 m .71534 .99836 L .71056 1.02012 L F
.70778 1.03115 m .72375 1.08378 L p .71554 .99753 L .482 .308 .568 r
F P
0 g
s
.71466 1.00133 m .71515 .99908 L .71464 1.00142 L .731 .724 .198 r
F
.70959 .99757 m .69904 1.00239 L p .70942 .99848 L .482 .308 .568 r
F P
0 g
s
.71 .99738 m .70964 .99738 L p .70961 .99747 L .439 .19 .439 r
F P
0 g
s
.6989 .99752 m .67916 1.07879 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.70964 .99738 m .6989 .99752 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.71233 .98195 m .69216 1.0013 L .71 .99738 L .468 .815 .998 r
F
.71 .99738 m .70961 .99747 L .70957 .99757 L .439 .19 .439 r
F
.728 1.03569 m .7227 1.01839 L .72098 1.02088 L .96 .784 .62 r
F
.7227 1.01839 m .71835 1.00418 L .72098 1.02088 L F
.7173 1.011 m .71573 .99699 L .74046 1.07635 L 0 0 .367 r
F
.71587 .99609 m .74046 1.07635 L p .71573 .99699 L F P
0 g
s
.74046 1.07635 m .73912 1.08369 L .71797 1.01454 L p 0 0 .367 r
F P
0 g
s
.7173 1.011 m .74046 1.07635 L .71797 1.01454 L 0 0 .367 r
F
.72375 1.08378 m .74046 1.07635 L .71587 .99609 L p .482 .308 .568 r
F P
0 g
s
.71561 .99615 m .72375 1.08378 L .71587 .99609 L .482 .308 .568 r
F
.71568 .9969 m .71555 .99746 L .71574 .99747 L F
.71561 .99615 m .71555 .99746 L .71568 .9969 L F
.71558 .99731 m .71515 .99908 L p .71466 1.00133 L .731 .724 .198 r
F P
0 g
s
.71534 .99836 m .71558 .99731 L .71466 1.00133 L .731 .724 .198 r
F
.71558 .99731 m .71169 .99736 L p .71171 .99741 L .327 .684 .979 r
F P
0 g
s
.73505 .99188 m .71769 .98429 L p .71587 .99609 L .468 .815 .998 r
F P
0 g
s
.71558 .99731 m .71 .99738 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.71 .99738 m .70957 .99757 L .68203 1.07235 L .439 .19 .439 r
F
.70996 .90945 m .71233 .98195 L p .73478 .91545 L .948 .647 .432 r
F P
0 g
s
.71465 .91059 m .75197 .91164 L .71632 .87956 L .96 .784 .62 r
F
.74849 .91876 m .75197 .91164 L .71465 .91059 L F
.70996 .87384 m .70996 .90945 L p .71632 .87956 L F P
0 g
s
.69838 .9119 m .69423 .91277 L .64101 1.04449 L .333 .272 .638 r
F
.68501 1.00816 m .66572 .99995 L .66367 .91922 L p .946 .648 .442 r
F P
0 g
s
.66572 .99995 m .69296 .98943 L p .70996 .90945 L .29 .123 .473 r
F P
0 g
s
.69296 .98943 m .71233 .98195 L .70996 .90945 L p .29 .123 .473 r
F P
0 g
s
.71233 .98195 m .66572 .99995 L .68501 1.00816 L p .468 .815 .998 r
F P
0 g
s
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .61173 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.45793 1.29994 m .58412 1.29994 L p .43102 1.27533 L .693 .453 .555 r
F P
0 g
s
.42955 1.27701 m .45793 1.29994 L .43102 1.27533 L .693 .453 .555 r
F
.39417 1.29558 m .41389 1.31592 L .43349 1.2932 L p .851 .695 .688 r
F P
0 g
s
.44611 1.30853 m .42955 1.32055 L .63045 1.32905 L .69 .689 .843 r
F
.41785 1.32905 m .43784 1.32905 L p .42955 1.32055 L F P
0 g
s
.43784 1.32905 m .63045 1.32905 L p .42955 1.32055 L .69 .689 .843 r
F P
0 g
s
.42955 1.32055 m .41389 1.31592 L p .45381 1.30294 L .076 0 .035 r
F P
0 g
s
.39417 1.29558 m .41389 1.31592 L .42955 1.32055 L p 0 .258 .754 r
F P
0 g
s
.46069 1.3007 m .4408 1.32387 L .42955 1.32055 L p .076 0 .035 r
F P
0 g
s
.45381 1.30294 m .46069 1.3007 L .42955 1.32055 L .076 0 .035 r
F
.39417 1.29558 m .42955 1.32055 L .42121 1.31198 L 0 .258 .754 r
F
.36901 1.29994 m .41785 1.32905 L .42955 1.32055 L .69 .689 .843 r
F
.4144 1.305 m .42955 1.32055 L .44611 1.30853 L F
.40947 1.29994 m .39417 1.29558 L p .42121 1.31198 L 0 .258 .754 r
F P
0 g
s
.36901 1.29994 m .42955 1.32055 L .4144 1.305 L .69 .689 .843 r
F
.40412 1.30385 m .44611 1.30853 L .40947 1.29994 L F
.4408 1.32387 m .42079 1.30317 L .40947 1.29994 L p 0 .258 .754 r
F P
0 g
s
.42121 1.31198 m .4408 1.32387 L .40947 1.29994 L 0 .258 .754 r
F
.42955 1.32055 m .4408 1.32387 L p .42121 1.31198 L F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .41785 1.32905 L p .69 .689 .843 r
F P
0 g
s
.45793 1.29994 m .40947 1.29994 L p .44611 1.30853 L .69 .689 .843 r
F P
0 g
s
.40947 1.29994 m .36901 1.29994 L p .40412 1.30385 L .69 .689 .843 r
F P
0 g
s
.43349 1.2932 m .41389 1.27286 L .39417 1.29558 L p .851 .695 .688 r
F P
0 g
s
.42955 1.27701 m .41389 1.27286 L p .41787 1.29035 L .065 0 .024 r
F P
0 g
s
.41389 1.27286 m .39417 1.29558 L .40947 1.29994 L p .065 0 .024 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .40947 1.29994 L p .693 .453 .555 r
F P
0 g
s
.40947 1.29994 m .45793 1.29994 L p .42125 1.2865 L .693 .453 .555 r
F P
0 g
s
.41389 1.27286 m .40947 1.29994 L .41787 1.29035 L .065 0 .024 r
F
.36955 1.26755 m .40947 1.29994 L .42125 1.2865 L .693 .453 .555 r
F
.40947 1.29994 m .42079 1.30317 L p .41787 1.29035 L .065 0 .024 r
F P
0 g
s
.36955 1.26755 m .45793 1.29994 L .42659 1.27462 L .693 .453 .555 r
F
.42955 1.27701 m .4408 1.27999 L p .43846 1.28421 L 0 .267 .761 r
F P
0 g
s
.42079 1.30317 m .4408 1.27999 L .43788 1.27922 L p .065 0 .024 r
F P
0 g
s
.43788 1.27922 m .42955 1.27701 L p .42588 1.28797 L .065 0 .024 r
F P
0 g
s
.42588 1.28797 m .42079 1.30317 L .43788 1.27922 L .065 0 .024 r
F
.41787 1.29035 m .42079 1.30317 L .42955 1.27701 L F
.42659 1.27462 m .42955 1.27701 L .43102 1.27533 L .693 .453 .555 r
F
.58412 1.29994 m .63099 1.29994 L p .5886 1.29469 L F P
0 g
s
.58611 1.27286 m .56692 1.29558 L .58412 1.29994 L p .102 0 .063 r
F P
0 g
s
.58611 1.27286 m .58412 1.29994 L .59231 1.29035 L .102 0 .063 r
F
.42659 1.27462 m .58412 1.29994 L .5886 1.29469 L .693 .453 .555 r
F
.63099 1.29994 m .63096 1.29866 L p .42619 1.27429 L F P
0 g
s
.42659 1.27462 m .63099 1.29994 L .42619 1.27429 L .693 .453 .555 r
F
.60519 1.2932 m .58611 1.27286 L .61632 1.27999 L p 0 .297 .787 r
F P
0 g
s
.60369 1.27701 m .58611 1.27286 L p .59231 1.29035 L .102 0 .063 r
F P
0 g
s
.61632 1.27999 m .63132 1.29606 L p .60519 1.2932 L 0 .297 .787 r
F P
0 g
s
.59178 1.26755 m .36955 1.26755 L p .63096 1.29866 L .693 .453 .555 r
F P
0 g
s
.58412 1.29994 m .59685 1.30317 L p .59231 1.29035 L .102 0 .063 r
F P
0 g
s
.59685 1.30317 m .61632 1.27999 L .61303 1.27922 L p .102 0 .063 r
F P
0 g
s
.61303 1.27922 m .60369 1.27701 L p .60083 1.28797 L .102 0 .063 r
F P
0 g
s
.60083 1.28797 m .59685 1.30317 L .61303 1.27922 L .102 0 .063 r
F
.58412 1.29994 m .45793 1.29994 L p .55851 1.3183 L .69 .689 .843 r
F P
0 g
s
.55851 1.3183 m .597 1.32532 L .58412 1.29994 L .69 .689 .843 r
F
.4408 1.27999 m .46069 1.3007 L .45793 1.29994 L p 0 .267 .761 r
F P
0 g
s
.43846 1.28421 m .4408 1.27999 L .45793 1.29994 L 0 .267 .761 r
F
.36955 1.26755 m .42659 1.27462 L .42619 1.27429 L .693 .453 .555 r
F
.59231 1.29035 m .59685 1.30317 L .60369 1.27701 L .102 0 .063 r
F
.60369 1.32055 m .61632 1.32387 L p .59556 1.31198 L 0 .289 .78 r
F P
0 g
s
.63567 1.3007 m .63132 1.3059 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.63132 1.3059 m .61632 1.32387 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70345 1.05256 m .70996 1.04757 L .7046 1.04733 L .333 .272 .638 r
F
.70265 .87403 m .66572 .99995 L .70881 .87398 L .29 .123 .473 r
F
.69838 .9119 m .70996 .87384 L .69423 .91277 L .333 .272 .638 r
F
.66253 .87438 m .66367 .91922 L p .70265 .87403 L .29 .123 .473 r
F P
0 g
s
.66367 .91922 m .66572 .99995 L p .6911 .91343 L .29 .123 .473 r
F P
0 g
s
.70265 .87403 m .66367 .91922 L .6911 .91343 L .29 .123 .473 r
F
.7082 .85514 m .66253 .87438 L p .70265 .87403 L F P
0 g
s
.65178 .87448 m .64101 .87438 L p .66253 .87438 L .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .70996 .87384 L p .70881 .87398 L .012 .587 .719 r
F P
0 g
s
.66253 .87438 m .64101 .87438 L .70881 .87398 L .012 .587 .719 r
F
.75797 .92105 m .77017 .87438 L .74849 .91876 L .96 .784 .62 r
F
.75038 .91922 m .75352 .99995 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.77017 .87438 m .75791 .87448 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .7598 .87429 L p .75197 .91164 L .96 .784 .62 r
F P
0 g
s
.7598 .87429 m .70996 .87384 L p .75197 .91164 L .96 .784 .62 r
F P
0 g
s
.77017 .924 m .77017 .87438 L p .75797 .92105 L .96 .784 .62 r
F P
0 g
s
.71233 .98195 m .75352 .99995 L .75038 .91922 L p .948 .647 .432 r
F P
0 g
s
.73478 .91545 m .71233 .98195 L .75038 .91922 L .948 .647 .432 r
F
.70996 1.10469 m .71155 1.10458 L p .71783 1.0746 L .96 .784 .62 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 .924 L p .333 .272 .638 r
F P
0 g
s
.69423 .91277 m .70996 .87384 L .64101 .924 L .333 .272 .638 r
F
.69564 .91248 m .66572 .99995 L .70996 .90945 L .29 .123 .473 r
F
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.34707 .23379 m .3466 .22046 L .32817 .22245 L p .525 .452 .716 r
F P
0 g
s
.33879 .36823 m .33879 .18543 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.38103 .36782 m .36908 .36794 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.36908 .36794 m .33879 .36823 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.37555 .2036 m .36908 .20184 L .36908 .20039 L 1 .816 .504 r
F
.37594 .17624 m .37643 .19026 L .37555 .2036 L p F P
0 g
s
.37555 .2036 m .37643 .19026 L .39599 .18806 L p .504 .366 .627 r
F P
0 g
s
.37643 .19026 m .37594 .17624 L .39551 .17399 L p .517 .446 .715 r
F P
0 g
s
.39551 .17399 m .39599 .18806 L .37643 .19026 L p .517 .446 .715 r
F P
0 g
s
.37411 .16211 m .37594 .17624 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.37102 .14847 m .37411 .16211 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.39599 .18806 m .39512 .20144 L .37555 .2036 L p .504 .366 .627 r
F P
0 g
s
.37335 .2157 m .37555 .2036 L .39512 .20144 L p .481 .268 .513 r
F P
0 g
s
.38103 .36782 m .38103 .22264 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.38103 .22264 m .38103 .22103 L p .38136 .22276 L .241 .197 .606 r
F P
0 g
s
.38136 .22276 m .3887 .2607 L .38103 .22264 L .241 .197 .606 r
F
.38729 .2255 m .3887 .23471 L .38217 .22306 L F
.38729 .2255 m .38217 .22306 L .38572 .22438 L F
.3887 .23471 m .3887 .2607 L .38103 .22103 L F
.38572 .22438 m .38954 .22398 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.37355 .21568 m .39275 .2136 L p .38022 .22045 L .44 .142 .361 r
F P
0 g
s
.3918 .2142 m .38025 .22047 L .39275 .2136 L .44 .142 .361 r
F
.38025 .22047 m .36992 .22607 L .38022 .22045 L F
.38025 .22047 m .38022 .22045 L .39275 .2136 L F
.39512 .20144 m .39299 .21334 L p .37335 .2157 L .481 .268 .513 r
F P
0 g
s
.39299 .21334 m .39294 .21358 L .39275 .2136 L p .481 .268 .513 r
F P
0 g
s
.39275 .2136 m .37335 .2157 L p .39299 .21334 L .481 .268 .513 r
F P
0 g
s
.37582 .22479 m .37746 .22412 L .37685 .23084 L .686 .56 .707 r
F
.36908 .22759 m .36992 .22607 L .37371 .22567 L p .369 0 .15 r
F P
0 g
s
.36992 .22607 m .37335 .2157 L .37355 .21568 L p .44 .142 .361 r
F P
0 g
s
.38022 .22045 m .36992 .22607 L .37355 .21568 L .44 .142 .361 r
F
.33879 .18543 m .36908 .18504 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.33561 .10515 m .34231 .10584 L p .36927 .18512 L 1 .816 .504 r
F P
0 g
s
.33879 .18543 m .36908 .18504 L p .30025 .16878 L .289 .763 .934 r
F P
0 g
s
.30025 .16878 m .36908 .18504 L .35855 .1804 L .289 .763 .934 r
F
.37555 .2036 m .3678 .18447 L .36927 .18512 L 1 .816 .504 r
F
.3678 .18447 m .33561 .10515 L .36927 .18512 L F
.37555 .2036 m .36908 .15364 L .37102 .14847 L F
.36155 .12489 m .36677 .13589 L p .37339 .18694 L F P
0 g
s
.37555 .2036 m .37252 .18656 L .37339 .18694 L 1 .816 .504 r
F
.37252 .18656 m .36155 .12489 L .37339 .18694 L F
.37594 .17624 m .37411 .16211 L .3937 .15982 L p .522 .513 .788 r
F P
0 g
s
.3937 .15982 m .39551 .17399 L .37594 .17624 L p .522 .513 .788 r
F P
0 g
s
.35556 .11596 m .36155 .12489 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34906 .10951 m .35556 .11596 L p .37157 .18614 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .3705 .18567 L .37157 .18614 L 1 .816 .504 r
F
.3705 .18567 m .34906 .10951 L .37157 .18614 L F
.34231 .10584 m .34906 .10951 L p .37555 .2036 L F P
0 g
s
.32926 .10751 m .33561 .10515 L p .3678 .18447 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .36595 .18366 L .3678 .18447 L 1 .816 .504 r
F
.36595 .18366 m .32926 .10751 L .3678 .18447 L F
.32355 .11284 m .32926 .10751 L p .36595 .18366 L F P
0 g
s
.37555 .2036 m .36352 .18259 L .36595 .18366 L 1 .816 .504 r
F
.36352 .18259 m .32355 .11284 L .36595 .18366 L F
.31874 .12093 m .32355 .11284 L p .37555 .2036 L F P
0 g
s
.30025 .16878 m .35855 .1804 L .33932 .17194 L .289 .763 .934 r
F
.31507 .13144 m .31874 .12093 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.3127 .1439 m .31507 .13144 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.30025 .16878 m .33122 .16837 L .32545 .16583 L .289 .763 .934 r
F
.31964 .16327 m .30025 .16878 L p .32545 .16583 L F P
0 g
s
.30025 .16878 m .33932 .17194 L .33122 .16837 L .289 .763 .934 r
F
.31176 .15774 m .3127 .1439 L p .31964 .15049 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .31964 .1634 L .31964 .15049 L 1 .816 .504 r
F
.37411 .16211 m .37102 .14847 L .39063 .14614 L p .52 .574 .849 r
F P
0 g
s
.39063 .14614 m .3937 .15982 L .37411 .16211 L p .52 .574 .849 r
F P
0 g
s
.3937 .15982 m .39551 .17399 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.39063 .14614 m .3937 .15982 L p .39457 .18544 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39379 .18509 L .39457 .18544 L 1 .816 .5 r
F
.39379 .18509 m .39063 .14614 L .39457 .18544 L F
.38103 .18488 m .3887 .18281 L p .33932 .17194 L .289 .763 .934 r
F P
0 g
s
.39551 .17399 m .39599 .18806 L .39512 .20144 L p 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .15132 L .39063 .14614 L 1 .816 .5 r
F
.38642 .1335 m .39063 .14614 L .37102 .14847 L p .513 .629 .903 r
F P
0 g
s
.38642 .1335 m .3887 .14036 L p .3887 .15132 L 1 .816 .5 r
F P
0 g
s
.3887 .14036 m .39063 .14614 L p .3887 .15132 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39235 .20795 L .39197 .20717 L 1 .816 .5 r
F
.36908 .2286 m .37685 .23084 L .36908 .23926 L .686 .56 .707 r
F
.37371 .22567 m .36992 .22607 L p .3918 .2142 L .44 .142 .361 r
F P
0 g
s
.33879 .36823 m .30541 .36334 L .30541 .17886 L p .932 .761 .647 r
F P
0 g
s
.30541 .17886 m .33879 .18543 L .33879 .36823 L p .932 .761 .647 r
F P
0 g
s
.30541 .36334 m .30025 .35584 L .30025 .16878 L p .847 .692 .158 r
F P
0 g
s
.30025 .16878 m .30541 .17886 L .30541 .36334 L p .847 .692 .158 r
F P
0 g
s
.30025 .16878 m .30025 .35584 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.37555 .2036 m .31964 .17596 L .31964 .1634 L 1 .816 .504 r
F
.32545 .16583 m .3267 .16585 L .32672 .16568 L .289 .763 .934 r
F
.37102 .14847 m .36677 .13589 L .38642 .1335 L p .513 .629 .903 r
F P
0 g
s
.38125 .12246 m .38642 .1335 L .36677 .13589 L p .497 .682 .949 r
F P
0 g
s
.38125 .12246 m .38642 .1335 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36677 .13589 m .36155 .12489 L .38125 .12246 L p .497 .682 .949 r
F P
0 g
s
.37531 .1135 m .38125 .12246 L .36155 .12489 L p .467 .73 .983 r
F P
0 g
s
.37531 .1135 m .38125 .12246 L p .39212 .18434 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39118 .18392 L .39212 .18434 L 1 .816 .5 r
F
.39118 .18392 m .37531 .1135 L .39212 .18434 L F
.36155 .12489 m .35556 .11596 L .37531 .1135 L p .467 .73 .983 r
F P
0 g
s
.36886 .10701 m .37531 .1135 L .35556 .11596 L p .416 .768 .996 r
F P
0 g
s
.36886 .10701 m .37531 .1135 L p .39118 .18392 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39012 .18345 L .39118 .18392 L 1 .816 .5 r
F
.39012 .18345 m .36886 .10701 L .39118 .18392 L F
.33932 .17194 m .3699 .17441 L .33122 .16837 L .289 .763 .934 r
F
.35556 .11596 m .34906 .10951 L .36886 .10701 L p .416 .768 .996 r
F P
0 g
s
.36218 .10332 m .36886 .10701 L .34906 .10951 L p .328 .776 .958 r
F P
0 g
s
.36218 .10332 m .36886 .10701 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.38103 .18488 m .3887 .18281 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.33932 .17194 m .3887 .18281 L .3699 .17441 L .289 .763 .934 r
F
.34906 .10951 m .34231 .10584 L .36218 .10332 L p .328 .776 .958 r
F P
0 g
s
.35554 .10262 m .36218 .10332 L .34231 .10584 L p .183 .715 .821 r
F P
0 g
s
.35554 .10262 m .36218 .10332 L p .3889 .1829 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .38744 .18225 L .3889 .1829 L 1 .816 .5 r
F
.38744 .18225 m .35554 .10262 L .3889 .1829 L F
.33122 .16837 m .35568 .16805 L .32545 .16583 L .289 .763 .934 r
F
.36677 .13589 m .36908 .14271 L p .36908 .15364 L 1 .816 .504 r
F P
0 g
s
.36908 .14271 m .37102 .14847 L p .36908 .15364 L 1 .816 .504 r
F P
0 g
s
.34924 .10498 m .35554 .10262 L p .38744 .18225 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .38561 .18143 L .38744 .18225 L 1 .816 .5 r
F
.38561 .18143 m .34924 .10498 L .38744 .18225 L F
.3267 .16585 m .35189 .16635 L .32672 .16568 L .289 .763 .934 r
F
.34358 .11032 m .34924 .10498 L p .38561 .18143 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3832 .18035 L .38561 .18143 L 1 .816 .5 r
F
.3832 .18035 m .34358 .11032 L .38561 .18143 L F
.3832 .18035 m .33971 .11967 L .34358 .11032 L F
.37979 .17883 m .33971 .11974 L .3832 .18035 L F
.33971 .11974 m .33882 .11843 L .33971 .11967 L F
.33971 .11974 m .33971 .11967 L .3832 .18035 L F
.32736 .16107 m .31964 .16327 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.32672 .16568 m .35161 .16623 L .34547 .16348 L .289 .763 .934 r
F
.35189 .16635 m .35161 .16623 L .32672 .16568 L F
.35568 .16805 m .35189 .16635 L .32545 .16583 L F
.32545 .16583 m .34547 .16348 L .31964 .16327 L F
.33518 .12897 m .33882 .11843 L p .37979 .17883 L 1 .816 .5 r
F P
0 g
s
.37444 .17644 m .33518 .12897 L .37979 .17883 L 1 .816 .5 r
F
.3699 .17441 m .36548 .17243 L .33122 .16837 L .289 .763 .934 r
F
.33122 .16837 m .36548 .17243 L .35568 .16805 L F
.35855 .1804 m .38103 .18488 L .33932 .17194 L F
.36908 .18504 m .38103 .18488 L p .35855 .1804 L F P
0 g
s
.30025 .16878 m .30541 .17886 L .33879 .18543 L p .289 .763 .934 r
F P
0 g
s
.31964 .16327 m .30025 .16878 L p .31683 .20967 L .218 .178 .597 r
F P
0 g
s
.31964 .20688 m .31683 .20967 L .31964 .21658 L .218 .178 .597 r
F
.31964 .16327 m .31683 .20967 L .31964 .20688 L F
.32207 .21381 m .31757 .20101 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.32755 .22478 m .32207 .21381 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.32207 .21381 m .34212 .21161 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31964 .20688 m .32207 .21381 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31757 .20101 m .31425 .18697 L p .31964 .18843 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .31964 .20111 L .31964 .18843 L 1 .816 .504 r
F
.31964 .20111 m .31757 .20101 L .31964 .18843 L F
.34547 .16348 m .34225 .16205 L .31964 .16327 L .289 .763 .934 r
F
.31425 .18697 m .31228 .17232 L p .36908 .20039 L 1 .816 .504 r
F P
0 g
s
.36908 .20184 m .31425 .18697 L .36908 .20039 L 1 .816 .504 r
F
.32736 .16107 m .31964 .16327 L p .31964 .20688 L .218 .178 .597 r
F P
0 g
s
.32018 .20635 m .31964 .20688 L .31964 .20977 L .218 .178 .597 r
F
.32736 .16107 m .31964 .20688 L .32018 .20635 L F
.34212 .21161 m .33971 .20466 L p .32657 .20001 L .501 .629 .909 r
F P
0 g
s
.32863 .19978 m .32657 .20001 L p .33971 .20466 L .501 .629 .909 r
F P
0 g
s
.34212 .21161 m .32657 .20001 L .32313 .20341 L .501 .629 .909 r
F
.33375 .23346 m .32755 .22478 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34037 .23947 m .33375 .23346 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34714 .2426 m .34037 .23947 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.35375 .24273 m .34714 .2426 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.35991 .2399 m .35375 .24273 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.33375 .23346 m .34037 .23947 L .36026 .23738 L p .388 .762 .992 r
F P
0 g
s
.36026 .23738 m .35369 .23134 L .33375 .23346 L p .388 .762 .992 r
F P
0 g
s
.32755 .22478 m .33375 .23346 L .35369 .23134 L p .447 .73 .987 r
F P
0 g
s
.35369 .23134 m .34755 .22262 L .32755 .22478 L p .447 .73 .987 r
F P
0 g
s
.32207 .21381 m .32755 .22478 L .34755 .22262 L p .482 .682 .954 r
F P
0 g
s
.34755 .22262 m .34212 .21161 L .32207 .21381 L p .482 .682 .954 r
F P
0 g
s
.33971 .2965 m .33098 .20082 L .32736 .3501 L .686 .56 .707 r
F
.32736 .16107 m .32736 .19889 L p .33098 .20082 L F P
0 g
s
.33971 .16091 m .32736 .16107 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.33971 .16091 m .32736 .16107 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33766 .19877 m .33014 .19498 L .32736 .19889 L .51 .572 .854 r
F
.32657 .20001 m .32863 .19978 L p .32736 .19889 L F P
0 g
s
.33098 .20082 m .32736 .19889 L .32863 .19978 L .686 .56 .707 r
F
.32863 .19978 m .33766 .19877 L p .32736 .19889 L .51 .572 .854 r
F P
0 g
s
.32736 .19889 m .32736 .19922 L p .32863 .19978 L .686 .56 .707 r
F P
0 g
s
.32736 .19922 m .32736 .3501 L p .33098 .20082 L .686 .56 .707 r
F P
0 g
s
.33971 .20466 m .33766 .19877 L .32863 .19978 L p .501 .629 .909 r
F P
0 g
s
.32736 .16107 m .31964 .20977 L .32082 .2081 L .218 .178 .597 r
F
.32736 .3501 m .32736 .16107 L p .31964 .21658 L F P
0 g
s
.32657 .20001 m .31757 .20101 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31425 .18697 m .31757 .20101 L .32657 .20001 L p .51 .572 .854 r
F P
0 g
s
.33014 .19498 m .31425 .18697 L .32657 .20001 L .51 .572 .854 r
F
.32082 .2081 m .31964 .20977 L .31964 .21658 L .218 .178 .597 r
F
.31757 .20101 m .31964 .20688 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.36537 .23426 m .35991 .2399 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.36992 .22607 m .36537 .23426 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .37335 .2157 L .36992 .22607 L p 1 .816 .504 r
F P
0 g
s
.36908 .18504 m .38103 .18488 L p .37746 .22412 L .686 .56 .707 r
F P
0 g
s
.37575 .22437 m .37685 .23084 L .36908 .2286 L .686 .56 .707 r
F
.36908 .18504 m .37746 .22412 L .37582 .22479 L F
.38572 .22438 m .38217 .22306 L .38103 .22103 L .241 .197 .606 r
F
.36908 .3162 m .37754 .22324 L .38103 .36782 L .686 .56 .707 r
F
.38103 .22103 m .38103 .36782 L p .37754 .22324 L F P
0 g
s
.39294 .21358 m .38954 .22398 L .37371 .22567 L p .44 .142 .361 r
F P
0 g
s
.39294 .21358 m .37371 .22567 L .3918 .2142 L .44 .142 .361 r
F
.38954 .22398 m .3887 .22549 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.38103 .18488 m .3887 .20052 L .38729 .2255 L .241 .197 .606 r
F
.38103 .1865 m .38103 .18488 L p .38132 .18678 L F P
0 g
s
.38132 .18678 m .38729 .2255 L .38103 .1865 L .241 .197 .606 r
F
.38103 .22103 m .38103 .1865 L p .38729 .2255 L F P
0 g
s
.38103 .18488 m .38103 .22103 L p .37754 .22324 L .686 .56 .707 r
F P
0 g
s
.33283 .14147 m .33518 .12897 L p .3887 .19368 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .19526 L .3887 .19368 L 1 .816 .5 r
F
.3887 .19526 m .33283 .14147 L .3887 .19368 L F
.39235 .20795 m .3887 .21651 L .39197 .20717 L F
.39197 .20717 m .3887 .21651 L .3887 .21309 L F
.39512 .20144 m .3887 .21309 L .3887 .21035 L F
.39275 .2136 m .39294 .21358 L p .3918 .2142 L .44 .142 .361 r
F P
0 g
s
.3887 .20052 m .3887 .22652 L .38729 .2255 L .241 .197 .606 r
F
.36908 .18504 m .37575 .22437 L .36908 .2286 L .686 .56 .707 r
F
.33766 .19877 m .33437 .18468 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34212 .21161 m .33766 .19877 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34755 .22262 m .34212 .21161 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.35369 .23134 m .34755 .22262 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36537 .23426 m .36908 .22759 L p .38572 .22438 L .369 0 .15 r
F P
0 g
s
.37371 .22567 m .38572 .22438 L p .36908 .22759 L .369 0 .15 r
F P
0 g
s
.36026 .23738 m .35369 .23134 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36908 .23926 m .37685 .23084 L .36908 .3162 L .686 .56 .707 r
F
.38504 .23218 m .36537 .23426 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.38725 .22495 m .36537 .23426 L .38572 .22438 L .369 0 .15 r
F
.35991 .2399 m .36537 .23426 L .38504 .23218 L p .25 0 0 r
F P
0 g
s
.38504 .23218 m .37962 .23783 L .35991 .2399 L p .25 0 0 r
F P
0 g
s
.35375 .24273 m .35991 .2399 L .37962 .23783 L p .073 0 0 r
F P
0 g
s
.37962 .23783 m .37351 .24067 L .35375 .24273 L p .073 0 0 r
F P
0 g
s
.36697 .24052 m .36026 .23738 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.40837 .24057 m .40837 .36233 L p .3887 .23471 L .241 .197 .606 r
F P
0 g
s
.38729 .2255 m .3887 .22652 L .3887 .23471 L .241 .197 .606 r
F
.3887 .22652 m .40837 .24057 L .3887 .23471 L F
.38954 .22398 m .3887 .22549 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.38739 .225 m .38504 .23218 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.3887 .22549 m .38504 .23218 L p .3887 .221 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .22549 L .3887 .221 L 1 .816 .5 r
F
.38504 .23218 m .37962 .23783 L p .39512 .20144 L F P
0 g
s
.39512 .20144 m .39294 .21358 L .38954 .22398 L p 1 .816 .5 r
F P
0 g
s
.3887 .20052 m .40837 .24057 L .3887 .22652 L .241 .197 .606 r
F
.3319 .15535 m .33283 .14147 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34547 .16348 m .37103 .16049 L .34225 .16205 L .289 .763 .934 r
F
.39512 .20144 m .37444 .17644 L .37979 .17883 L 1 .816 .5 r
F
.37103 .16049 m .33971 .16091 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.40465 .1674 m .37103 .16049 L p .34547 .16348 L .289 .763 .934 r
F P
0 g
s
.35161 .16623 m .40465 .1674 L .34547 .16348 L .289 .763 .934 r
F
.35189 .16635 m .40465 .1674 L .35161 .16623 L F
.35568 .16805 m .40465 .1674 L .35189 .16635 L F
.3699 .17441 m .40837 .17751 L .36548 .17243 L F
.40837 .17751 m .40465 .1674 L p .35568 .16805 L F P
0 g
s
.36548 .17243 m .40837 .17751 L .35568 .16805 L .289 .763 .934 r
F
.33242 .16998 m .3319 .15535 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.33437 .18468 m .33242 .16998 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34714 .2426 m .35375 .24273 L .37351 .24067 L p .126 .675 .772 r
F P
0 g
s
.37351 .24067 m .36697 .24052 L .34714 .2426 L p .126 .675 .772 r
F P
0 g
s
.34037 .23947 m .34714 .2426 L .36697 .24052 L p .285 .758 .937 r
F P
0 g
s
.36697 .24052 m .36026 .23738 L .34037 .23947 L p .285 .758 .937 r
F P
0 g
s
.37103 .16049 m .33971 .16091 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.3887 .18281 m .40837 .17751 L p .3699 .17441 L .289 .763 .934 r
F P
0 g
s
.37351 .24067 m .36697 .24052 L p .3887 .21035 L 1 .816 .5 r
F P
0 g
s
.37103 .34966 m .37103 .16049 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.32736 .3501 m .33971 .34998 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33971 .34998 m .37103 .34966 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33882 .11843 m .33971 .11692 L p .33971 .11967 L 1 .816 .5 r
F P
0 g
s
.33971 .11692 m .34358 .11032 L p .33971 .11967 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .37979 .17883 L .3832 .18035 L 1 .816 .5 r
F
.31228 .17232 m .31176 .15774 L p .31964 .1634 L 1 .816 .504 r
F P
0 g
s
.31964 .17596 m .31228 .17232 L .31964 .1634 L 1 .816 .504 r
F
.40837 .17751 m .40837 .24057 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.3887 .18281 m .40837 .17751 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.31964 .1634 m .31176 .15774 L .31964 .15049 L 1 .816 .504 r
F
.30025 .35584 m .31964 .35174 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.31964 .35174 m .32736 .3501 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.3887 .23471 m .40837 .36233 L .3887 .2607 L .241 .197 .606 r
F
.37962 .23783 m .37351 .24067 L p .3887 .21309 L 1 .816 .5 r
F P
0 g
s
.3887 .21651 m .37962 .23783 L .3887 .21309 L 1 .816 .5 r
F
.3887 .21309 m .37351 .24067 L .3887 .21035 L F
.40837 .36233 m .3887 .36628 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.3887 .36628 m .38103 .36782 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.33879 .36823 m .38103 .36782 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.30025 .35584 m .30541 .36334 L .33879 .36823 L p .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.61805 .23379 m .61766 .22046 L .59844 .22245 L p .533 .457 .716 r
F P
0 g
s
.40465 .35481 m .40837 .36233 L .40837 .17751 L p .813 .664 .115 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.38103 .36782 m .40837 .36233 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.40837 .36233 m .40465 .35481 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.37103 .34966 m .32736 .3501 L .30025 .35584 L p .224 .73 .894 r
F P
0 g
s
.40465 .35481 m .37103 .34966 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40837 .17751 m .40465 .1674 L .40465 .35481 L p .813 .664 .115 r
F P
0 g
s
.37103 .34966 m .40465 .35481 L .40465 .1674 L p .938 .766 .643 r
F P
0 g
s
.40465 .1674 m .37103 .16049 L .37103 .34966 L p .938 .766 .643 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.62462 .36823 m .62462 .18543 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.66708 .36782 m .65506 .36794 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.65506 .36794 m .62462 .36823 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.6604 .2036 m .65506 .20184 L .65506 .20039 L .996 .813 .454 r
F
.66072 .17624 m .66112 .19026 L .6604 .2036 L p F P
0 g
s
.6604 .2036 m .66112 .19026 L .68156 .18806 L p .514 .376 .631 r
F P
0 g
s
.66112 .19026 m .66072 .17624 L .68117 .17399 L p .525 .452 .716 r
F P
0 g
s
.68117 .17399 m .68156 .18806 L .66112 .19026 L p .525 .452 .716 r
F P
0 g
s
.65921 .16211 m .66072 .17624 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65666 .14847 m .65921 .16211 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.68156 .18806 m .68085 .20144 L .6604 .2036 L p .514 .376 .631 r
F P
0 g
s
.65859 .2157 m .6604 .2036 L .68085 .20144 L p .492 .283 .523 r
F P
0 g
s
.66708 .36782 m .66708 .22264 L p .67558 .2607 L .284 .232 .621 r
F P
0 g
s
.66708 .22264 m .66708 .22103 L p .66745 .22276 L .284 .232 .621 r
F P
0 g
s
.66745 .22276 m .67558 .2607 L .66708 .22264 L .284 .232 .621 r
F
.67401 .2255 m .67558 .23471 L .66834 .22306 L F
.67401 .2255 m .66834 .22306 L .67228 .22438 L F
.67558 .23471 m .67558 .2607 L .66708 .22103 L F
.67228 .22438 m .67626 .22398 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.65879 .21568 m .67885 .2136 L p .66617 .22045 L .455 .162 .378 r
F P
0 g
s
.6779 .2142 m .66621 .22047 L .67885 .2136 L .455 .162 .378 r
F
.66621 .22047 m .65575 .22607 L .66617 .22045 L F
.66621 .22047 m .66617 .22045 L .67885 .2136 L F
.68085 .20144 m .6791 .21334 L p .65859 .2157 L .492 .283 .523 r
F P
0 g
s
.6791 .21334 m .67906 .21358 L .67885 .2136 L p .492 .283 .523 r
F P
0 g
s
.67885 .2136 m .65859 .2157 L p .6791 .21334 L .492 .283 .523 r
F P
0 g
s
.66184 .22479 m .66349 .22412 L .66287 .23084 L .686 .56 .707 r
F
.65506 .22759 m .65575 .22607 L .65972 .22567 L p .388 0 .176 r
F P
0 g
s
.65575 .22607 m .65859 .2157 L .65879 .21568 L p .455 .162 .378 r
F P
0 g
s
.66617 .22045 m .65575 .22607 L .65879 .21568 L .455 .162 .378 r
F
.62462 .18543 m .65506 .18504 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.62749 .10515 m .63301 .10584 L p .65522 .18512 L .996 .813 .454 r
F P
0 g
s
.62462 .18543 m .65506 .18504 L p .59274 .16878 L .289 .763 .934 r
F P
0 g
s
.59274 .16878 m .65506 .18504 L .64638 .1804 L .289 .763 .934 r
F
.6604 .2036 m .65401 .18447 L .65522 .18512 L .996 .813 .454 r
F
.65401 .18447 m .62749 .10515 L .65522 .18512 L F
.6604 .2036 m .65506 .15364 L .65666 .14847 L F
.64886 .12489 m .65316 .13589 L p .65862 .18694 L F P
0 g
s
.6604 .2036 m .6579 .18656 L .65862 .18694 L .996 .813 .454 r
F
.6579 .18656 m .64886 .12489 L .65862 .18694 L F
.66072 .17624 m .65921 .16211 L .67968 .15982 L p .529 .516 .786 r
F P
0 g
s
.67968 .15982 m .68117 .17399 L .66072 .17624 L p .529 .516 .786 r
F P
0 g
s
.64393 .11596 m .64886 .12489 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63857 .10951 m .64393 .11596 L p .65712 .18614 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65624 .18567 L .65712 .18614 L .996 .813 .454 r
F
.65624 .18567 m .63857 .10951 L .65712 .18614 L F
.63301 .10584 m .63857 .10951 L p .6604 .2036 L F P
0 g
s
.62226 .10751 m .62749 .10515 L p .65401 .18447 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65249 .18366 L .65401 .18447 L .996 .813 .454 r
F
.65249 .18366 m .62226 .10751 L .65401 .18447 L F
.61755 .11284 m .62226 .10751 L p .65249 .18366 L F P
0 g
s
.6604 .2036 m .65048 .18259 L .65249 .18366 L .996 .813 .454 r
F
.65048 .18259 m .61755 .11284 L .65249 .18366 L F
.61359 .12093 m .61755 .11284 L p .6604 .2036 L F P
0 g
s
.59274 .16878 m .64638 .1804 L .63055 .17194 L .289 .763 .934 r
F
.61057 .13144 m .61359 .12093 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.60862 .1439 m .61057 .13144 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.59274 .16878 m .62387 .16837 L .61912 .16583 L .289 .763 .934 r
F
.61433 .16327 m .59274 .16878 L p .61912 .16583 L F P
0 g
s
.59274 .16878 m .63055 .17194 L .62387 .16837 L .289 .763 .934 r
F
.60784 .15774 m .60862 .1439 L p .61433 .15049 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .61433 .1634 L .61433 .15049 L .996 .813 .454 r
F
.65921 .16211 m .65666 .14847 L .67716 .14614 L p .528 .575 .846 r
F P
0 g
s
.67716 .14614 m .67968 .15982 L .65921 .16211 L p .528 .575 .846 r
F P
0 g
s
.67968 .15982 m .68117 .17399 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.67716 .14614 m .67968 .15982 L p .6804 .18544 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67976 .18509 L .6804 .18544 L .995 .813 .449 r
F
.67976 .18509 m .67716 .14614 L .6804 .18544 L F
.66708 .18488 m .67558 .18281 L p .63055 .17194 L .289 .763 .934 r
F P
0 g
s
.68117 .17399 m .68156 .18806 L .68085 .20144 L p .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .15132 L .67716 .14614 L .995 .813 .449 r
F
.67371 .1335 m .67716 .14614 L .65666 .14847 L p .52 .629 .899 r
F P
0 g
s
.67371 .1335 m .67558 .14036 L p .67558 .15132 L .995 .813 .449 r
F P
0 g
s
.67558 .14036 m .67716 .14614 L p .67558 .15132 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67868 .20623 L .67836 .20564 L .995 .813 .449 r
F
.67868 .20623 m .67558 .21309 L .67836 .20564 L F
.67836 .20564 m .67558 .21309 L .67558 .21035 L F
.68085 .20144 m .67558 .21035 L .67558 .20805 L F
.65666 .14847 m .65316 .13589 L .67371 .1335 L p .52 .629 .899 r
F P
0 g
s
.66946 .12246 m .67371 .1335 L .65316 .13589 L p .504 .682 .946 r
F P
0 g
s
.66946 .12246 m .67371 .1335 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65316 .13589 m .64886 .12489 L .66946 .12246 L p .504 .682 .946 r
F P
0 g
s
.66458 .1135 m .66946 .12246 L .64886 .12489 L p .475 .73 .982 r
F P
0 g
s
.66458 .1135 m .66946 .12246 L p .67838 .18434 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67761 .18392 L .67838 .18434 L .995 .813 .449 r
F
.67761 .18392 m .66458 .1135 L .67838 .18434 L F
.64886 .12489 m .64393 .11596 L .66458 .1135 L p .475 .73 .982 r
F P
0 g
s
.65929 .10701 m .66458 .1135 L .64393 .11596 L p .422 .768 .996 r
F P
0 g
s
.65929 .10701 m .66458 .1135 L p .67761 .18392 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67674 .18345 L .67761 .18392 L .995 .813 .449 r
F
.67674 .18345 m .65929 .10701 L .67761 .18392 L F
.63055 .17194 m .66014 .17441 L .62387 .16837 L .289 .763 .934 r
F
.64393 .11596 m .63857 .10951 L .65929 .10701 L p .422 .768 .996 r
F P
0 g
s
.65379 .10332 m .65929 .10701 L .63857 .10951 L p .329 .776 .959 r
F P
0 g
s
.65379 .10332 m .65929 .10701 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.66708 .18488 m .67558 .18281 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.63055 .17194 m .67558 .18281 L .66014 .17441 L .289 .763 .934 r
F
.63857 .10951 m .63301 .10584 L .65379 .10332 L p .329 .776 .959 r
F P
0 g
s
.64834 .10262 m .65379 .10332 L .63301 .10584 L p .173 .709 .814 r
F P
0 g
s
.64834 .10262 m .65379 .10332 L p .67574 .1829 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67454 .18225 L .67574 .1829 L .995 .813 .449 r
F
.67454 .18225 m .64834 .10262 L .67574 .1829 L F
.62387 .16837 m .64846 .16805 L .61912 .16583 L .289 .763 .934 r
F
.64318 .10498 m .64834 .10262 L p .67454 .18225 L .995 .813 .449 r
F P
0 g
s
.67304 .18143 m .64318 .10498 L .67454 .18225 L .995 .813 .449 r
F
.65316 .13589 m .65506 .14271 L p .65506 .15364 L .996 .813 .454 r
F P
0 g
s
.65506 .14271 m .65666 .14847 L p .65506 .15364 L .996 .813 .454 r
F P
0 g
s
.63853 .11032 m .64318 .10498 L p .67304 .18143 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67106 .18035 L .67304 .18143 L .995 .813 .449 r
F
.67106 .18035 m .63853 .11032 L .67304 .18143 L F
.62293 .16107 m .61433 .16327 L p .63743 .16205 L .289 .763 .934 r
F P
0 g
s
.67106 .18035 m .63534 .11967 L .63853 .11032 L .995 .813 .449 r
F
.66826 .17883 m .63534 .11974 L .67106 .18035 L F
.63534 .11974 m .63462 .11843 L .63534 .11967 L F
.63534 .11974 m .63534 .11967 L .67106 .18035 L F
.61912 .16583 m .64007 .16348 L .61433 .16327 L .289 .763 .934 r
F
.64007 .16348 m .63743 .16205 L .61433 .16327 L F
.61912 .16583 m .64535 .16635 L .64007 .16348 L F
.64846 .16805 m .64535 .16635 L .61912 .16583 L F
.62462 .36823 m .59386 .36334 L .59386 .17886 L p .943 .77 .638 r
F P
0 g
s
.59386 .17886 m .62462 .18543 L .62462 .36823 L p .943 .77 .638 r
F P
0 g
s
.59274 .16878 m .59386 .17886 L .62462 .18543 L p .289 .763 .934 r
F P
0 g
s
.59386 .36334 m .59274 .35584 L .59274 .16878 L p .741 .605 .035 r
F P
0 g
s
.59274 .16878 m .59386 .17886 L .59386 .36334 L p .741 .605 .035 r
F P
0 g
s
.59274 .16878 m .59274 .35584 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.65506 .20039 m .61433 .18829 L .61433 .17596 L .996 .813 .454 r
F
.61433 .16327 m .59274 .16878 L p .61121 .20967 L .264 .216 .614 r
F P
0 g
s
.61433 .20688 m .61121 .20967 L .61433 .21658 L .264 .216 .614 r
F
.61433 .16327 m .61121 .20967 L .61433 .20688 L F
.61634 .21381 m .61263 .20101 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.62085 .22478 m .61634 .21381 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.61634 .21381 m .63733 .21161 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.61433 .20688 m .61634 .21381 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.65506 .20184 m .61433 .18843 L .65506 .20039 L .996 .813 .454 r
F
.61433 .18843 m .60989 .18697 L .61433 .18829 L F
.61433 .18843 m .61433 .18829 L .65506 .20039 L F
.60827 .17232 m .60784 .15774 L p .6604 .2036 L F P
0 g
s
.61263 .20101 m .60989 .18697 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.62293 .16107 m .61433 .16327 L p .61433 .20688 L .264 .216 .614 r
F P
0 g
s
.61493 .20635 m .61433 .20688 L .61433 .20977 L .264 .216 .614 r
F
.62293 .16107 m .61433 .20688 L .61493 .20635 L F
.63733 .21161 m .63534 .20466 L p .62205 .20001 L .509 .629 .905 r
F P
0 g
s
.62421 .19978 m .62205 .20001 L p .63534 .20466 L .509 .629 .905 r
F P
0 g
s
.63733 .21161 m .62205 .20001 L .61822 .20341 L .509 .629 .905 r
F
.62595 .23346 m .62085 .22478 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63141 .23947 m .62595 .23346 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63699 .2426 m .63141 .23947 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.64243 .24273 m .63699 .2426 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.64751 .2399 m .64243 .24273 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65201 .23426 m .64751 .2399 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65506 .23044 m .66287 .23084 L .65506 .23926 L .686 .56 .707 r
F
.65575 .22607 m .65201 .23426 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65859 .2157 L .65575 .22607 L p .996 .813 .454 r
F P
0 g
s
.66177 .22437 m .66246 .22842 L .65506 .2286 L .686 .56 .707 r
F
.65972 .22567 m .65575 .22607 L p .6779 .2142 L .455 .162 .378 r
F P
0 g
s
.65506 .18504 m .66708 .18488 L p .66349 .22412 L .686 .56 .707 r
F P
0 g
s
.65506 .18504 m .66349 .22412 L .66184 .22479 L .686 .56 .707 r
F
.67228 .22438 m .66834 .22306 L .66708 .22103 L .284 .232 .621 r
F
.65506 .3162 m .66357 .22324 L .66708 .36782 L .686 .56 .707 r
F
.66708 .22103 m .66708 .36782 L p .66357 .22324 L F P
0 g
s
.67906 .21358 m .67626 .22398 L .65972 .22567 L p .455 .162 .378 r
F P
0 g
s
.67906 .21358 m .65972 .22567 L .6779 .2142 L .455 .162 .378 r
F
.65506 .2286 m .66246 .22842 L .65506 .23044 L .686 .56 .707 r
F
.65506 .18504 m .66177 .22437 L .65506 .2286 L F
.66246 .22842 m .66287 .23084 L .65506 .23044 L F
.65506 .23926 m .66287 .23084 L .65506 .3162 L F
.64751 .2399 m .65201 .23426 L .67257 .23218 L p .272 0 0 r
F P
0 g
s
.62595 .23346 m .63141 .23947 L .65222 .23738 L p .394 .764 .993 r
F P
0 g
s
.65222 .23738 m .64683 .23134 L .62595 .23346 L p .394 .764 .993 r
F P
0 g
s
.62085 .22478 m .62595 .23346 L .64683 .23134 L p .456 .73 .986 r
F P
0 g
s
.64683 .23134 m .64178 .22262 L .62085 .22478 L p .456 .73 .986 r
F P
0 g
s
.61634 .21381 m .62085 .22478 L .64178 .22262 L p .49 .682 .951 r
F P
0 g
s
.64178 .22262 m .63733 .21161 L .61634 .21381 L p .49 .682 .951 r
F P
0 g
s
.63534 .2965 m .62657 .20082 L .62293 .3501 L .686 .56 .707 r
F
.62293 .16107 m .62293 .19889 L p .62657 .20082 L F P
0 g
s
.63534 .16091 m .62293 .16107 L p .63743 .16205 L .289 .763 .934 r
F P
0 g
s
.66014 .17441 m .65651 .17243 L .62387 .16837 L .289 .763 .934 r
F
.62387 .16837 m .65651 .17243 L .64846 .16805 L F
.64638 .1804 m .66708 .18488 L .63055 .17194 L F
.64243 .24273 m .64751 .2399 L .66812 .23783 L p .093 0 0 r
F P
0 g
s
.66812 .23783 m .6631 .24067 L .64243 .24273 L p .093 0 0 r
F P
0 g
s
.63141 .23947 m .63699 .2426 L .65773 .24052 L p .287 .759 .938 r
F P
0 g
s
.67257 .23218 m .66812 .23783 L .64751 .2399 L p .272 0 0 r
F P
0 g
s
.65773 .24052 m .65222 .23738 L .63141 .23947 L p .287 .759 .938 r
F P
0 g
s
.63534 .16091 m .62293 .16107 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63366 .19877 m .62602 .19498 L .62293 .19889 L .519 .573 .85 r
F
.62205 .20001 m .62421 .19978 L p .62293 .19889 L F P
0 g
s
.62657 .20082 m .62293 .19889 L .62421 .19978 L .686 .56 .707 r
F
.62421 .19978 m .63366 .19877 L p .62293 .19889 L .519 .573 .85 r
F P
0 g
s
.62293 .19889 m .62293 .19922 L p .62421 .19978 L .686 .56 .707 r
F P
0 g
s
.62293 .19922 m .62293 .3501 L p .62657 .20082 L .686 .56 .707 r
F P
0 g
s
.63534 .20466 m .63366 .19877 L .62421 .19978 L p .509 .629 .905 r
F P
0 g
s
.62293 .16107 m .61433 .20977 L .61564 .2081 L .264 .216 .614 r
F
.62293 .3501 m .62293 .16107 L p .61433 .21658 L F P
0 g
s
.62205 .20001 m .61263 .20101 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.60989 .18697 m .61263 .20101 L .62205 .20001 L p .519 .573 .85 r
F P
0 g
s
.62602 .19498 m .60989 .18697 L .62205 .20001 L .519 .573 .85 r
F
.61564 .2081 m .61433 .20977 L .61433 .21658 L .264 .216 .614 r
F
.61263 .20101 m .61433 .20688 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.60989 .18697 m .60827 .17232 L p .61433 .17596 L .996 .813 .454 r
F P
0 g
s
.61433 .18829 m .60989 .18697 L .61433 .17596 L .996 .813 .454 r
F
.63163 .12897 m .63462 .11843 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65506 .18504 m .66708 .18488 L p .64638 .1804 L .289 .763 .934 r
F P
0 g
s
.6297 .14147 m .63163 .12897 L p .67558 .19368 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .19526 L .67558 .19368 L .995 .813 .449 r
F
.67626 .22398 m .67558 .22549 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.66708 .18488 m .67558 .20052 L .67401 .2255 L .284 .232 .621 r
F
.66708 .18529 m .66708 .18488 L p .66716 .18539 L F P
0 g
s
.66716 .18539 m .67401 .2255 L .66708 .18529 L .284 .232 .621 r
F
.66708 .22103 m .66708 .18529 L p .67401 .2255 L F P
0 g
s
.66708 .18488 m .66708 .22103 L p .66357 .22324 L .686 .56 .707 r
F P
0 g
s
.67558 .19526 m .6297 .14147 L .67558 .19368 L .995 .813 .449 r
F
.67885 .2136 m .67906 .21358 L p .6779 .2142 L .455 .162 .378 r
F P
0 g
s
.67558 .20052 m .67558 .22652 L .67401 .2255 L .284 .232 .621 r
F
.63366 .19877 m .63096 .18468 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63733 .21161 m .63366 .19877 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64178 .22262 m .63733 .21161 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64683 .23134 m .64178 .22262 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65201 .23426 m .65506 .22759 L p .67228 .22438 L .388 0 .176 r
F P
0 g
s
.65972 .22567 m .67228 .22438 L p .65506 .22759 L .388 0 .176 r
F P
0 g
s
.67257 .23218 m .65201 .23426 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.67396 .22495 m .65201 .23426 L .67228 .22438 L .388 0 .176 r
F
.65222 .23738 m .64683 .23134 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.66812 .23783 m .6631 .24067 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.67257 .23218 m .66812 .23783 L p .67558 .21651 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .221 L .67558 .21651 L .995 .813 .449 r
F
.67401 .2255 m .67558 .22652 L .67558 .23471 L .284 .232 .621 r
F
.67558 .22549 m .67257 .23218 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.67558 .221 m .67257 .23218 L .67558 .21651 L .995 .813 .449 r
F
.69736 .24057 m .69736 .36233 L p .67558 .23471 L .284 .232 .621 r
F P
0 g
s
.67558 .22652 m .69736 .24057 L .67558 .23471 L .284 .232 .621 r
F
.67626 .22398 m .67257 .23218 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67906 .21358 L .67626 .22398 L p .995 .813 .449 r
F P
0 g
s
.67558 .20052 m .69736 .24057 L .67558 .22652 L .284 .232 .621 r
F
.62893 .15535 m .6297 .14147 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64007 .16348 m .66684 .16049 L .63743 .16205 L .289 .763 .934 r
F
.66684 .16049 m .63534 .16091 L p .63743 .16205 L F P
0 g
s
.69769 .1674 m .66684 .16049 L p .64007 .16348 L .289 .763 .934 r
F P
0 g
s
.64535 .16635 m .69769 .1674 L .64007 .16348 L .289 .763 .934 r
F
.64846 .16805 m .69769 .1674 L .64535 .16635 L F
.66014 .17441 m .69736 .17751 L .65651 .17243 L F
.69736 .17751 m .69769 .1674 L p .64846 .16805 L F P
0 g
s
.65651 .17243 m .69736 .17751 L .64846 .16805 L .289 .763 .934 r
F
.67558 .18281 m .69736 .17751 L p .66014 .17441 L F P
0 g
s
.62936 .16998 m .62893 .15535 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63096 .18468 m .62936 .16998 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63699 .2426 m .64243 .24273 L .6631 .24067 L p .116 .668 .763 r
F P
0 g
s
.6631 .24067 m .65773 .24052 L .63699 .2426 L p .116 .668 .763 r
F P
0 g
s
.66684 .16049 m .63534 .16091 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.6631 .24067 m .65773 .24052 L p .67558 .21035 L .995 .813 .449 r
F P
0 g
s
.67558 .21309 m .6631 .24067 L .67558 .21035 L .995 .813 .449 r
F
.65773 .24052 m .65222 .23738 L p .67558 .20805 L F P
0 g
s
.67558 .21035 m .65773 .24052 L .67558 .20805 L .995 .813 .449 r
F
.66684 .34966 m .66684 .16049 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.62293 .3501 m .63534 .34998 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63534 .34998 m .66684 .34966 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63462 .11843 m .63534 .11692 L p .63534 .11967 L .995 .813 .449 r
F P
0 g
s
.63534 .11692 m .63853 .11032 L p .63534 .11967 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .66826 .17883 L .67106 .18035 L .995 .813 .449 r
F
.68085 .20144 m .67304 .18143 L .67454 .18225 L F
.69736 .17751 m .69736 .24057 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.67558 .18281 m .69736 .17751 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.61433 .1634 m .60784 .15774 L .61433 .15049 L .996 .813 .454 r
F
.59274 .35584 m .61433 .35174 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.61433 .35174 m .62293 .3501 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.67558 .23471 m .69736 .36233 L .67558 .2607 L .284 .232 .621 r
F
.69736 .36233 m .67558 .36628 L p .67558 .2607 L F P
0 g
s
.67558 .36628 m .66708 .36782 L p .67558 .2607 L .284 .232 .621 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62462 .36823 m .66708 .36782 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.59274 .35584 m .59386 .36334 L .62462 .36823 L p .224 .73 .894 r
F P
0 g
s
.66708 .36782 m .69736 .36233 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.69769 .35481 m .69736 .36233 L .69736 .17751 L p 0 0 .01 r
F P
0 g
s
.69736 .36233 m .69769 .35481 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.66684 .34966 m .62293 .3501 L .59274 .35584 L p .224 .73 .894 r
F P
0 g
s
.69769 .35481 m .66684 .34966 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.69736 .17751 m .69769 .1674 L .69769 .35481 L p 0 0 .01 r
F P
0 g
s
.66684 .34966 m .69769 .35481 L .69769 .1674 L p .949 .775 .632 r
F P
0 g
s
.69769 .1674 m .66684 .16049 L .66684 .34966 L p .949 .775 .632 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.46069 1.3007 m .4408 1.27999 L .42079 1.30317 L p .854 .697 .687 r
F P
0 g
s
.42079 1.30317 m .4408 1.32387 L .46069 1.3007 L p .854 .697 .687 r
F P
0 g
s
.63567 1.3007 m .61632 1.27999 L .59685 1.30317 L p .857 .7 .686 r
F P
0 g
s
.59685 1.30317 m .61632 1.32387 L .63567 1.3007 L p .857 .7 .686 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.67916 1.07879 m .69598 1.07885 L .71558 .99731 L p .439 .19 .439 r
F P
0 g
s
.74046 1.07635 m .72375 1.08378 L .73912 1.08369 L closepath p .576 .915 .969 \
r
F P
0 g
s
.69598 1.07885 m .67916 1.07879 L .69488 1.08618 L closepath p .303 .677 .975 \
r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.34231 .10584 m .33561 .10515 L .35554 .10262 L p .183 .715 .821 r
F P
0 g
s
.63301 .10584 m .62749 .10515 L .64834 .10262 L p .173 .709 .814 r
F P
0 g
s
.33561 .10515 m .32926 .10751 L .34924 .10498 L p .013 0 0 r
F P
0 g
s
.34924 .10498 m .35554 .10262 L .33561 .10515 L p .013 0 0 r
F P
0 g
s
.62749 .10515 m .62226 .10751 L .64318 .10498 L p .035 0 0 r
F P
0 g
s
.64318 .10498 m .64834 .10262 L .62749 .10515 L p .035 0 0 r
F P
0 g
s
.32926 .10751 m .32355 .11284 L .34358 .11032 L p .203 0 0 r
F P
0 g
s
.34358 .11032 m .34924 .10498 L .32926 .10751 L p .203 0 0 r
F P
0 g
s
.62226 .10751 m .61755 .11284 L .63853 .11032 L p .228 0 0 r
F P
0 g
s
.63853 .11032 m .64318 .10498 L .62226 .10751 L p .228 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.32355 .11284 m .31874 .12093 L .33882 .11843 L p .339 0 .107 r
F P
0 g
s
.33882 .11843 m .34358 .11032 L .32355 .11284 L p .339 0 .107 r
F P
0 g
s
.61755 .11284 m .61359 .12093 L .63462 .11843 L p .36 0 .136 r
F P
0 g
s
.63462 .11843 m .63853 .11032 L .61755 .11284 L p .36 0 .136 r
F P
0 g
s
.31874 .12093 m .31507 .13144 L .33518 .12897 L p .42 .113 .336 r
F P
0 g
s
.33518 .12897 m .33882 .11843 L .31874 .12093 L p .42 .113 .336 r
F P
0 g
s
.61359 .12093 m .61057 .13144 L .63163 .12897 L p .436 .136 .356 r
F P
0 g
s
.63163 .12897 m .63462 .11843 L .61359 .12093 L p .436 .136 .356 r
F P
0 g
s
.31507 .13144 m .3127 .1439 L .33283 .14147 L p .467 .25 .501 r
F P
0 g
s
.33283 .14147 m .33518 .12897 L .31507 .13144 L p .467 .25 .501 r
F P
0 g
s
.61057 .13144 m .60862 .1439 L .6297 .14147 L p .479 .266 .512 r
F P
0 g
s
.6297 .14147 m .63163 .12897 L .61057 .13144 L p .479 .266 .512 r
F P
0 g
s
.31228 .17232 m .31425 .18697 L .33437 .18468 L p .512 .509 .79 r
F P
0 g
s
.33766 .19877 m .33437 .18468 L .31425 .18697 L p .51 .572 .854 r
F P
0 g
s
.60827 .17232 m .60989 .18697 L .63096 .18468 L p .521 .513 .788 r
F P
0 g
s
.63366 .19877 m .63096 .18468 L .60989 .18697 L p .519 .573 .85 r
F P
0 g
s
.3127 .1439 m .31176 .15774 L .3319 .15535 L p .493 .355 .621 r
F P
0 g
s
.3319 .15535 m .33283 .14147 L .3127 .1439 L p .493 .355 .621 r
F P
0 g
s
.60862 .1439 m .60784 .15774 L .62893 .15535 L p .503 .366 .626 r
F P
0 g
s
.62893 .15535 m .6297 .14147 L .60862 .1439 L p .503 .366 .626 r
F P
0 g
s
.31176 .15774 m .31228 .17232 L .33242 .16998 L p .507 .439 .714 r
F P
0 g
s
.33437 .18468 m .33242 .16998 L .31228 .17232 L p .512 .509 .79 r
F P
0 g
s
.60784 .15774 m .60827 .17232 L .62936 .16998 L p .516 .445 .715 r
F P
0 g
s
.63096 .18468 m .62936 .16998 L .60827 .17232 L p .521 .513 .788 r
F P
0 g
s
.33242 .16998 m .3319 .15535 L .31176 .15774 L p .507 .439 .714 r
F P
0 g
s
.62936 .16998 m .62893 .15535 L .60784 .15774 L p .516 .445 .715 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00h03oool800000;<0oooo2000003M0?oo
o`00fP3oool8000000H0om1o0P00002[0?ooo`P000001P3nd7800`000000oooo0?ooo`3J0?ooo`00
e@3oool700000080<`0000<000000?o@O`3od7l02@3od7l200000:@0oooo2000000203X000030000
003nd780o]1b00L0o]1b00<000000?ooo`3oool0f@3oool00=80oooo1000000703<000030000003o
d7l0om1o00`0om1o00<000000?ooo`3oool0W`3oool4000000L0>P0000<000000?k@LP3nd7802@3n
d7800`000000oooo0?ooo`3H0?ooo`00d@3oool00`000000<`0003<0000803<000030000003od7l0
om1o00h0om1o00<000000?ooo`3oool0W@3oool00`000000>P0003X0000903X000030000003nd780
o]1b00X0o]1b00<000000?ooo`3oool0e`3oool00=00oooo00<0000003<0000c00000`0c00060000
0180om1o00<000000?ooo`3oool0V`3oool00`000000>P0003X0000303X000L000003P3nd7800`00
0000oooo0?ooo`3F0?ooo`00c`3oool7000000@0EP0K00<000000?o@O`3od7l04P3od7l00`000000
oooo0?ooo`2I0?ooo`L000001P1L02800`000000o]1b0?k@LP0=0?k@LP030000003oool0oooo0=D0
oooo003>0?ooo`030000001F01/0EP0K00T0EP0K00<000000?o@O`3od7l04`3od7l00`000000oooo
0?ooo`2G0?ooo`030000001L0280G00R00X0G00R00<000000?k@LP3nd7803`3nd7800`000000oooo
0?ooo`3D0?ooo`00cP3oool00`000000EP0K05H06`0805H06`030000003od7l0om1o01D0om1oV@3o
ool00`000000G00R05`08P0:05`08P030000003nd780o]1b0100o]1beP3oool00<d0oooo00<00000
05H06`1F01/02@1F01/00`000000om1o0?o@O`0E0?o@O`030000003oool0oooo09D0oooo00<00000
05`08P1L02802P1L02800`000000o]1b0?k@LP0A0?k@LP030000003oool0oooo0=<0oooo003<0?oo
o`030000001F01/0EP0K00H0EP0K1000000H0?o@O`030000003oool0oooo09D0oooo00<0000005`0
8P1L02801`1L0284000001<0o]1b00<000000?ooo`3oool0d`3oool00<`0oooo00<0000005H06`1F
01/01P00000306/LEP030000003od7l0om1o01L0om1o00<000000?ooo`3oool0T`3oool010000000
G00R05`08P1L0287000000<0Kb9K00<000000?k@LP3nd7804P3nd7800`000000oooo0?ooo`3B0?oo
o`00b`3oool4000000P0JaaF00<000000?o@O`3od7l0603od7l00`000000oooo0?ooo`2C0?ooo`@0
00002@1_8U/00`000000o]1b0?k@LP0C0?k@LP030000003oool0oooo0=80oooo003;0?ooo`030000
001[75H0JaaF00T0JaaF00<000000?o@O`3od7l06@3od7l00`000000oooo0?ooo`2B0?ooo`030000
001_8U/0Kb9K00X0Kb9K00<000000?k@LP3nd780503nd7800`000000oooo0?ooo`3A0?ooo`00bP3o
ool00`000000JaaF06/LEP0:06/LEP050000003od7l0om1o0?o@O`3od840603od7l00`000000oooo
0?ooo`2@0?ooo`030000001_8U/0Kb9K00/0Kb9K00<000000?k@LP3nd7805@3nd7;C0?ooo`00bP3o
ool00`000000JaaF06/LEP0:06/LEP030000003od7l0om1o01X0om1o00<000000?ooo`3oool0T03o
ool00`000000Kb9K06lRF`0;06lRF`030000003nd780o]1b01D0o]1b00<000000?ooo`3oool0d03o
ool00<X0oooo00<0000006/LEP1[75H02@1[75H00`000000om1o0?o@O`0L0?o@O`030000003oool0
oooo08l0oooo00<0000006lRF`1_8U/02P1_8U/00`000000o]1b0?k@LP0F0?k@LP030000003oool0
oooo0=00oooo00390?ooo`030000001[75H0JaaF00@0JaaF1`0000060?o@O`030?o@P@3od7l0om1o
01D0om1o00<000000?ooo`3oool0SP3oool00`000000Kb9K06lRF`0506lRF`L000006@3nd7800`00
0000oooo0?ooo`3?0?ooo`00b@3oool7000000H0Mcn000<000000?o@O`3od7l07@3od7l00`000000
oooo0?ooo`2=0?ooo`P000001P1jA8<00`000000o]1b0?k@LP0G0?k@LP030000003oool0oooo0<l0
oooo00390?ooo`030000001g?h00Mcn000T0Mcn000<000000?o@O`3od7l07P3od7l00`000000oooo
0?ooo`2=0?ooo`030000001jA8<0NTB300X0NTB300<000000?k@LP3nd7806@3nd7800`000000oooo
0?ooo`3>0?ooo`00b@3oool00`000000Mcn007LoP00907LoP0030000003od7l0om1o00L0om1o00<0
om210?o@O`3od7l05@3od7l00`000000oooo0?ooo`2<0?ooo`030000001jA8<0NTB300X0NTB300<0
00000?k@LP3nd7804`3nd7800`000000o]1b0?k@LP030?k@LP030000003oool0oooo0<h0oooo0039
0?ooo`030000001g?h00Mcn000T0Mcn000<000000?o@O`3od7l0803od7n>0?ooo`030000001jA8<0
NTB300X0NTB300<000000?k@LP3nd7806P3nd7;@0?ooo`00b03oool00`000000Mcn007LoP00:07Lo
P0030000003od7l0om1o0200om1oS@3oool00`000000NTB307Y4P`0;07Y4P`030000003nd780o]1b
01X0o]1bd03oool00<P0oooo00<0000007LoP01g?h002@1g?h000`000000om1o0?o@O`0:0?o@O`03
0?o@P@3od7l0om1o01@0om1o00<000000?ooo`3oool0RP3oool00`000000NTB307Y4P`0:07Y4P`03
0000003nd780o]1b01/0o]1b00<000000?ooo`3oool0c@3oool00<P0oooo00<0000007LoP01g?h00
2@1g?h000`000000om1o0?o@O`0Q0?o@O`030000003oool0oooo08X0oooo00<0000007Y4P`1jA8<0
2P1jA8<00`000000o]1b0?k@LP0E0?k@LP0308FQiP3nd780o]1b00<0o]1b00<000000?ooo`3oool0
c@3oool00<P0oooo00<0000007LoP01g?h00101g?h06000002<0om1o00<000000?ooo`3oool0RP3o
ool00`000000NTB307Y4P`0407Y4P`L000007@3nd7800`000000oooo0?ooo`3=0?ooo`00b03oool7
000000D0OUZN00<000000?o@O`3od7l08@3od7l00`000000oooo0?ooo`2:0?ooo`L000001P20GJ00
0`000000o]1b0?k@LP0K0?k@LP030000003oool0oooo0<d0oooo00380?ooo`030000001nFYh0OUZN
00T0OUZN00<000000?o@O`3od7l08P3od7l00`000000oooo0?ooo`290?ooo`0300000020GJ00P5fP
00X0P5fP00<000000?k@LP3nd780703nd7800`000000oooo0?ooo`3<0?ooo`00b03oool00`000000
OUZN07iJWP0907iJWP030000003od7l0om1o0280om1o00<000000?ooo`3oool0R@3oool00`000000
P5fP081MX00:081MX0030000003nd780o]1b01H0o]1b00<000000?k@LP3nd7800`3nd7800`000000
oooo0?ooo`3<0?ooo`00b03oool00`000000OUZN07iJWP0907iJWP030000003od7l0om1o02<0om1o
R`3oool00`000000P5fP081MX00:081MX0030000003nd780o]1b01d0o]1bcP3oool00<P0oooo00<0
000007iJWP1nFYh02@1nFYh00`000000om1o0?o@O`0S0?o@Oh/0oooo00<00000081MX020GJ002P20
GJ000`000000o]1b0?k@LP0M0?k@L/h0oooo00370?ooo`030000001nFYh0OUZN00X0OUZN00<00000
0?o@O`3od7l08`3od7l00`000000oooo0?ooo`270?ooo`0300000020GJ00P5fP00/0P5fP00<00000
0?k@LP3nd7807@3nd7;>0?ooo`00a`3oool00`000000OUZN07iJWP0:07iJWP030000003od7l0om1o
02<0om1o00<000000?ooo`3oool0Q`3oool00`000000P5fP081MX00;081MX0030000003nd780o]1b
01L0o]1b00<0Qi?H0?k@LP3nd7800`3nd7;>0?ooo`00a`3oool00`000000OUZN07iJWP0:07iJWP03
0000003od7l0om1o0140om1o00<0om210?o@O`3od7l03`3od7l00`000000oooo0?ooo`270?ooo`03
00000020GJ00P5fP00/0P5fP00<000000?k@LP3nd780103nd7800`3nd7@0o]1b0?k@LP0@0?k@LP03
08NCf03nd780o]1b00<0o]1b00<000000?ooo`3oool0b`3oool00<L0oooo00<0000007iJWP1nFYh0
101nFYh7000002D0om1o00<000000?ooo`3oool0Q`3oool00`000000P5fP081MX005081MX0L00000
7`3nd7800`000000oooo0?ooo`3;0?ooo`00a`3oool7000000H0PG2f00<000000?o@O`3od7l0903o
d7l00`000000oooo0?ooo`260?ooo`P000001P24LKL00`000000o]1b0?k@LP0M0?k@LP030000003o
ool0oooo0</0oooo00370?ooo`0300000021L;H0PG2f00X0PG2f00<000000?o@O`3od7l04`3od7l0
0`3od840om1o0?o@O`0>0?o@O`030000003oool0oooo08H0oooo00<0000008Aa]`24LKL02`24LKL0
0`000000o]1b0?k@LP0H0?k@LP0308NCf03nd780o]1b0080o]1b00<000000?ooo`3oool0b`3oool0
0<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@OaL000002P3od7l20000
08P0oooo00<0000008Aa]`24LKL02`24LKL010000000o]1b0?k@LP3nd78H000000@0o]1b00<00000
0?ooo`3oool0b`3oool00<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@01@0000050?o@O`0308F3b@3od7l0oooo08L0oooo00<0000008Aa
]`24LKL02`24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00D0000000<0o]1b
0?ooo`3oool0b`3oool00<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@01@3`a:@6000000030?o@O`3oool0oooo08H0oooo00<0000008Aa
]`24LKL02`24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00D0l/JQ1@000039
0?ooo`00a`3oool00`000000PG2f085`]P0:085`]P030000003od7l0om1o0080om1o502_Sk@00`00
0000l<BT0?34Y00;0?34Y0D00000P`3oool2000000d0Q76g00@000000?k@LP3nd780o]1b502_Sk@0
0`000000l/JQ0?;6X@0:0?;6X@D00000a03oool00<<0oooo1@00000<085`]P030000003od7l0om1o
0080om1o502_Sk@00`000000l<BT0?34Y00@0?34Y0<00000N`3oool500000080@cNM00<0000008Aa
]`24LKL02P24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00l0l/JQ0`000031
0?ooo`00`03oool3000000@0=bfH00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@04P3`a:@00`000000oooo0?ooo`1f0?ooo`<000001`13=id00`00
0000Q76g08Aa]`0:08Aa]`040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ404@3baZ40
0`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00403L]V00300000021L;H0PG2f
00L0PG2f100000040?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@2000007L0oooo00<0000004<g
W@13=id01`13=id00`000000Q76g08Aa]`0708Aa]`@000000`3nd78D0:n?]0030000003baZ40l/JQ
0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0100g;IP010000000
PG2f085`]P21L;H6000000<0Ph;:00<000000?o@O`3od7l00P3od7lD0:n?]0030000003`a:@0l<BT
0180l<BT0P00001g0?ooo`0300000013=id0@cNM00L0@cNM00@0000008Aa]`24LKL0Q76g1P000003
08F3b@040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?oo
o`2o0?ooo`00`03oool2000000D0=bfH1000000908>2bP030000003od7l0om1o0080om1o502_Sk@0
0`000000l<BT0?34Y00B0?34Y0030000003@ZAd0000007H0oooo00<0000004<gW@13=id01`13=id4
000000T0QH?900@000000?k@LP3nd780o]1b502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003o
ool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00@0=bfH00<0000008>2bP23P/X02P23P/X0
0`000000om1o0?o@O`020?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@00`000000d:TM0000001f
0?ooo`0300000013=id0@cNM00L0@cNM00<0000008F3b@25PlT02P25PlT010000000o]1b0?k@LP3n
d78D0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<00000
03L]V00g;IP0100g;IP00`000000Ph;:08>2bP0:08>2bP030000003od7l0om1o0080om1o502_Sk@0
0`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id01`13
=id00`000000QH?908F3b@0:08F3b@040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ40
4@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00503L]V00300000023
P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id01`13=id00`000000QH?908F3b@0;08F3b@03
0000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00503L]V00300000023P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0
om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<g
W@13=id01`13=id00`000000QH?908F3b@0;08F3b@030000003nd780o]1b01@0[hnd00<000000?;6
X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00503L]V003
00000023P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34
Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02013=id00`000000QH?908F3b@0:
08F3b@030000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00503L]V00300000023P/X0Ph;:00X0Ph;:00@000000?o@
O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0
000004<gW@13=id02013=id00`000000QH?908F3b@0:08F3b@030000003nd780o]1b01@0[hnd00<0
00000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V006
03L]V00300000023P/X0Ph;:00L0Ph;:0`0000030?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@0
10000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM00P0@cNM00<0000008F3b@25PlT01`25
PlT400000080o]1b502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo0030
0?ooo`030000000g;IP0=bfH00H0=bfH00@0000008>2bP23P/X0Ph;:1P00000208:BfP040000003o
d7l0om1o0?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`03
00000013=id0@cNM0080@cNM00<0lLFS04<gW@13=id00`13=id010000000QH?908F3b@25PlT60000
00<0Q9;I00<000000?k@LP3nd780502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo
0;l0oooo00300?ooo`030000000g;IP0=bfH00H0=bfH1000000908:BfP030000003od7l0om1o01@0
[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM
00P0@cNM1000000908BBf@030000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`00
0000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00603L]V00300000022T]X0om2100X0
PY;J00<000000?o@O`3od7l0502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM0000
07D0oooo00<0000004<gW@13=id02013=id00`000000Q9;I0?k@M00;08BBf@030000003nd780[hnd
01<0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000
=bfH03L]V00603L]V00500000022T]X0PY;J08:BfP0g;IP02022T]X00`000000om1o0?o@O`0D0:n?
]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@08
04<gW@0500000024T]T0Q9;I08BBf@13=id02@24T]T00`000000o]1b0:n?]00C0:n?]0030000003b
aZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP01`0g;IP0
0`000000PY;J08:BfP0208:BfP0303L]V022T]X0PY;J00D0PY;J00<000000?o@O`2_Sk@04`2_Sk@0
0`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02@13
=id00`000000Q9;I08BBf@0208BBf@0304<gW@24T]T0Q9;I00D0Q9;I00<000000?k@LP2_Sk@04`2_
Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0
=bfH00L0=bfH00<0000008:BfP22T]X01022T]X00`000000PY;J08:BfP0308:BfP030000003od7l0
[hnd01<0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013
=id0@cNM00T0@cNM00<0000008BBf@24T]T01024T]T00`000000Q9;I08BBf@0308BBf@030000003n
d780[hnd01<0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool0
0`000000=bfH03L]V00703L]V00300000022T]X0PY;J00H0PY;J00H0om2108:BfP22T]X0PY;J0000
003od7lD0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000
@cNM04<gW@0904<gW@0300000024T]T0Q9;I00H0Q9;I00<0o]1d08BBf@24T]T00P24T]T00`000000
[hnd0:n?]00B0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo
00<0000003L]V00g;IP01`0g;IP00`000000PY;J08:BfP0508:BfP030:n?]022T]X0PY;J00<0PY;J
00<000000:n?]02_Sk@04P2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0
oooo00<0000004<gW@13=id02@13=id00`000000Q9;I08BBf@0;08BBf@030000002_Sk@0[hnd0180
[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH
03L]V00803L]V00300000022T]X0PY;J00<0PY;J00<0000008:BfP22T]X00P22T]X3000001@0[hnd
00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM00X0
@cNM00<0000008BBf@24T]T02024T]T3000001@0[hnd00<000000?;6X@3baZ404@3baZ400`000000
oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00803L]V00300000022T]X0PY;J00P00000
0P20XNP00`000000[hnd0:n?]00B0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
0000M@3oool00`000000@cNM04<gW@0:04<gW@0400000024T]T0Q9;I08BBf@L000000P22XNL00`00
0000[hnd0:n?]00B0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00
oooo00<0000003L]V00g;IP0200g;IP300000007082Qj00g;IP0=bfH0000002_Sk@0P:7X0:n?]003
082Qj0030000002_Sk@0[hnd0180[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00
001e0?ooo`0300000013=id0@cNM00X0@cNM100000001P22XNL0@cNM0000002_Sk@0PZ7W0:n?]0<0
PZ7W00<000000:n?]02_Sk@04P2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0
oooo00300?ooo`030000000g;IP0=bfH00P0=bfH00<00000082Qj020XNP00`0g;IP00`000000[hnd
0:n?]0030:n?]080P:7X502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0
oooo00<0000004<gW@13=id01`13=id0103aaJ<0@cNM04<gW@00000208:Qi`<0@cNM00<000000:n?
]02_Sk@00`2_Sk@208:Qia@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?oo
o`00`03oool00`000000=bfH03L]V00803L]V00300000020XNP0P:7X00<0=bfH00<000000:n?]02_
Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<g
W@13=id02P13=id00`000000PZ7W08:Qi`0304<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6
X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00903L]V003
0000000g;IP0=bfH0080=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y004
0000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02013=id0103aaJ<0@cNM04<gW@000004
04<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00903L]V0030000000g;IP0=bfH0080=bfH00<000000:n?
]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<00000
04<gW@13=id02`13=id00`000000@cNM04<gW@0204<gW@030000002_Sk@0[hnd01T0[hnd00<00000
0?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]
V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e
0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A
0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?
]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<00000
04<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<00000
0?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP010000000[hnd0:n?]020XNPH
0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<g
W@0@04<gW@040000002_Sk@0[hnd000001P0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo
0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0040000002_Sk@0[hnd000001P0[hnd
00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100
@cNM00@000000:n?]02_Sk@0OJkc602_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo
0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00@000000:n?]02_Sk@0Njkd602_Sk@00`00
0000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id04013=id0
10000000[hnd0:n?]01m[_<H0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3o
ool00<00oooo00<0000003L]V00g;IP03P0g;IP010000000[hnd0:n?]01k[_@H0:n?]0030000003`
a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@040000
002_Sk@0[hnd07f^laP0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@0
4P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
0000M@3oool00`000000@cNM04<gW@0@04<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6X@3b
aZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000
002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`03
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@03
0000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@0
4P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00D000000:n?]02_Sk@0[hnd07:jo00G0:n?]0030000003`a:@0l<BT0180
l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@050000002_Sk@0[hnd
0:n?]01d^_`05`2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?oo
o`030000000g;IP0=bfH00h0=bfH00D000000:n?]02_Sk@0[hnd07:jo00G0:n?]0030000003`a:@0
l<BT0180l<BT00<000000=2Y7@3@ZAd01000001`0?ooo`<000004P13=id01@000000[hnd0:n?]02_
Sk@0M;[l01L0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool0
0`000000=bfH03L]V00>03L]V0050000002_Sk@0[hnd0:n?]01b^_`05`2_Sk@00`000000l<BT0?34
Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000?ooo`3oool0J`3oool300000080C3jP
00<0000004<gW@13=id04013=id01@000000[hnd0:n?]02_Sk@0M;[l01L0[hnd00<000000?;6X@3b
aZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000
002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@0000020>g1YP80
0000K03oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V0P00001/0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]0020:n?]0030>k2
Y@2_Sk@0[hnd01@0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@0000020>g1YP03
0000003AZal0000006/0oooo00<0000004`nX01<?Z000P1<?Z000`000000@cNM04<gW@0@04<gW@03
0000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd0080[hnd00<0k/:U0:n?]02_Sk@0
502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
0`2_Sk@00`3^`ZD0[hnd0:n?]00C0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000000G0?oooc`00000603oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
00000`3ooolD000000T0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@0
0000103oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00=0?34Y1400000
7@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0b:Bc01/0b:Bc4@00000;04<gW@030000
002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03o
ool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00@000000?34Y03`a:@0l<BT
3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc
0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000K0:n?]0030000003baZ40l/JQ0140l/JQ
00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?
]00A0:n?]0`000004P24K:l00`000000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b
[`0@0=^b[``000003`2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo0030
0?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@01`2_Sk@:000001P0Q6b_6`00001@
03Rji1D000007P3K/Zl:000000D0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0000000L000000`1SD:L00`00
0000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@000000>c0Y`3/`:L0k<2W2000000A
0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00P0=bfH2000000;06=@
Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`000001P3K/Zl00`000000k<2W0>c0Y`090>c0
Y`P000002@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00800000100
He2W2P00002f03Rji0L000004`3/`:L8000000030?;6X@000000oooo0<00oooo002m0?ooo`H00000
401SD:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001S
D:L0He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c
0?ooo`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<00000
0?[<V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<
V0D00000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0
oooo002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3o
ool2000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003o
d7`0000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o
03Rji1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool30000
00H0001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l
00D0om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<0
0000V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo
002F0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3
000000H0001l0`00003P03Rji0030000000h^^@0>;[T05d0>;[T0P0000070?o@O0<00000U03oool0
09<0oooo00@000000000B`0004/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@00000
0?34B`3`a4/00000T`3oool00940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;
03Rji0<0000000<0om1l0000003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;
00<0001;0P00003o03Rji540>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`80
0000100004/200000?l0>;[TE@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;
0000B`030000B`030000000h^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000
003oool0oooo08/0oooo002=0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji0800000
0`3`a4/00`000000oooo0?ooo`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T
00@000000?34B`3`a4/00000S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03o
ool200000?l0>;[TI@0h^^@2000008`0oooo002<0?ooo`8000005@0h^^@203Vji9X0>;[T00<00000
03Rji00h^^@03@0h^^@00`3F[k40>;[T03Rji02P03Rji0800000S03oool008`0oooo0P00000[03Rj
i0@0>K[TJ@0h^^@2000000<0001a2`0h^^@908ab/@030000003F[k40eZna00L0eZna200h^^@00`3F
[k40>;[T03Rji02N03Rji0800000S03oool008`0oooo00<0000003Rji00h^^@0?`0h^^@603Vji5P0
>;[T00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0
>;[T0P00002<0?ooo`00S03oool00`000000>;[T03Rji02K03Rji080001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma09d0>;[T00<000000?ooo`3oool0
RP3oool008`0oooo00<0000003Rji00h^^@0V00h^^@50000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@030?k?LIX0>;[T00<000000?ooo`3oool0RP3o
ool008`0oooo00<0000003Rji00h^^@0U@0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T09D0>;[T00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0<@0h^^@=03Vj
i5H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>K[T03Vji02D03Rji0030000003oool0oooo
08/0oooo002>0?ooo`800000IP0h^^@I03Vji1D0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji00=03Rji100>K[TM@0h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[TF00h^^@00`000000oooo
0?ooo`2>0?ooo`00T@3oool00`000000>;[T03Rji02@03Rji003000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
000003Rji00h^^@09P0h^^@00`0i^^@0>;[T03Rji00T03Rji0P0>K[T>`0h^^@00`000000oooo0?oo
o`2?0?ooo`00TP3oool200000900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]
03Rji0@0>K[T7@0h^^@200000980oooo002D0?ooo`030000000h^^@0>;[T08d0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji02=03Rji0030000003oool0oooo0980oooo002F0?ooo`80
0000S00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08X0>;[T0P00002F0?ooo`00
V03oool2000008X0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02803Rji0800000
V03oool009X0oooo0`00002703Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h
^^@3000009X0oooo002M0?ooo`800000Q@0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T08<0>;[T0P00002M0?ooo`00W`3oool2000008<0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji02103Rji0800000W`3oool00:40oooo1000001o03Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0O@0h^^@400000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T07P0>;[T1@00002U0?ooo`00ZP3oool5000007D0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00001`
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0KP0h^^@500000:l0oooo002d0?oo
o`D00000J`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06T0>;[T1@00002d0?oo
o`00^@3oool5000006H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01T03Rji0D0
0000^@3oool00;h0oooo1@00001Q03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
G`0h^^@500000;h0oooo00330?ooo`D00000G00h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T05X0>;[T1@0000330?ooo`00b03oool5000005L0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji01E03Rji0D00000b03oool00<d0oooo1`00001@03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0CP0h^^@700000<d0oooo003D0?ooo`X00000AP0h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T04@0>;[T2P00003D0?ooo`00gP3oool:000003`0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00j03Rji0X00000gP3oool00>P0oooo3@00
000_03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0;@0h^^@=00000>P0oooo003e
0?oooa0000007`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T01d0>;[T4000003e
0?ooo`00o`3oool60?oooaT000001P0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T
00@0>;[T6@00003o0?ooo`H0oooo003o0?oooal0oooo1`0000070000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@L00000o`3ooolO0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00``3oool3000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002`0?ooo`8000004@3oool00`000000NUVP07YIX005000005T0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj000000000000
3`3oool00`000000NUVP07YIX00607YIX0<00000EP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00
NUVP00L0NUVP0P00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Y`3oool00`000000Nfjj07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YI
X0800000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0
oooo00<0000007]^^P1kK[X01`1kK[X2000000d0oooo00<0000007YIX01jFJ00201jFJ000`000000
oooo0?ooo`1E0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
Z03oool00`000000Nfjj07]^^P0807]^^P030<1i003oool0oooo00/0oooo00<0000007YIX01jFJ00
201jFJ000`000000oooo0?ooo`1E0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00/0oooo00<0
000007YIX01jFJ001`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj0P00000<0?ooo`030000001jFJ00
NUVP00L0NUVP0P00001G0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool00`000000Nfjj07]^^P0707]^^P8000002`3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool02@3oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05H0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool0
2@3oool00`000000NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?oo
o`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^^P030<1i00000000
oooo00P0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1G0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^
^P8000002@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00P0
Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX00707YIX0800000F@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^
^P0707]^^P8000001`3oool00`000000NUVP07YIX00707YIX0030=fn^P000000oooo05T0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0
Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0F03oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^
^P1kK[X0201kK[X00`30N@0000000?ooo`050?ooo`030000001jFJ00NUVP00L0NUVP0P00001J0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000
Nfjj07]^^P0807]^^P030<1i00000000oooo00D0oooo00<0000007YIX01jFJ001`1jFJ02000005X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000
001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000001jFJ00NUVP00P0NUVP0P00001J0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^
^P0707]^^P8000001@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05T0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0
Nfjj00P0Nfjj0P0000040?ooo`030000001jFJ00NUVP00L0NUVP0P00001K0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool2000000T0Nfjj00<0`7T00000
003oool00`3oool00`000000NUVP07YIX00707YIX0800000F`3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo00<0000007]^^P1kK[X01`1kK[X2000000<0
oooo00<0000007YIX01jFJ00201jFJ02000005/0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0FP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:d0oooo00<0000007]^^P1kK[X0201kK[X200000080oooo00<0
000007YIX01jFJ001`1jFJ02000005`0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002]0?ooo`8000002@1kK[X01@30N@0000000?ooo`3oool0000000T0NUVP0P00
001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool0
0`000000Nfjj07]^^P0707]^^P80000000<0oooo0000001jFJ002@1jFJ02000005`0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj
00L0Nfjj1000000807YIX0030=fn^P000000000005d0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00P0Nfjj0`00000907YIX080
0000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo
0P00000907]^^P<000002@1jFJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000807YIX0040=fn^P1j
FJ00b<M6000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002_0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000907YIX0800000GP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1kK[X0201kK[X0
0`000000NUVP07YIX00707YIX0800000GP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:l0oooo0P00000907]^^P030000001jFJ00NUVP00L0NUVP0P00001N0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool00`000000
Nfjj07]^^P0707]^^P030000001jFJ00NUVP00L0NUVP00<0b<M60000003oool0G@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo00<0000007]^^P1kK[X0
201kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00
001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool2
000000T0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YI
X01jFJ001@1jFJ000`38adH000000?ooo`1N0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00/@3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00<0
NUVP0`00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
/@3oool2000000T0Nfjj00H0000007YIX01jFJ00NUVP0=fn^P1jFJ0200000600oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X00`000000
NUVP07YIX00307YIX0800000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00;80oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00307YIX0030<S7
AP000000oooo05l0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002b0?ooo`030000001kK[X0Nfjj00P0Nfjj00@0000007YIX03M_[X0NUVP0`00001P0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool2000000T0Nfjj00@0
000007YIX01jFJ00NUVP0P00001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00/P3oool2000000T0Nfjj00@0000007YIX01jFJ00NUVP0P00001Q0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool00`000000Nfjj07]^
^P0707]^^P060000003M_[X0NUVP07YIX038adH00000H@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00;<0oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP
0000000200000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;@0oooo00<0
000007]^^P1kK[X01`1kK[X010000000NUVP0<S7AP00001R0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00]03oool00`000000Nfjj07]^^P0807]^^P<00000HP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo8`00001C
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool>0000
00`0B3^N00<000000?74X`3aa:<0303aa:<?000004`0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo04L0oooo?P00003o0?ooob80oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`/000002@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om2600L0om262`00003o0?oooaL0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@09`2dTk@2000001<0om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`1H0?ooo`800000^P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0EP3oool200000004
04XON@000000000000000;P0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo05@0oooo0P00000304XON@03
0000003bYFh0lZE^00800000]P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0D@3oool3000000D0BQmi
00<000000?:UKP3bYFh00P3bYFh200000;@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04l0oooo0P00
000804XON@030000003bYFh0lZE^00@0lZE^0P00002b0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1=
0?ooo`8000002P1:7gT00`000000lZE^0?:UKP060?:UKP800000/03oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0B`3oool2000000`0BQmi00<000000?:UKP3bYFh0203bYFh200000:h0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo04P0oooo0`00000>04XON@030000003bYFh0lZE^00X0lZE^0P00002/0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`160?ooo`8000004@1:7gT00`000000lZE^0?:UKP0<0?:UKP800000
ZP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0A03oool2000001<0BQmi00<000000?:UKP3bYFh03P3b
YFh200000:P0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0440oooo0`00000E04XON@030000003bYFh0
lZE^0100lZE^0P00002V0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`800000601:7gT00`00
0000lZE^0?:UKP0B0?:UKP800000Y03oool00:00oooo00<0000004PkWP18>ih01018>ihX000000P0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`8000001P1:7gT]00000:80
oooo002C0?oooa@000004P17>Yh00`000000lLFS0?75X`0C0?75XaL00000<03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?oooaL000005@1EAJ<2000000h0mLRN5`00002C0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3bYFh08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00@00000
0?G8WP3eb9h0lZE^8P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS02T0EDFS00D000000?G8WP3eb9h0mLRN0?:UKP0Q0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<09@1EAJ<01@1:7gT0EDFS05E5X`1EAJ<0000000d0
mLRN00<0lZE^0?G8WP3eb9h05@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0303eb9h00`3bYFh0mLRN
0?G8WP0D0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<00`1:7gT0EDFS05E5X`02
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0S05E5X`0304XON@1EAJ<0EDFS00<0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
0280EDFS00<0BQmi05E5X`1EAJ<0101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<08P1EAJ<00`1:7gT0
EDFS05E5X`0405E5X`040000003eb9h0mLRN0?:UKR80mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0U05E5X`@0BQmi00<000000?:UKP3b
YFh08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS0200EDFS2@1:7gT00`000000lZE^0?:UKP050?:UKQh0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0K05E5X`h0BQmi00<0
00000?:UKP3bYFh02@3bYFhJ0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<05`1EAJ<B04XON@030000003bYFh0lZE^00d0lZE^5P3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
01<0EDFS5P1:7gT00`000000lZE^0?:UKP0B0?:UKQ40mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0>05E5Xa/0BQmi00<000000?:UKP3b
YFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XON@0K04XON@030000
003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT06`1:
7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0;05E5X`030000001:7gT0
BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`00
0000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0
EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0;05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN
0?G8WP090?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<0
00000?G8WP3eb9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G
0?:UKP030000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0;05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:U
KP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XON@0K04XON@03
0000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT0
6`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0;05E5X`030000001:
7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<0
0`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
00`0EDFS00<0000004XON@1:7gT06P1:7gT00`000000lZE^0?:UKP0H0?:UKP030000003eb9h0mLRN
00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0<05E5X`030000001:7gT0BQmi01X0BQmi00<000000?:UKP3bYFh0603bYFh00`000000
mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0301EAJ<00`000000BQmi04XON@0J04XON@030000003bYFh0lZE^01P0lZE^
00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS00`0EDFS00<0000004XON@1:7gT06P1:7gT00`000000lZE^0?:U
KP0H0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0<05E5X`030000001:7gT0BQmi01/0BQmi00<00000
0?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<00`000000BQmi04XON@0K04XO
N@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;`00000C00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H_00000080
oooo00<0000005E5X`1EAJ<0301EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0
lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS<@00000300d;QPh000000`0=2hH00`000000]9>d
0;BC]00X0;BC]1@0om262@00000800D0024000003P1EAJ<00`000000BQmi04XON@0K04XON@030000
003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<0
00000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`8000003P1EAJ<00`000000BQmi
04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00
00100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000
3P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0
203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@
QP3od8I00:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^
00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP110:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003b
YFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`8000003P1EAJ<00`000000BQmi04XON@0K
04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000110:eT
N`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`8000003P1EAJ<00`00
0000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260:eTN`110:eTN`80
00003P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3e
b9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]I7/0
@@2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000
003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000003o
d8H0[FAk0440[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3b
YFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@0
0`000000[FAk0:eTN`110:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0
lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d
02T0]9>d00<000000:eTN`2]I7/0@@2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`00
0000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000
]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440[FAk0P00000>05E5X`030000001:7gT0BQmi01/0
BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk
00<000000;BC]02dTk@0:02dTkA40:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000
003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000130:eTN`030000002d
Tk@0]9>d02P0]9>dA02]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:U
KP0G0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X
0;BC]4@0[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh0
0`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000>05E5X`030000001:7gT0BQmi
01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80
[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000
mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi
00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00
000?05E5X`030000001:7gT0BQmi01X0BQmi00<000000?:UKP3bYFh0603bYFh00`000000mLRN0?G8
WP070?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000?05E5X`030000001:7gT0BQmi01T0BQmi0`00000I
0?:UKP030000003eb9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000l0EDFS00<0000004XO
N@1:7gT05P1:7gT3000000<0Mm3o0P00000G0?:UKP030000003eb9h0mLRN00L0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`80
0000/P2]I7/2000000l0EDFS00<0000004XON@1:7gT04`1:7gT4000000L0Mm3o0`00000D0?:UKP03
0000003eb9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000l0EDFS00<0000004XON@1:7gT0
401:7gT4000000d0Mm3o0P00000B0?:UKP030000003eb9h0mLRN00L0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]
I7/2000000l0EDFS00<0000004XON@1:7gT03@1:7gT400000180Mm3o0`00000?0?:UKP030000003e
b9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;40[FAk0P00000?05E5X`030000001:7gT0
BQmi00/0BQmi1000000<07O@o`030?G8WP1gd?l0Mm3o00P0Mm3o0P00000=0?:UKP030000003eb9h0
mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk05d0[FAk00<0[[KO0:eTN`2]I7/0DP2]I7/00`00
0000EDFS05E5X`0=05E5X`030000001:7gT0BQmi00P0BQmi1000000L07O@o`8000002`3bYFh00`00
0000mLRN0?G8WP070?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00/0
EDFS00<0m<NP05E5X`000000201:7gT300000240Mm3o0`0000080?:UKP030000003eb9h0mLRN00L0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk06@0[FAk00<0[[KO0:eTN`2]I7/0B`2]I7/00`000000EDFS
05E5X`0=05E5X`030000001:7gT0BQmi00@0BQmi0`00000E07O@o`030000001gd?l0Mm3o00h0Mm3o
0P0000060?:UKP030000003eb9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0
000005E5X`1EAJ<03@1EAJ<010000000BQmi04XON@1:7gT3000001H0Mm3o1000000A07O@o`<00000
0`3bYFh00`000000mLRN0?G8WP070?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS00d0EDFS00@0000004XON@0000000000601gd?l200000003070`L0000000NdjA01@0Mm3o
0P0000000`3bYFh000000?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1_0:eTN`030:jfg`2]
I7/0[FAk0400[FAk00<0000005E5X`1EAJ<03@1EAJ<2000001@0Mm3o2@1`<7000`000000NdjA0000
000E07O@o`8000002@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0?
05E5X`800000401gd?l00`000000L31`070`L007070`L0040000002k^C80NdjA00000180Mm3o0`00
000;0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1f0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<00000
05E5X`1EAJ<04@1EAJ<2000000h0Mm3o00<00000070`L01`<7001`1`<70010000000NdjA07]>T@00
00020?G8WPh0Mm3o0P00000>0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0
EDFS01<0EDFS0`00000907O@o`0305E5X`000000000000T0L31`00@0000007]>T@1kCY400000103e
b9h907O@o`<00000403eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/00`2^]]l0[FAk0:eTN`0b
0:eTN`030000001EAJ<0EDFS01H0EDFS0P00000407O@o`@0EDFS00<00000070`L01`<700201`<700
1@000000NdjA07]>T@1kCY40000000D0mLRN101gd?l3000001<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0601EAJ<2000000H0EDFS00<00000070`L01`<7001`1`<700
0`000000NdjA07]>T@0207]>T@030000003eb9h0Mm3o00D0mLRN0P0000040?G8WP0305Q8Y03eb9h0
mLRN00l0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk08@0[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`00
0000EDFS05E5X`0P05E5X`030000001`<700L31`00L0L31`00<0000007]>T@1kCY400P1kCY400`00
0000mLRN0?G8WP0M0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS01l0
EDFS0P000009070`L0030000001kCY40NdjA00<0NdjA00<000000?G8WP3eb9h0703eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:eTN`2]I7/0R`2]I7/00`2^]]l0[FAk0:eTN`0T0:eTN`030000001EAJ<0EDFS01l0EDFS
00<00000070`L01`<700201`<7000`000000NdjA07]>T@0307]>T@030000003eb9h0mLRN01`0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07`1EAJ<00`000000L31`070`
L008070`L0030000001kCY40NdjA00<0NdjA00<000000?G8WP3eb9h0703eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0O05E5X`030000001`<700L31`00L0L31`00<00000
07]>T@1kCY401@1kCY400`000000mLRN0?G8WP0K0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eT
N`030000001EAJ<0EDFS01h0EDFS0P000009070`L0030000001kCY40NdjA00D0NdjA00<000000?G8
WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0N05E5X`03
0000001`<700L31`00P0L31`00<0000007]>T@1kCY401@1kCY400`000000mLRN0?G8WP0K0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS01h0EDFS00<00000070`L01`<700
201`<7000`000000NdjA07]>T@0507]>T@030000003eb9h0mLRN01/0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]
I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07P1EAJ<00`000000L31`070`L004070`L0040000001`
<700L31`000000T0NdjA00<000000?G8WP3eb9h06P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0M05E5X`8000002@1`<7000`000000NdjA07]>T@0707]>T@030000003e
b9h0mLRN01X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07@1EAJ<2
000000T0L31`00<0000007]>T@1kCY401`1kCY400`000000mLRN0?G8WP0J0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS01d0EDFS00<00000070`L01`<700201`<7000`00
0000NdjA07]>T@0807]>T@040000003eb9h0mLRN05Q8Y1P0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk
0;80[FAk00<0000005E5X`1EAJ<07@1EAJ<00`000000L31`070`L007070`L0030000001kCY40NdjA
00T0NdjA00<000000?G8WP3eb9h06@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS]P00000O05E5X`030000001`<700L31`00L0
L31`00<0000007]>T@1kCY402@1kCY400`000000mLRN0?G8WP0I0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ
0:fhh@2b0:fhh@030000001EAJ<0EDFS01`0EDFS0P000009070`L0030000001kCY40NdjA00T0NdjA
00<000000?G8WP1HB:@06@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5
X`0L05E5X`030000001`<700L31`00<0L31`00<0gij>070`L01`<7000P1`<7000`000000NdjA07]>
T@0:07]>T@030000003eb9h0mLRN01P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<00000
05E5X`1EAJ<0701EAJ<00`000000L31`070`L008070`L08000002`1kCY400`000000mLRN0?G8WP0H
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS01`0EDFS00<00000070`
L01`<7001`1`<703000000/0NdjA00<000000?G8WP3eb9h0603eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]
^>40/P2]^>400`000000EDFS05E5X`0K05E5X`8000002@1`<703000000`0NdjA00<000000?G8WP3e
b9h05`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0K05E5X`030000
001`<700L31`00P0L31`0P0000000`1EAJ<0000007]>T@0:07]>T@030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<06`1EAJ<00`000000L31`070`
L008070`L0040000001EAJ<0EDFS000000/0NdjA00<000000?G8WP3eb9h05`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0K05E5X`030000001`<700L31`00L0L31`0P00
000205E5X`030000001kCY40NdjA00X0NdjA00<000000?G8WP3eb9h05P3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0J05E5X`8000002@1`<70200000080EDFS0P00000;
07]>T@030000003eb9h0mLRN01H0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5
X`1EAJ<06P1EAJ<00`000000L31`070`L008070`L08000000P1EAJ<2000000/0NdjA00<000000?G8
WP3eb9h05P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS01<0lLFS5`00002d0:fhhA/000000P1EAJ<01@000000L31`070`L01`<700gij>
00H0L31`00@0000005E5X`1EAJ<0EDFS0P00000;07]>T@030000003eb9h0mLRN01H0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75
XaH0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO0H0EDFS00<00000070`
L01`<700201`<7001`000000EDFS05E5X`1EAJ<000000?G8WP0000002`1kCY400`000000mLRN0?G8
WP0E0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`0502^IG`5
05E5X`8000002@1`<7000`000000EDFS05E5X`0205E5X`030000003eb9h0000000/0NdjA00<00000
0?G8WP3eb9h05@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl
01D0[VEl101EAJ<00`000000L31`070`L008070`L0030000001EAJ<0EDFS0080EDFS00<000000?G8
WP0000002`1kCY400`000000mLRN0?G8WP0E0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04@3aaJ<H0:iUO0030000002]^>40[KSQ0;80
[KSQ00<000000:iUO02^IG`05@2^IG`405E5X`030000001`<700L31`00P0L31`00<0000005E5X`1E
AJ<00P1EAJ<010000000mLRN0?G8WP00000;07]>T@030000003eb9h0mLRN01@0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0
[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO0<0EDFS00<00000070`L01`
<700201`<7000`000000EDFS05E5X`0205E5X`040000003eb9h0mLRN000000/0NdjA00<000000?G8
WP3eb9h0503eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS0100lLFS6@2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01L0
[VEl0P1EAJ<00`000000L31`070`L007070`L0800000101EAJ<010000000mLRN0?G8WP00000;07]>
T@030000003eb9h0mLRN01@0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0?0?75XaX0[VEl0P00002b0:fhh@8000006@2^IG`01@1EAJ<0
0000070`L01`<700gij>00L0L31`0P00000405E5X`040000003eb9h0mLRN000000/0NdjA00<00000
0?G8WP3eb9h0503eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00l0lLFS6P2^IG`200000;80[KSQ0P00000J0:iUO0030000001`<700L31`
00P0L31`00<0000005E5X`1EAJ<00`1EAJ<01@000000mLRN0?G8WP3eb9h0000000/0NdjA00<00000
0?G8WP3eb9h04`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00h0lLFS6`2^IG`200000;80[KSQ0P00000J0:iUO0030000001`<700L31`
00P0L31`00<0000005E5X`1EAJ<00`1EAJ<01@000000mLRN0?G8WP3eb9h0000000/0NdjA00<00000
0?G8WP3eb9h04`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00h0lLFS6`2^IG`200000;80[KSQ0P00000J0:iUO0030000001`<700L31`
00L0L31`0P00000505E5X`050000003eb9h0mLRN0?G8WP0000002`1kCY400`000000mLRN0?G8WP0C
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<03@3aaJ<L0:iUO0800000/P2]^>42000001T0[VEl00<00000070`L01`<700201`<7020000
00D0EDFS00<000000?G8WP3eb9h00P3eb9h00`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN
0180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0=0?75Xa`0[VEl0P00002b0:fhh@8000006@2^IG`00`000000L31`070`L008070`L003
0000001EAJ<0EDFS00@0EDFS00<000000?G8WP3eb9h00P3eb9h00`000000NdjA07]>T@0907]>T@03
0000003eb9h0mLRN0180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0<0?75X`80[VEl00<0lLFS0:iUO02^IG`06@2^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl01P0[VEl00<00000070`L01`<700201`<7000`000000EDFS
05E5X`0405E5X`030000003eb9h0mLRN0080mLRN00<0000007]>T@1kCY402@1kCY400`000000mLRN
0?G8WP0B0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<02`3aaJ<40:iUO0030?75X`2^IG`0[VEl01P0[VEl00<000000:fhh@2]^>40/02]
^>400`000000[VEl0:iUO00H0:iUO0030000003OWXh0L31`00P0L31`00<0000005E5X`1EAJ<0101E
AJ<00`000000mLRN0?G8WP030?G8WP030000001kCY40NdjA00T0NdjA00<000000?G8WP3eb9h04@3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS00/0lLFS1@2^IG`00`3aaJ<0[VEl0:iUO00G0:iUO0030000002]^>40[KSQ0;00[KSQ00<00000
0:iUO02^IG`05`2^IG`00`000000L31`070`L008070`L08000001P1EAJ<00`000000mLRN0?G8WP03
0?G8WP030000001kCY40NdjA00T0NdjA00<000000?G8WP3eb9h04@3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00X0lLFS1`2^IG`00`3a
aJ<0[VEl0:iUO00F0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`05`2^IG`00`00
0000gij>070`L008070`L0030000001EAJ<0EDFS00D0EDFS00<000000?G8WP3eb9h00`3eb9h00`00
0000NdjA07]>T@0907]>T@030000003eb9h0mLRN0140mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75X`T0[VEl00<0lLFS0:iUO02^
IG`05@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01L0[VEl00<00000070`L01`
<700201`<7000`000000EDFS05E5X`0505E5X`030000003eb9h0mLRN0080mLRN00<0F4RT0?G8WP00
00002P1kCY400`000000mLRN0?G8WP0A0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ
00<000000:iUO02^IG`05`2^IG`00`000000L31`070`L008070`L0030000001EAJ<0EDFS00D0EDFS
00<000000?G8WP3eb9h0103eb9h00`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN0100mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`080?75X`d0[VEl00<0lLFS0:iUO02^IG`04P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^
IG`0[VEl01H0[VEl00<00000070`L01`<700201`<702000000L0EDFS00<000000?G8WP3eb9h0103e
b9h00`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN0100mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75X`h0[VEl00<0lLFS
0:iUO02^IG`04@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01H0[VEl00<00000
070`L01`<700201`<7000`000000EDFS05E5X`0605E5X`030000003eb9h0mLRN00D0mLRN00<00000
07]>T@1kCY401P1kCY4300000180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`070?75Xa00[VEl00<0lLFS0:iUO02^IG`0402^IG`00`00
0000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01H0[VEl3000000805E5X`050000003eb9h0mLRN
0?G8WP1HB:@00`3eb9h00`000000NdjA07]>T@0407]>T@8000000P2Cj_P00`000000mLRN0?G8WP0@
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<01P3aaJ<B0:iUO0030?75X`2^IG`0[VEl00l0[VEl00<000000:fhh@2]^>40/02]^>400`00
0000[VEl0:iUO00H0:iUO08000001`1=[OT00`000000EDFS05E5X`0605E5X`030000003eb9h0mLRN
00D0mLRN00<0000007]>T@1kCY400P1kCY42000000<0Tn[h00<000000?G8WP3eb9h04@3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00H0
lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01X0[VEl0`00000304f]n@80
0000201EAJ<00`000000mLRN0?G8WP060?G8WP80NdjA0P00000509?Zn0030000003eb9h0mLRN0140
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`050?75XbD0[VEl00<000000:fhh@2]^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@030000
002]^>40[KSQ0380[KSQ00<000000:iUO02^IG`07@2^IG`20000000304f]n@000000[VEl00P0EDFS
00<000000?G8WP3eb9h01P3eb9h:000001<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XaL0[VEl00<0lLFS0:iUO02^IG`0@02^
IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`07`2^
IG`200000080[VEl1`1EAJ<010000000mLRN0?G8WP1HB:@R0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0103aaJ<I0:iUO0030?75X`2^
IG`0[VEl03l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^
IG`0[VEl02@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ<K0:iUO0030?75X`2^IG`0
[VEl0300[VEl00<0[KSQ0:iUO02^IG`02`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0
[VEl0380[VEl00<000000:iUO02^IG`0902^IG`605E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`030?75
Xe`0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl
02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iUO0030;^I1P2]^>40[KSQ04H0
[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00V0:iUO0@0EDFS00<000000?G8WP1H
B:@08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS0080lLFSG@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl
00<000000:iUO02^IG`09P2^IG`405E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh010000000lLFS0?75X`3aaJ<R0:iUO0030?75
X`2^IG`0[VEl03T0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000
002^IG`0[VEl02L0[VEl0`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0902^IG`00`3aaJ<0[VEl0:iU
O00a0:iUO0030:fhh@2^IG`0[VEl00@0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iU
O00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0G`2^IG`0
0`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^IG`2
05E5X`030000000G0000mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo1`00000O04Lj
WP030000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02T0[VEl00<0EDFS0000003eb9h07P3eb9h7000009<0oooo002J0?ooo``0
00004`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^
IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN0180mLRN3000002J0?ooo`00
YP3oool=000000H0AcZN00<000000:iUO02^IG`0G`2^IG`00`2kV@H0000000000017000003@0[VEl
00<000000:iUO02^IG`0:P2^IG`00`000000mLRN0?G8WP050?G8WP`00000YP3oool00;<0ooooJP00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<00006000000000000J000002b0?ooo`00^@3oool0
0`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo
0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR
0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR
00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i
0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?oo
o`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?oo
o`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fh
hP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fh
hP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00
^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003o
ool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`00
0000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0
oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fh
hP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<0
00000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002k0?oo
o`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000
002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3o
ool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]
^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]
^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool0
0;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool20000
05l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo
00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`0=0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00d0oooo
00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`2i0?ooo`00^`3ooomQ000000l0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool03@3ooomQ00000;/0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00`0@3HL01@3od8T040f7
010=Q`0@3HL0000001@0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T0
1@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`06010=Q`030?o@R@000000]9>d01<0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00k@3ooolo
000000T040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Qcl00000k@3oool0
0>d0oooo00<0000008<51P231@H010231@H00`1Mb_P0P`D608<51P0e08<51PL040f700<0P`D6010=
Q`000000502dTk@00`000000om270?o@Q`060?o@Qcl0P`D600<000000?ooo`3oool0j`3oool00>d0
oooo00<0000008<51P231@H02`231@H00`1Mb_P0P`D608<51P0_08<51PP040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`050?o@Qd00P`D600<000000?ooo`3oool0j`3oool00>d0oooo
00<0000008<51P231@H04P231@H00`1Mb_P0P`D608<51P0Y08<51PL040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`040?o@Qd40P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0
000008<51P231@H060231@H305g:n2@0P`D60`0@3HL010231@H040f7010=Q`00000D0;BC]0030000
003od8L0om2700<0om27@P231@H00`000000oooo0?ooo`3[0?ooo`00k03oool00`000000P`D608<5
1P0P08<51P<0GL[h7`231@H4010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00P3o
d8M308<51P030000003oool0oooo0>/0oooo003/0?ooo`03000000231@H0P`D602L0P`D60`00000I
08<51P<040f700<000000;BC]02dTk@04P2dTk@010000000om270?o@Q`3od8M508<51P030000003o
ool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D602d0P`D61@2`[mLB08<51P8040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`1608<51P030000003oool0oooo0>X0oooo003/0?oo
o`03000000231@H0P`D603@0P`D61@2`[mL<08<51P03010=Q`000000]9>d01<0]9>d00<000000?o@
Q`231@H07@231@H50;2_eb@0P`D600<000000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P23
1@H0>`231@H00`2`[mL00000010=Q`02010=Q`H0P`D600<000000;BC]02dTk@04P2dTk@00`000000
P`D608<51P0[08<51PT0/:oG4P231@H00`000000oooo0?ooo`3Z0?ooo`00k03ooom900000540P`D6
3P00003/0?ooo`00k03oool00`000000/G>>0;5cSP050;5cSP030;2_e`2aLhh0/G>>09`0/G>>00<0
00000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0302aLhh20;2_eiH0/G>>00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh01@2aLhh00`2`[mL0/G>>0;5cSP0;0;5c
SP@0/:oGS@2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0J0;5cSP80
00000`2`[mMa0;5cSP030;2_e`2aLhh0/G>>0140/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;5cSP2aLhh02P2aLhh00`2`[mL0/G>>0;5cSP0D0;5cSPH0/:oGO@2aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0=0;5cSP030;2_e`2aLhh0/G>>01<0/G>>0P00
00060;5cSPD0/:oGH`2aLhh2000000l0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<00000
0;5cSP2aLhh03`2aLhh00`2`[mL0/G>>0;5cSP0A0;5cSP804006100000080;5cSP030;2_e`2aLhh0
/:oG00@0/:oGF`2aLhh201X040@000002`2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`00
0000/G>>0;5cSP0B0;5cSP030;2_e`2aLhh0/G>>00d0/G>>1P0@00H4000000d0/G>>00@0/:oG0;5c
SP2aLhh000000P0@3HL00`3od8T0/G>>0;5cSP1@0;5cSPH06P0@100000080;5cSP030000003oool0
oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>01@0/G>>00<0/:oG0000002aLhh02P2aLhh90100
1P030000003J/Zl0000001@0/G>>00<040f70;5cSP2aLhh00P0@3HL00`000000]9>d0;BC]0180;5c
SPT06P0@00<000000=^c[`0000001`2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/G>>0;5cSP0G0;5cSP8040061`2aLhh901001P050000003J/Zl0f[:_0=Zb[`0000006`2aLhh0102d
Tk@0/G>>0;5cSP2aLhh40;BC]3l0/G>>2@0J01001@000000fk>_0=^c[`3K/jl0000000H0/G>>00<0
00000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh06@2aLhh201001PD0/G>>200@00H0
0`000000f[:_0=Zb[`030=Zb[`030000002aLhh0/G>>0200/G>>0P2dTk@30;5cSP<0]9>d=`2aLhh8
01X040030000003K/jl0fk>_00<0fk>_00<000000;5cSP2aLhh00`2aLhh00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/G>>0;5cSP0L0;5cSP80400600<0/G>>01001P0@00H01`0@00H00`00
0000f[:_0=Zb[`030=Zb[`030000002aLhh0/G>>02P0/G>>0P2dTk@40;5cSP<0om27;@2aLhh901X0
40030000003K/jl0fk>_00<0fk>_0P0000040;5cSP030000003oool0oooo0>X0oooo003/0?ooo`03
0000002aLhh0/G>>01h0/G>>2@0@00H00`000000f[:_0=Zb[`050=Zb[`030000002aLhh0/G>>02l0
/G>>0P3od8L40;5cSP<0/:oG902aLhh901X040030000003K/jl0fk>_00D0fk>_0P0000030;5cSP03
0000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>01d0/G>>2@0@00H00`000000f[:_
0=Zb[`070=Zb[`030000002aLhh0/G>>03H0/G>>0P0000050;5cSP8000006`2aLhh901X040030000
003K/jl0fk>_00L0fk>_00D000000;5cSP2aLhh0/G>>0000003/0?ooo`00k03oool00`000000/G>>
0;5cSP0L0;5cSPT0400600<000000=Zb[`3J/Zl02@3J/Zl00`000000/G>>0;5cSP0m0;5cSP80/GB?
1P2aLhh20;5dSa40/G>>2@0J01000`000000fk>_0=^c[`090=^c[`040000002aLhh0/G>>00000>`0
oooo003/0?ooo`030000002aLhh0/G>>01`0/G>>200@00H00`000000f[:_0=Zb[`0;0=Zb[`030000
002aLhh0/G>>04@0/G>>0`2aM8l60;5cSP0301X0402aLhh0/G>>00H0/G>>2@0J01000`000000fk>_
0=^c[`0;0=^c[`030000002aLhh000000>`0oooo003/0?ooo`030000002aLhh0/G>>01/0/G>>200@
00H00`000000f[:_0=Zb[`0=0=Zb[`030000002aLhh0/G>>04/0/G>>0`0J01060;5cSPT06P0@00<0
00000=^c[`3K/jl03@3K/jl200000>`0oooo003/0?ooo`030000002aLhh0/G>>01X0/G>>200@00H0
0`000000f[:_0=Zb[`0?0=Zb[`030000002aLhh0/G>>0580/G>>2@0J01000`000000fk>_0=^c[`0?
0=^c[`030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>01T0/G>>200@00H00`00
0000f[:_0=Zb[`0@0=Zb[`030000002aLhh0/G>>0540/G>>2@0J01000`000000fk>_0=^c[`0@0=^c
[`800000j`3oool00>`0oooo00<000000;5cSP2aLhh0602aLhh901001P030000003J/Zl0f[:_0140
f[:_00<000000;5cSP2aLhh0C`2aLhh:01X040030000003K/jl0fk>_0140fk>_0P00003Z0?ooo`00
k03ooolL000000L0400600<000000=Zb[`3J/Zl04`3J/ZmB000000P06P0@00<000000=^c[`3K/jl0
4`3K/jl00`000000oooo0?ooo`3X0?ooo`00k03oool00`000000/;3G0;2`e`0H0;2`e`030012`@00
00000000008000000P0@00H00`000000f[:_0=Zb[`0E0=Zb[`030000002`/=L0/;3G04d0/;3G00<0
04W70000000000000P00000301X040030000003K/jl0fk>_01D0fk>_00<000000?ooo`3oool0i`3o
ool00>`0oooo00<000000;2`e`2`/=L06@2`/=L40012`@8000005`3J/Zl00`000000/;3G0;2`e`1?
0;2`e`@004W70`00000G0=^c[`030000003oool0oooo0>P0oooo003/0?ooo`030000002`/=L0/;3G
01X0/;3G1@00@/400`000000f[:_0=Zb[`0C0=Zb[`030000002`/=L0/;3G0540/;3G1P00BLL00`00
0000fk>_0=^c[`0C0=^c[`800000jP3oool00>`0oooo00<000000;2`e`2`/=L06`2`/=L50012`@03
0000003J/Zl0f[:_0140f[:_00<000000;2`e`2`/=L0D`2`/=L60019a`030000003K/jl0fk>_0140
fk>_0P00003[0?ooo`00k03oool00`000000/;3G0;2`e`0L0;2`e`D004;100<000000=Zb[`3J/Zl0
403J/Zl00`000000/;3G0;2`e`1D0;2`e`H004W700<000000=^c[`3K/jl0403K/jl00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`0M0;2`e`D004;100<000000=Zb[`3J/Zl03P3J
/Zl00`000000/;3G0;2`e`1F0;2`e`H004W700<000000=^c[`3K/jl03P3K/jl200000>`0oooo003/
0?ooo`030000002`/=L0/;3G01h0/;3G1@00@/400`000000f[:_0=Zb[`0<0=Zb[`030000002`/=L0
/;3G05P0/;3G1P00BLL00`000000fk>_0=^c[`0<0=^c[`030000002`/=L000000>`0oooo003/0?oo
o`030000002`/=L0/;3G01h0/;3G1P00@/400`000000f[:_0=Zb[`0:0=Zb[`030000002`/=L0/;3G
00d0/;3G00<0/GB?0;2`e`2`/=L0BP2`/=L60019a`030000003K/jl0fk>_00X0fk>_00@000000;2`
e`2`/=L00000k03oool00>`0oooo00<000000;2`e`2`/=L07`2`/=L60012`@030000003J/Zl0f[:_
00P0f[:_00<000000;2`e`2`/=L05`2`/=L20;5dSd<0/;3G1P00BLL00`000000fk>_0=^c[`080=^c
[`050000002`/=L0/;3G0;2`e`000000k03oool00>`0oooo00<000000;2`e`2`/=L0802`/=L60012
`@030000003J/Zl0f[:_00H0f[:_00<000000;2`e`2`/=L08@2`/=L20;5dSc/0/;3G1P00BLL00`00
0000fk>_0=^c[`060=^c[`8000000`2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/;3G0;2`e`0Q0;2`e`H004;100<000000=Zb[`3J/Zl0103J/Zl00`000000/;3G0;2`e`0[0;2`e`<0
/GB?<P2`/=L60019a`030000003K/jl0fk>_00@0fk>_0P0000040;2`e`030000003oool0oooo0>X0
oooo003/0?ooo`030000002`/=L0/;3G0280/;3G1P00@/400`000000f[:_0=Zb[`030=Zb[`030000
002`/=L0/;3G03@0/;3G102aM8lY0;2`e`H004W700<000000=^c[`3K/jl00`3K/jl00`000000/;3G
0;2`e`030;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G02<0/;3G0P00
00040012`@050000003J/Zl0f[:_0=Zb[`000000@02`/=L400000240/;3G0P0000040019a`050000
003K/jl0fk>_0=^c[`0000001P2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G
0;2`e`0U0;2`e`@0000000@004;10000003J/Zl00000BP2`/=L508H;3AT0/;3G100000001000BLL0
00000=^c[`0000070;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G02T0
/;3G0`00001D0;2`e`H0QP/=4`2`/=L3000000P0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;2`e`2`/=L0R@2`/=L608H;3AD0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<0
00000;2`e`2`/=L0TP2`/=L508H;3@d0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<00000
0;2`e`2`/=L0V`2`/=L308H;3@H0/;3G00<000000?ooo`3oool0jP3oool00>`0ooooZ000003/0?oo
o`00k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo003/0?ooo`030000
001Fb?D0E/Se0:@0E/Se00<000000?ooo`3oool0jP3oool00>d0oooo00<0000005K8m@1Fb?D0XP1F
b?D00`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000E/Se05K8m@2R05K8m@030000003oool0
oooo0>/0oooo003]0?ooojH00000k@3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo0000\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.65808 .41234 m .6195 .41337 L .6195 .24609 L p .649 .53 .705 r
F P
0 g
s
.6195 .24609 m .65808 .24471 L .65808 .41234 L p .649 .53 .705 r
F P
0 g
s
.6195 .41337 m .5885 .40982 L .5885 .24132 L p .898 .734 .669 r
F P
0 g
s
.5885 .24132 m .6195 .24609 L .6195 .41337 L p .898 .734 .669 r
F P
0 g
s
.65808 .41234 m .65808 .24471 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.68245 .40731 m .67551 .40874 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.67551 .40874 m .65808 .41234 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.68918 .24604 m .6868 .25851 L p .67551 .27142 L .78 .637 .703 r
F P
0 g
s
.67551 .26559 m .68918 .24604 L .67551 .27142 L .78 .637 .703 r
F
.689 .23321 m .68918 .24604 L p .67551 .26559 L F P
0 g
s
.67551 .25771 m .689 .23321 L .67551 .26559 L .78 .637 .703 r
F
.65808 .24471 m .67551 .23987 L p .67551 .27929 L .228 .186 .601 r
F P
0 g
s
.66504 .29113 m .67551 .27929 L .67551 .36098 L .228 .186 .601 r
F
.65808 .24471 m .67551 .27929 L .66504 .29113 L F
.67551 .27929 m .68195 .27008 L .68315 .26923 L p 0 0 0 r
F P
0 g
s
.68315 .26923 m .6865 .26686 L p .68245 .27144 L 0 0 0 r
F P
0 g
s
.68245 .27144 m .67551 .27929 L .68315 .26923 L 0 0 0 r
F
.65808 .24471 m .67551 .23987 L p .5885 .24132 L .289 .763 .934 r
F P
0 g
s
.6806 .24012 m .68625 .22057 L .68507 .24034 L .78 .637 .703 r
F
.67551 .24618 m .6781 .24 L .67551 .25771 L F
.6781 .24 m .68625 .22057 L .6806 .24012 L F
.6781 .24 m .6806 .24012 L .67551 .25771 L F
.5885 .24132 m .67551 .23987 L .65578 .2389 L .289 .763 .934 r
F
.68107 .20866 m .68625 .22057 L p .6781 .24 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .67172 .23968 L .6781 .24 L .78 .637 .703 r
F
.67172 .23968 m .68107 .20866 L .6781 .24 L F
.67366 .19801 m .68107 .20866 L p .65515 .29467 L F P
0 g
s
.66435 .18907 m .67366 .19801 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .65578 .2389 L .62026 .23715 L .289 .763 .934 r
F
.5885 .24132 m .6195 .24609 L .65808 .24471 L p F P
0 g
s
.65353 .18223 m .66435 .18907 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.64167 .1778 m .65353 .18223 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.6293 .17598 m .64167 .1778 L p .64868 .23855 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .64286 .23826 L .64868 .23855 L .78 .637 .703 r
F
.64286 .23826 m .6293 .17598 L .64868 .23855 L F
.61694 .17686 m .6293 .17598 L p .65515 .29467 L F P
0 g
s
.60513 .18039 m .61694 .17686 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.59441 .18645 m .60513 .18039 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .62026 .23715 L .6055 .23642 L .289 .763 .934 r
F
.58523 .19475 m .59441 .18645 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .6055 .23642 L .59504 .23591 L .289 .763 .934 r
F
.57802 .20495 m .58523 .19475 L p .61471 .23688 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .60506 .2364 L .61471 .23688 L .78 .637 .703 r
F
.60506 .2364 m .57802 .20495 L .61471 .23688 L F
.58456 .23539 m .5885 .24132 L p .59504 .23591 L .289 .763 .934 r
F P
0 g
s
.57309 .21659 m .57802 .20495 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.57067 .22916 m .57309 .21659 L p .58456 .2275 L .78 .637 .703 r
F P
0 g
s
.58456 .23993 m .57067 .22916 L .58456 .2275 L .78 .637 .703 r
F
.5885 .24132 m .5885 .29475 L p .58511 .27763 L .88 .718 .202 r
F P
0 g
s
.58456 .23539 m .5885 .24132 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58643 .27753 m .57892 .26684 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.57892 .26684 m .58456 .27487 L p .58344 .2692 L 0 .237 .754 r
F P
0 g
s
.57086 .24211 m .57067 .22916 L p .58456 .23993 L .78 .637 .703 r
F P
0 g
s
.58456 .25065 m .57086 .24211 L .58456 .23993 L .78 .637 .703 r
F
.57365 .25485 m .57086 .24211 L p .65515 .29467 L F P
0 g
s
.57892 .26684 m .57365 .25485 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.58299 .23303 m .58456 .23539 L p .58456 .27487 L .88 .718 .202 r
F P
0 g
s
.58299 .23303 m .58456 .27487 L .58437 .27388 L .88 .718 .202 r
F
.58299 .23303 m .58456 .27967 L .58441 .27855 L F
.58344 .2692 m .58299 .26693 L .57892 .26684 L 0 .237 .754 r
F
.58241 .26403 m .58054 .26553 L p .58299 .26693 L F P
0 g
s
.58054 .26553 m .57892 .26684 L p .58299 .26693 L 0 .237 .754 r
F P
0 g
s
.57875 .25064 m .57365 .25485 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.58299 .26821 m .58299 .23303 L p .58441 .27855 L .88 .718 .202 r
F P
0 g
s
.65515 .29467 m .58456 .25065 L .58456 .23993 L .78 .637 .703 r
F
.65515 .29467 m .58456 .23993 L .58456 .2275 L F
.58299 .23303 m .58456 .23539 L p .59438 .23129 L .289 .763 .934 r
F P
0 g
s
.58299 .23303 m .58299 .26693 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.61035 .23208 m .58973 .20807 L .62006 .23256 L .781 .637 .703 r
F
.57819 .21213 m .58315 .20041 L p .58973 .20807 L F P
0 g
s
.59504 .23591 m .60027 .23158 L .58456 .23539 L .289 .763 .934 r
F
.61035 .23208 m .58973 .22311 L .58973 .20807 L .781 .637 .703 r
F
.59853 .23149 m .58973 .22311 L .61035 .23208 L F
.60027 .23158 m .59438 .23129 L .58456 .23539 L .289 .763 .934 r
F
.58973 .23106 m .58299 .23303 L p .59438 .23129 L F P
0 g
s
.58973 .23106 m .58299 .23303 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.57575 .22478 m .57819 .21213 L p .59853 .23149 L .781 .637 .703 r
F P
0 g
s
.59504 .23591 m .61208 .23217 L .60027 .23158 L .289 .763 .934 r
F
.58973 .20807 m .58973 .20614 L .62006 .23256 L .781 .637 .703 r
F
.58315 .20041 m .59041 .19015 L p .62006 .23256 L F P
0 g
s
.6055 .23642 m .61908 .23251 L .59504 .23591 L .289 .763 .934 r
F
.64167 .1778 m .6293 .17598 L .63474 .17128 L p .28 .735 .955 r
F P
0 g
s
.64839 .23397 m .63474 .17128 L .65424 .23426 L .781 .637 .703 r
F
.6293 .17598 m .61694 .17686 L .6223 .17215 L p .35 .814 .921 r
F P
0 g
s
.6223 .17215 m .63474 .17128 L .6293 .17598 L p .35 .814 .921 r
F P
0 g
s
.6223 .17215 m .63474 .17128 L p .64839 .23397 L .781 .637 .703 r
F P
0 g
s
.64224 .23366 m .6223 .17215 L .64839 .23397 L .781 .637 .703 r
F
.65353 .18223 m .64167 .1778 L .64719 .17311 L p .206 .636 .95 r
F P
0 g
s
.63474 .17128 m .64719 .17311 L .64167 .1778 L p .28 .735 .955 r
F P
0 g
s
.63474 .17128 m .64719 .17311 L p .65424 .23426 L .781 .637 .703 r
F P
0 g
s
.62026 .23715 m .6456 .23383 L .6055 .23642 L .289 .763 .934 r
F
.68625 .22057 m .68107 .20866 L .68682 .20418 L p 0 .126 .666 r
F P
0 g
s
.68107 .20866 m .67366 .19801 L .67937 .19346 L p 0 .267 .772 r
F P
0 g
s
.67937 .19346 m .68682 .20418 L .68107 .20866 L p 0 .267 .772 r
F P
0 g
s
.67937 .19346 m .68123 .19613 L p .67742 .23541 L .781 .637 .703 r
F P
0 g
s
.68123 .19613 m .68682 .20418 L p .68123 .22276 L .781 .637 .703 r
F P
0 g
s
.67742 .23541 m .68123 .19613 L .68123 .22276 L .781 .637 .703 r
F
.6714 .23511 m .67937 .19346 L .67742 .23541 L F
.68245 .23794 m .68123 .23559 L p .62026 .23715 L .289 .763 .934 r
F P
0 g
s
.67742 .23541 m .68682 .20418 L .68384 .23572 L .781 .637 .703 r
F
.62026 .23715 m .68123 .23559 L .6456 .23383 L .289 .763 .934 r
F
.65578 .2389 m .68245 .23794 L .62026 .23715 L F
.67551 .23987 m .68245 .23794 L p .65578 .2389 L F P
0 g
s
.65515 .29467 m .67551 .24618 L .67551 .25771 L .78 .637 .703 r
F
.65515 .29467 m .67551 .25771 L .67551 .26559 L F
.65515 .29467 m .67551 .26559 L .67551 .27142 L F
.6868 .25851 m .68195 .27008 L p .65515 .29467 L F P
0 g
s
.68195 .27008 m .67484 .28024 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.67484 .28024 m .66578 .28856 L .65515 .29467 L p .78 .637 .703 r
F P
0 g
s
.67366 .19801 m .66435 .18907 L .67 .18446 L p .058 .399 .855 r
F P
0 g
s
.67 .18446 m .67937 .19346 L .67366 .19801 L p .058 .399 .855 r
F P
0 g
s
.67 .18446 m .67937 .19346 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.66435 .18907 m .65353 .18223 L .65912 .17757 L p .132 .522 .915 r
F P
0 g
s
.65912 .17757 m .67 .18446 L .66435 .18907 L p .132 .522 .915 r
F P
0 g
s
.65912 .17757 m .67 .18446 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.64719 .17311 m .65912 .17757 L .65353 .18223 L p .206 .636 .95 r
F P
0 g
s
.64719 .17311 m .65912 .17757 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68123 .23559 m .67809 .22957 L p .6456 .23383 L .289 .763 .934 r
F P
0 g
s
.68625 .22057 m .689 .23321 L p .68507 .24034 L .78 .637 .703 r
F P
0 g
s
.689 .23321 m .68625 .22057 L .69204 .21617 L p 0 0 .536 r
F P
0 g
s
.68682 .20418 m .69204 .21617 L .68625 .22057 L p 0 .126 .666 r
F P
0 g
s
.68682 .20418 m .69204 .21617 L p .68384 .23572 L .781 .637 .703 r
F P
0 g
s
.67551 .25771 m .6806 .24012 L .68507 .24034 L .78 .637 .703 r
F
.68195 .27008 m .6868 .25851 L .69259 .25436 L p 0 0 0 r
F P
0 g
s
.67551 .36098 m .68022 .27748 L .68245 .40731 L .228 .186 .601 r
F
.69259 .25436 m .68943 .2619 L p .68195 .27008 L 0 0 0 r
F P
0 g
s
.6865 .26686 m .68195 .27008 L p .68943 .2619 L 0 0 0 r
F P
0 g
s
.68245 .23794 m .68245 .27371 L p .68022 .27748 L .228 .186 .601 r
F P
0 g
s
.68245 .27371 m .68245 .40731 L p .68022 .27748 L .228 .186 .601 r
F P
0 g
s
.68943 .2619 m .68771 .266 L .6865 .26686 L p 0 0 0 r
F P
0 g
s
.67551 .23987 m .68245 .23794 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.67484 .28024 m .67551 .27929 L p .6823 .27189 L 0 0 0 r
F P
0 g
s
.68226 .27203 m .67484 .28024 L .6823 .27189 L 0 0 0 r
F
.68245 .40731 m .68245 .27144 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.67809 .40107 m .68123 .40556 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.68123 .40556 m .68245 .40731 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.68102 .27329 m .67551 .27929 L .68106 .27301 L 0 0 0 r
F
.68147 .2745 m .67809 .40107 L .68245 .27144 L .849 .693 .16 r
F
.68102 .27329 m .68106 .27301 L .6865 .26686 L 0 0 0 r
F
.6865 .26686 m .68771 .266 L p .68102 .27329 L F P
0 g
s
.66578 .28856 m .67484 .28024 L .68056 .27623 L p 0 0 0 r
F P
0 g
s
.68147 .2745 m .68123 .27527 L .68123 .28367 L .849 .693 .16 r
F
.68056 .27623 m .67484 .28024 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68771 .266 m .68123 .27527 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68123 .27527 m .68056 .27623 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68123 .28367 m .68082 .27656 L .67809 .40107 L .849 .693 .16 r
F
.66075 .29074 m .68123 .27195 L .68056 .27623 L .781 .637 .703 r
F
.68123 .27527 m .68056 .27623 L p .68123 .27195 L F P
0 g
s
.68245 .23794 m .68123 .23559 L p .68123 .27527 L .849 .693 .16 r
F P
0 g
s
.68245 .23794 m .68123 .27527 L .68147 .2745 L .849 .693 .16 r
F
.68245 .27144 m .68245 .23794 L p .68147 .2745 L F P
0 g
s
.66075 .29074 m .67742 .23541 L .68384 .23572 L .781 .637 .703 r
F
.68056 .27623 m .67144 .2846 L .66578 .28856 L p 0 0 0 r
F P
0 g
s
.6868 .25851 m .68918 .24604 L .69499 .24181 L p 0 0 .196 r
F P
0 g
s
.69499 .24181 m .69259 .25436 L .6868 .25851 L p 0 0 .196 r
F P
0 g
s
.69499 .24181 m .69259 .25436 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68918 .24604 m .689 .23321 L .6948 .2289 L p 0 0 .38 r
F P
0 g
s
.6948 .2289 m .69499 .24181 L .68918 .24604 L p 0 0 .38 r
F P
0 g
s
.6948 .2289 m .69499 .24181 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.69204 .21617 m .6948 .2289 L .689 .23321 L p 0 0 .536 r
F P
0 g
s
.69204 .21617 m .6948 .2289 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.69259 .25436 m .68771 .266 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68056 .27623 m .67144 .2846 L .66075 .29074 L p .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .67809 .28511 L p .68082 .27656 L .849 .693 .16 r
F P
0 g
s
.67809 .28511 m .67809 .40107 L p .68082 .27656 L .849 .693 .16 r
F P
0 g
s
.68771 .266 m .68226 .27203 L .6823 .27189 L 0 0 0 r
F
.68771 .266 m .68123 .27527 L p .68123 .27195 L .781 .637 .703 r
F P
0 g
s
.68123 .23559 m .67809 .22957 L p .68123 .28367 L .849 .693 .16 r
F P
0 g
s
.6456 .23383 m .63733 .23342 L .6055 .23642 L .289 .763 .934 r
F
.6055 .23642 m .63733 .23342 L .61908 .23251 L F
.61694 .17686 m .60513 .18039 L .61042 .17571 L p .41 .861 .84 r
F P
0 g
s
.61042 .17571 m .6223 .17215 L .61694 .17686 L p .41 .861 .84 r
F P
0 g
s
.61042 .17571 m .6223 .17215 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.6456 .23383 m .67809 .22957 L .63733 .23342 L .289 .763 .934 r
F
.66075 .29074 m .6714 .23511 L .67742 .23541 L .781 .637 .703 r
F
.66075 .29074 m .64224 .23366 L .64839 .23397 L F
.60513 .18039 m .59441 .18645 L .59963 .1818 L p .453 .864 .705 r
F P
0 g
s
.59963 .1818 m .61042 .17571 L .60513 .18039 L p .453 .864 .705 r
F P
0 g
s
.59963 .1818 m .61042 .17571 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.59041 .19015 m .59963 .1818 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .64674 .22455 L p .61908 .23251 L .289 .763 .934 r
F P
0 g
s
.63733 .23342 m .67809 .22957 L .61908 .23251 L .289 .763 .934 r
F
.61908 .23251 m .64674 .22455 L .61208 .23217 L F
.61908 .23251 m .61208 .23217 L .59504 .23591 L F
.66075 .29074 m .64839 .23397 L .65424 .23426 L .781 .637 .703 r
F
.66075 .29074 m .58973 .23563 L .59853 .23149 L F
.64674 .22455 m .607 .22601 L p .60027 .23158 L .289 .763 .934 r
F P
0 g
s
.61208 .23217 m .64674 .22455 L .60027 .23158 L .289 .763 .934 r
F
.66075 .29074 m .59853 .23149 L .61035 .23208 L .781 .637 .703 r
F
.59585 .28646 m .58643 .27753 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.60676 .29324 m .59585 .28646 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.61868 .29758 m .60676 .29324 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.60676 .29324 m .61868 .29758 L .62406 .29366 L p .163 .617 .934 r
F P
0 g
s
.59585 .28646 m .60676 .29324 L .61207 .28929 L p .087 .502 .901 r
F P
0 g
s
.62406 .29366 m .61207 .28929 L .60676 .29324 L p .163 .617 .934 r
F P
0 g
s
.58643 .27753 m .59585 .28646 L .60109 .28246 L p .011 .374 .84 r
F P
0 g
s
.61207 .28929 m .60109 .28246 L .59585 .28646 L p .087 .502 .901 r
F P
0 g
s
.60109 .28246 m .59161 .27347 L .58643 .27753 L p .011 .374 .84 r
F P
0 g
s
.57594 .23781 m .57575 .22478 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58973 .25544 m .58299 .26693 L .58973 .27079 L .206 .168 .592 r
F
.57875 .25064 m .57594 .23781 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58405 .26271 m .57875 .25064 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.59161 .27347 m .58973 .27079 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58973 .27079 m .58405 .26271 L p .58973 .26478 L .781 .637 .703 r
F P
0 g
s
.66075 .29074 m .58973 .27079 L .58973 .26478 L .781 .637 .703 r
F
.58299 .40365 m .58299 .26821 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58441 .27855 m .58456 .28348 L .58299 .26821 L .88 .718 .202 r
F
.58456 .28348 m .58511 .27763 L .5885 .40982 L F
.5885 .29475 m .5885 .40982 L p .58511 .27763 L F P
0 g
s
.5885 .40982 m .58456 .40541 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58456 .40541 m .58299 .40365 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58299 .26693 m .58299 .40365 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.59161 .27347 m .58405 .26271 L .58241 .26403 L p 0 .237 .754 r
F P
0 g
s
.59161 .27347 m .58241 .26403 L .58344 .2692 L 0 .237 .754 r
F
.58643 .27753 m .59161 .27347 L p .58344 .2692 L F P
0 g
s
.60109 .28246 m .59161 .27347 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.60014 .27675 m .58973 .27079 L .58973 .35378 L .206 .168 .592 r
F
.58437 .27388 m .58456 .27487 L .58456 .27967 L .88 .718 .202 r
F
.58441 .27855 m .58456 .27967 L .58456 .28348 L F
.58456 .27487 m .58643 .27753 L p .58344 .2692 L 0 .237 .754 r
F P
0 g
s
.58973 .27079 m .58299 .26693 L .58973 .35378 L .206 .168 .592 r
F
.61207 .28929 m .60109 .28246 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.607 .39843 m .607 .22601 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58299 .40365 m .58973 .40218 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58973 .40218 m .607 .39843 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58973 .23563 m .58344 .23075 L .58973 .23106 L .781 .637 .703 r
F
.58973 .23563 m .58973 .23106 L .59853 .23149 L F
.58344 .23075 m .57575 .22478 L .59853 .23149 L F
.60027 .23158 m .607 .22601 L .59438 .23129 L .289 .763 .934 r
F
.58973 .22311 m .57819 .21213 L .58973 .20807 L .781 .637 .703 r
F
.607 .22601 m .58973 .25544 L .60014 .27675 L .206 .168 .592 r
F
.58973 .25544 m .58973 .27079 L .60014 .27675 L F
.607 .22601 m .58973 .23106 L p .59438 .23129 L .289 .763 .934 r
F P
0 g
s
.607 .22601 m .58973 .23106 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.58973 .20807 m .58315 .20041 L .58973 .20614 L .781 .637 .703 r
F
.66075 .29074 m .61035 .23208 L .62006 .23256 L F
.58405 .26271 m .5814 .25668 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.5814 .25668 m .57875 .25064 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.57365 .25485 m .57892 .26684 L .58241 .26403 L p 0 .09 .643 r
F P
0 g
s
.58241 .26403 m .58405 .26271 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.58202 .26117 m .57365 .25485 L .58241 .26403 L 0 .09 .643 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5885 .40982 m .6195 .41337 L .65808 .41234 L p .224 .73 .894 r
F P
0 g
s
.65808 .41234 m .68245 .40731 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.65515 .29467 m .66578 .28856 L .67144 .2846 L p .398 .823 .652 r
F P
0 g
s
.67144 .2846 m .66075 .29074 L .65515 .29467 L p .398 .823 .652 r
F P
0 g
s
.64674 .39734 m .67809 .40107 L .67809 .22957 L p .904 .738 .666 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.68245 .40731 m .67809 .40107 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.39597 .41234 m .35794 .41337 L .35794 .24609 L p .648 .529 .705 r
F P
0 g
s
.35794 .24609 m .39597 .24471 L .39597 .41234 L p .648 .529 .705 r
F P
0 g
s
.39597 .41234 m .39597 .24471 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41762 .40731 m .41145 .40874 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41145 .40874 m .39597 .41234 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.4254 .24604 m .42297 .25851 L p .41145 .27142 L .779 .636 .703 r
F P
0 g
s
.41145 .26559 m .4254 .24604 L .41145 .27142 L .779 .636 .703 r
F
.42521 .23321 m .4254 .24604 L p .41145 .26559 L F P
0 g
s
.41145 .25771 m .42521 .23321 L .41145 .26559 L .779 .636 .703 r
F
.39597 .24471 m .41145 .23987 L p .41145 .27929 L .175 .143 .58 r
F P
0 g
s
.40215 .29113 m .41145 .27929 L .41145 .36098 L .175 .143 .58 r
F
.39597 .24471 m .41145 .27929 L .40215 .29113 L F
.41145 .27929 m .41803 .27008 L .41887 .26923 L p 0 0 0 r
F P
0 g
s
.41887 .26923 m .42122 .26686 L p .41762 .27144 L 0 0 0 r
F P
0 g
s
.41762 .27144 m .41145 .27929 L .41887 .26923 L 0 0 0 r
F
.39597 .24471 m .41145 .23987 L p .32503 .24132 L .289 .763 .934 r
F P
0 g
s
.41664 .24012 m .42241 .22057 L .42121 .24034 L .779 .636 .703 r
F
.41145 .24618 m .4141 .24 L .41145 .25771 L F
.4141 .24 m .42241 .22057 L .41664 .24012 L F
.4141 .24 m .41664 .24012 L .41145 .25771 L F
.32503 .24132 m .41145 .23987 L .39134 .2389 L .289 .763 .934 r
F
.41712 .20866 m .42241 .22057 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.40957 .19801 m .41712 .20866 L p .40759 .23968 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .40149 .23939 L .40759 .23968 L .779 .636 .703 r
F
.40149 .23939 m .40957 .19801 L .40759 .23968 L F
.32503 .24132 m .35794 .24609 L .39597 .24471 L p .289 .763 .934 r
F P
0 g
s
.40007 .18907 m .40957 .19801 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .39134 .2389 L .35512 .23715 L .289 .763 .934 r
F
.38904 .18223 m .40007 .18907 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.37696 .1778 m .38904 .18223 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.36434 .17598 m .37696 .1778 L p .3841 .23855 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .37817 .23826 L .3841 .23855 L .779 .636 .703 r
F
.37817 .23826 m .36434 .17598 L .3841 .23855 L F
.35173 .17686 m .36434 .17598 L p .3907 .29467 L F P
0 g
s
.33969 .18039 m .35173 .17686 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32876 .18645 m .33969 .18039 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .35512 .23715 L .34007 .23642 L .289 .763 .934 r
F
.32503 .24132 m .35794 .24609 L .35794 .41337 L p .89 .727 .673 r
F P
0 g
s
.3194 .19475 m .32876 .18645 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .34007 .23642 L .3294 .23591 L .289 .763 .934 r
F
.31205 .20495 m .3194 .19475 L p .34946 .23688 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .33962 .2364 L .34946 .23688 L .779 .636 .703 r
F
.33962 .2364 m .31205 .20495 L .34946 .23688 L F
.31872 .23539 m .32503 .24132 L p .3294 .23591 L .289 .763 .934 r
F P
0 g
s
.30703 .21659 m .31205 .20495 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.35794 .41337 m .32503 .40982 L .32503 .24132 L p .89 .727 .673 r
F P
0 g
s
.30455 .22916 m .30703 .21659 L p .31872 .2275 L .779 .636 .703 r
F P
0 g
s
.31872 .23993 m .30455 .22916 L .31872 .2275 L .779 .636 .703 r
F
.32503 .24132 m .32503 .29475 L p .31959 .27763 L .943 .77 .305 r
F P
0 g
s
.31872 .23539 m .32503 .24132 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.32063 .27753 m .31297 .26684 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.31297 .26684 m .31872 .27487 L p .31692 .2692 L 0 .18 .715 r
F P
0 g
s
.30475 .24211 m .30455 .22916 L p .31872 .23993 L .779 .636 .703 r
F P
0 g
s
.31872 .25065 m .30475 .24211 L .31872 .23993 L .779 .636 .703 r
F
.30759 .25485 m .30475 .24211 L p .3907 .29467 L F P
0 g
s
.31297 .26684 m .30759 .25485 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.3162 .23303 m .31872 .23539 L p .31872 .27487 L .943 .77 .305 r
F P
0 g
s
.31821 .27326 m .31872 .27487 L .31872 .28348 L .943 .77 .305 r
F
.3162 .23303 m .31872 .27487 L .31821 .27326 L F
.31692 .2692 m .3162 .26693 L .31297 .26684 L 0 .18 .715 r
F
.31528 .26403 m .31404 .26553 L p .3162 .26693 L F P
0 g
s
.31404 .26553 m .31297 .26684 L p .3162 .26693 L 0 .18 .715 r
F P
0 g
s
.30759 .25485 m .31297 .26684 L .31528 .26403 L p 0 .013 .588 r
F P
0 g
s
.3162 .26821 m .3162 .23303 L p .31847 .27855 L .943 .77 .305 r
F P
0 g
s
.3907 .29467 m .31872 .25065 L .31872 .23993 L .779 .636 .703 r
F
.3907 .29467 m .31872 .23993 L .31872 .2275 L F
.3162 .23303 m .31872 .23539 L p .32689 .23129 L .289 .763 .934 r
F P
0 g
s
.3162 .23303 m .3162 .26693 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.34319 .23208 m .32215 .21929 L .32215 .20807 L .779 .636 .703 r
F
.33113 .23149 m .32215 .22311 L .34319 .23208 L F
.32215 .22311 m .31039 .21213 L .32215 .21929 L F
.32215 .22311 m .32215 .21929 L .34319 .23208 L F
.3294 .23591 m .3329 .23158 L .31872 .23539 L .289 .763 .934 r
F
.3079 .22478 m .31039 .21213 L p .33113 .23149 L .779 .636 .703 r
F P
0 g
s
.31574 .23075 m .3079 .22478 L .33113 .23149 L .779 .636 .703 r
F
.3329 .23158 m .3374 .22601 L .32689 .23129 L .289 .763 .934 r
F
.3329 .23158 m .32689 .23129 L .31872 .23539 L F
.32215 .23106 m .3162 .23303 L p .32689 .23129 L F P
0 g
s
.32215 .23106 m .3162 .23303 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.36434 .17598 m .35173 .17686 L .35537 .17215 L p .361 .819 .928 r
F P
0 g
s
.37571 .23366 m .35537 .17215 L .38197 .23397 L .779 .636 .703 r
F
.35173 .17686 m .33969 .18039 L .34326 .17571 L p .441 .878 .864 r
F P
0 g
s
.34326 .17571 m .35537 .17215 L .35173 .17686 L p .441 .878 .864 r
F P
0 g
s
.34326 .17571 m .35537 .17215 L p .37571 .23366 L .779 .636 .703 r
F P
0 g
s
.36897 .23333 m .34326 .17571 L .37571 .23366 L .779 .636 .703 r
F
.37696 .1778 m .36434 .17598 L .36805 .17128 L p .272 .732 .952 r
F P
0 g
s
.35537 .17215 m .36805 .17128 L .36434 .17598 L p .361 .819 .928 r
F P
0 g
s
.35537 .17215 m .36805 .17128 L p .38197 .23397 L .779 .636 .703 r
F P
0 g
s
.41712 .20866 m .40957 .19801 L .41357 .19346 L p 0 .215 .74 r
F P
0 g
s
.40544 .23511 m .41357 .19346 L .41158 .23541 L .779 .636 .703 r
F
.40957 .19801 m .40007 .18907 L .40401 .18446 L p 0 .364 .833 r
F P
0 g
s
.40401 .18446 m .41357 .19346 L .40957 .19801 L p 0 .364 .833 r
F P
0 g
s
.40401 .18446 m .41357 .19346 L p .40544 .23511 L .779 .636 .703 r
F P
0 g
s
.39954 .23482 m .40401 .18446 L .40544 .23511 L .779 .636 .703 r
F
.42241 .22057 m .41712 .20866 L .42117 .20418 L p 0 .055 .619 r
F P
0 g
s
.41357 .19346 m .42117 .20418 L .41712 .20866 L p 0 .215 .74 r
F P
0 g
s
.41357 .19346 m .41546 .19613 L p .41158 .23541 L .779 .636 .703 r
F P
0 g
s
.41546 .19613 m .42117 .20418 L p .41546 .22276 L .779 .636 .703 r
F P
0 g
s
.41158 .23541 m .41546 .19613 L .41546 .22276 L .779 .636 .703 r
F
.40007 .18907 m .38904 .18223 L .39292 .17757 L p .086 .501 .901 r
F P
0 g
s
.39292 .17757 m .40401 .18446 L .40007 .18907 L p .086 .501 .901 r
F P
0 g
s
.39292 .17757 m .40401 .18446 L p .39954 .23482 L .779 .636 .703 r
F P
0 g
s
.40992 .23784 m .40992 .23532 L p .35512 .23715 L .289 .763 .934 r
F P
0 g
s
.35512 .23715 m .40992 .23532 L .37913 .23383 L .289 .763 .934 r
F
.39134 .2389 m .41762 .23794 L .35512 .23715 L F
.41145 .23987 m .41762 .23794 L p .39134 .2389 L F P
0 g
s
.3907 .29467 m .41145 .24618 L .41145 .25771 L .779 .636 .703 r
F
.3907 .29467 m .41145 .25771 L .41145 .26559 L F
.3907 .29467 m .41145 .26559 L .41145 .27142 L F
.42297 .25851 m .41803 .27008 L p .3907 .29467 L F P
0 g
s
.39458 .29074 m .39375 .23454 L .39954 .23482 L .779 .636 .703 r
F
.39375 .23454 m .39292 .17757 L .39954 .23482 L F
.38904 .18223 m .37696 .1778 L .38075 .17311 L p .18 .625 .941 r
F P
0 g
s
.38075 .17311 m .39292 .17757 L .38904 .18223 L p .18 .625 .941 r
F P
0 g
s
.38075 .17311 m .39292 .17757 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.36805 .17128 m .38075 .17311 L .37696 .1778 L p .272 .732 .952 r
F P
0 g
s
.36805 .17128 m .38075 .17311 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.40992 .23532 m .40992 .22957 L p .37913 .23383 L .289 .763 .934 r
F P
0 g
s
.4254 .24604 m .42521 .23321 L .42931 .2289 L p 0 0 .293 r
F P
0 g
s
.42649 .21617 m .42931 .2289 L .42521 .23321 L p 0 0 .47 r
F P
0 g
s
.42649 .21617 m .42931 .2289 L p .42528 .23607 L .779 .636 .703 r
F P
0 g
s
.41077 .23785 m .41762 .23794 L .41546 .23559 L .289 .763 .934 r
F
.41145 .25771 m .41664 .24012 L .42121 .24034 L .779 .636 .703 r
F
.41803 .27008 m .41078 .28024 L p .3907 .29467 L F P
0 g
s
.41762 .23794 m .41762 .40731 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41145 .23987 m .41762 .23794 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41078 .28024 m .41145 .27929 L p .41737 .27189 L 0 0 0 r
F P
0 g
s
.41729 .27203 m .41078 .28024 L .41737 .27189 L 0 0 0 r
F
.41762 .40731 m .41762 .27144 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.40992 .40107 m .41546 .40556 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.41546 .40556 m .41762 .40731 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.41272 .27771 m .41145 .27929 L .41267 .27775 L 0 0 0 r
F
.4159 .2745 m .40992 .40107 L .41762 .27144 L .923 .754 .269 r
F
.41272 .27771 m .41267 .27775 L .42122 .26686 L 0 0 0 r
F
.42122 .26686 m .42208 .266 L p .41272 .27771 L F P
0 g
s
.4159 .2745 m .41546 .27527 L .41546 .28367 L .923 .754 .269 r
F
.41478 .27623 m .41078 .28024 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.42208 .266 m .41546 .27527 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.41546 .27527 m .41478 .27623 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.41546 .28367 m .41474 .27656 L .40992 .40107 L .923 .754 .269 r
F
.39458 .29074 m .41546 .27195 L .41478 .27623 L .779 .636 .703 r
F
.41762 .23794 m .41546 .23559 L p .41546 .27527 L .923 .754 .269 r
F P
0 g
s
.41762 .23794 m .41546 .27527 L .4159 .2745 L .923 .754 .269 r
F
.42241 .22057 m .42521 .23321 L p .42121 .24034 L .779 .636 .703 r
F P
0 g
s
.41762 .27144 m .41762 .23794 L p .4159 .2745 L .923 .754 .269 r
F P
0 g
s
.39458 .29074 m .41812 .23572 L .42528 .23607 L .779 .636 .703 r
F
.41077 .23785 m .41546 .23559 L .41051 .23535 L .289 .763 .934 r
F
.39458 .29074 m .40544 .23511 L .41158 .23541 L .779 .636 .703 r
F
.41078 .28024 m .40154 .28856 L .3907 .29467 L p F P
0 g
s
.40154 .28856 m .41078 .28024 L .41478 .27623 L p .496 .833 .546 r
F P
0 g
s
.41478 .27623 m .40548 .2846 L .40154 .28856 L p .496 .833 .546 r
F P
0 g
s
.42297 .25851 m .4254 .24604 L .4295 .24181 L p 0 0 .091 r
F P
0 g
s
.41803 .27008 m .42297 .25851 L .42705 .25436 L p 0 0 0 r
F P
0 g
s
.4295 .24181 m .42705 .25436 L .42297 .25851 L p 0 0 .091 r
F P
0 g
s
.4295 .24181 m .42705 .25436 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42931 .2289 m .4295 .24181 L .4254 .24604 L p 0 0 .293 r
F P
0 g
s
.42931 .2289 m .4295 .24181 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42705 .25436 m .42208 .266 L .41803 .27008 L p 0 0 0 r
F P
0 g
s
.42705 .25436 m .42208 .266 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42521 .23321 m .42241 .22057 L .42649 .21617 L p 0 0 .47 r
F P
0 g
s
.42117 .20418 m .42649 .21617 L .42241 .22057 L p 0 .055 .619 r
F P
0 g
s
.42117 .20418 m .42649 .21617 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.41478 .27623 m .40548 .2846 L .39458 .29074 L p .779 .636 .703 r
F P
0 g
s
.40992 .22957 m .40992 .28511 L p .41474 .27656 L .923 .754 .269 r
F P
0 g
s
.40992 .28511 m .40992 .40107 L p .41474 .27656 L .923 .754 .269 r
F P
0 g
s
.42208 .266 m .41729 .27203 L .41737 .27189 L 0 0 0 r
F
.42208 .266 m .41546 .27527 L p .41546 .27195 L .779 .636 .703 r
F P
0 g
s
.41546 .27527 m .41478 .27623 L p .41546 .27195 L .779 .636 .703 r
F P
0 g
s
.41812 .23572 m .42649 .21617 L .42528 .23607 L .779 .636 .703 r
F
.41051 .23535 m .41546 .23559 L .40992 .22957 L .289 .763 .934 r
F
.41546 .23559 m .40992 .22957 L p .41546 .28367 L .923 .754 .269 r
F P
0 g
s
.39458 .29074 m .39954 .23482 L .40544 .23511 L .779 .636 .703 r
F
.35512 .23715 m .37913 .23383 L .34007 .23642 L .289 .763 .934 r
F
.37913 .23383 m .40992 .22957 L .37069 .23342 L F
.37913 .23383 m .37069 .23342 L .34007 .23642 L F
.34007 .23642 m .37069 .23342 L .35209 .23251 L F
.33969 .18039 m .32876 .18645 L .33225 .1818 L p .508 .9 .756 r
F P
0 g
s
.33225 .1818 m .34326 .17571 L .33969 .18039 L p .508 .9 .756 r
F P
0 g
s
.33225 .1818 m .34326 .17571 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32876 .18645 m .3194 .19475 L .32284 .19015 L p .552 .876 .601 r
F P
0 g
s
.32284 .19015 m .33225 .1818 L .32876 .18645 L p .552 .876 .601 r
F P
0 g
s
.32284 .19015 m .33225 .1818 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.34007 .23642 m .35209 .23251 L .3294 .23591 L .289 .763 .934 r
F
.35209 .23251 m .34494 .23217 L .3294 .23591 L F
.3294 .23591 m .34494 .23217 L .3329 .23158 L F
.31544 .20041 m .32284 .19015 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.40992 .22957 m .37656 .22455 L p .35209 .23251 L .289 .763 .934 r
F P
0 g
s
.37069 .23342 m .40992 .22957 L .35209 .23251 L .289 .763 .934 r
F
.39458 .29074 m .36897 .23333 L .37571 .23366 L .779 .636 .703 r
F
.35209 .23251 m .37656 .22455 L .34494 .23217 L .289 .763 .934 r
F
.37656 .22455 m .3374 .22601 L p .3329 .23158 L F P
0 g
s
.34494 .23217 m .37656 .22455 L .3329 .23158 L .289 .763 .934 r
F
.39458 .29074 m .37571 .23366 L .38197 .23397 L .779 .636 .703 r
F
.39458 .29074 m .32215 .23563 L .33113 .23149 L F
.33619 .23622 m .33113 .23149 L .33672 .23177 L F
.33619 .23622 m .33672 .23177 L .34319 .23208 L F
.39458 .29074 m .33619 .23622 L .34319 .23208 L F
.31872 .28348 m .31959 .27763 L .32503 .40982 L .943 .77 .305 r
F
.32503 .29475 m .32503 .40982 L p .31959 .27763 L F P
0 g
s
.32503 .40982 m .31872 .40541 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.33023 .28646 m .32063 .27753 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.34136 .29324 m .33023 .28646 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.33023 .28646 m .34136 .29324 L .34493 .28929 L p .037 .477 .882 r
F P
0 g
s
.32063 .27753 m .33023 .28646 L .33374 .28246 L p 0 .335 .813 r
F P
0 g
s
.34493 .28929 m .33374 .28246 L .33023 .28646 L p .037 .477 .882 r
F P
0 g
s
.33374 .28246 m .32407 .27347 L .32063 .27753 L p 0 .335 .813 r
F P
0 g
s
.30809 .23781 m .3079 .22478 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32215 .25544 m .3162 .26693 L .32215 .27079 L .149 .121 .569 r
F
.31095 .25064 m .30809 .23781 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.31636 .26271 m .31095 .25064 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32407 .27347 m .32215 .27079 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32215 .27079 m .31636 .26271 L p .32215 .26478 L .779 .636 .703 r
F P
0 g
s
.39458 .29074 m .32215 .27079 L .32215 .26478 L .779 .636 .703 r
F
.3162 .40365 m .3162 .26821 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.31847 .27855 m .31872 .28348 L .3162 .26821 L .943 .77 .305 r
F
.31872 .40541 m .3162 .40365 L p .31872 .28348 L F P
0 g
s
.3162 .26693 m .3162 .40365 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32407 .27347 m .31636 .26271 L .31528 .26403 L p 0 .18 .715 r
F P
0 g
s
.32407 .27347 m .31528 .26403 L .31692 .2692 L 0 .18 .715 r
F
.32063 .27753 m .32407 .27347 L p .31692 .2692 L F P
0 g
s
.33374 .28246 m .32407 .27347 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.33135 .27675 m .32215 .27079 L .32215 .35378 L .149 .121 .569 r
F
.31872 .27487 m .32063 .27753 L p .31692 .2692 L 0 .18 .715 r
F P
0 g
s
.32215 .27079 m .3162 .26693 L .32215 .35378 L .149 .121 .569 r
F
.34493 .28929 m .33374 .28246 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.3374 .39843 m .3374 .22601 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.3162 .40365 m .32215 .40218 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32215 .40218 m .3374 .39843 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32215 .23563 m .31574 .23075 L .32215 .23106 L .779 .636 .703 r
F
.32215 .23563 m .32215 .23106 L .33113 .23149 L F
.3374 .22601 m .32215 .25544 L .33135 .27675 L .149 .121 .569 r
F
.32215 .25544 m .32215 .27079 L .33135 .27675 L F
.3374 .22601 m .32215 .23106 L p .32689 .23129 L .289 .763 .934 r
F P
0 g
s
.3374 .22601 m .32215 .23106 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.31039 .21213 m .31544 .20041 L p .32215 .20807 L .779 .636 .703 r
F P
0 g
s
.32215 .21929 m .31039 .21213 L .32215 .20807 L .779 .636 .703 r
F
.31528 .26403 m .31636 .26271 L p .31465 .26117 L 0 .013 .588 r
F P
0 g
s
.31465 .26117 m .30759 .25485 L .31528 .26403 L 0 .013 .588 r
F
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.607 .39843 m .58299 .40365 L .5885 .40982 L p .224 .73 .894 r
F P
0 g
s
.64674 .39734 m .607 .39843 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.67809 .40107 m .64674 .39734 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.63108 .29929 m .61868 .29758 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .64341 .2983 L .63108 .29929 L p .78 .637 .703 r
F P
0 g
s
.64341 .2983 m .65515 .29467 L .66075 .29074 L p .361 .831 .799 r
F P
0 g
s
.63108 .29929 m .64341 .2983 L .64894 .29439 L p .304 .792 .892 r
F P
0 g
s
.66075 .29074 m .64894 .29439 L .64341 .2983 L p .361 .831 .799 r
F P
0 g
s
.64894 .29439 m .63653 .29538 L .63108 .29929 L p .304 .792 .892 r
F P
0 g
s
.62406 .29366 m .61207 .28929 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.63653 .29538 m .62406 .29366 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.66075 .29074 m .64894 .29439 L .63653 .29538 L p .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .64674 .22455 L .64674 .39734 L p .904 .738 .666 r
F P
0 g
s
.61868 .29758 m .63108 .29929 L .63653 .29538 L p .236 .716 .934 r
F P
0 g
s
.63653 .29538 m .62406 .29366 L .61868 .29758 L p .236 .716 .934 r
F P
0 g
s
.607 .39843 m .64674 .39734 L .64674 .22455 L p .647 .528 .705 r
F P
0 g
s
.64674 .22455 m .607 .22601 L .607 .39843 L p .647 .528 .705 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32503 .40982 m .35794 .41337 L .39597 .41234 L p .224 .73 .894 r
F P
0 g
s
.39597 .41234 m .41762 .40731 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3374 .39843 m .3162 .40365 L .32503 .40982 L p .224 .73 .894 r
F P
0 g
s
.37656 .39734 m .3374 .39843 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.40992 .40107 m .37656 .39734 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.41762 .40731 m .40992 .40107 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.3907 .29467 m .40154 .28856 L .40548 .2846 L p .457 .867 .709 r
F P
0 g
s
.40548 .2846 m .39458 .29074 L .3907 .29467 L p .457 .867 .709 r
F P
0 g
s
.37656 .39734 m .40992 .40107 L .40992 .22957 L p .895 .731 .67 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.35351 .29758 m .34136 .29324 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.36615 .29929 m .35351 .29758 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .37873 .2983 L .36615 .29929 L p .779 .636 .703 r
F P
0 g
s
.37873 .2983 m .3907 .29467 L .39458 .29074 L p .395 .852 .828 r
F P
0 g
s
.36615 .29929 m .37873 .2983 L .38254 .29439 L p .316 .798 .9 r
F P
0 g
s
.39458 .29074 m .38254 .29439 L .37873 .2983 L p .395 .852 .828 r
F P
0 g
s
.35351 .29758 m .36615 .29929 L .36988 .29538 L p .227 .712 .929 r
F P
0 g
s
.38254 .29439 m .36988 .29538 L .36615 .29929 L p .316 .798 .9 r
F P
0 g
s
.34136 .29324 m .35351 .29758 L .35716 .29366 L p .133 .604 .922 r
F P
0 g
s
.36988 .29538 m .35716 .29366 L .35351 .29758 L p .227 .712 .929 r
F P
0 g
s
.35716 .29366 m .34493 .28929 L .34136 .29324 L p .133 .604 .922 r
F P
0 g
s
.59441 .18645 m .58523 .19475 L .59041 .19015 L p 0 0 0 r
F P
0 g
s
.59041 .19015 m .59963 .1818 L .59441 .18645 L p 0 0 0 r
F P
0 g
s
.58523 .19475 m .57802 .20495 L .58315 .20041 L p 0 0 0 r
F P
0 g
s
.58315 .20041 m .59041 .19015 L .58523 .19475 L p 0 0 0 r
F P
0 g
s
.3194 .19475 m .31205 .20495 L .31544 .20041 L p 0 0 0 r
F P
0 g
s
.31544 .20041 m .32284 .19015 L .3194 .19475 L p 0 0 0 r
F P
0 g
s
.57802 .20495 m .57309 .21659 L .57819 .21213 L p 0 0 0 r
F P
0 g
s
.57819 .21213 m .58315 .20041 L .57802 .20495 L p 0 0 0 r
F P
0 g
s
.31205 .20495 m .30703 .21659 L .31039 .21213 L p 0 0 0 r
F P
0 g
s
.31039 .21213 m .31544 .20041 L .31205 .20495 L p 0 0 0 r
F P
0 g
s
.57086 .24211 m .57365 .25485 L .57875 .25064 L p 0 0 .506 r
F P
0 g
s
.30475 .24211 m .30759 .25485 L .31095 .25064 L p 0 0 .431 r
F P
0 g
s
.31636 .26271 m .31095 .25064 L .30759 .25485 L p 0 .013 .588 r
F P
0 g
s
.57309 .21659 m .57067 .22916 L .57575 .22478 L p 0 0 .147 r
F P
0 g
s
.57575 .22478 m .57819 .21213 L .57309 .21659 L p 0 0 .147 r
F P
0 g
s
.30703 .21659 m .30455 .22916 L .3079 .22478 L p 0 0 .035 r
F P
0 g
s
.3079 .22478 m .31039 .21213 L .30703 .21659 L p 0 0 .035 r
F P
0 g
s
.57067 .22916 m .57086 .24211 L .57594 .23781 L p 0 0 .341 r
F P
0 g
s
.57875 .25064 m .57594 .23781 L .57086 .24211 L p 0 0 .506 r
F P
0 g
s
.30455 .22916 m .30475 .24211 L .30809 .23781 L p 0 0 .245 r
F P
0 g
s
.31095 .25064 m .30809 .23781 L .30475 .24211 L p 0 0 .431 r
F P
0 g
s
.57594 .23781 m .57575 .22478 L .57067 .22916 L p 0 0 .341 r
F P
0 g
s
.30809 .23781 m .3079 .22478 L .30455 .22916 L p 0 0 .245 r
F P
0 g
s
.35716 .29366 m .34493 .28929 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.36988 .29538 m .35716 .29366 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.39458 .29074 m .38254 .29439 L .36988 .29538 L p .779 .636 .703 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.40992 .22957 m .37656 .22455 L .37656 .39734 L p .895 .731 .67 r
F P
0 g
s
.3374 .39843 m .37656 .39734 L .37656 .22455 L p .646 .527 .705 r
F P
0 g
s
.37656 .22455 m .3374 .22601 L .3374 .39843 L p .646 .527 .705 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .70623 .8322 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.75114 .87453 m .70139 .8749 L p .74865 .87438 L F P
0 g
s
.74865 .87438 m .74181 .87165 L .74467 .87415 L .631 .119 0 r
F
.74865 .87438 m .70623 .8322 L .71556 .86115 L p F P
0 g
s
.70996 .87384 m .77017 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70496 .91631 m .74865 .87438 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70996 1.10469 m .76548 .89235 L .74555 .88571 L .96 .784 .62 r
F
.70996 .93399 m .70996 1.10469 L p .73436 .95458 L F P
0 g
s
.73436 .95458 m .74555 .88571 L .70996 .93399 L .96 .784 .62 r
F
.70623 .8322 m .66253 .87438 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70559 .87438 m .66253 .87438 L .70996 .87384 L .012 .587 .719 r
F
.67022 .87415 m .70996 .87384 L p .66253 .87438 L F P
0 g
s
.70139 .8749 m .64101 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.66253 .87438 m .70496 .91631 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.66253 .87438 m .70496 .91631 L .70996 .93399 L p .653 .141 0 r
F P
0 g
s
.64101 1.04449 m .69353 .91452 L .65546 .88543 L .333 .272 .638 r
F
.64101 .87438 m .64101 .89646 L p .65546 .88543 L F P
0 g
s
.64101 .89646 m .64101 1.04449 L p .65546 .88543 L .333 .272 .638 r
F P
0 g
s
.66253 .87438 m .70996 .93399 L .67582 .89355 L .653 .141 0 r
F
.70996 .87384 m .67022 .87415 L p .69353 .91452 L .333 .272 .638 r
F P
0 g
s
.70623 .8322 m .66253 .87438 L p .67022 .87415 L 0 0 0 r
F P
0 g
s
.66253 .87438 m .65965 .87438 L .67022 .87415 L .012 .587 .719 r
F
.65965 .87438 m .64101 .87438 L .67022 .87415 L F
.69353 .91452 m .66367 .87915 L .68405 .90728 L .333 .272 .638 r
F
.66367 .87915 m .66335 .87939 L .68405 .90728 L F
.65952 .87424 m .64101 .87438 L p .68405 .90728 L F P
0 g
s
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.50802 1.25704 m .54018 1.25552 L .52667 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .54517 1.25817 L F
.54018 1.25552 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.51938 1.25967 m .51947 1.25865 L .52667 1.25967 L .365 .792 .97 r
F
.452 1.25967 m .51947 1.25865 L .51938 1.25967 L F
.452 1.25967 m .50802 1.25704 L .51947 1.25865 L F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L .365 .792 .97 r
F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.52783 1.09787 m .46974 1.09988 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.36257 1.04436 m .3516 1.04413 L .36228 1.04465 L .066 0 0 r
F
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .36099 1.04601 L p .34335 1.04519 L .066 0 0 r
F P
0 g
s
.34335 1.04519 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L F P
0 g
s
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.484 1.29086 m .47278 1.29329 L p .46863 1.25897 L .997 .814 .539 r
F P
0 g
s
.46983 1.25648 m .484 1.29086 L .46863 1.25897 L .997 .814 .539 r
F
.46771 1.25133 m .46983 1.25648 L .46863 1.25897 L F
.46771 1.28484 m .46771 1.25133 L p .47278 1.29329 L F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.28484 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.47278 1.29329 m .46133 1.29296 L p .46771 1.28484 L .526 .721 .962 r
F P
0 g
s
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.41389 1.31592 m .41923 1.29174 L .48168 1.29355 L p .577 .233 .351 r
F P
0 g
s
.46771 1.29439 m .46832 1.28585 L p .47278 1.29329 L .997 .814 .539 r
F P
0 g
s
.47058 1.25401 m .46771 1.28484 L .46846 1.28388 L .063 .051 .53 r
F
.46771 1.28484 m .47675 1.2746 L .47278 1.29329 L .526 .721 .962 r
F
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.48163 1.25846 m .48371 1.25952 L .48217 1.2658 L .997 .814 .539 r
F
.48371 1.25952 m .484 1.25967 L .48217 1.2658 L F
.484 1.25967 m .484 1.29086 L p .48217 1.2658 L F P
0 g
s
.47808 1.26098 m .47452 1.27245 L .48273 1.26531 L .063 .051 .53 r
F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48168 1.29355 m .47675 1.31785 L .41389 1.31592 L p .577 .233 .351 r
F P
0 g
s
.47675 1.31785 m .48168 1.29355 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.47174 1.29894 m .4765 1.31691 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.4765 1.31691 m .47675 1.31785 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.48371 1.29798 m .48371 1.29322 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .48204 1.29334 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47468 1.25782 m .48371 1.26622 L .51629 1.26622 L .513 .022 .027 r
F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L .513 .022 .027 r
F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62827 1.30072 m .62806 1.27693 L .62849 1.28848 L 0 0 .059 r
F
.62791 1.30812 m .62791 1.2604 L .62827 1.30072 L F
.62866 1.29284 m .65354 1.29355 L p .62899 1.30169 L .578 .237 .354 r
F P
0 g
s
.64977 1.2746 m .65354 1.29355 L .62866 1.29284 L p .529 .72 .961 r
F P
0 g
s
.62926 1.28051 m .64977 1.2746 L .62866 1.29284 L .529 .72 .961 r
F
.62958 1.27405 m .64977 1.2746 L p .62926 1.28051 L F P
0 g
s
.65354 1.29355 m .64977 1.31785 L .62958 1.31724 L p .578 .237 .354 r
F P
0 g
s
.62791 1.3207 m .62827 1.30072 L .62871 1.29411 L 0 0 .059 r
F
.62791 1.3207 m .62871 1.29411 L .62892 1.29966 L F
.62791 1.3207 m .62791 1.30812 L .62827 1.30072 L F
.62899 1.30169 m .65354 1.29355 L .62958 1.31724 L .578 .237 .354 r
F
.62958 1.31724 m .64977 1.31785 L p .62985 1.31176 L .526 .721 .962 r
F P
0 g
s
.62791 1.3207 m .63016 1.30551 L .6292 1.32493 L 0 0 .059 r
F
.64977 1.31785 m .64595 1.29894 L .63051 1.29849 L p .526 .721 .962 r
F P
0 g
s
.64595 1.29894 m .64977 1.2746 L .62958 1.27405 L p .576 .233 .35 r
F P
0 g
s
.63027 1.2921 m .64595 1.29894 L .62958 1.27405 L .576 .233 .35 r
F
.62791 1.3207 m .62983 1.28057 L .63041 1.29598 L 0 0 .059 r
F
.63051 1.29849 m .64595 1.29894 L p .63027 1.2921 L .576 .233 .35 r
F P
0 g
s
.62791 1.3207 m .63085 1.29168 L .63016 1.30551 L 0 0 .059 r
F
.62892 1.29966 m .62871 1.29411 L .63045 1.26755 L F
.62917 1.25133 m .63011 1.26323 L p .62827 1.30072 L F P
0 g
s
.63011 1.26323 m .63045 1.26755 L p .62827 1.30072 L 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62849 1.28848 L 0 0 .059 r
F P
0 g
s
.62806 1.27693 m .62791 1.2604 L .62849 1.28848 L 0 0 .059 r
F
.59029 1.29174 m .58611 1.27286 L .62958 1.27405 L p .529 .72 .961 r
F P
0 g
s
.59029 1.29174 m .62958 1.27405 L .62926 1.28051 L .529 .72 .961 r
F
.58611 1.31592 m .59029 1.29174 L .62866 1.29284 L p .578 .237 .354 r
F P
0 g
s
.58611 1.31592 m .62866 1.29284 L .62899 1.30169 L .578 .237 .354 r
F
.62866 1.29284 m .59029 1.29174 L p .62926 1.28051 L .529 .72 .961 r
F P
0 g
s
.59029 1.29174 m .58611 1.27286 L .58188 1.29708 L p .919 .751 .263 r
F P
0 g
s
.58188 1.29708 m .58611 1.31592 L .59029 1.29174 L p .919 .751 .263 r
F P
0 g
s
.58611 1.27286 m .58188 1.29708 L .63051 1.29849 L p .576 .233 .35 r
F P
0 g
s
.58611 1.27286 m .63051 1.29849 L .63027 1.2921 L .576 .233 .35 r
F
.62985 1.31176 m .64977 1.31785 L .63051 1.29849 L .526 .721 .962 r
F
.63085 1.29168 m .63099 1.29994 L p .63065 1.3022 L 0 0 .059 r
F P
0 g
s
.63016 1.30551 m .63051 1.29849 L .63065 1.3022 L 0 0 .059 r
F
.63051 1.29849 m .63085 1.29168 L .63065 1.3022 L F
.63045 1.26755 m .63085 1.29168 L p .63041 1.29598 L F P
0 g
s
.62983 1.28057 m .63045 1.26755 L .63041 1.29598 L 0 0 .059 r
F
.62958 1.27405 m .58611 1.27286 L p .63027 1.2921 L .576 .233 .35 r
F P
0 g
s
.61362 1.30679 m .62899 1.30169 L .62937 1.31161 L .578 .237 .354 r
F
.61362 1.30679 m .62937 1.31161 L .62958 1.31724 L F
.62958 1.31724 m .58611 1.31592 L p .61362 1.30679 L F P
0 g
s
.63051 1.29849 m .58188 1.29708 L p .62985 1.31176 L .526 .721 .962 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .6292 1.32493 L 0 0 .059 r
F P
0 g
s
.63016 1.30551 m .63099 1.29994 L .6292 1.32493 L 0 0 .059 r
F
.58188 1.29708 m .58611 1.31592 L .62958 1.31724 L p .526 .721 .962 r
F P
0 g
s
.58188 1.29708 m .62958 1.31724 L .62985 1.31176 L .526 .721 .962 r
F
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.46974 1.09988 m .46771 1.09965 L .484 1.09787 L .09 0 0 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L .707 .577 .707 r
F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.47544 1.27499 m .47675 1.2746 L .46771 1.28484 L .526 .721 .962 r
F
.48146 1.10121 m .46846 1.28388 L .48371 1.10147 L .063 .051 .53 r
F
.46846 1.28388 m .46771 1.29439 L .46859 1.28371 L F
.46846 1.28388 m .46859 1.28371 L .48371 1.10147 L F
.47452 1.27245 m .47261 1.27859 L .47577 1.27457 L F
.47144 1.24935 m .46771 1.29439 L .48371 1.24284 L F
.41923 1.29174 m .41389 1.27286 L .47577 1.27457 L p .526 .721 .962 r
F P
0 g
s
.47577 1.27457 m .47675 1.2746 L p .47544 1.27499 L .526 .721 .962 r
F P
0 g
s
.41923 1.29174 m .47577 1.27457 L .47544 1.27499 L .526 .721 .962 r
F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L .063 .051 .53 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L .09 0 0 r
F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L F P
0 g
s
.47675 1.2746 m .48168 1.29355 L .47278 1.29329 L p .526 .721 .962 r
F P
0 g
s
.46771 1.29439 m .4765 1.29636 L p .4765 1.27795 L .063 .051 .53 r
F P
0 g
s
.48168 1.29355 m .47675 1.2746 L .4765 1.27581 L p .941 .768 .3 r
F P
0 g
s
.47261 1.27859 m .46771 1.29439 L .4765 1.27795 L .063 .051 .53 r
F
.4765 1.27581 m .47675 1.2746 L .47577 1.27457 L p .574 .229 .346 r
F P
0 g
s
.47261 1.27859 m .4765 1.27795 L .4765 1.27364 L .063 .051 .53 r
F
.4765 1.27581 m .47174 1.29894 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.4765 1.29636 m .48168 1.29355 L .4765 1.27581 L .941 .768 .3 r
F
.4765 1.27364 m .4765 1.27795 L .48371 1.26445 L .063 .051 .53 r
F
.48371 1.29798 m .48371 1.26622 L p .4765 1.27795 L F P
0 g
s
.48308 1.26563 m .4765 1.27795 L .48371 1.26622 L .063 .051 .53 r
F
.47452 1.27245 m .47577 1.27457 L .48291 1.26547 L F
.48273 1.26531 m .48291 1.26547 L .48371 1.26445 L F
.47452 1.27245 m .48291 1.26547 L .48273 1.26531 L F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.48371 1.26622 m .48371 1.26445 L p .48308 1.26563 L .063 .051 .53 r
F P
0 g
s
.4765 1.29636 m .48371 1.29798 L p .4765 1.27795 L .063 .051 .53 r
F P
0 g
s
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.48371 1.26445 m .48371 1.24284 L p .47808 1.26098 L .063 .051 .53 r
F P
0 g
s
.47808 1.26098 m .48273 1.26531 L .48371 1.26445 L .063 .051 .53 r
F
.46387 1.27844 m .47544 1.27499 L .46771 1.28484 L .526 .721 .962 r
F
.46771 1.28484 m .46771 1.29439 L p .46846 1.28388 L .063 .051 .53 r
F P
0 g
s
.41923 1.29174 m .46387 1.27844 L .46771 1.28484 L .526 .721 .962 r
F
.46133 1.29296 m .41923 1.29174 L p .46771 1.28484 L F P
0 g
s
.47174 1.29894 m .4765 1.27581 L p .46131 1.27417 L .574 .229 .346 r
F P
0 g
s
.47577 1.27457 m .46131 1.27417 L p .4765 1.27581 L .574 .229 .346 r
F P
0 g
s
.46131 1.27417 m .41389 1.27286 L p .45336 1.29066 L .574 .229 .346 r
F P
0 g
s
.45336 1.29066 m .47174 1.29894 L .46131 1.27417 L .574 .229 .346 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L .513 .022 .027 r
F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46974 1.09988 m .46368 1.10009 L .46771 1.09965 L F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.64107 1.0445 m .64107 1.04434 L .64101 1.04449 L .333 .272 .638 r
F
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.6578 1.04524 m .64107 1.04434 L .64107 1.0445 L .333 .272 .638 r
F
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70996 .87384 L .64107 1.04434 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 .93399 m .70496 .91631 L p .72618 .91199 L 0 0 0 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.77017 .87438 m .75114 .87453 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .75401 .87424 L p .76548 .89235 L .96 .784 .62 r
F P
0 g
s
.70496 .91631 m .74865 .87438 L .75038 .87915 L p 0 0 0 r
F P
0 g
s
.75401 .87424 m .74467 .87415 L p .75038 .87915 L .96 .784 .62 r
F P
0 g
s
.76548 .89235 m .75401 .87424 L .75038 .87915 L .96 .784 .62 r
F
.70496 .91631 m .75038 .87915 L .72881 .90842 L 0 0 0 r
F
.74467 .87415 m .70996 .87384 L p .76548 .89235 L .96 .784 .62 r
F P
0 g
s
.75038 .87915 m .75759 .89891 L p .72881 .90842 L 0 0 0 r
F P
0 g
s
.75759 .89891 m .75986 .90514 L p .74504 .90816 L 0 0 0 r
F P
0 g
s
.70496 .91631 m .75759 .89891 L .74504 .90816 L 0 0 0 r
F
.70996 1.04757 m .70996 .93399 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70996 .93399 m .70996 .87384 L p .68637 .95138 L .333 .272 .638 r
F P
0 g
s
.6578 1.04524 m .70996 .93399 L .68637 .95138 L .333 .272 .638 r
F
.71417 .94885 m .66987 .90514 L .66367 .87915 L p .653 .141 0 r
F P
0 g
s
.67582 .89355 m .71417 .94885 L .66367 .87915 L .653 .141 0 r
F
.66367 .87915 m .66253 .87438 L p .67582 .89355 L F P
0 g
s
.69353 .91452 m .67022 .87415 L .66367 .87915 L .333 .272 .638 r
F
.67582 .89355 m .70996 .93399 L .69528 .9216 L .653 .141 0 r
F
.66987 .90514 m .71556 .86115 L .70996 .84379 L p 0 0 0 r
F P
0 g
s
.70996 .84379 m .70623 .8322 L p .6946 .85553 L 0 0 0 r
F P
0 g
s
.6946 .85553 m .66987 .90514 L .70996 .84379 L 0 0 0 r
F
.66367 .87915 m .65952 .87424 L .66335 .87939 L .333 .272 .638 r
F
.66253 .87438 m .66367 .87915 L p .67022 .87415 L 0 0 0 r
F P
0 g
s
.67022 .87415 m .65952 .87424 L p .66367 .87915 L .333 .272 .638 r
F P
0 g
s
.6946 .85553 m .67022 .87415 L .68554 .87369 L 0 0 0 r
F
.70623 .8322 m .67022 .87415 L .6946 .85553 L F
.68554 .87369 m .67022 .87415 L .66987 .90514 L F
.66367 .87915 m .66987 .90514 L p .67022 .87415 L F P
0 g
s
.70996 .93399 m .71417 .94885 L p .69528 .9216 L .653 .141 0 r
F P
0 g
s
.75986 .90514 m .71417 .94885 L .70996 .93399 L p 0 0 0 r
F P
0 g
s
.72618 .91199 m .75986 .90514 L .70996 .93399 L 0 0 0 r
F
.70996 .87384 m .70996 .93399 L p .74555 .88571 L .96 .784 .62 r
F P
0 g
s
.71556 .86115 m .72766 .87316 L p .74467 .87415 L .631 .119 0 r
F P
0 g
s
.74181 .87165 m .71556 .86115 L .74467 .87415 L .631 .119 0 r
F
.72766 .87316 m .75986 .90514 L .74865 .87438 L p F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.38636 .3673 m .34485 .36852 L .34485 .18583 L p .642 .524 .704 r
F P
0 g
s
.34485 .18583 m .38636 .18419 L .38636 .3673 L p .642 .524 .704 r
F P
0 g
s
.34485 .36852 m .30878 .36429 L .30878 .18013 L p .902 .736 .667 r
F P
0 g
s
.30878 .18013 m .34485 .18583 L .34485 .36852 L p .902 .736 .667 r
F P
0 g
s
.38636 .3673 m .38636 .18419 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40993 .36128 m .40321 .363 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40321 .363 m .38636 .3673 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.41846 .18522 m .4158 .19884 L p .40321 .21289 L .785 .641 .702 r
F P
0 g
s
.40321 .20652 m .41846 .18522 L .40321 .21289 L .785 .641 .702 r
F
.41826 .1712 m .41846 .18522 L p .40321 .20652 L F P
0 g
s
.40321 .19791 m .41826 .1712 L .40321 .20652 L .785 .641 .702 r
F
.38636 .18419 m .40321 .17841 L p .40321 .2215 L .131 .107 .561 r
F P
0 g
s
.39308 .23472 m .40321 .2215 L .40321 .31079 L .131 .107 .561 r
F
.38636 .18419 m .40321 .2215 L .39308 .23472 L F
.40321 .2215 m .4104 .21146 L .41131 .21044 L p 0 0 0 r
F P
0 g
s
.41131 .21044 m .41385 .20761 L p .40993 .21273 L 0 0 0 r
F P
0 g
s
.40993 .21273 m .40321 .2215 L .41131 .21044 L 0 0 0 r
F
.38636 .18419 m .40321 .17841 L p .30878 .18013 L .289 .763 .934 r
F P
0 g
s
.40889 .17871 m .4152 .15736 L .41388 .17897 L .785 .641 .702 r
F
.40321 .1853 m .4061 .17856 L .40321 .19791 L F
.4061 .17856 m .4152 .15736 L .40889 .17871 L F
.4061 .17856 m .40889 .17871 L .40321 .19791 L F
.30878 .18013 m .40321 .17841 L .3812 .17725 L .289 .763 .934 r
F
.40941 .14432 m .4152 .15736 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.40115 .13264 m .40941 .14432 L p .39899 .17818 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .39231 .17783 L .39899 .17818 L .785 .641 .702 r
F
.39231 .17783 m .40115 .13264 L .39899 .17818 L F
.30878 .18013 m .34485 .18583 L .38636 .18419 L p .289 .763 .934 r
F P
0 g
s
.39076 .12281 m .40115 .13264 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .3812 .17725 L .34157 .17516 L .289 .763 .934 r
F
.3787 .11528 m .39076 .12281 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.36547 .11038 m .3787 .11528 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.35166 .10832 m .36547 .11038 L p .37328 .17683 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .36679 .17649 L .37328 .17683 L .785 .641 .702 r
F
.36679 .17649 m .35166 .10832 L .37328 .17683 L F
.33786 .10921 m .35166 .10832 L p .3805 .23822 L F P
0 g
s
.32468 .11301 m .33786 .10921 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.31271 .11957 m .32468 .11301 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .34157 .17516 L .32509 .17429 L .289 .763 .934 r
F
.30247 .1286 m .31271 .11957 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .32509 .17429 L .31341 .17367 L .289 .763 .934 r
F
.29441 .13972 m .30247 .1286 L p .33537 .17483 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .3246 .17426 L .33537 .17483 L .785 .641 .702 r
F
.3246 .17426 m .29441 .13972 L .33537 .17483 L F
.30171 .17305 m .30878 .18013 L p .31341 .17367 L .289 .763 .934 r
F P
0 g
s
.28891 .15243 m .29441 .13972 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.2862 .16617 m .28891 .15243 L p .30171 .16442 L .785 .641 .702 r
F P
0 g
s
.30171 .17802 m .2862 .16617 L .30171 .16442 L .785 .641 .702 r
F
.30878 .18013 m .30878 .23853 L p .3027 .21933 L .934 .763 .288 r
F P
0 g
s
.30171 .17305 m .30878 .18013 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.3038 .21915 m .29541 .20742 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.29541 .20742 m .30171 .21623 L p .2997 .20987 L 0 .166 .704 r
F P
0 g
s
.28641 .18033 m .2862 .16617 L p .30171 .17802 L .785 .641 .702 r
F P
0 g
s
.30171 .18974 m .28641 .18033 L .30171 .17802 L .785 .641 .702 r
F
.28953 .19429 m .28641 .18033 L p .3805 .23822 L F P
0 g
s
.29541 .20742 m .28953 .19429 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.29889 .17022 m .30171 .17305 L p .30171 .21623 L .934 .763 .288 r
F P
0 g
s
.30114 .21442 m .30171 .21623 L .30171 .22565 L .934 .763 .288 r
F
.29889 .17022 m .30171 .21623 L .30114 .21442 L F
.2997 .20987 m .29889 .20732 L .29541 .20742 L 0 .166 .704 r
F
.29786 .20405 m .29655 .20585 L p .29889 .20732 L F P
0 g
s
.29655 .20585 m .29541 .20742 L p .29889 .20732 L 0 .166 .704 r
F P
0 g
s
.28953 .19429 m .29541 .20742 L .29786 .20405 L p 0 0 .572 r
F P
0 g
s
.29889 .20872 m .29889 .17022 L p .30144 .22023 L .934 .763 .288 r
F P
0 g
s
.3805 .23822 m .30171 .18974 L .30171 .17802 L .785 .641 .702 r
F
.3805 .23822 m .30171 .17802 L .30171 .16442 L F
.29889 .17022 m .30171 .17305 L p .31055 .16814 L .289 .763 .934 r
F P
0 g
s
.29889 .17022 m .29889 .20732 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.3284 .16909 m .30535 .15498 L .30535 .14271 L .785 .641 .702 r
F
.31518 .16839 m .30535 .15917 L .3284 .16909 L F
.30535 .15917 m .29246 .14708 L .30535 .15498 L F
.30535 .15917 m .30535 .15498 L .3284 .16909 L F
.31341 .17367 m .31713 .16849 L .30171 .17305 L .289 .763 .934 r
F
.28973 .16092 m .29246 .14708 L p .31518 .16839 L .785 .641 .702 r
F P
0 g
s
.29832 .16749 m .28973 .16092 L .31518 .16839 L .785 .641 .702 r
F
.31713 .16849 m .32192 .16181 L .31055 .16814 L .289 .763 .934 r
F
.31713 .16849 m .31055 .16814 L .30171 .17305 L F
.30535 .16786 m .29889 .17022 L p .31055 .16814 L F P
0 g
s
.30535 .16786 m .29889 .17022 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.35166 .10832 m .33786 .10921 L .34174 .10357 L p .363 .82 .929 r
F P
0 g
s
.36401 .17098 m .34174 .10357 L .37088 .17135 L .785 .641 .702 r
F
.33786 .10921 m .32468 .11301 L .32848 .1074 L p .448 .882 .87 r
F P
0 g
s
.32848 .1074 m .34174 .10357 L .33786 .10921 L p .448 .882 .87 r
F P
0 g
s
.32848 .1074 m .34174 .10357 L p .36401 .17098 L .785 .641 .702 r
F P
0 g
s
.35663 .17059 m .32848 .1074 L .36401 .17098 L .785 .641 .702 r
F
.36547 .11038 m .35166 .10832 L .35563 .10269 L p .27 .731 .951 r
F P
0 g
s
.34174 .10357 m .35563 .10269 L .35166 .10832 L p .363 .82 .929 r
F P
0 g
s
.34174 .10357 m .35563 .10269 L p .37088 .17135 L .785 .641 .702 r
F P
0 g
s
.40941 .14432 m .40115 .13264 L .40546 .1272 L p 0 .202 .73 r
F P
0 g
s
.39657 .17271 m .40546 .1272 L .40329 .17307 L .785 .641 .702 r
F
.40115 .13264 m .39076 .12281 L .39501 .1173 L p 0 .355 .827 r
F P
0 g
s
.39501 .1173 m .40546 .1272 L .40115 .13264 L p 0 .355 .827 r
F P
0 g
s
.39501 .1173 m .40546 .1272 L p .39657 .17271 L .785 .641 .702 r
F P
0 g
s
.39011 .17237 m .39501 .1173 L .39657 .17271 L .785 .641 .702 r
F
.4152 .15736 m .40941 .14432 L .41378 .13897 L p 0 .037 .606 r
F P
0 g
s
.40546 .1272 m .41378 .13897 L .40941 .14432 L p 0 .202 .73 r
F P
0 g
s
.40546 .1272 m .40754 .13013 L p .40329 .17307 L .785 .641 .702 r
F P
0 g
s
.40754 .13013 m .41378 .13897 L p .40754 .15926 L .785 .641 .702 r
F P
0 g
s
.40329 .17307 m .40754 .13013 L .40754 .15926 L .785 .641 .702 r
F
.39076 .12281 m .3787 .11528 L .38286 .10971 L p .075 .496 .897 r
F P
0 g
s
.38286 .10971 m .39501 .1173 L .39076 .12281 L p .075 .496 .897 r
F P
0 g
s
.38286 .10971 m .39501 .1173 L p .39011 .17237 L .785 .641 .702 r
F P
0 g
s
.40139 .17598 m .40139 .17297 L p .34157 .17516 L .289 .763 .934 r
F P
0 g
s
.34157 .17516 m .40139 .17297 L .36777 .17118 L .289 .763 .934 r
F
.3812 .17725 m .40993 .1761 L .34157 .17516 L F
.40321 .17841 m .40993 .1761 L p .3812 .17725 L F P
0 g
s
.3805 .23822 m .40321 .1853 L .40321 .19791 L .785 .641 .702 r
F
.3805 .23822 m .40321 .19791 L .40321 .20652 L F
.3805 .23822 m .40321 .20652 L .40321 .21289 L F
.38468 .23352 m .38377 .17203 L .39011 .17237 L F
.38377 .17203 m .38286 .10971 L .39011 .17237 L F
.3787 .11528 m .36547 .11038 L .36954 .10476 L p .173 .622 .939 r
F P
0 g
s
.36954 .10476 m .38286 .10971 L .3787 .11528 L p .173 .622 .939 r
F P
0 g
s
.36954 .10476 m .38286 .10971 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.35563 .10269 m .36954 .10476 L .36547 .11038 L p .27 .731 .951 r
F P
0 g
s
.35563 .10269 m .36954 .10476 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40139 .17297 m .40139 .16608 L p .36777 .17118 L .289 .763 .934 r
F P
0 g
s
.41846 .18522 m .41826 .1712 L .42269 .16604 L p 0 0 .27 r
F P
0 g
s
.41961 .15211 m .42269 .16604 L .41826 .1712 L p 0 0 .452 r
F P
0 g
s
.41961 .15211 m .42269 .16604 L p .41828 .17386 L .785 .641 .702 r
F P
0 g
s
.40241 .176 m .40993 .1761 L .40754 .17329 L .289 .763 .934 r
F
.40321 .19791 m .40889 .17871 L .41388 .17897 L .785 .641 .702 r
F
.4158 .19884 m .4104 .21146 L p .3805 .23822 L F P
0 g
s
.4104 .21146 m .40247 .22253 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.40993 .1761 m .40993 .36128 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40321 .17841 m .40993 .1761 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40247 .22253 m .40321 .2215 L p .40965 .21319 L 0 0 0 r
F P
0 g
s
.40956 .21334 m .40247 .22253 L .40965 .21319 L 0 0 0 r
F
.40993 .36128 m .40993 .21273 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40139 .35382 m .40754 .3592 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40754 .3592 m .40993 .36128 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40531 .21879 m .40321 .2215 L .40525 .21883 L 0 0 0 r
F
.40802 .2159 m .40139 .35382 L .40993 .21273 L .913 .745 .252 r
F
.40531 .21879 m .40525 .21883 L .41385 .20761 L 0 0 0 r
F
.41385 .20761 m .41477 .20658 L p .40531 .21879 L F P
0 g
s
.40802 .2159 m .40754 .21669 L .40754 .22587 L .913 .745 .252 r
F
.40679 .21773 m .40247 .22253 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.41477 .20658 m .40754 .21669 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.40754 .21669 m .40679 .21773 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.40754 .22587 m .40673 .21803 L .40139 .35382 L .913 .745 .252 r
F
.38468 .23352 m .40754 .21306 L .40679 .21773 L .785 .641 .702 r
F
.40993 .1761 m .40754 .17329 L p .40754 .21669 L .913 .745 .252 r
F P
0 g
s
.40993 .1761 m .40754 .21669 L .40802 .2159 L .913 .745 .252 r
F
.4152 .15736 m .41826 .1712 L p .41388 .17897 L .785 .641 .702 r
F P
0 g
s
.40993 .21273 m .40993 .1761 L p .40802 .2159 L .913 .745 .252 r
F P
0 g
s
.38468 .23352 m .41045 .17345 L .41828 .17386 L .785 .641 .702 r
F
.40241 .176 m .40754 .17329 L .4021 .173 L .289 .763 .934 r
F
.38468 .23352 m .39657 .17271 L .40329 .17307 L .785 .641 .702 r
F
.40247 .22253 m .39236 .23159 L .3805 .23822 L p F P
0 g
s
.39236 .23159 m .40247 .22253 L .40679 .21773 L p .514 .847 .564 r
F P
0 g
s
.40679 .21773 m .39661 .22685 L .39236 .23159 L p .514 .847 .564 r
F P
0 g
s
.4158 .19884 m .41846 .18522 L .42289 .18016 L p 0 0 .065 r
F P
0 g
s
.42289 .18016 m .42022 .19387 L .4158 .19884 L p 0 0 .065 r
F P
0 g
s
.42289 .18016 m .42022 .19387 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.42269 .16604 m .42289 .18016 L .41846 .18522 L p 0 0 .27 r
F P
0 g
s
.42269 .16604 m .42289 .18016 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.4104 .21146 m .4158 .19884 L .42022 .19387 L p 0 0 0 r
F P
0 g
s
.42022 .19387 m .41477 .20658 L .4104 .21146 L p 0 0 0 r
F P
0 g
s
.42022 .19387 m .41477 .20658 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.41826 .1712 m .4152 .15736 L .41961 .15211 L p 0 0 .452 r
F P
0 g
s
.41378 .13897 m .41961 .15211 L .4152 .15736 L p 0 .037 .606 r
F P
0 g
s
.41378 .13897 m .41961 .15211 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40679 .21773 m .39661 .22685 L .38468 .23352 L p .785 .641 .702 r
F P
0 g
s
.40139 .16608 m .40139 .22688 L p .40673 .21803 L .913 .745 .252 r
F P
0 g
s
.40139 .22688 m .40139 .35382 L p .40673 .21803 L .913 .745 .252 r
F P
0 g
s
.41477 .20658 m .40956 .21334 L .40965 .21319 L 0 0 0 r
F
.41477 .20658 m .40754 .21669 L p .40754 .21306 L .785 .641 .702 r
F P
0 g
s
.40754 .21669 m .40679 .21773 L p .40754 .21306 L .785 .641 .702 r
F P
0 g
s
.41045 .17345 m .41961 .15211 L .41828 .17386 L .785 .641 .702 r
F
.4021 .173 m .40754 .17329 L .40139 .16608 L .289 .763 .934 r
F
.40754 .17329 m .40139 .16608 L p .40754 .22587 L .913 .745 .252 r
F P
0 g
s
.38468 .23352 m .39011 .17237 L .39657 .17271 L .785 .641 .702 r
F
.34157 .17516 m .36777 .17118 L .32509 .17429 L .289 .763 .934 r
F
.36777 .17118 m .40139 .16608 L .35852 .17069 L F
.36777 .17118 m .35852 .17069 L .32509 .17429 L F
.32509 .17429 m .35852 .17069 L .33815 .16961 L F
.32468 .11301 m .31271 .11957 L .31642 .114 L p .519 .907 .766 r
F P
0 g
s
.31642 .114 m .32848 .1074 L .32468 .11301 L p .519 .907 .766 r
F P
0 g
s
.31642 .114 m .32848 .1074 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.31271 .11957 m .30247 .1286 L .30611 .1231 L p .569 .888 .618 r
F P
0 g
s
.30611 .1231 m .31642 .114 L .31271 .11957 L p .569 .888 .618 r
F P
0 g
s
.30611 .1231 m .31642 .114 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.32509 .17429 m .33815 .16961 L .31341 .17367 L .289 .763 .934 r
F
.33815 .16961 m .33032 .16919 L .31341 .17367 L F
.31341 .17367 m .33032 .16919 L .31713 .16849 L F
.30247 .1286 m .29441 .13972 L .298 .13429 L p .59 .819 .43 r
F P
0 g
s
.298 .13429 m .30611 .1231 L .30247 .1286 L p .59 .819 .43 r
F P
0 g
s
.298 .13429 m .30611 .1231 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40139 .16608 m .36478 .16006 L p .33815 .16961 L .289 .763 .934 r
F P
0 g
s
.35852 .17069 m .40139 .16608 L .33815 .16961 L .289 .763 .934 r
F
.38468 .23352 m .35663 .17059 L .36401 .17098 L .785 .641 .702 r
F
.33815 .16961 m .36478 .16006 L .33032 .16919 L .289 .763 .934 r
F
.36478 .16006 m .32192 .16181 L p .31713 .16849 L F P
0 g
s
.33032 .16919 m .36478 .16006 L .31713 .16849 L .289 .763 .934 r
F
.38468 .23352 m .36401 .17098 L .37088 .17135 L .785 .641 .702 r
F
.38468 .23352 m .30535 .17287 L .31518 .16839 L F
.32055 .17341 m .31518 .16839 L .3211 .1687 L F
.32055 .17341 m .3211 .1687 L .3284 .16909 L F
.38468 .23352 m .32055 .17341 L .3284 .16909 L F
.30171 .22565 m .3027 .21933 L .30878 .36429 L .934 .763 .288 r
F
.30878 .23853 m .30878 .36429 L p .3027 .21933 L F P
0 g
s
.30878 .36429 m .30171 .35902 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.31432 .22896 m .3038 .21915 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.3265 .23643 m .31432 .22896 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.31432 .22896 m .3265 .23643 L .33031 .2317 L p .025 .471 .877 r
F P
0 g
s
.3038 .21915 m .31432 .22896 L .31805 .22418 L p 0 .326 .805 r
F P
0 g
s
.33031 .2317 m .31805 .22418 L .31432 .22896 L p .025 .471 .877 r
F P
0 g
s
.31805 .22418 m .30745 .21429 L .3038 .21915 L p 0 .326 .805 r
F P
0 g
s
.28994 .17518 m .28973 .16092 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30535 .19455 m .29889 .20732 L .30535 .21135 L .101 .083 .548 r
F
.29308 .18924 m .28994 .17518 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.29901 .20247 m .29308 .18924 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30745 .21429 m .30535 .21135 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30535 .21135 m .29901 .20247 L p .30535 .20477 L .785 .641 .702 r
F P
0 g
s
.38468 .23352 m .30535 .21135 L .30535 .20477 L .785 .641 .702 r
F
.29889 .35691 m .29889 .20872 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.30144 .22023 m .30171 .22565 L .29889 .20872 L .934 .763 .288 r
F
.30171 .35902 m .29889 .35691 L p .30171 .22565 L F P
0 g
s
.29889 .20732 m .29889 .35691 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30745 .21429 m .29901 .20247 L .29786 .20405 L p 0 .166 .704 r
F P
0 g
s
.30745 .21429 m .29786 .20405 L .2997 .20987 L 0 .166 .704 r
F
.3038 .21915 m .30745 .21429 L p .2997 .20987 L F P
0 g
s
.31805 .22418 m .30745 .21429 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.31534 .21758 m .30535 .21135 L .30535 .30218 L .101 .083 .548 r
F
.30171 .21623 m .3038 .21915 L p .2997 .20987 L 0 .166 .704 r
F P
0 g
s
.30535 .21135 m .29889 .20732 L .30535 .30218 L .101 .083 .548 r
F
.33031 .2317 m .31805 .22418 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.32192 .35065 m .32192 .16181 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.29889 .35691 m .30535 .35515 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30535 .35515 m .32192 .35065 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30535 .17287 m .29832 .16749 L .30535 .16786 L .785 .641 .702 r
F
.30535 .17287 m .30535 .16786 L .31518 .16839 L F
.32192 .16181 m .30535 .19455 L .31534 .21758 L .101 .083 .548 r
F
.30535 .19455 m .30535 .21135 L .31534 .21758 L F
.32192 .16181 m .30535 .16786 L p .31055 .16814 L .289 .763 .934 r
F P
0 g
s
.32192 .16181 m .30535 .16786 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.29246 .14708 m .298 .13429 L p .30535 .14271 L .785 .641 .702 r
F P
0 g
s
.30535 .15498 m .29246 .14708 L .30535 .14271 L .785 .641 .702 r
F
.29786 .20405 m .29901 .20247 L p .29715 .20087 L 0 0 .572 r
F P
0 g
s
.29715 .20087 m .28953 .19429 L .29786 .20405 L 0 0 .572 r
F
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.30878 .36429 m .34485 .36852 L .38636 .3673 L p .224 .73 .894 r
F P
0 g
s
.38636 .3673 m .40993 .36128 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.32192 .35065 m .29889 .35691 L .30878 .36429 L p .224 .73 .894 r
F P
0 g
s
.36478 .34935 m .32192 .35065 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.40139 .35382 m .36478 .34935 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.40993 .36128 m .40139 .35382 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.33981 .24123 m .3265 .23643 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.35364 .24315 m .33981 .24123 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .36741 .24213 L .35364 .24315 L p .785 .641 .702 r
F P
0 g
s
.35364 .24315 m .36741 .24213 L .37149 .23746 L p .319 .799 .901 r
F P
0 g
s
.33981 .24123 m .35364 .24315 L .35763 .23848 L p .225 .711 .928 r
F P
0 g
s
.37149 .23746 m .35763 .23848 L .35364 .24315 L p .319 .799 .901 r
F P
0 g
s
.35763 .23848 m .3437 .23654 L .33981 .24123 L p .225 .711 .928 r
F P
0 g
s
.3437 .23654 m .33031 .2317 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.35763 .23848 m .3437 .23654 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.38468 .23352 m .37149 .23746 L .35763 .23848 L p .785 .641 .702 r
F P
0 g
s
.32192 .35065 m .36478 .34935 L .36478 .16006 L p .64 .523 .704 r
F P
0 g
s
.3265 .23643 m .33981 .24123 L .3437 .23654 L p .127 .6 .918 r
F P
0 g
s
.3437 .23654 m .33031 .2317 L .3265 .23643 L p .127 .6 .918 r
F P
0 g
s
.36478 .16006 m .32192 .16181 L .32192 .35065 L p .64 .523 .704 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3805 .23822 m .39236 .23159 L .39661 .22685 L p .47 .875 .721 r
F P
0 g
s
.39661 .22685 m .38468 .23352 L .3805 .23822 L p .47 .875 .721 r
F P
0 g
s
.36478 .34935 m .40139 .35382 L .40139 .16608 L p .907 .741 .664 r
F P
0 g
s
.36741 .24213 m .3805 .23822 L .38468 .23352 L p .402 .857 .834 r
F P
0 g
s
.38468 .23352 m .37149 .23746 L .36741 .24213 L p .402 .857 .834 r
F P
0 g
s
.40139 .16608 m .36478 .16006 L .36478 .34935 L p .907 .741 .664 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67268 .3673 m .63052 .36852 L .63052 .18583 L p .643 .525 .704 r
F P
0 g
s
.63052 .36852 m .59672 .36429 L .59672 .18013 L p .911 .744 .662 r
F P
0 g
s
.59672 .18013 m .63052 .18583 L .63052 .36852 L p .911 .744 .662 r
F P
0 g
s
.59249 .17305 m .57731 .16617 L .59249 .16442 L .787 .642 .702 r
F
.59249 .17802 m .58566 .17268 L .59249 .17305 L F
.58566 .17268 m .57731 .16617 L .59249 .17305 L F
.59249 .17305 m .59672 .18013 L p .60394 .17367 L .289 .763 .934 r
F P
0 g
s
.63052 .18583 m .67268 .18419 L .67268 .3673 L p .643 .525 .704 r
F P
0 g
s
.59672 .18013 m .63052 .18583 L .67268 .18419 L p .289 .763 .934 r
F P
0 g
s
.67268 .18419 m .69185 .17841 L p .59672 .18013 L .289 .763 .934 r
F P
0 g
s
.59672 .18013 m .69185 .17841 L .67031 .17725 L .289 .763 .934 r
F
.59672 .18013 m .59672 .23853 L p .59308 .21933 L .866 .707 .183 r
F P
0 g
s
.59249 .17305 m .59672 .18013 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59454 .21915 m .58633 .20742 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.58633 .20742 m .59249 .21623 L p .59129 .20987 L 0 .225 .746 r
F P
0 g
s
.57751 .18033 m .57731 .16617 L p .59249 .17802 L .787 .642 .702 r
F P
0 g
s
.59249 .18974 m .57751 .18033 L .59249 .17802 L .787 .642 .702 r
F
.58056 .19429 m .57751 .18033 L p .66962 .23822 L F P
0 g
s
.58633 .20742 m .58056 .19429 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.5908 .17022 m .59249 .17305 L p .59249 .21623 L .866 .707 .183 r
F P
0 g
s
.5908 .17022 m .59249 .21623 L .59228 .21512 L .866 .707 .183 r
F
.5908 .17022 m .59249 .22148 L .59233 .22023 L F
.59129 .20987 m .5908 .20732 L .58633 .20742 L 0 .225 .746 r
F
.59018 .20405 m .58812 .20585 L p .5908 .20732 L F P
0 g
s
.58812 .20585 m .58633 .20742 L p .5908 .20732 L 0 .225 .746 r
F P
0 g
s
.5862 .18924 m .58056 .19429 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.5908 .20872 m .5908 .17022 L p .59233 .22023 L .866 .707 .183 r
F P
0 g
s
.66962 .23822 m .59249 .18974 L .59249 .17802 L .787 .642 .702 r
F
.66255 .17683 m .6549 .11038 L .66874 .17716 L F
.64138 .10832 m .6549 .11038 L p .66255 .17683 L F P
0 g
s
.6562 .17649 m .64138 .10832 L .66255 .17683 L .787 .642 .702 r
F
.6549 .11038 m .66785 .11528 L p .66874 .17716 L F P
0 g
s
.69468 .17856 m .70358 .15736 L .70229 .17897 L .787 .642 .702 r
F
.69792 .14432 m .70358 .15736 L p .69185 .1853 L F P
0 g
s
.67268 .3673 m .67268 .18419 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69185 .16447 m .69792 .14432 L .69185 .1853 L .787 .642 .702 r
F
.69185 .19791 m .69468 .17856 L .70229 .17897 L F
.67268 .18419 m .69185 .17841 L p .69185 .2215 L .191 .156 .586 r
F P
0 g
s
.68033 .23472 m .69185 .2215 L .69185 .31079 L .191 .156 .586 r
F
.67268 .18419 m .69185 .2215 L .68033 .23472 L F
.69185 .2215 m .69888 .21146 L .70022 .21044 L p 0 0 0 r
F P
0 g
s
.70022 .21044 m .70395 .20761 L p .69949 .21273 L 0 0 0 r
F P
0 g
s
.69949 .21273 m .69185 .2215 L .70022 .21044 L 0 0 0 r
F
.70678 .18522 m .70418 .19884 L p .69185 .21289 L .787 .642 .702 r
F P
0 g
s
.66962 .23822 m .69185 .20652 L .69185 .21289 L .787 .642 .702 r
F
.69185 .20652 m .70678 .18522 L .69185 .21289 L F
.70658 .1712 m .70678 .18522 L p .66962 .23822 L F P
0 g
s
.70418 .19884 m .69888 .21146 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.69888 .21146 m .70418 .19884 L .71063 .19387 L p 0 0 0 r
F P
0 g
s
.69888 .21146 m .69112 .22253 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.71063 .19387 m .70718 .2021 L p .69888 .21146 L 0 0 0 r
F P
0 g
s
.70718 .2021 m .7053 .20658 L .70395 .20761 L p 0 0 0 r
F P
0 g
s
.70395 .20761 m .69888 .21146 L p .70718 .2021 L 0 0 0 r
F P
0 g
s
.69185 .31079 m .69703 .21939 L .69949 .36128 L .191 .156 .586 r
F
.69949 .1761 m .69949 .21521 L p .69703 .21939 L F P
0 g
s
.69949 .21521 m .69949 .36128 L p .69703 .21939 L .191 .156 .586 r
F P
0 g
s
.69949 .36128 m .69185 .363 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69949 .36128 m .69949 .21273 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69847 .2159 m .69496 .35382 L .69949 .21273 L .833 .68 .14 r
F
.69185 .1853 m .69468 .17856 L .69185 .19791 L .787 .642 .702 r
F
.69185 .17841 m .69949 .1761 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69112 .22253 m .69185 .2215 L p .69934 .21319 L 0 0 0 r
F P
0 g
s
.7053 .20658 m .69929 .21334 L .69934 .21319 L 0 0 0 r
F
.69929 .21334 m .69112 .22253 L .69934 .21319 L F
.70395 .20761 m .7053 .20658 L p .69185 .2215 L F P
0 g
s
.69496 .22688 m .69496 .35382 L p .69847 .2159 L .833 .68 .14 r
F P
0 g
s
.7053 .20658 m .69749 .21773 L .69112 .22253 L p 0 0 0 r
F P
0 g
s
.67585 .23352 m .69822 .21306 L .69749 .21773 L .787 .643 .702 r
F
.66962 .23822 m .69185 .16447 L .69185 .1853 L .787 .642 .702 r
F
.68983 .13264 m .69792 .14432 L p .66962 .23822 L F P
0 g
s
.67966 .12281 m .68983 .13264 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.59672 .18013 m .67031 .17725 L .63151 .17516 L .289 .763 .934 r
F
.66785 .11528 m .67966 .12281 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.62787 .10921 m .64138 .10832 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61498 .11301 m .62787 .10921 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.60325 .11957 m .61498 .11301 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.59672 .18013 m .63151 .17516 L .61538 .17429 L .289 .763 .934 r
F
.59323 .1286 m .60325 .11957 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.69949 .1761 m .69822 .17329 L p .63151 .17516 L .289 .763 .934 r
F P
0 g
s
.70358 .15736 m .69792 .14432 L .70433 .13897 L p 0 .111 .657 r
F P
0 g
s
.69822 .17329 m .70433 .13897 L .70107 .17345 L .787 .643 .702 r
F
.69406 .17307 m .69822 .15926 L .69822 .17329 L F
.69822 .15926 m .70433 .13897 L .69822 .17329 L F
.63151 .17516 m .69822 .17329 L .65929 .17118 L .289 .763 .934 r
F
.66962 .23822 m .69185 .1853 L .69185 .19791 L .787 .642 .702 r
F
.67031 .17725 m .69949 .1761 L .63151 .17516 L .289 .763 .934 r
F
.69792 .14432 m .68983 .13264 L .69619 .1272 L p 0 .256 .765 r
F P
0 g
s
.69619 .1272 m .70433 .13897 L .69792 .14432 L p 0 .256 .765 r
F P
0 g
s
.69619 .1272 m .70433 .13897 L p .69406 .17307 L .787 .643 .702 r
F P
0 g
s
.69185 .17841 m .69949 .1761 L p .67031 .17725 L .289 .763 .934 r
F P
0 g
s
.67585 .23352 m .68748 .17271 L .69406 .17307 L .787 .643 .702 r
F
.68748 .17271 m .69619 .1272 L .69406 .17307 L F
.68983 .13264 m .67966 .12281 L .68596 .1173 L p .043 .391 .851 r
F P
0 g
s
.68596 .1173 m .69619 .1272 L .68983 .13264 L p .043 .391 .851 r
F P
0 g
s
.68596 .1173 m .69619 .1272 L p .68748 .17271 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .68116 .17237 L .68748 .17271 L .787 .643 .702 r
F
.68116 .17237 m .68596 .1173 L .68748 .17271 L F
.59672 .18013 m .61538 .17429 L .60394 .17367 L .289 .763 .934 r
F
.58535 .13972 m .59323 .1286 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.63151 .17516 m .65929 .17118 L .61538 .17429 L .289 .763 .934 r
F
.67966 .12281 m .66785 .11528 L .67406 .10971 L p .122 .518 .912 r
F P
0 g
s
.67406 .10971 m .68596 .1173 L .67966 .12281 L p .122 .518 .912 r
F P
0 g
s
.67406 .10971 m .68596 .1173 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.66785 .11528 m .6549 .11038 L .66103 .10476 L p .2 .633 .948 r
F P
0 g
s
.66103 .10476 m .67406 .10971 L .66785 .11528 L p .2 .633 .948 r
F P
0 g
s
.66103 .10476 m .67406 .10971 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.6549 .11038 m .64138 .10832 L .64742 .10269 L p .278 .735 .954 r
F P
0 g
s
.64742 .10269 m .66103 .10476 L .6549 .11038 L p .278 .735 .954 r
F P
0 g
s
.64742 .10269 m .66103 .10476 L p .66873 .17169 L .787 .643 .702 r
F P
0 g
s
.66962 .23822 m .66255 .17683 L .66874 .17716 L .787 .642 .702 r
F
.67585 .23352 m .66234 .17135 L .66873 .17169 L .787 .643 .702 r
F
.66234 .17135 m .64742 .10269 L .66873 .17169 L F
.57996 .15243 m .58535 .13972 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.65929 .17118 m .65025 .17069 L .61538 .17429 L .289 .763 .934 r
F
.66962 .23822 m .6562 .17649 L .66255 .17683 L .787 .642 .702 r
F
.64138 .10832 m .62787 .10921 L .63382 .10357 L p .352 .815 .923 r
F P
0 g
s
.63382 .10357 m .64742 .10269 L .64138 .10832 L p .352 .815 .923 r
F P
0 g
s
.63382 .10357 m .64742 .10269 L p .66234 .17135 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .65562 .17098 L .66234 .17135 L .787 .643 .702 r
F
.65562 .17098 m .63382 .10357 L .66234 .17135 L F
.61538 .17429 m .63031 .16961 L .60394 .17367 L .289 .763 .934 r
F
.61538 .17429 m .65025 .17069 L .63031 .16961 L F
.62787 .10921 m .61498 .11301 L .62084 .1074 L p .417 .865 .846 r
F P
0 g
s
.62084 .1074 m .63382 .10357 L .62787 .10921 L p .417 .865 .846 r
F P
0 g
s
.62084 .1074 m .63382 .10357 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.61498 .11301 m .60325 .11957 L .60904 .114 L p .466 .873 .718 r
F P
0 g
s
.60904 .114 m .62084 .1074 L .61498 .11301 L p .466 .873 .718 r
F P
0 g
s
.60904 .114 m .62084 .1074 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60325 .11957 m .59323 .1286 L .59895 .1231 L p .489 .828 .539 r
F P
0 g
s
.59895 .1231 m .60904 .114 L .60325 .11957 L p .489 .828 .539 r
F P
0 g
s
.59895 .1231 m .60904 .114 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.63031 .16961 m .62265 .16919 L .60394 .17367 L .289 .763 .934 r
F
.60394 .17367 m .62265 .16919 L .60973 .16849 L F
.59339 .17872 m .59249 .17802 L .59249 .17578 L .787 .642 .702 r
F
.59339 .17872 m .59249 .17578 L .59249 .17305 L F
.66962 .23822 m .59339 .17872 L .59249 .17305 L F
.5908 .17022 m .5908 .20732 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.63138 .16966 m .59821 .14271 L .59895 .1231 L .787 .643 .702 r
F
.67585 .23352 m .62076 .16909 L .63138 .16966 L F
.62076 .16909 m .59821 .14271 L .63138 .16966 L F
.60205 .17357 m .59249 .17305 L .59249 .16442 L .787 .642 .702 r
F
.5908 .17022 m .59249 .17305 L p .60329 .16814 L .289 .763 .934 r
F P
0 g
s
.58558 .14708 m .59101 .13429 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.60394 .17367 m .60973 .16849 L .59249 .17305 L .289 .763 .934 r
F
.62076 .16909 m .59821 .15917 L .59821 .14271 L .787 .643 .702 r
F
.60783 .16839 m .59821 .15917 L .62076 .16909 L F
.60973 .16849 m .60329 .16814 L .59249 .17305 L .289 .763 .934 r
F
.59821 .16786 m .5908 .17022 L p .60329 .16814 L F P
0 g
s
.66962 .23822 m .59249 .17305 L .60205 .17357 L .787 .642 .702 r
F
.59821 .16786 m .5908 .17022 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.57731 .16617 m .57996 .15243 L p .59249 .16442 L .787 .642 .702 r
F P
0 g
s
.58292 .16092 m .58558 .14708 L p .59821 .15917 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .59821 .17287 L .59821 .15917 L .787 .643 .702 r
F
.59821 .17287 m .58292 .16092 L .59821 .15917 L F
.67585 .23352 m .60783 .16839 L .62076 .16909 L F
.66075 .16006 m .61719 .16181 L p .60973 .16849 L .289 .763 .934 r
F P
0 g
s
.62265 .16919 m .66075 .16006 L .60973 .16849 L .289 .763 .934 r
F
.60484 .22896 m .59454 .21915 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61676 .23643 m .60484 .22896 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.62978 .24123 m .61676 .23643 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61676 .23643 m .62978 .24123 L .63574 .23654 L p .156 .614 .932 r
F P
0 g
s
.60484 .22896 m .61676 .23643 L .62263 .2317 L p .076 .496 .897 r
F P
0 g
s
.63574 .23654 m .62263 .2317 L .61676 .23643 L p .156 .614 .932 r
F P
0 g
s
.59454 .21915 m .60484 .22896 L .61063 .22418 L p 0 .366 .835 r
F P
0 g
s
.62263 .2317 m .61063 .22418 L .60484 .22896 L p .076 .496 .897 r
F P
0 g
s
.61063 .22418 m .60026 .21429 L .59454 .21915 L p 0 .366 .835 r
F P
0 g
s
.58312 .17518 m .58292 .16092 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.59821 .19455 m .5908 .20732 L .59821 .21135 L .166 .136 .576 r
F
.5862 .18924 m .58312 .17518 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.592 .20247 m .5862 .18924 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60026 .21429 m .59821 .21135 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.59821 .21135 m .592 .20247 L p .59821 .20477 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .59821 .21135 L .59821 .20477 L .787 .643 .702 r
F
.5908 .35691 m .5908 .20872 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59233 .22023 m .59249 .22565 L .5908 .20872 L .866 .707 .183 r
F
.59249 .22565 m .59308 .21933 L .59672 .36429 L F
.59672 .23853 m .59672 .36429 L p .59308 .21933 L F P
0 g
s
.59672 .36429 m .59249 .35902 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59249 .35902 m .5908 .35691 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.5908 .20732 m .5908 .35691 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.60026 .21429 m .592 .20247 L .59018 .20405 L p 0 .225 .746 r
F P
0 g
s
.60026 .21429 m .59018 .20405 L .59129 .20987 L 0 .225 .746 r
F
.59454 .21915 m .60026 .21429 L p .59129 .20987 L F P
0 g
s
.61063 .22418 m .60026 .21429 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60965 .21758 m .59821 .21135 L .59821 .30218 L .166 .136 .576 r
F
.59228 .21512 m .59249 .21623 L .59249 .22148 L .866 .707 .183 r
F
.59233 .22023 m .59249 .22148 L .59249 .22565 L F
.59249 .21623 m .59454 .21915 L p .59129 .20987 L 0 .225 .746 r
F P
0 g
s
.59821 .21135 m .5908 .20732 L .59821 .30218 L .166 .136 .576 r
F
.62263 .2317 m .61063 .22418 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.61719 .35065 m .61719 .16181 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.5908 .35691 m .59821 .35515 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.59821 .35515 m .61719 .35065 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.60973 .16849 m .61719 .16181 L .60329 .16814 L .289 .763 .934 r
F
.59821 .15917 m .58558 .14708 L .59821 .14271 L .787 .643 .702 r
F
.61719 .16181 m .59821 .19455 L .60965 .21758 L .166 .136 .576 r
F
.59821 .19455 m .59821 .21135 L .60965 .21758 L F
.61719 .16181 m .59821 .16786 L p .60329 .16814 L .289 .763 .934 r
F P
0 g
s
.61719 .16181 m .59821 .16786 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.59101 .13429 m .59821 .12414 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.59821 .12414 m .59895 .1231 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.63031 .16961 m .66075 .16006 L .62265 .16919 L .289 .763 .934 r
F
.65929 .17118 m .69496 .16608 L .65025 .17069 L F
.69496 .16608 m .66075 .16006 L p .63031 .16961 L F P
0 g
s
.65025 .17069 m .69496 .16608 L .63031 .16961 L .289 .763 .934 r
F
.69822 .17329 m .69496 .16608 L p .65929 .17118 L F P
0 g
s
.69949 .1761 m .69822 .17329 L p .69822 .19032 L .833 .68 .14 r
F P
0 g
s
.67585 .23352 m .69406 .17307 L .69822 .17329 L .787 .643 .702 r
F
.69949 .1761 m .69822 .19032 L .69847 .2159 L .833 .68 .14 r
F
.69949 .21273 m .69949 .1761 L p .69847 .2159 L F P
0 g
s
.69822 .18023 m .69822 .17329 L .70107 .17345 L .787 .643 .702 r
F
.67585 .23352 m .69822 .17329 L .69822 .18023 L F
.69822 .21669 m .69749 .21773 L p .69822 .21306 L F P
0 g
s
.68123 .23159 m .69112 .22253 L .69749 .21773 L p 0 0 0 r
F P
0 g
s
.69749 .21773 m .68753 .22685 L .68123 .23159 L p 0 0 0 r
F P
0 g
s
.69822 .19032 m .69822 .21669 L .69847 .2159 L .833 .68 .14 r
F
.70418 .19884 m .70678 .18522 L .71325 .18016 L p 0 0 .173 r
F P
0 g
s
.71325 .18016 m .71063 .19387 L .70418 .19884 L p 0 0 .173 r
F P
0 g
s
.71325 .18016 m .71063 .19387 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.70678 .18522 m .70658 .1712 L .71305 .16604 L p 0 0 .362 r
F P
0 g
s
.71305 .16604 m .71325 .18016 L .70678 .18522 L p 0 0 .362 r
F P
0 g
s
.71305 .16604 m .71325 .18016 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.70358 .15736 m .70658 .1712 L p .70229 .17897 L .787 .642 .702 r
F P
0 g
s
.70658 .1712 m .70358 .15736 L .71003 .15211 L p 0 0 .523 r
F P
0 g
s
.71003 .15211 m .71305 .16604 L .70658 .1712 L p 0 0 .523 r
F P
0 g
s
.71003 .15211 m .71305 .16604 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.71063 .19387 m .7053 .20658 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.69112 .22253 m .68123 .23159 L .66962 .23822 L p .787 .642 .702 r
F P
0 g
s
.69749 .21773 m .68753 .22685 L .67585 .23352 L p .787 .643 .702 r
F P
0 g
s
.69822 .19032 m .69496 .22688 L .69822 .21669 L .833 .68 .14 r
F
.69496 .16608 m .69496 .22688 L p .69822 .19032 L F P
0 g
s
.69822 .17329 m .69496 .16608 L p .69822 .19032 L .833 .68 .14 r
F P
0 g
s
.70433 .13897 m .71003 .15211 L .70358 .15736 L p 0 .111 .657 r
F P
0 g
s
.70433 .13897 m .71003 .15211 L p .70107 .17345 L .787 .643 .702 r
F P
0 g
s
.7053 .20658 m .69822 .21669 L p .69822 .21306 L .787 .643 .702 r
F P
0 g
s
.69496 .35382 m .69822 .3592 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69822 .3592 m .69949 .36128 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69185 .363 m .67268 .3673 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.592 .20247 m .5891 .19586 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.5891 .19586 m .5862 .18924 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.58056 .19429 m .58633 .20742 L .59018 .20405 L p 0 .074 .632 r
F P
0 g
s
.59018 .20405 m .592 .20247 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.58976 .20087 m .58056 .19429 L .59018 .20405 L 0 .074 .632 r
F
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59672 .36429 m .63052 .36852 L .67268 .3673 L p .224 .73 .894 r
F P
0 g
s
.67268 .3673 m .69949 .36128 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.61719 .35065 m .5908 .35691 L .59672 .36429 L p .224 .73 .894 r
F P
0 g
s
.66075 .34935 m .61719 .35065 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.69496 .35382 m .66075 .34935 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.69949 .36128 m .69496 .35382 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64333 .24315 m .62978 .24123 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.66962 .23822 m .6568 .24213 L .64333 .24315 L p .787 .642 .702 r
F P
0 g
s
.6568 .24213 m .66962 .23822 L .67585 .23352 L p .368 .836 .806 r
F P
0 g
s
.64333 .24315 m .6568 .24213 L .66294 .23746 L p .307 .793 .893 r
F P
0 g
s
.67585 .23352 m .66294 .23746 L .6568 .24213 L p .368 .836 .806 r
F P
0 g
s
.62978 .24123 m .64333 .24315 L .64938 .23848 L p .234 .716 .933 r
F P
0 g
s
.66294 .23746 m .64938 .23848 L .64333 .24315 L p .307 .793 .893 r
F P
0 g
s
.64938 .23848 m .63574 .23654 L .62978 .24123 L p .234 .716 .933 r
F P
0 g
s
.63574 .23654 m .62263 .2317 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.64938 .23848 m .63574 .23654 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .66294 .23746 L .64938 .23848 L p .787 .643 .702 r
F P
0 g
s
.61719 .35065 m .66075 .34935 L .66075 .16006 L p .641 .523 .704 r
F P
0 g
s
.66075 .16006 m .61719 .16181 L .61719 .35065 L p .641 .523 .704 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.66962 .23822 m .68123 .23159 L .68753 .22685 L p .412 .833 .666 r
F P
0 g
s
.68753 .22685 m .67585 .23352 L .66962 .23822 L p .412 .833 .666 r
F P
0 g
s
.66075 .34935 m .69496 .35382 L .69496 .16608 L p .917 .748 .658 r
F P
0 g
s
.69496 .16608 m .66075 .16006 L .66075 .34935 L p .917 .748 .658 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.41923 1.29174 m .41389 1.27286 L .40848 1.29708 L p .952 .777 .322 r
F P
0 g
s
.40848 1.29708 m .41389 1.31592 L .41923 1.29174 L p .952 .777 .322 r
F P
0 g
s
.65354 1.29355 m .64977 1.2746 L .64595 1.29894 L p .904 .738 .238 r
F P
0 g
s
.64595 1.29894 m .64977 1.31785 L .65354 1.29355 L p .904 .738 .238 r
F P
0 g
s
.41389 1.27286 m .40848 1.29708 L .47174 1.29894 L p .574 .229 .346 r
F P
0 g
s
.40848 1.29708 m .41389 1.31592 L .47675 1.31785 L p .522 .721 .964 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.47675 1.31785 m .47174 1.29894 L .40848 1.29708 L p .522 .721 .964 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.75986 .90514 m .73989 .88531 L p .72051 .91463 L .702 .642 .786 r
F P
0 g
s
.72082 .89564 m .72051 .91463 L .73989 .88531 L .702 .642 .786 r
F
.72004 .94324 m .73919 .92491 L p .72051 .91463 L F P
0 g
s
.73919 .92491 m .75986 .90514 L p .72051 .91463 L .702 .642 .786 r
F P
0 g
s
.71476 .91147 m .72007 .91432 L .72051 .91463 L p .402 0 0 r
F P
0 g
s
.71476 .91147 m .69637 .90888 L .71417 .94885 L .702 .642 .786 r
F
.6817 .91682 m .71417 .94885 L p .69637 .90888 L F P
0 g
s
.68201 .89345 m .66987 .90514 L p .69637 .90888 L .702 .642 .786 r
F P
0 g
s
.70327 .90514 m .69637 .90888 L .71476 .91147 L .702 .642 .786 r
F
.68201 .89345 m .69637 .90888 L .70327 .90514 L F
.70378 .90453 m .71476 .91147 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.70378 .90453 m .70767 .93077 L .70375 .90794 L .662 .108 0 r
F
.72038 .89534 m .71496 .89881 L p .71476 .91147 L .791 .714 .78 r
F P
0 g
s
.71476 .91147 m .72007 .91432 L .72008 .91395 L p .791 .714 .78 r
F P
0 g
s
.72008 .91395 m .72038 .89534 L p .71476 .91147 L .791 .714 .78 r
F P
0 g
s
.72007 .91432 m .72038 .89534 L .74996 .91582 L p 0 0 .398 r
F P
0 g
s
.72038 .89534 m .71496 .89881 L p .72056 .89578 L .106 0 0 r
F P
0 g
s
.71417 .94885 m .72004 .94324 L p .71556 .86115 L .702 .642 .786 r
F P
0 g
s
.72082 .89564 m .72038 .89534 L p .72056 .89578 L .106 0 0 r
F P
0 g
s
.72051 .91463 m .72007 .91432 L p .72051 .91434 L 0 0 .398 r
F P
0 g
s
.72128 .86683 m .71556 .86115 L p .72004 .94324 L .702 .642 .786 r
F P
0 g
s
.72026 .91494 m .72027 .91457 L p .72011 .91448 L .605 .56 .778 r
F P
0 g
s
.71476 .91147 m .72051 .91463 L .72027 .91457 L .402 0 0 r
F
.71476 .91147 m .72026 .91494 L p .71496 .89906 L .605 .56 .778 r
F P
0 g
s
.72026 .91494 m .70767 .93077 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.71476 .91147 m .72026 .91494 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.72026 .91494 m .72027 .91457 L p .71344 .91535 L .892 .759 .259 r
F P
0 g
s
.72026 .91494 m .71344 .91535 L .71335 .91558 L .892 .759 .259 r
F
.70767 .93077 m .70353 .93598 L p .70375 .90794 L .662 .108 0 r
F P
0 g
s
.70796 .91138 m .70382 .91646 L p .72027 .91457 L .892 .759 .259 r
F P
0 g
s
.70382 .91646 m .70353 .93598 L .72026 .91494 L p .892 .759 .259 r
F P
0 g
s
.721 .91498 m .7496 .93532 L p .71476 .91147 L .402 0 0 r
F P
0 g
s
.72056 .89632 m .71496 .89906 L .72011 .91448 L .605 .56 .778 r
F
.70378 .90453 m .71476 .91147 L p .71496 .89906 L F P
0 g
s
.71496 .89881 m .70378 .90453 L p .72056 .89632 L .605 .56 .778 r
F P
0 g
s
.70327 .90514 m .70378 .90453 L p .70377 .90542 L .662 .108 0 r
F P
0 g
s
.71496 .89881 m .70327 .90514 L .71476 .91147 L .702 .642 .786 r
F
.71496 .89881 m .70413 .90575 L .71476 .91147 L p .791 .714 .78 r
F P
0 g
s
.70413 .90575 m .71476 .91147 L p .71487 .91154 L .402 0 0 r
F P
0 g
s
.70413 .90575 m .71487 .91154 L .7496 .93532 L .402 0 0 r
F
.7496 .93532 m .73325 .92655 L .70413 .90575 L p F P
0 g
s
.70413 .90575 m .71431 .91303 L p .72055 .89635 L .106 0 0 r
F P
0 g
s
.72027 .91457 m .72056 .89632 L p .72011 .91448 L .605 .56 .778 r
F P
0 g
s
.72056 .89578 m .71723 .8978 L .72056 .89632 L .106 0 0 r
F
.71496 .89881 m .70413 .90575 L p .72056 .89578 L F P
0 g
s
.72009 .89653 m .72057 .89594 L .71496 .89881 L p .605 .56 .778 r
F P
0 g
s
.72057 .89594 m .72041 .89639 L p .72056 .89632 L .605 .56 .778 r
F P
0 g
s
.72027 .91457 m .72056 .89632 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.71723 .8978 m .70413 .90575 L .72075 .89623 L .106 0 0 r
F
.72057 .89594 m .70796 .91138 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.72056 .89632 m .72057 .89594 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.72067 .89604 m .72056 .89632 L .72075 .89623 L .106 0 0 r
F
.72056 .89578 m .72056 .89632 L .72067 .89604 L F
.74996 .91582 m .7496 .93532 L .72051 .91463 L p 0 0 .398 r
F P
0 g
s
.72051 .91434 m .74996 .91582 L .72051 .91463 L 0 0 .398 r
F
.72075 .89623 m .72055 .89635 L .73325 .92655 L .106 0 0 r
F
.72051 .91463 m .721 .91498 L p .72027 .91457 L .402 0 0 r
F P
0 g
s
.71431 .91303 m .73325 .92655 L p .72055 .89635 L .106 0 0 r
F P
0 g
s
.71335 .91558 m .71344 .91535 L .70382 .91646 L .892 .759 .259 r
F
.71496 .89881 m .70378 .90453 L .70327 .90514 L p 0 0 0 r
F P
0 g
s
.71556 .86115 m .68201 .89345 L p .70327 .90514 L .702 .642 .786 r
F P
0 g
s
.71556 .86115 m .70327 .90514 L .71496 .89881 L .702 .642 .786 r
F
.70353 .93598 m .68657 .92525 L .70327 .90514 L p .662 .108 0 r
F P
0 g
s
.70377 .90542 m .70353 .93598 L .70327 .90514 L .662 .108 0 r
F
.72057 .89594 m .71496 .89881 L p .68657 .92525 L 0 0 0 r
F P
0 g
s
.70327 .90514 m .68657 .92525 L p .71496 .89881 L 0 0 0 r
F P
0 g
s
.66987 .90514 m .6817 .91682 L p .69637 .90888 L .702 .642 .786 r
F P
0 g
s
.73325 .92655 m .74996 .91582 L .72082 .89564 L p .106 0 0 r
F P
0 g
s
.72056 .89578 m .73325 .92655 L .72082 .89564 L .106 0 0 r
F
.73989 .88531 m .72128 .86683 L p .72082 .89564 L .702 .642 .786 r
F P
0 g
s
.68657 .92525 m .70382 .91646 L .72057 .89594 L p 0 0 0 r
F P
0 g
s
.59323 .1286 m .58535 .13972 L .59101 .13429 L p 0 0 0 r
F P
0 g
s
.59101 .13429 m .59895 .1231 L .59323 .1286 L p 0 0 0 r
F P
0 g
s
.29441 .13972 m .28891 .15243 L .29246 .14708 L p 0 0 0 r
F P
0 g
s
.29246 .14708 m .298 .13429 L .29441 .13972 L p 0 0 0 r
F P
0 g
s
.58535 .13972 m .57996 .15243 L .58558 .14708 L p 0 0 0 r
F P
0 g
s
.58558 .14708 m .59101 .13429 L .58535 .13972 L p 0 0 0 r
F P
0 g
s
.28641 .18033 m .28953 .19429 L .29308 .18924 L p 0 0 .411 r
F P
0 g
s
.29901 .20247 m .29308 .18924 L .28953 .19429 L p 0 0 .572 r
F P
0 g
s
.57751 .18033 m .58056 .19429 L .5862 .18924 L p 0 0 .491 r
F P
0 g
s
.28891 .15243 m .2862 .16617 L .28973 .16092 L p 0 0 .007 r
F P
0 g
s
.28973 .16092 m .29246 .14708 L .28891 .15243 L p 0 0 .007 r
F P
0 g
s
.57996 .15243 m .57731 .16617 L .58292 .16092 L p 0 0 .123 r
F P
0 g
s
.58292 .16092 m .58558 .14708 L .57996 .15243 L p 0 0 .123 r
F P
0 g
s
.2862 .16617 m .28641 .18033 L .28994 .17518 L p 0 0 .22 r
F P
0 g
s
.29308 .18924 m .28994 .17518 L .28641 .18033 L p 0 0 .411 r
F P
0 g
s
.57731 .16617 m .57751 .18033 L .58312 .17518 L p 0 0 .321 r
F P
0 g
s
.5862 .18924 m .58312 .17518 L .57751 .18033 L p 0 0 .491 r
F P
0 g
s
.28994 .17518 m .28973 .16092 L .2862 .16617 L p 0 0 .22 r
F P
0 g
s
.58312 .17518 m .58292 .16092 L .57731 .16617 L p 0 0 .321 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.74996 .91582 m .73325 .92655 L .7496 .93532 L closepath p .793 .719 .782 r
F P
0 g
s
.70382 .91646 m .68657 .92525 L .70353 .93598 L closepath p .601 .56 .78 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00g`3oool900000;80oooo2@00003M0?oo
o`00f@3oool6000000T0b:Bc1P00002V0?ooo`H000002@39Y;<600000=L0oooo003E0?ooo`@00000
5@38Y;<3000009l0oooo1000000E0<VT/`800000e@3oool00=80oooo0`00000L0<RT/`<00000V@3o
ool3000001/0bJBc0`00003B0?ooo`00d03oool200000280b:Bc0P00002E0?ooo`8000008@39Y;<2
00000=00oooo003>0?ooo`8000009P38Y;<200000940oooo0P00000U0<VT/`800000cP3oool00<`0
oooo0P00000Z0<RT/`030000003oool0oooo08`0oooo0P00000Y0<VT/`030000003oool0oooo0</0
oooo003:0?ooo`800000;@38Y;<00`000000oooo0?ooo`290?ooo`800000;039Y;<00`000000oooo
0?ooo`3:0?ooo`00b@3oool00`000000b:Bc0<RT/`0^0<RT/`800000R03oool00`000000bJBc0<VT
/`0]0<VT/`800000bP3oool00<P0oooo00<000000<RT/`38Y;<0<@38Y;<00`000000oooo0?ooo`24
0?ooo`0300000039Y;<0bJBc0300bJBc00<000000?ooo`3oool0a`3oool00<H0oooo0P00000e0<RT
/`030000003oool0oooo0880oooo00<000000<VT/`39Y;<0<P39Y;<00`000000oooo0?ooo`360?oo
o`00a@3oool00`000000b:Bc0<RT/`0f0<RT/`030000003oool0oooo0800oooo00<000000<VT/`39
Y;<0=039Y;<00`000000oooo0?ooo`350?ooo`00a03oool00`000000b:Bc0<RT/`0h0<RT/`030000
003oool0oooo07h0oooo00<000000<VT/`39Y;<0=P39Y;<00`000000oooo0?ooo`340?ooo`00``3o
ool00`000000b:Bc0<RT/`0j0<RT/`030000003oool0oooo07`0oooo00<000000<VT/`39Y;<0>039
Y;<00`000000oooo0?ooo`330?ooo`00`P3oool00`000000b:Bc0<RT/`0l0<RT/`030000003oool0
oooo07X0oooo00<000000<VT/`39Y;<0>P39Y;<00`000000oooo0?ooo`320?ooo`00`P3oool00`00
0000b:Bc0<RT/`0m0<RT/`030000003oool0oooo07P0oooo0P00000m0<VT/`030000003oool0oooo
0<40oooo00310?ooo`0300000038Y;<0b:Bc03l0b:Bc00<000000?ooo`3oool0MP3oool2000003l0
bJBc00<000000?ooo`3oool0`03oool00<00oooo00<000000<RT/`38Y;<0@038Y;<2000007H0oooo
0P0000110<VT/`030000003oool0oooo0;l0oooo002o0?ooo`0300000038Y;<0b:Bc0480b:Bc00<0
00000?ooo`3oool0L`3oool200000480bJBc00<000000?ooo`3oool0_`3oool00;l0oooo00<00000
0<RT/`38Y;<0@`38Y;<00`000000oooo0?ooo`1b0?ooo`800000@`39Y;<00`000000oooo0?ooo`2n
0?ooo`00_P3oool00`000000b:Bc0<RT/`150<RT/`030000003oool0oooo0700oooo0P0000150<VT
/`030000003oool0oooo0;d0oooo002m0?ooo`800000A`38Y;<200000700oooo0P0000170<VT/`03
0000003oool0oooo0;`0oooo002m0?ooo`0300000038Y;<0b:Bc04L0b:Bc00<000000?ooo`3oool0
K@3oool3000004L0bJBc00<000000?ooo`3oool0_03oool00;`0oooo0P00001:0<RT/`030000003o
ool0oooo06`0oooo0P0000190<VT/`030000003oool0oooo0;/0oooo002l0?ooo`0300000038Y;<0
b:Bc04T0b:Bc00<000000?ooo`3oool0J`3oool3000004T0bJBc00<000000?ooo`3oool0^`3oool0
0;/0oooo0P00001<0<RT/`030000003oool0oooo06X0oooo0P00001;0<VT/`030000003oool0oooo
0;X0oooo002k0?ooo`800000C038Y;<00`000000oooo0?ooo`1Y0?ooo`<00000B`39Y;<00`000000
oooo0?ooo`2j0?ooo`00^P3oool2000004h0b:Bc00<000000?ooo`3oool0J03oool2000004d0bJBc
00<000000?ooo`3oool0^@3oool00;X0oooo0P00001>0<RT/`030000003oool0oooo06L0oooo0`00
001=0<VT/`030000003oool0oooo0;T0oooo002i0?ooo`<00000C`38Y;<00`000000oooo0?ooo`1V
0?ooo`<00000CP39Y;<00`000000oooo0?ooo`2h0?ooo`00^@3oool00`00000000010000001?0<RT
/`030000003oool0oooo06H0oooo00<0000000007`000000CP39Y;<00`000000oooo0?ooo`2h0?oo
o`00^03oool300000540b:Bc00<000000?ooo`3oool0I03oool20000000300007`000000bJBc04h0
bJBc00<000000?ooo`3oool0]`3oool00;P0oooo00<0000000000@000000D@38Y;<00`000000oooo
0?ooo`1T0?ooo`040000000001l0000O000004l0bJBc00<000000?ooo`3oool0]`3oool00;P0oooo
00<0000000000@000000D@38Y;<00`000000oooo0?ooo`1T0?ooo`030000000001l000000500bJBc
00<000000?ooo`3oool0]`3oool00;P0oooo00<0000000000@000000D@38Y;<00`000000oooo0?oo
o`1T0?ooo`030000000001l000000500bJBc00<000000?ooo`3oool0]`3oool00;P0oooo0P00001C
0<RT/`030000003oool0oooo0680oooo00@0000000007`0001l00000D@39Y;<00`000000oooo0?oo
o`2f0?ooo`00^03oool2000005<0b:Bc00<000000?ooo`3oool0HP3oool010000000000O00007`00
001A0<VT/`030000003oool0oooo0;H0oooo002g0?ooo`0300000000004000000280b:Bc4000000Q
0<RT/`030000003oool0oooo0680oooo00@0000000007`0001l000008`39Y;<@000001h0bJBc00<0
00000?ooo`3oool0]P3oool00;L0oooo0`00000C0<RT/`l000003@2SQK@00`000000j;fY0>RmZ@06
000001/0b:Bc00<000000?ooo`3oool0HP3oool010000000000O00000000000C0<VT/a0000003@2T
QK@00`000000j[nX0>ZoZ006000001P0bJBc00<000000?ooo`3oool0]P3oool00;L0oooo0`00000@
0<RT/`<0000000<06AF<0000002SQK@06@2SQK@00`000000j;fY0>RmZ@060>RmZ@H000005P38Y;<0
0`000000oooo0?ooo`1P0?ooo`050000000001l000000000DP0000004039Y;<30000000302XRT`00
0000Y8Fd01X0Y8Fd00<000000>ZoZ03Z_jP01P3Z_jP5000000l0bJBc00<000000<VT/`39Y;<00P39
Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h0000000>0<RT/`800000100I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY00`0j;fY1P00000@0<RT/`030000003oool0
oooo0600oooo0P0000020000DP0300000039Y;<0bJBc00/0bJBc0`00000402XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP02`3Z_jP6000000h0bJBc00<000000?ooo`3oool0]@3oool0
0;L0oooo00<000000000>00000002`38Y;<3000000H06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0B0>RmZ@<000003@38Y;<00`000000oooo0?ooo`1P0?ooo`05000000000580001B
0000DP0000002P39Y;<3000000L0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00A
0>ZoZ0<000002`39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT
/`8000002@0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY0P00000<0<RT
/`030000003oool0oooo0600oooo00D000000000DP000580001B000000080<VT/`8000002P0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000<VT/`39Y;<02@39Y;<0
0`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT/`/06AF<00<000000:>5
]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00000000/0b:Bc00<000000?oo
o`3oool0H03oool01@000000001B0000DP000580000000P0bJBc300Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX0P00000:0<VT/`030000003oool0oooo0;D0oooo002g0?oo
o`030000000003P0000000T0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00@000000>Vn@03Y_T0000002P38Y;<00`000000oooo0?ooo`1P0?ooo`05000000000580
001B0000DP0000002039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z
_jP2000000X0bJBc00<000000?ooo`3oool0]@3oool00;L0oooo00<000000000>00000002@38Y;<:
01TES0030<RT/`000000XhFd01T0XhFd00<000000>RmZ@3X_JT0503X_JT01@000000jKi00>Vn@03Y
_T00000000T0b:Bc00<000000?ooo`3oool0H03oool01@000000001B0000DP000580000000P0bJBc
300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`000000
2@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT/`X06AF<00<0
b:Bc0000002SQK@06@2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0L0b:Bc
00@000000<RT/`38Y;<00000HP3oool01@000000001B0000DP000580000000P0bJBc300Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<02@39Y;<00`00
0000oooo0?ooo`2e0?ooo`00]`3oool3000000T0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T00jKi02P38Y;<00`000000oooo0?ooo`1P0?oo
o`03000000000580001B008000002039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>Zo
Z03Z_jP04`3Z_jP00`000000eJhS0<VT/`090<VT/`030000003oool0oooo0;D0oooo002g0?ooo`<0
00002@38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000
jKi00>Vn@03Y_T0:0<RT/`030000003oool0oooo0600oooo00D000000000DP000000001m00000008
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
bJBc000000P0bJBc00<000000?ooo`3oool0]@3oool00;L0oooo00@000000000J@0006T000002038
Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000jKi00>Vn
@03Y_T0:0<RT/`030000003oool0oooo0600oooo0P0000030000O@0300000039Y;<0bJBc00D0bJBc
300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<0
2@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT/`/06AF<
00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0X0
b:Bc00<000000?ooo`3oool0H03oool00`000000001m0000O@020000O@0300000039Y;<0bJBc00D0
bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`3E
[R<02@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT/`/0
6AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn
@0X0b:Bc00<000000?ooo`3oool0H03oool00`000000001m0000O@020000O@0300000039Y;<0bJBc
00D0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^
8`39Y;<02@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT
/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
0>Vn@0T0b:Bc00<000000?ooo`3oool0H@3oool00`000000001m0000O@020000O@0300000039Y;<0
bJBc00D0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<00000
0=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000J@000007
0<RT/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00
jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@0300000039
Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<0
00000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000J@00
00070<RT/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@030000
0039Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX
00<000000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000
J@0000070<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000
003Y_T00jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@03
00000039Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0
j[nX00<000000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y
0000000000070<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@04
0000003Y_T00jKi00>Vn@0P0b:Bc00<000000?ooo`3oool0H`3oool010000000001m0000O@0007d2
000000H0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<00000
0=F^8`39Y;<01`39Y;<00`000000oooo0?ooo`2g0?ooo`00^@3oool2000000030000TP000000b:Bc
00D0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00H000000>Vn
@03Y_T00jKi00<RT/`3Y_T060<RT/`030000003oool0oooo06@0oooo00@000000000O@00000001:Q
0P0000050<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000
003E[R<0bJBc00L0bJBc00<000000?ooo`3oool0]`3oool00;T0oooo00@000000000TP0009800000
1P38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000jKi0
0>Vn@03Y_T080<RT/`030000003oool0oooo06@0oooo0P000003000BX@0300000039Y;<0bJBc00<0
bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39
Y;<01`39Y;<00`000000oooo0?ooo`2g0?ooo`00^@3oool01@000000002B0000TP000980000000D0
b:Bc200I5H`01038Y;<06AF<01TES000000J0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn
@03Y_T00jKi01`38Y;<2000006H0oooo00<00000000BX@004Z400P004Z400`000000bJBc0<VT/`03
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0
bJBc00L0bJBc00<000000?ooo`3oool0]`3oool00;T0oooo00D000000000TP000980002B00000005
0<RT/`P06AF<00@0b:Bc01TES00I5H`000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0L0b:Bc00<000000?ooo`3oool0I@3oool00`00000001:Q000BX@02000BX@800000
1039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP00`000000eJhS
0<VT/`060<VT/`030000003oool0oooo0;P0oooo002j0?ooo`05000000000980002B0000TP000000
1038Y;<801TES0040<RT/`0I5H`06AF<000001X0XhFd00<000000>RmZ@3X_JT0503X_JT010000000
jKi00>Vn@03Y_T070<RT/`030000003oool0oooo06H0oooo00@00000000BX@004Z4001:Q0P000004
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0
bJBc00H0bJBc00<000000?ooo`3oool0^03oool00;X0oooo00D000000000TP000980002B00000004
0<RT/`P06AF<00@0b:Bc01TES00I5H`000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0H0b:Bc0P00001W0?ooo`80000010004Z400`000000bJBc0<VT/`020<VT/``0:R:C
00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0bJBc00D0bJBc
0P00002j0?ooo`00^`3oool01@000000002B0000TP000980000000<0b:Bc2`0I5H`00`000000XhFd
0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T00jKi01P38Y;<3000006H0
oooo0`000003000BX@8000000`39Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z
_jP04`3Z_jP00`000000eJhS0<VT/`050<VT/`030000003oool0oooo0;T0oooo002k0?ooo`050000
00000980002B0000TP0000000`38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X
_JT0503X_JT010000000jKi00>Vn@03Y_T060<RT/`0300000037X[<0000006D0oooo10000004000B
X@0400000039Y;<0bJBc0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0030000003E[R<0bJBc00D0bJBc00<000000?ooo`3oool0^@3oool00;`0oooo00D000000000
TP00000002Zd000000020<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@040000003Y_T00jKi00>Vn@0D0b:Bc00D000000<NR/`37X[<0aj:c0000001S0?ooo`@00000
00L0aj>c000000004Z4001:Q00000000>Kh000000080bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5
]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<01039Y;<00`000000oooo0?ooo`2j0?oo
o`00_03oool20000008002Zd0P0000000`38Y;<06AF<01TES00501TES0050<RT/`0I5H`06AF<01TE
S00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0D0b:Bc00D00000
0<NR/`37X[<0aj:c0000001S0?ooo`<000000P37Xk<00`00000001:Q00000003000i_P0300000039
Y;<0:R:C00/0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E
[R<0bJBc00@0bJBc00<000000?ooo`3oool0^P3oool00;d0oooo00H00000000Z]000:[@002Zd0000
0038Y;<701TES0050<RT/`0I5H`06AF<01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@04
0000003Y_T00jKi00>Vn@0@0b:Bc00<000000<NR/`37X[<00`37X[<00`000000oooo0?ooo`1O0?oo
o`@000000`37Xk<00`00000003Vn000i_P03000i_P030000000Z8Y<0:R:C00X0:R:C00<000000:B5
]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0bJBc00<0bJBc00<000000?oo
o`3oool0^`3oool00;h0oooo0P00:[@00`0I5H`002Zd0000000701TES0050<RT/`0I5H`06AF<01TE
S00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0@0b:Bc00L00000
0<NR/`37X[<0aj:c000>WP37X[<000000640oooo100000040<NS/`0600000000>Kh003Vn02XRT`00
>Kh00000300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^
8`39Y;<00`39Y;<00`000000oooo0?ooo`2k0?ooo`00_P3oool00`00000002Zd01TES00901TES005
0<RT/`0I5H`06AF<01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
0>Vn@0<0b:Bc00<000000<NR/`37X[<01037X[<00`000000oooo0?ooo`1N0?ooo`@000001@37Xk<0
0`00000003Vn000i_P0?02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
0`000000eJhS0<VT/`020<VT/`030000003oool0oooo0;`0oooo002o0?ooo`030000000I5H`06AF<
00P06AF<00D0b:Bc01TES00I5H`06AF<0000000J0:>5]0030000003X_JT0j;fY01@0j;fY00@00000
0>Vn@03Y_T00jKi00P38Y;<00`000000aj:c0<NR/`060<NR/`030000003oool0oooo05d0oooo1000
00060<NS/`8000003`0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00D0
00000=F^8`39Y;<0bJBc0000002o0?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01@000000jKi00>Vn@03Y_T00b:Bc00800000
2037X[<00`000000oooo0?ooo`1M0?ooo`@000001`37Xk<00`000000:R:C02XRT`0=02XRT`030000
002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP00`000000eJhS0<VT/`0200000;l0oooo
002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>Rm
Z@0D0>RmZ@050000003Y_T00jKi00>Vn@038Y;<00P0000090<NR/`030000003oool0oooo05/0oooo
100000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX
0>ZoZ00C0>ZoZ0040000003E[R<0bJBc00000<00oooo002o0?ooo`030000000I5H`06AF<00L06AF<
00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY
00L000000>Vn@03Y_T00jKi00000003Y_T00000000T0aj:c00<000000?ooo`3oool0F`3oool01000
0000000U00009@0000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0000000000<00oooo002o0?ooo`030000000I5H`0
6AF<00L06AF<00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00L000000>Vn@03Y_T00jKi00000003Y_T00000000T0aj:c00<000000?ooo`3oool0
F`3oool010000000000U00009@0000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02T
QK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0000000000<00oooo002o0?ooo`03
0000000I5H`06AF<00L06AF<00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000aj:c0<NR/`070<NR/`03
0000003oool0oooo05/0oooo00@0000000009@0002D000002037Xk<00`000000:R:C02XRT`0=02XR
T`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`000030
0?ooo`00_`3oool00`0000006AF<01TES00701TES0030000000I5H`06AF<00806AF<00<000000:>5
]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000<NR
/`37X[<02037X[<00`000000oooo0?ooo`1J0?ooo`030000000002D0000000T0aj>c00<0000002XR
T`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^
8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01`0I5H`00`00Dlh06AF<01TES00201TE
S0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn
@00300000037X[<0aj:c00P0aj:c00<000000?ooo`3oool0F@3oool010000000000U00009@000009
0<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00L06AF<00<005?>
01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T000`000000aj:c0<NR/`080<NR/`030000003oool0oooo05T0oooo00@00000
00009@0002D000002@37Xk<00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<0
00000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TE
S00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01`000000jKi00>Vn
@03Y_T008A^?0>Vn@00000002P37X[<00`000000oooo0?ooo`1I0?ooo`040000000002D000000000
00T0aj>c00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX
01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`00
0000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y
_T00000000/0aj:c00<000000?ooo`3oool0F03oool2000000030000E`000000aj>c00P0aj>c00<0
000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@0
00000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5
]00H0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T00000000/0
aj:c00<000000?ooo`3oool0F03oool010000000001G0000E`0000090<NS/`030000000Z8Y<0:R:C
00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS
00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0D0>RmZ@060000003Y_T00jKi00>Vn@00Q6hl0jKi00P0000080<NR/`0300000037
X[<0000005X0oooo00@000000000E`0005L000002037Xk<2000000l0:R:C00<000000:B5]02TQK@0
6@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000
000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H0:>5]0030000
003X_JT0j;fY01@0j;fY00H000000>Vn@03Y_T00jKi0024KS`3Y_T02000000P0aj:c00<000000<NR
/`000000FP3oool010000000001G0000E`0000080<NS/`0303@[U`000000:R:C00h0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00T000000>Vn@03Y_T00jKi0024KS`3Y_T0000000>c1A000
00002@37X[<00`000000oooo0?ooo`1H0?ooo`040000000005L0001G000000P0aj>c00<0=2^G0000
000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^
8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01P0I5H`00`3V_:X06AF<01TES00301TE
S0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01`000000jKi00>Vn@03Y_T00
8A^?0>Vn@00000000P3/`D@00`000000aj:c0<NR/`060<NR/`030000003oool0oooo05P0oooo00@0
00000000E`0005L000002037Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd
00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<
01TES00601TES0030>JlZP0I5H`06AF<00<06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY
0>RmZ@0D0>RmZ@070000003Y_T00jKi00>Vn@00Q6hl0jKi0000000020>c1A0T0aj:c00<000000?oo
o`3oool0F03oool010000000001G0000E`0000080<NS/`0303@[U`000000:R:C00h0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T0000000080k<54
2@37X[<00`000000oooo0?ooo`1H0?ooo`040000000005L00000000000P0aj>c00<0=2^G0000000Z
8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E
[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T0000000080k<542@37X[<0
0`000000oooo0?ooo`1H0?ooo`80000000<0002100000037Xk<01`37Xk<00`0d:iL0000002XRT`0>
02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`00
00300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<00000
0>RmZ@3X_JT0503X_JT01`000000jKi00>Vn@03Y_T008A^?0>Vn@00000000P3/`D@90<NR/`030000
003oool0oooo05P0oooo00D000000000P@0008400021000000070<NS/`0303@[U`000000:R:C00h0
:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS0000
0<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000
j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@02@37X[<00`000000
oooo0?ooo`1H0?ooo`0500000000084000210000P@0000001`37Xk<00`0d:iL0000002XRT`0>02XR
T`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`000030
0?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>Rm
Z@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c0P00001J0?oo
o`0500000000084000210000P@0000001`37Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00501TES0030>JlZP0I5H`06AF<00@06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@01`37X[<0
0`000000aj:c0000001K0?ooo`040000000008400021000000L0aj>c00<0=2^G0000000Z8Y<03P0Z
8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000
`03oool00;l0oooo00<0000001TES00I5H`01@0I5H`00`3V_:X06AF<01TES00401TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/
`D@0k<5400P0aj:c00<000000?ooo`3oool0FP3oool01@00000000210000P@000840000000H0aj>c
00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX
00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01@0I5H`00`3V_:X06AF<
01TES00401TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0
0>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3oool0FP3oool01@0000000021
0000P@000840000000H0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]003
0000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I
5H`01@0I5H`00`3V_:X06AF<01TES00401TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X
_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3o
ool0FP3oool01@00000000210000P@000840000000H0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool0
0;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0080<NR/`030000003oool0oooo
05/0oooo100000060<NS/`0303@[U`000000:R:C00h0:R:C00<000000:B5]02TQK@06@2TQK@00`00
0000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<
00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi0
00<0jKi000<000000>c1A03/`D@02037X[<00`000000oooo0?ooo`1K0?ooo`05000000005j@001NT
000GY00000001@37Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3oool0F`3oool01@00000001NT000GY000
5j@0000000D0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z
_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I
5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y
_T000`000000k<540>c1A0070<NR/`030000003oool0oooo05d0oooo00D00000000GY0005j@001NT
000000040<NS/`0303@[U`000000:R:C00h0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX
0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<
00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80
jKi000<000000>c1A03/`D@01`37X[<00`000000oooo0?ooo`1M0?ooo`05000000005j@001NT000G
Y00000001037Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>Zo
Z03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00401TE
S0030>JlZP0I5H`06AF<00D06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>Rm
Z@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/`D@01P37X[<00`000000oooo0?ooo`1N
0?ooo`03000000005j@001NT008001NT00H000000<NS/`37Xk<0aj>c03@[U`00000?02XRT`030000
002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00
_`3oool00`0000006AF<01TES00401TES0030>JlZP0I5H`06AF<00D06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/
`D@01P37X[<00`000000oooo0?ooo`1O0?ooo`05000000005j@001NT000GY00000000`37Xk<00`0d
:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP01000
0000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00401TES0030>JlZP0I5H`06AF<
00D06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
024KS`80jKi000<000000>c1A03/`D@01@37X[<00`000000oooo0?ooo`1P0?ooo`0:000000005j@0
01NT00000000?<40000003@[U`37Xk<0=2^G000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`00
0000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<
00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
024KS`80jKi000<000000>c1A03/`D@01@37X[<00`000000oooo0?ooo`1Q0?ooo`8000000P00?<40
1@000000aj>c0<NS/`0d:iL0000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>Zo
Z00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<0
00000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi0
00<000000>c1A03/`D@01037X[<00`000000oooo0?ooo`1R0?ooo`0300000000?<4003c1008003c1
00@000000<NS/`0d:iL000003`0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0
j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000
XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T008A^?0P3Y_T000`00
0000k<540>c1A0030<NR/`030000003oool0oooo06@0oooo00P00000000l`@00?<40=2^G000l`@00
0000=2^G000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000
003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/
`D@00P37X[<2000006H0oooo0P0000001P00?<40=2^G03@[U`00?<40=2^G000000l0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P37X[<00`000000oooo0?ooo`1V
0?ooo`800000100d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0040000003/`D@0k<540<NR/`800000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z
8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E
[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00<06AF<00<0000001TES00I5H`01P0I
5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y
_T001P000000k<540>c1A0000000k<54000006T0oooo00<0000003@[U`0d:iL00P0d:iL00`000000
:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000
eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00301TES0030000000I5H`06AF<00H0
6AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0
jKi000H000000>c1A03/`D@000000>c1A000001Y0?ooo`030000000d:iL0=2^G0080=2^G00<00000
02XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@00000
0=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A002
0>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=
02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`00
00300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<00000
0>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<00000
0?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W
0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<00000
01TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0oooo06L0oooo00<00000
03@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0060000003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000
000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000
003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0
;2BD0>c1A000001Y0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool0
0;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00<000000>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0
000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<0
00000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TE
S00201TES0030>o3B@0I5H`06AF<00L06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>Rm
Z@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y0?ooo`03
0000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]003
0000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I
5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@00Q
6hl00`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0024KS`030>Vn@0060000003/`D@0
k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C
00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00
oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY
0>RmZ@0D0>RmZ@030000003Y_T008A^?00<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y0?oo
o`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5
]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TE
S00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn
@00Q6hl00`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL00P0d
:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z
_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0024KS`030>Vn@0060000003/
`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0
:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS0000
0<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000
j;fY0>RmZ@0D0>RmZ@030000003Y_T008A^?00<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y
0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<00000
01TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL0
0P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP0
4`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000
002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0060000
003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C
00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS
00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0;2BD0>c1A000
001Y0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5
]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0
000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<0
00000>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d
:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z
_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES003
0000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@006
0000003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<540>c1A0020>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0
k<540080k<5400<000000?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000024KS`3Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`0000008A^?0>Vn@0030>Vn@0030000003/`D@0
;2BD0080k<5400<000000?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000000Q6hl0jKi000<0jKi000<000000>c1A00/99@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<5402`TU0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0;2BD0080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A00/99@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo01@0oooo?000000G0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo01@000002@2NPK<00`000000]9>d0;BC]00V
0;BC]00300000038Y;<0b:Bc00L0b:Bc500000030?ooo`030000000d:iL0=2^G0080=2^G00<00000
02XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@00000
0=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY0140j;fY4@00000M09j1/`030000002dTk@0]9>d02H0]9>d00<00000
0<RT/`38Y;<06`38Y;<A000000L0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<00000
0:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@050>RmZ@`000001P24K:l00`000000WX6c09j1/`0U
09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`04
0=^b[``000005`2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0502SQK@<00000180Q6b_00<00000
09j1/`2NPK<04P2NPK=@000001@0b:Bc00<000000=^b[`3K/Zl0403K/Zl<000000/0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd00X0XhFd2P00000H08A/[a/00000D00h^^@E000001h0fk:_2P000000
0`2TQK@000000>ZoZ00D0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@00P2SQK@8000000<0He2W00<0000008A/[`24K:l04024K:l<
000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0Y`P000003`3Z_jP010000000eJhS0=F^
8`0000300?ooo`00_`3oool00`0000006AF<01TES00901TES0P000002`1SD:L00`000000Q6b_08A/
[`0408A/[``00000WP0h^^@<000000H0fk:_00<000000>c0Y`3/`:L02@3/`:L8000000L0j[nX00@0
00000=F^8`3E[R<00000`03oool00;l0oooo00@0000001TES00I5H`06AF<2000000@06=@Y`X00000
]P0h^^@7000001<0k<2W200000020=F^8`030000003oool0oooo0;h0oooo002m0?ooo`H00000401S
D:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0
He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?oo
o`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<
V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D0
0000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo
002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool2
000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`0
000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rj
i1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0
001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0
om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000
V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F
0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool30000
00H0001l0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`00
04/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool0
0940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000
003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540
>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[T
E@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h
^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=
0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?oo
o`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000
S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2
000008`0oooo002<0?ooo`8000007@0h^^@403Vji900>;[T00<0000003Rji00h^^@0/00h^^@20000
08`0oooo002<0?ooo`800000>`0h^^@703Vji6H0>;[T2@2<L[400`000000eZna0=J_/@0=0=J_/J<0
>;[T0P00002<0?ooo`00S03oool00`000000>;[T03Rji01G03Rji0`0>K[T>P0h^^@00`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h^^@0W00h^^@2000008`0oooo
002<0?ooo`030000000h^^@0>;[T07D0>;[T3`0i^^@G03Rji080001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0U@0h
^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T03Rji02B03Rji0<0>K[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg400`3ncg4@03Rji0L0>K[TP`0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`00
0000>;[T03Rji02E03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07P0h^^@803Vj
i6l0>;[T00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0U00h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T0300>;[T2@0i^^AK03Rji0030000003oool0oooo08/0
oooo002>0?ooo`800000U00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00d0>;[T
400i^^@V03Rji0L0>K[TB00h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[T7@0h^^@503Vji3H0>;[T00<0
00000?ooo`3oool0SP3oool00940oooo00<0000003Rji00h^^@0T00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T04d0>;[T200i^^@C03Rji0@0>K[T900h^^@00`000000oooo0?ooo`2?
0?ooo`00TP3oool200000900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rj
i0@0>K[T2P0h^^@203Vji140>;[T0P00002B0?ooo`00U03oool00`000000>;[T03Rji02=03Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@03
08ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0S@0h^^@00`000000oooo0?ooo`2B0?ooo`00
UP3oool2000008`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji02:03Rji0800000
UP3oool009P0oooo0P00002:03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0R00h
^^@2000009P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0
>;[T08D0>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@00000O`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00Y@3oool5000007X0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000Y@3oool00:X0oooo1@00001e
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0L`0h^^@500000:X0oooo002_0?oo
o`D00000L00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06h0>;[T1@00002_0?oo
o`00]03oool5000006/0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01Y03Rji0D0
0000]03oool00;T0oooo1@00001V03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
I00h^^@500000;T0oooo002n0?ooo`D00000H@0h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T05l0>;[T1@00002n0?ooo`00``3oool5000005`0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00l0eZna00<0SG>a0=J_/@0000001`3ncg40
0`000000>;[T03Rji01J03Rji0D00000``3oool00<P0oooo1@00001G03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0?0=J_/@0308ec/@3F[k400000
00L0o/ma00<0000003Rji00h^^@0E@0h^^@500000<P0oooo003=0?ooo`L00000D00h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k400`2=Lk40
eZna000000070?k?L@030000000h^^@0>;[T04h0>;[T1`00003=0?ooo`00e03oool:000004H0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01403Rji0X00000e03oool00=h0oooo2P00
000l03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0>P0h^^@:00000=h0oooo003X
0?ooo`d00000;`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T02d0>;[T3@00003X
0?ooo`00m@3oool@000001l0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00M03Rj
i1000000m@3oool00?l0oooo1P3ooolI000000H0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji00403Rji1T00000o`3oool60?ooo`00o`3ooolO0?ooo`L000001`0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg4700000?l0oooo
7`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
3P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
3P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
3P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403@3F[k401@2=Lk40eZna0=J_/@3F[k400000
00L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@0508ec/@3F[k40eZna0=J_
/@0000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0eZna00D0SG>a0=J_/@3F
[k40eZna000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k40303F[k400`2=Lk40eZna0=J_/@020=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0<0=J_/@0308ec/@3F[k40eZna0080eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00`0eZna00<0
SG>a0=J_/@3F[k400P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k402`3F[k400`2=Lk40eZna0=J_/@03
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0;0=J_
/@0308ec/@3F[k40eZna00<0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00X0eZna00<0SG>a0=J_/@3F
[k40103F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
2P3F[k400`2=Lk40eZna0=J_/@040=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0:0=J_/@0308ec/@3F[k40eZna00@0eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00T0eZna00<0SG>a0=J_/@3F[k401@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k402@3F[k400`2=Lk40eZna0=J_/@050=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@080=J_/@0308ec/@3F[k40eZna00H0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna00P0eZna00<0SG>a0=J_/@3F[k401P3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k401`3F[k400`2=Lk40eZna0=J_/@070=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@070=J_/@0308ec/@3F[k40eZna00L0eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna00H0eZna00<0SG>a0=J_/@3F[k40203F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k401P3F[k400`2=Lk40eZna0=J_/@080=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@050=J_/@0308ec/@3F[k40eZna00T0eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00@0eZna00<0
SG>a0=J_/@3F[k402P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00<<0oooo0`00001N0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool200000140
oooo00<0000007YIX01jFJ001@00001I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00[@3oool30000000307]^^P000000000000l0oooo00<0000007YIX01jFJ00
1P1jFJ03000005H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002Y0?ooo`@000001@1kK[X00`000000oooo0?ooo`0=0?ooo`030000001jFJ00NUVP00P0NUVP00<0
00000?ooo`3oool0E03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:L0oooo0P00000907]^^P8000003P3oool00`000000NUVP07YIX00707YIX0800000EP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:L0oooo00<0000007]^
^P1kK[X0201kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02000005H0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00<0eZna00<0SG>a0=J_
/@3F[k402`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0
oooo00<0000007]^^P1kK[X01`1kK[X2000000d0oooo00<0000007YIX01jFJ00201jFJ000`000000
oooo0?ooo`1E0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
Z03oool00`000000Nfjj07]^^P0807]^^P030<1i003oool0oooo00/0oooo00<0000007YIX01jFJ00
201jFJ000`000000oooo0?ooo`1E0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00/0oooo00<0
000007YIX01jFJ001`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj0P00000<0?ooo`030000001jFJ00
NUVP00L0NUVP0P00001G0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool00`000000Nfjj07]^^P0707]^^P8000002`3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool02@3oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05H0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool0
2@3oool00`000000NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?oo
o`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^^P030<1i00000000
oooo00P0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1G0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^
^P8000002@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00P0
Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX00707YIX0800000F@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^
^P0707]^^P8000001`3oool00`000000NUVP07YIX00707YIX0030=fn^P000000oooo05T0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0080eZna00<0
SG>a0=J_/@3F[k40303F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:/0oooo00<0000007]^^P1kK[X01`1kK[X2000000L0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1H0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00D0oooo00<0000007YI
X01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01@3oool00`000000
NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0oooo00<0000007YIX01jFJ00
201jFJ02000005X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000001jFJ00NUVP00P0NUVP00<0
00000?ooo`3oool0F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:`0oooo00<0000007]^^P1kK[X0201kK[X2000000@0oooo00<0000007YIX01jFJ001`1jFJ02
000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002/0?oo
o`8000002@1kK[X00`30N@0000000?ooo`030?ooo`030000001jFJ00NUVP00L0NUVP0P00001K0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool00`000000
Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YIX0800000F`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo00<0000007]^^P1kK[X0
1`1kK[X2000000<0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1J0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool00`000000Nfjj07]^
^P0807]^^P8000000P3oool00`000000NUVP07YIX00707YIX0800000G03oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo0P00000907]^^P050<1i00000000
oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000000`3oool0000007YIX009
07YIX0800000G03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:h0oooo00<0000007]^^P1kK[X01`1kK[X4000000P0NUVP00<0gKjj000000000000G@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1k
K[X0201kK[X3000000T0NUVP0P00001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00[P3oool2000000T0Nfjj0`00000907YIX0800000G@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1kK[X01`1k
K[X2000000P0NUVP00@0gKjj07YIX038adH00000G@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000T0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool0
0`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00L0NUVP0P00001N0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool2000000T0Nfjj00<0000007YI
X01jFJ001`1jFJ02000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002`0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YIX01jFJ001`1jFJ000`38adH0
00000?ooo`1M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
/03oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool2000000T0Nfjj00<0
000007YIX01jFJ001@1jFJ02000005l0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo00<0000007]^
^P1kK[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7AP000000oooo05h0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`030000001kK[X0Nfjj00P0
Nfjj00<0000007YIX01jFJ000`1jFJ03000005l0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@040000003F[k40eZna08ec/A00eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X01P000000NUVP07YIX01jFJ00gKjj
07YIX0800000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00001P0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`000000Nfjj07]^^P0707]^^P03
0000001jFJ00NUVP00<0NUVP00<0b<M60000003oool0G`3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00;80oooo00<0000007]^^P1kK[X0201kK[X010000000NUVP
0=fn^P1jFJ0300000600oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002b0?ooo`8000002@1kK[X010000000NUVP07YIX01jFJ0200000640oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`8000002@1kK[X010000000NUVP
07YIX01jFJ0200000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002c0?ooo`030000001kK[X0Nfjj00L0Nfjj00H000000=fn^P1jFJ00NUVP0<S7AP00001Q0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool00`000000
Nfjj07]^^P0807]^^P030000001jFJ00000000800000H@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00;<0oooo0P00000907]^^P040000001jFJ00000000000680
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`800000
2@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00]03oool00`000000Nfjj07]^^P0707]^^P040000001jFJ00b<M600000680
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002d0?ooo`030000
001kK[X0Nfjj00P0Nfjj0`00001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00[P3ooolS000005<0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002P0?ooo`h000003018>ih00`000000lLBS0?74X`0<0?74X`l00000C03oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0A`3oooln00000?l0oooo8P3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo2`00000900d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H01`3od8H;
00000?l0oooo5`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oo
oaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oo
oaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo05L0oooo00<000000?ooo`3oool0^P3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0EP3oool300000;/0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo05D0oooo1@00002j0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`1D0?ooo`D0000000<0XAh00000003oool0^03oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0D`3oool7000000030:4N00000000oooo0;L0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
0580oooo200000020:4N00030000003oool0oooo0;D0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0540
oooo2P0000020:4N00030000003oool0oooo0;@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0500oooo
2`0000030:4N00030000003oool0oooo0;<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04l0oooo3000
00040:4N00030000003oool0oooo0;80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04h0oooo3P000004
0:4N00030000003oool0oooo0;40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04d0oooo3`0000050:4N
00030000003oool0oooo0;00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04`0oooo400000060:4N0003
0000003oool0oooo0:l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04/0oooo4@0000070:4N00030000
003oool0oooo0:h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04X0oooo4`0000070:4N00030000003o
ool0oooo0:d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo04P0oooo5@0000080:4N00800000[@3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0A`3ooolF000000X0XAh000<000000?ooo`3oool0ZP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0AP3ooolG000000/0XAh000<000000?ooo`3oool0Z@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0A@3ooolI000000/0XAh000<000000?ooo`3oool0Z03oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0A03ooolJ000000`0XAh000<000000?ooo`3oool0Y`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0@`3ooolJ000000030;>Tb@000000XAh000/0XAh000<000000?ooo`3oool0YP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0@P3ooolJ000000<0/jC900<000000:4N002Q7P002P2Q7P000`00
0000oooo0?ooo`2U0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`110?oooaX000001@2cY<T00`000000
XAh00:4N000:0:4N00030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0400oooo
6P0000070;>Tb@030000002Q7P00XAh000X0XAh000<000000?ooo`3oool0X`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0?`3ooolJ000000T0/jC900<000000:4N002Q7P002P2Q7P000`000000oooo0?oo
o`2R0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?oooaX000002`2cY<T00`000000XAh00:4N000:
0:4N00030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03d0oooo6P00000=0;>T
b@030000002Q7P00XAh000L0XAh000@0/j?80:4N002Q7P000000XP3oool00:00oooo00<0000004Pk
WP18>ih01018>ihX000000P0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0l0?oo
o`h0000000<0/j?80000000000002@00000?0;>Tb@030000002Q7P00XAh000X0XAh000<000000?oo
o`3oool0W`3oool009<0oooo5000000B04LjWP030000003aaJ<0lLFS01<0lLFS5`00000`0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo9`00000A0;>Tb@030000002Q7P00XAh000X0XAh03P00002C0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00h0EDFS2P0000000`1EAJ<00000
00000008000001<0/jC900<000000:4N002Q7P002@2Q7P000`000000mLRN0?G8WP0:0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<03@1E
AJ<E000001D0/jC900<000000:4N002Q7P002@2Q7P000`000000mLRN0?G8WP090?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<<
0000000305E5X`000000000000L000005`2cY<T00`000000XAh00:4N00080:4N00030000003eb9h0
mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0;05E5XaD000006@2cY<T00`000000XAh00:4N00070:4N00030000001HB:@0mLRN
00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0;05E5X`/0000000<0EDFS0000000000001P00000K0;>Tb@030000002Q7P00XAh000L0
XAh000<0000005Q8Y03eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS00`0EDFS4P00000M0;>Tb@030000002Q7P00XAh000H0XAh0
00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS00`0EDFS2@0000000`1EAJ<0000000000005000001l0/jC900<0
00000:4N002Q7P001P2Q7P000`000000mLRN0?G8WP070?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<@00000240/jC900<00000
0:4N002Q7P001@2Q7P000`000000mLRN0?G8WP070?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<80000000305E5X`0000000000
00@000008`2cY<T2000000D0XAh000<0000005Q8Y03eb9h01`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00d0EDFS3@00000U0;>Tb@80
00001@2Q7P0010000000mLRN0?G8WP1HB:@50?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<03@1EAJ<60000000305E5X`000000000000<0
00009`2cY<T2000000@0XAh000<000000?G8WP3eb9h00`3eb9h0101HB:@0mLRN0?G8WP00002C0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00d0EDFS2`00000Y0;>Tb@80
00000`2Q7P000`000000mLRN0?G8WP060?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<03@1EAJ<5000000030:LT00000000000000800000
6@2cY<T00`000000/jC90;>Tb@0?0;>Tb@8000000`2Q7P000`000000mLRN0?G8WP050?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<03P1E
AJ<8000001P0/jC900<06`000000000000000P00000A0;>Tb@040000002Q7P00XAh0000000L0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0>05E5X`<0000000@0Yb@000000000000000005`2cY<T4000000<06`0000<000000;>Tb@2cY<T0
3`2cY<T010000000XAh00:4N000000020?G8WP0505Q8Y03eb9h0mLRN0?G8WP000000T`3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0>05E5X`H000005`2cY<T400000003
0>C2@P0K0000001U00806`0000<000000;>Tb@2cY<T03`2cY<T00`000000XAh0000000060?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
3P1EAJ<2000000030:LT00000000/jC901H0/jC91@0000000`3T`T806`0001/0000401/000800000
402cY<T2000000H0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0?05E5X`8000005P2cY<T7000000030>C2@P0K00006`0000H06`0000<0
00000;>Tb@2cY<T03P2cY<T2000000D0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0?05E5X`030000002cY<T0/jC901<0/jC920000002
0>C2@PT06`0000<000000;>Tb@2cY<T03P2cY<T00`000000F4RT0?G8WP030?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0401EAJ<00`00
0000/jC90;>Tb@0A0;>Tb@P000000P3T`T8;01/0008000003@2cY<T00`000000mLRN0?G8WP040?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<04@1EAJ<00`000000/jC90;>Tb@0?0;>Tb@P000000`3T`T8501/000030000I@0K00006`0000D0
6`0000<000000;>Tb@2cY<T02@2cY<T00`000000mLRN0?G8WP050?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<04P1EAJ<00`000000/jC9
0;>Tb@0=0;>Tb@P00000103T`T8>01/000800000202cY<T00`000000mLRN0?G8WP060?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<04`1E
AJ<00`000000/jC90;>Tb@0<0;>Tb@L00000103T`T8A01/000030000002cY<T0/jC900@0/jC900D0
00000?G8WP3eb9h0mLRN05Q8Y0050?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0501EAJ<00`000000/jC90;>Tb@0:0;>Tb@P00000103T
`T8B01/000030000002cY<T0/jC90080/jC900<000000?G8WP3eb9h0203eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01D0EDFS00<00000
0;>Tb@2cY<T0202cY<T8000000@0i<9200<0000001/0000K00004@0K0002000000030;>Tb@000000
mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0F05E5X`030000002cY<T0/jC900H0/jC9200000060>C2@P8000004`0K00000`00
0000mLRN0?G8WP0:0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<05`1EAJ<00`000000/jC90;>Tb@040;>Tb@P00000203T`T8200000100
6`000`0000050?G8WP0305Q8Y03eb9h0mLRN00@0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0H05E5X`030000002cY<T0/jC90080/jC9
1`0000000`2ISlL000000>C2@P060>C2@P030000002cY<T0/jC9008000003@0K000010000000bkS8
0<^hb000000<0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<06@1EAJ<010000000/jC90;>Tb@2cY<T5000000<0VHo700<000000>C2@P3T
`T801@3T`T800`000000/jC90;>Tb@020;>Tb@030000000K00006`0000T06`0000D000000<^hb03;
^<P0bkS80000000<0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<06P1EAJ<00`000000/jC900000003000000D0VHo700<000000>C2@P3T
`T80103T`T800`000000/jC90;>Tb@040;>Tb@8000001`0K0002000000@0bkS800<000000?G8WP3e
b9h02P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS01/0EDFS0`00000709V?a`030000003T`T80i<9200<0i<9200<000000;>Tb@2cY<T0
1`2cY<T00`0000006`0001/0000301/000030000003;^<P0bkS800@0bkS800<000000?G8WP3eb9h0
2P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS01X0EDFS0P00000909V?a`030000003T`T80i<920080i<9200<000000;>Tb@2cY<T02@2c
Y<T20000000301/000000000000000L0bkS800<000000?G8WP3eb9h02P3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01/0EDFS0P000008
09V?a`030000003T`T80i<920080i<9200<000000;>Tb@2cY<T02`2cY<T00`000000bkS80<^hb007
0<^hb0030000003eb9h0mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0M05E5X`030000002ISlL0VHo700D0VHo700D000000>C2
@P3T`T80i<920000000?0;>Tb@8000001`3;^<P00`000000mLRN0?G8WP0:0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<07P1EAJ<20000
00D0VHo700@000000>C2@P3T`T800000402cY<T010000000mLRN0000000000050<^hb0030000003e
b9h0mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0J05E5X`030?C7X01EAJ<0EDFS00<0EDFS0P00000309V?a`030000003T`T80
00000100/jC900H000000?G8WP3eb9h0F4RT0?G8WP0000040<^hb0030000003eb9h0mLRN00X0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Q05E5X`8000000P2ISlL00`000000i<920000000?0;>Tb@050000003eb9h0mLRN0?G8WP1HB:@0
0P3eb9h200000080bkS800<000000?G8WP3eb9h02P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01T0EDFS00D0m<NP05E5X`1EAJ<0EDFS
0?C7X00505E5X`@000003P2cY<T2000000T0mLRN0`00000<0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<2000000h0/jC900<0
00000?G8WP3eb9h02`3eb9h00`000000mLRN0?G8WP0:0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<09@1EAJ<00`000000/jC90;>Tb@0;
0;>Tb@030000003eb9h0mLRN00@0mLRN00<0F4RT0?G8WP3eb9h04P3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01P0EDFS00<0m<NP05E5
X`1EAJ<02`1EAJ<00`000000/jC90;>Tb@090;>Tb@030000003eb9h0mLRN00D0mLRN00<0F4RT0?G8
WP3eb9h04P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS01`0EDFS00<0m<NP05E5X`1EAJ<0201EAJ<00`000000/jC90;>Tb@070;>Tb@03
0000003eb9h0mLRN00H0mLRN00<0F4RT0?G8WP3eb9h04P3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01L0EDFS00<0m<NP05E5X`1EAJ<0
3P1EAJ<00`000000/jC90;>Tb@050;>Tb@030000003eb9h0mLRN00L0mLRN00<0F4RT0?G8WP3eb9h0
4P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS02T0EDFS00<000000;>Tb@2cY<T00`2cY<T00`000000mLRN0?G8WP0M0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<06`1EAJ<0
0`3daj00EDFS05E5X`0;05E5X`8000000`2cY<T00`000000mLRN0?G8WP0N0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<05P1EAJ<00`3d
aj00EDFS05E5X`0@05E5X`050000003eb9h000000;>Tb@0000002`3eb9h00`1HB:@0mLRN0?G8WP07
0?G8WP0305Q8Y03eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`040000003eb9h0mLRN000000`0mLRN00<0F4RT
0?G8WP3eb9h04`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;`00000C00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H_00000080oooo00<0000005E5X`1EAJ<05@1EAJ<00`3d
aj00EDFS05E5X`0205E5X`030?C7X01EAJ<0EDFS00`0EDFS00<000000?G8WP3eb9h03@3eb9h00`1H
B:@0mLRN0?G8WP0C0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<d000001403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QPT000002005000Q000002/0EDFS00<000000?G8WP3eb9h03@3eb9h00`1HB:@0
mLRN0?G8WP0C0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000
003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN01H0mLRN00<0F4RT0?G8WP3e
b9h02P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om26
0?o@QP3od8I00:eTN`8000005P1EAJ<00`3daj00EDFS05E5X`0205E5X`030?C7X01EAJ<0EDFS00d0
EDFS00<000000?G8WP3eb9h0303eb9h00`1HB:@0mLRN0?G8WP0D0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk
0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000K05E5X`03
0?C7X01EAJ<0EDFS00d0EDFS00<000000?G8WP3eb9h0303eb9h00`1HB:@0mLRN0?G8WP0D0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk
0P00000E05E5X`030?C7X01EAJ<0EDFS01<0EDFS00<000000?G8WP3eb9h0303eb9h00`1HB:@0mLRN
0?G8WP0D0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260440[FAk0P00000J05E5X`030?C7X01EAJ<0EDFS00h0EDFS00<000000?G8WP3eb9h0303e
b9h00`1HB:@0mLRN0?G8WP060?G8WP0305Q8Y03eb9h0mLRN00/0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/2
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000001X0EDFS00<0m<NP
05E5X`1EAJ<03P1EAJ<00`000000mLRN0?G8WP0<0?G8WP0305Q8Y03eb9h0mLRN01@0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`800000@@2]I7/200d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP2]I7/0@@2]I7/20000
01@0EDFS00<0m<NP05E5X`1EAJ<0501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480
[FAk00<03@^60000002dTk@0:@2dTk@00`000000om260:eTN`110:eTN`800000:`1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000om26
0:eTN`110:eTN`8000006@1EAJ<00`3daj00EDFS05E5X`0?05E5X`030000003eb9h0mLRN00/0mLRN
00<0F4RT0?G8WP3eb9h01P3eb9h00`1HB:@0mLRN0?G8WP0<0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<0
3@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8
WP0;0?G8WP0305Q8Y03eb9h0mLRN01D0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y
0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN00/0mLRN00<0F4RT
0?G8WP3eb9h05@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000130:eTN`030000002dTk@0]9>d02P0]9>d00<000000:eT
N`2]I7/0@@2]I7/200000180EDFS00<0m<NP05E5X`1EAJ<00`1EAJ<00`3daj00EDFS05E5X`0@05E5
X`030000003eb9h0mLRN00/0mLRN00<0F4RT0?G8WP3eb9h05@3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000130:eTN`03
0000002dTk@0]9>d02P0]9>dA02]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
0P0000130:eTN`030000002dTk@0]9>d02P0]9>dA02]I7/2000002/0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS0P0000130:eTN`030000002dTk@0]9>d02P0]9>dA02]I7/2000001L0EDFS00<0
m<NP05E5X`1EAJ<04@1EAJ<00`000000mLRN0?G8WP0:0?G8WP0305Q8Y03eb9h0mLRN01H0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h02P3eb9h00`1HB:@0mLRN0?G8WP0F
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000;80[FAk0P00000@05E5X`030?C7X01EAJ<0EDFS01P0EDFS00<000000?G8
WP3eb9h02P3eb9h00`1HB:@0mLRN0?G8WP0F0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000F05E5X`03
0?C7X01EAJ<0EDFS0180EDFS00<000000?G8WP3eb9h02P3eb9h00`1HB:@0mLRN0?G8WP0F0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]
I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000>05E5X`030?C7X01EAJ<0EDFS
00@0EDFS00<0m<NP05E5X`1EAJ<04`1EAJ<00`000000mLRN0?G8WP090?G8WP0305Q8Y03eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h02@3eb9h00`1HB:@0
mLRN0?G8WP0G0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN00T0mLRN
00<0F4RT0?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/@2]I7/2000001@0EDFS00<0
m<NP05E5X`1EAJ<0501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1M
0:eTN`030:jfg`2]I7/0[FAk0580[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00X0EDFS00<0m<NP05E5
X`1EAJ<0701EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1T0:eTN`03
0:jfg`2]I7/0[FAk04/0[FAk00<0000005E5X`1EAJ<04@1EAJ<00`3daj00EDFS05E5X`0E05E5X`03
0000003eb9h0mLRN00P0mLRN00<0F4RT0?G8WP3eb9h0603eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0
/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00P0mLRN00<0F4RT0?G8WP3eb9h0
603eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN00P0mLRN00<0F4RT0?G8WP3eb9h0603eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0K`2]I7/0
0`2^]]l0[FAk0:eTN`100:eTN`030000001EAJ<0EDFS0100EDFS00<0m<NP05E5X`1EAJ<05P1EAJ<0
0`000000mLRN0?G8WP080?G8WP0305Q8Y03eb9h0mLRN01P0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk
0;80[FAk00<0000005E5X`1EAJ<0201EAJ<00`3daj00EDFS05E5X`0N05E5X`030000003eb9h0mLRN
00h0mLRN00<0F4RT0?G8WP3eb9h04P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0MP2]I7/00`2^]]l0
[FAk0:eTN`0i0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00L0mLRN
00<0F4RT0?G8WP3eb9h06@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/00`2^]]l0[FAk0:eT
N`0b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h01`3eb9h00`1HB:@0mLRN0?G8
WP0I0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h01`3eb9h00`1HB:@0mLRN0?G8WP030?G8WP0305Q8Y03eb9h0mLRN01<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk08@0[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN00L0mLRN00<0F4RT0?G8WP3eb9h06@3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
002]I7/0[FAk08/0[FAk00<0[[KO0:eTN`2]I7/0902]I7/00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0
EDFS00d0EDFS00<0m<NP05E5X`1EAJ<06@1EAJ<00`000000mLRN0?G8WP060?G8WP0305Q8Y03eb9h0
mLRN01X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP060?G8WP0305Q8Y03eb9h0mLRN01X0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP060?G8WP0305Q8Y03eb9h0mLRN01X0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0301EAJ<00`3daj00EDFS
05E5X`0J05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00D0mLRN00<0F4RT0?G8
WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN00D0mLRN00<0F4RT0?G8WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0
/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00D0mLRN00<0F4RT0?G8WP3eb9h0
6`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40
[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP040?G8WP0305Q8Y03eb9h0mLRN01`0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP040?G8WP0305Q8Y03eb9h0mLRN01`0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h00`3eb9h00`1HB:@0mLRN0?G8WP0M0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<G
00000;@0[KSQ6`00000A05E5X`030000003eb9h0mLRN00<0mLRN00<0F4RT0?G8WP3eb9h07@3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
01<0lLFS5P2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01@0[VEl5@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^
IG`05@2^IG`D05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0B0?75XaL0[VEl00<000000:fhh@2]^>40
/P2]^>400`000000[VEl0:iUO00E0:iUO1@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^
IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<04@3aaJ<H0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05P2^IG`C
05E5X`030000003eb9h0mLRN0080mLRN00<0F4RT0?G8WP3eb9h07P3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0100lLFS6@2^IG`00`00
0000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01L0[VEl4P1EAJ<00`000000mLRN0?G8WP020?G8
WP0405Q8Y03eb9h0mLRN05Q8Y1d0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75Xa/0[VEl00<000000:fhh@2]^>40/02]^>420000
01X0[VEl4@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40[KSQ0;00
[KSQ0P00000J0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00h0lLFS5@2^IG`00`3aaJ<0[VEl
0:iUO0040:iUO0030000002]^>40[KSQ0;00[KSQ0P00000K0:iUO100EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00h0lLFS702^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0=0?75Xad0[VEl00<000000:fhh@2]^>40/02]^>42000001`0[VEl3`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000M0:iU
O0h0EDFS00D000000?G8WP3eb9h0mLRN05Q8Y00Q0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0702^IG`>05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0;0?75Xal0
[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M0:iUO0d0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00/0lLFS7`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0[VEl
3@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02P3aaJ<P0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`07P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75Xb40[VEl00<00000
0:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01l0[VEl2`1EAJ<01000
0000mLRN0?G8WP1HB:@R0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0203aaJ<R0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iU
O02^IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]
^>40/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00L0lLFS
8`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240[VEl2@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08P2^
IG`805E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>40
0`000000[VEl0:iUO0050:iUO00305E5X`2^IG`0[VEl01X0[VEl201EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<01@3aaJ<U0:iUO0030000002]^>40[KSQ0380[KSQ00<0^iT60:fhh@2]^>40AP2]^>400`00
0000[KSQ0:fhh@0b0:fhh@030000002^IG`0[VEl02<0[VEl1`1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<01@3aaJ=J0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000
[VEl0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00@0lLFS?`2^IG`00`2]^>40[VEl
0:iUO00I0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl
0:iUO00=0:iUO00305E5X`2^IG`0[VEl01@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3a
aJ=>0:iUO0030:fhh@2^IG`0[VEl00/0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iU
O00b0:iUO0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ=5
0:iUO0030:fhh@2^IG`0[VEl01@0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b
0:iUO0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iU
O0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00E0:iU
O00305E5X`2^IG`0[VEl00h0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=;0:iUO003
0:fhh@2^IG`0[VEl00l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO003
0000002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00@000000?75X`3aaJ<0lLFSGP2^IG`00`2kV@H0
[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09`2^IG`305E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`1H0:iUO0030:fhh@2^IG`0[VEl00@0[VEl00<0^iT60:fhh@2]^>40
AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02P0[VEl0P1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<0
00000:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>40
0`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0EDFS0000003eb9h07P3eb9h7
000009<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ
04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN
0180mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iUO02^IG`0G`2^IG`00`2kV@H0
000000000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`000000mLRN0?G8WP040?G8WPd0
0000YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006000000000000
I`00002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<00000
0:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P
0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?oo
o`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80
G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000
003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool0
0`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo
0;L0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?oo
o`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fh
hP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fh
hP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00
^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003o
ool0oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`00
0000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0
oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fh
hP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<0
00000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?oo
o`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`0=0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`2i0?ooo`00
^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00`0@3HL01@3od8T040f7
010=Q`0@3HL0000001@0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`02010=Q`030?o@R@0@3HL040f7008040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7
010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00@00000010=Q`0@3HL0om291P0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00k@3ooolo000000T040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Qcl00000k@3oool00>d0oooo00<0000008<51P231@H010231@H00`1Mb_P0P`D608<5
1P0e08<51PT040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`060?o@Qcl0P`D600<0
00000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H02`231@H00`1Mb_P0P`D608<51P0_
08<51PP040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`050?o@Qd00P`D600<00000
0?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H04P231@H00`1Mb_P0P`D608<51P0Y08<5
1PL040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`040?o@Qd40P`D600<000000?oo
o`3oool0j`3oool00>d0oooo00<0000008<51P231@H060231@H305g:n2@0P`D61P0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700<0om27@P231@H00`000000oooo0?ooo`3[0?ooo`00
k03oool00`000000P`D608<51P0P08<51P<0GL[h7`231@H4010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L00P3od8M308<51P800000k03oool00>`0oooo00<0000008<51P231@H09`23
1@H3000001P0P`D6100@3HL00`000000]9>d0;BC]00B0;BC]0040000003od8L0om270?o@QdD0P`D6
00<000000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0;@231@H50;2_ea40P`D60`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2704H0P`D600<000000?ooo`3oool0jP3o
ool00>`0oooo00<0000008<51P231@H0=0231@H50;2_e`/0P`D60P0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0P`D601d0P`D61@2`[mLT08<51P030000003oool0oooo0>X0oooo003/0?oo
o`03000000231@H0P`D603/0P`D600<0/:oG0000000@3HL00P0@3HL608<51P030000002dTk@0]9>d
0180]9>d00<0000008<51P231@H0:`231@H90;2_ea80P`D600<000000?ooo`3oool0jP3oool00>`0
ooooZ000003/0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo
003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<00000
0;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5c
SP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>3@00003P0?ooo`00
k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00T0Tc]I00<000000?ooo`3oool0
gP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<kF@0909<kF@030000003o
ool0oooo0=h0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<0000009<kF@2C>eT02@2C>eT2
00000=l0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<0000009<kF@2C>eT0202C>eT00`00
0000ik`l0000003O0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00P0
Tc]I00<000000>Nl?0000000g`3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I
09<kF@0809<kF@030000003W_3`000000=l0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<0
000009<kF@2C>eT0202C>eT010000000ik`l0>Nl?000003N0?ooo`00k03oool00`000000/G>>0;5c
SP2T0;5cSP030000002C>eT0Tc]I00P0Tc]I00@000000>Nl?03W_3`00000gP3oool00>`0oooo00<0
00000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<kF@0809<kF@040000003W_3`0ik`l00000=h0oooo
003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<0000009<kF@2C>eT0202C>eT010000000ik`l0>Nl
?000003N0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00P0Tc]I00D0
00000>Nl?03W_3`0ik`l0000003M0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C
>eT0Tc]I00L0Tc]I00<000000>Nl?03W_3`00P3W_3`00`000000oooo0?ooo`3K0?ooo`00k03oool0
0`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00L0Tc]I00<000000>Nl?03W_3`00P3W_3`0
0`000000oooo0?ooo`3K0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I
00L0Tc]I00<000000>Nl?03W_3`00P3W_3`00`000000oooo0?ooo`3K0?ooo`00k03oool00`000000
/G>>0;5cSP2T0;5cSP/000000`3W_3`00`000000oooo0?ooo`3L0?ooo`00k03ooonX000000T0Q[Sf
00D000000>Nl?03W_3`0ik`l0000003N0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000
0026^?H0Q[Sf00L0Q[Sf00D000000>Nl?03W_3`0ik`l0000003N0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`0300000026^?H0Q[Sf00L0Q[Sf00D000000>Nl?03W_3`0ik`l0000003N0?ooo`00
k03oool00`000000/;3G0;2`e`2T0;2`e`0300000026^?H0Q[Sf00P0Q[Sf00@000000>Nl?03W_3`0
0000gP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000Q[Sf08JhmP0808JhmP030000
003W_3`000000=l0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<0000008JhmP26^?H02026
^?H00`000000ik`l0000003O0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`0300000026^?H0
Q[Sf00P0Q[Sf00<000000>Nl?0000000g`3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`00
0000Q[Sf08JhmP0808JhmP030000003W_3`000000=l0oooo003/0?ooo`030000002`/=L0/;3G0:@0
/;3G00<0000008JhmP26^?H02026^?H00`000000ik`l0000003O0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`0300000026^?H0Q[Sf00T0Q[Sf0P00003O0?ooo`00k03oool00`000000/;3G0;2`
e`2T0;2`e`0300000026^?H0Q[Sf00T0Q[Sf00<000000?ooo`3oool0gP3oool00>`0oooo00<00000
0;2`e`2`/=L0Y02`/=L6000000H0Q[Sf00<000000?ooo`3oool0gP3oool00>`0oooo00<000000;2`
e`2`/=L0Y02`/=L00`000000oooo0?ooo`030?ooo`L00000h03oool00>`0oooo00<000000;2`e`2`
/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000
003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3o
ool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`00
0000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0
/;3G00<000000?ooo`3oool0jP3oool00>`0ooooZ000003/0?ooo`00k03oool00`000000E/Se05K8
m@2T05K8m@030000003oool0oooo0>X0oooo003/0?ooo`030000001Fb?D0E/Se0:@0E/Se00<00000
0?ooo`3oool0jP3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?oo
o`00k@3oool00`000000E/Se05K8m@2R05K8m@030000003oool0oooo0>/0oooo003]0?ooojH00000
k@3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo0000
\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.58974 .24896 m .58987 .2453 L p .60116 .26076 L .42 .343 .664 r
F P
0 g
s
.58987 .2453 m .59019 .23617 L p .59397 .24462 L .42 .343 .664 r
F P
0 g
s
.60116 .26076 m .58987 .2453 L .59397 .24462 L .42 .343 .664 r
F
.59019 .23617 m .58974 .24896 L .57748 .24561 L p .97 .809 .626 r
F P
0 g
s
.59019 .23617 m .59276 .22341 L p .5995 .24371 L .42 .343 .664 r
F P
0 g
s
.59712 .2441 m .59019 .23617 L .5995 .24371 L .42 .343 .664 r
F
.60116 .26076 m .59019 .23617 L .60116 .24873 L F
.59276 .22341 m .59019 .23617 L .57793 .23275 L p .95 .869 .722 r
F P
0 g
s
.57748 .24561 m .57793 .23275 L .59019 .23617 L p .97 .809 .626 r
F P
0 g
s
.60116 .29094 m .60456 .28459 L .62507 .41352 L .865 .706 .683 r
F
.62507 .24629 m .62507 .29588 L p .60456 .28459 L F P
0 g
s
.62507 .29588 m .62507 .41352 L p .60456 .28459 L .865 .706 .683 r
F P
0 g
s
.60077 .28229 m .60116 .28272 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.59276 .22341 m .59732 .21122 L p .60116 .22791 L .42 .343 .664 r
F P
0 g
s
.60116 .24344 m .62507 .24629 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.60116 .24344 m .62507 .24629 L p .60976 .24202 L .289 .763 .934 r
F P
0 g
s
.61675 .29571 m .60116 .24873 L .60116 .22791 L .42 .343 .664 r
F
.60116 .24873 m .59276 .22341 L .60116 .22791 L F
.60116 .24873 m .59712 .2441 L .5995 .24371 L F
.60116 .26873 m .58974 .24896 L .60116 .26076 L F
.5914 .26125 m .58974 .24896 L p .61675 .29571 L F P
0 g
s
.59513 .27252 m .5914 .26125 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.60077 .28229 m .59513 .27252 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.59513 .27252 m .60077 .28229 L .60005 .2821 L p .88 .45 .163 r
F P
0 g
s
.59937 .28173 m .60116 .28298 L .60116 .29094 L .865 .706 .683 r
F
.59933 .28154 m .60005 .2821 L .59937 .28173 L F
.60005 .2821 m .60116 .28298 L .59937 .28173 L F
.59193 .27571 m .59513 .27252 L .60005 .2821 L .88 .45 .163 r
F
.59168 .41055 m .59168 .27895 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.5914 .26125 m .59441 .27034 L p .5842 .26964 L .947 .612 .356 r
F P
0 g
s
.59441 .27034 m .59513 .27252 L .59383 .27218 L p .947 .612 .356 r
F P
0 g
s
.59383 .27218 m .5842 .26964 L p .59441 .27034 L .947 .612 .356 r
F P
0 g
s
.58347 .26873 m .5914 .26125 L .5842 .26964 L .947 .612 .356 r
F
.59168 .27552 m .59168 .27895 L p .59112 .27639 L .959 .783 .339 r
F P
0 g
s
.59168 .27895 m .59168 .41055 L p .58893 .36112 L .959 .783 .339 r
F P
0 g
s
.58545 .29858 m .58893 .28761 L .58893 .36112 L .959 .783 .339 r
F
.58893 .28761 m .59168 .27895 L .58893 .36112 L F
.59168 .27895 m .59168 .27552 L p .60112 .2907 L .865 .706 .683 r
F P
0 g
s
.5842 .26964 m .59383 .27218 L p .59142 .27532 L .88 .45 .163 r
F P
0 g
s
.59933 .28154 m .60112 .2907 L .59168 .27552 L .865 .706 .683 r
F
.59383 .27218 m .59513 .27252 L p .59088 .27676 L .88 .45 .163 r
F P
0 g
s
.58853 .2791 m .59383 .27218 L .59088 .27676 L .88 .45 .163 r
F
.59168 .27552 m .59168 .24231 L p .59933 .28154 L .865 .706 .683 r
F P
0 g
s
.58853 .2791 m .58288 .26929 L .5842 .26964 L p .88 .45 .163 r
F P
0 g
s
.58853 .2791 m .5842 .26964 L .59142 .27532 L .88 .45 .163 r
F
.58893 .28186 m .59168 .27895 L .58893 .28761 L .959 .783 .339 r
F
.58853 .2791 m .58288 .26929 L p .58893 .27579 L .417 .341 .663 r
F P
0 g
s
.58893 .27953 m .58853 .2791 L .58925 .27929 L p .748 .228 0 r
F P
0 g
s
.58893 .27944 m .58853 .2791 L .58893 .27579 L .417 .341 .663 r
F
.58925 .27929 m .58853 .2791 L p .59088 .27676 L .88 .45 .163 r
F P
0 g
s
.58974 .24896 m .5914 .26125 L .57915 .25796 L p .972 .727 .507 r
F P
0 g
s
.57915 .25796 m .57748 .24561 L .58974 .24896 L p .972 .727 .507 r
F P
0 g
s
.58288 .26929 m .57915 .25796 L .5914 .26125 L p .947 .612 .356 r
F P
0 g
s
.57748 .24561 m .57793 .23275 L p .58893 .25746 L .417 .341 .663 r
F P
0 g
s
.58457 .28276 m .58925 .27929 L .58476 .28627 L .959 .783 .339 r
F
.59112 .27639 m .59168 .27895 L .58893 .28186 L F
.58893 .2798 m .58893 .28186 L .58476 .28627 L F
.59112 .27639 m .58893 .28186 L .58893 .2798 L F
.5842 .26964 m .58288 .26929 L p .58347 .26873 L .947 .612 .356 r
F P
0 g
s
.58288 .26929 m .57915 .25796 L p .58893 .27129 L .417 .341 .663 r
F P
0 g
s
.59833 .2841 m .59621 .28122 L .60005 .2821 L .748 .228 0 r
F
.60112 .2907 m .60116 .29094 L .59168 .27895 L .865 .706 .683 r
F
.59585 .28698 m .59621 .28122 L .59833 .2841 L .748 .228 0 r
F
.59585 .28698 m .58893 .27953 L p .59621 .28122 L F P
0 g
s
.58893 .27731 m .59112 .27639 L .58925 .27929 L .959 .783 .339 r
F
.58893 .26642 m .59112 .27639 L .58893 .27731 L F
.58925 .27929 m .60005 .2821 L p .58893 .27953 L .748 .228 0 r
F P
0 g
s
.60005 .2821 m .58925 .27929 L p .59193 .27571 L .88 .45 .163 r
F P
0 g
s
.59088 .27676 m .59193 .27571 L .58925 .27929 L .88 .45 .163 r
F
.58893 .26548 m .57748 .24561 L .58893 .25746 L .417 .341 .663 r
F
.59168 .24231 m .59168 .27552 L p .58893 .26395 L .959 .783 .339 r
F P
0 g
s
.58893 .24005 m .59168 .24231 L p .58893 .26395 L .959 .783 .339 r
F P
0 g
s
.57793 .23275 m .5805 .21992 L .59276 .22341 L p .95 .869 .722 r
F P
0 g
s
.57793 .23275 m .5805 .21992 L p .58726 .24033 L .417 .341 .663 r
F P
0 g
s
.59732 .21122 m .60371 .20013 L p .60943 .24208 L .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .6046 .24287 L .60943 .24208 L .42 .343 .664 r
F
.6046 .24287 m .59732 .21122 L .60943 .24208 L F
.62507 .24629 m .61839 .2406 L .60976 .24202 L .289 .763 .934 r
F
.60371 .20013 m .61165 .19061 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.62507 .24629 m .63066 .23858 L .61839 .2406 L .289 .763 .934 r
F
.61165 .19061 m .62081 .18307 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6629 .41183 m .62507 .41352 L .62507 .24629 L p .607 .496 .701 r
F P
0 g
s
.62507 .24629 m .6629 .24402 L .6629 .41183 L p .607 .496 .701 r
F P
0 g
s
.65156 .17528 m .66142 .17807 L p .63896 .23722 L .42 .343 .664 r
F P
0 g
s
.62507 .24629 m .6606 .23365 L .63066 .23858 L .289 .763 .934 r
F
.68375 .23673 m .67749 .23087 L p .62507 .24629 L F P
0 g
s
.62507 .24629 m .67749 .23087 L .6606 .23365 L .289 .763 .934 r
F
.62507 .24629 m .6629 .24402 L .68375 .23673 L p F P
0 g
s
.68375 .4064 m .6629 .41183 L .6629 .24402 L p .122 .1 .557 r
F P
0 g
s
.6629 .24402 m .68375 .23673 L .68375 .4064 L p .122 .1 .557 r
F P
0 g
s
.68375 .23673 m .67749 .23087 L p .67749 .2705 L .943 .77 .305 r
F P
0 g
s
.68132 .28215 m .67749 .2705 L .67749 .35363 L .943 .77 .305 r
F
.68375 .23673 m .67749 .2705 L .68132 .28215 L F
.68148 .26376 m .67485 .27496 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.68375 .4064 m .68375 .23673 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.68626 .25135 m .68148 .26376 L p .67749 .26573 L .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .67749 .25695 L .67749 .26573 L .42 .343 .664 r
F
.67749 .25695 m .68626 .25135 L .67749 .26573 L F
.67499 .40031 m .67749 .40205 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.67749 .40205 m .68375 .4064 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.68895 .23829 m .68626 .25135 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.67485 .27496 m .67749 .2705 L p .67235 .26408 L .863 .947 .869 r
F P
0 g
s
.67101 .26468 m .67485 .27496 L .67235 .26408 L .863 .947 .869 r
F
.61675 .29571 m .67749 .22453 L .67749 .23676 L .42 .343 .664 r
F
.68377 .20112 m .68767 .2126 L p .61675 .29571 L F P
0 g
s
.6779 .19127 m .68377 .20112 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.67749 .23087 m .67499 .22854 L p .6606 .23365 L .289 .763 .934 r
F P
0 g
s
.61675 .29571 m .68479 .22967 L .68895 .23829 L .42 .343 .664 r
F
.67499 .2629 m .67499 .22854 L p .66737 .26631 L .87 .71 .682 r
F P
0 g
s
.67465 .26186 m .66942 .26041 L p .67749 .2705 L .863 .947 .869 r
F P
0 g
s
.67485 .27496 m .66666 .28447 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66666 .28447 m .67485 .27496 L .66277 .27168 L p .787 .956 .924 r
F P
0 g
s
.66277 .27168 m .67485 .27496 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.67499 .22854 m .66542 .24251 L .66737 .26631 L .87 .71 .682 r
F
.61675 .29571 m .6334 .23813 L .63896 .23722 L .42 .343 .664 r
F
.61675 .29571 m .60116 .26076 L .60116 .24873 L F
.61675 .29571 m .60116 .26873 L .60116 .26076 L F
.61675 .29571 m .60807 .29013 L .60077 .28229 L p F P
0 g
s
.60807 .29013 m .61675 .29571 L .60455 .29258 L p .531 0 0 r
F P
0 g
s
.67033 .18347 m .6779 .19127 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66142 .17807 m .67033 .18347 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6412 .17522 m .65156 .17528 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6308 .17786 m .6412 .17522 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.62081 .18307 m .6308 .17786 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.60455 .29258 m .66542 .26239 L .66277 .27168 L .417 .341 .663 r
F
.66542 .26719 m .66277 .27168 L p .66542 .26239 L F P
0 g
s
.66542 .24251 m .66542 .26719 L .66737 .26631 L .87 .71 .682 r
F
.67421 .24793 m .66942 .26041 L p .66542 .26239 L .417 .341 .663 r
F P
0 g
s
.60455 .29258 m .66542 .25356 L .66542 .26239 L .417 .341 .663 r
F
.66542 .25356 m .67421 .24793 L .66542 .26239 L F
.6334 .23813 m .65156 .17528 L .63896 .23722 L .42 .343 .664 r
F
.67499 .22854 m .66542 .22735 L p .63066 .23858 L .289 .763 .934 r
F P
0 g
s
.63066 .23858 m .66542 .22735 L .63516 .23238 L .289 .763 .934 r
F
.6606 .23365 m .67499 .22854 L .63066 .23858 L F
.67499 .22854 m .66542 .22735 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.60807 .29013 m .59585 .28698 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.60116 .28272 m .60807 .29013 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.60455 .29258 m .59585 .28698 L .60807 .29013 L p .531 0 0 r
F P
0 g
s
.67563 .20897 m .67738 .22162 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.67171 .19744 m .67563 .20897 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.66583 .18754 m .67171 .19744 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.65825 .17971 m .66583 .18754 L p .64016 .23155 L .417 .341 .663 r
F P
0 g
s
.63302 .23273 m .65825 .17971 L .64016 .23155 L .417 .341 .663 r
F
.63066 .23858 m .63516 .23238 L .61839 .2406 L .289 .763 .934 r
F
.65156 .17528 m .6412 .17522 L .62905 .17144 L p .125 .651 .877 r
F P
0 g
s
.66142 .17807 m .65156 .17528 L .63944 .1715 L p 0 .408 .698 r
F P
0 g
s
.62905 .17144 m .63944 .1715 L .65156 .17528 L p .125 .651 .877 r
F P
0 g
s
.63944 .1715 m .64931 .17429 L .66142 .17807 L p 0 .408 .698 r
F P
0 g
s
.64931 .17429 m .65825 .17971 L p .63302 .23273 L .417 .341 .663 r
F P
0 g
s
.62681 .23376 m .64931 .17429 L .63302 .23273 L .417 .341 .663 r
F
.63516 .23238 m .641 .22434 L .62822 .23353 L .289 .763 .934 r
F
.63516 .23238 m .62822 .23353 L .61839 .2406 L F
.61839 .2406 m .62822 .23353 L .61304 .23605 L F
.60455 .29258 m .62681 .23376 L .63302 .23273 L .417 .341 .663 r
F
.60455 .29258 m .63302 .23273 L .64016 .23155 L F
.60976 .24202 m .60725 .23701 L .59754 .23862 L .289 .763 .934 r
F
.60371 .20013 m .59732 .21122 L .58508 .20767 L p .863 .936 .869 r
F P
0 g
s
.61165 .19061 m .60371 .20013 L .59148 .19651 L p .792 .947 .923 r
F P
0 g
s
.58508 .20767 m .59148 .19651 L .60371 .20013 L p .863 .936 .869 r
F P
0 g
s
.62081 .18307 m .61165 .19061 L .59943 .18694 L p .696 .937 .964 r
F P
0 g
s
.59148 .19651 m .59943 .18694 L .61165 .19061 L p .792 .947 .923 r
F P
0 g
s
.59943 .18694 m .60861 .17935 L .62081 .18307 L p .696 .937 .964 r
F P
0 g
s
.59943 .18694 m .60861 .17935 L p .60654 .23713 L .417 .341 .663 r
F P
0 g
s
.60976 .24202 m .59754 .23862 L .60116 .24344 L .289 .763 .934 r
F
.59732 .21122 m .59276 .22341 L .5805 .21992 L p .915 .91 .802 r
F P
0 g
s
.5805 .21992 m .58508 .20767 L .59732 .21122 L p .915 .91 .802 r
F P
0 g
s
.5805 .21992 m .58508 .20767 L p .59237 .23948 L .417 .341 .663 r
F P
0 g
s
.58726 .24033 m .5805 .21992 L .59237 .23948 L .417 .341 .663 r
F
.59754 .23862 m .59272 .23942 L .60116 .24344 L .289 .763 .934 r
F
.59168 .24231 m .60116 .24344 L p .60116 .28298 L .865 .706 .683 r
F P
0 g
s
.58508 .20767 m .59148 .19651 L p .59721 .23867 L .417 .341 .663 r
F P
0 g
s
.59168 .24231 m .60116 .24344 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.58893 .24005 m .59168 .24231 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.60455 .29258 m .59237 .23948 L .59721 .23867 L .417 .341 .663 r
F
.59237 .23948 m .58508 .20767 L .59721 .23867 L F
.58187 .23425 m .58893 .24005 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.59148 .19651 m .59943 .18694 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.59754 .23862 m .58187 .23425 L .59272 .23942 L .289 .763 .934 r
F
.60005 .2821 m .60077 .28229 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.59168 .24231 m .60116 .28298 L .59933 .28154 L .865 .706 .683 r
F
.60455 .29258 m .58726 .24033 L .59237 .23948 L .417 .341 .663 r
F
.60455 .29258 m .6019 .2379 L .60654 .23713 L F
.6019 .2379 m .59943 .18694 L .60654 .23713 L F
.61839 .2406 m .61304 .23605 L .60976 .24202 L .289 .763 .934 r
F
.61304 .23605 m .60725 .23701 L .60976 .24202 L F
.6308 .17786 m .62081 .18307 L .60861 .17935 L p .562 .897 .982 r
F P
0 g
s
.6412 .17522 m .6308 .17786 L .61863 .17411 L p .376 .809 .962 r
F P
0 g
s
.60861 .17935 m .61863 .17411 L .6308 .17786 L p .562 .897 .982 r
F P
0 g
s
.61863 .17411 m .62905 .17144 L .6412 .17522 L p .376 .809 .962 r
F P
0 g
s
.61863 .17411 m .62905 .17144 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.60861 .17935 m .61863 .17411 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.61304 .23605 m .60211 .22675 L .60725 .23701 L .289 .763 .934 r
F
.63944 .1715 m .64931 .17429 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.62905 .17144 m .63944 .1715 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.641 .22434 m .60211 .22675 L p .61304 .23605 L .289 .763 .934 r
F P
0 g
s
.62822 .23353 m .641 .22434 L .61304 .23605 L .289 .763 .934 r
F
.66542 .22735 m .641 .22434 L p .63516 .23238 L F P
0 g
s
.67749 .35363 m .67575 .26663 L .67499 .40031 L .943 .77 .305 r
F
.67499 .22854 m .67499 .26334 L p .67575 .26663 L F P
0 g
s
.67499 .26334 m .67499 .40031 L p .67575 .26663 L .943 .77 .305 r
F P
0 g
s
.67749 .23087 m .67499 .22854 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.67421 .24793 m .67247 .25245 L p .68148 .26376 L .918 .921 .8 r
F P
0 g
s
.67247 .25245 m .66942 .26041 L .67465 .26186 L p .918 .921 .8 r
F P
0 g
s
.67465 .26186 m .68148 .26376 L p .67247 .25245 L .918 .921 .8 r
F P
0 g
s
.60455 .29258 m .67274 .22614 L .6769 .2348 L .417 .341 .663 r
F
.67738 .22162 m .67724 .22539 L p .67274 .22614 L F P
0 g
s
.67724 .22539 m .6769 .2348 L p .67274 .22614 L .417 .341 .663 r
F P
0 g
s
.6769 .2348 m .67421 .24793 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.641 .22434 m .641 .27815 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.66542 .22735 m .641 .22434 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.66542 .24251 m .641 .27815 L .66542 .26719 L .87 .71 .682 r
F
.66942 .26041 m .66542 .26719 L p .66542 .26239 L .417 .341 .663 r
F P
0 g
s
.66942 .26041 m .66542 .26719 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.66542 .26719 m .66277 .27168 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.64716 .29681 m .63672 .29914 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.65729 .29185 m .64716 .29681 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66666 .28447 m .65729 .29185 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.63672 .29914 m .64716 .29681 L .63502 .29366 L p .336 .794 .943 r
F P
0 g
s
.64517 .28867 m .63502 .29366 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.65456 .28124 m .64517 .28867 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.66277 .27168 m .65456 .28124 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.64716 .29681 m .65729 .29185 L .64517 .28867 L p .537 .895 .975 r
F P
0 g
s
.64517 .28867 m .63502 .29366 L .64716 .29681 L p .537 .895 .975 r
F P
0 g
s
.65729 .29185 m .66666 .28447 L .65456 .28124 L p .682 .942 .962 r
F P
0 g
s
.65456 .28124 m .64517 .28867 L .65729 .29185 L p .682 .942 .962 r
F P
0 g
s
.66277 .27168 m .65456 .28124 L .66666 .28447 L p .787 .956 .924 r
F P
0 g
s
.641 .27815 m .641 .39718 L p .66737 .26631 L .87 .71 .682 r
F P
0 g
s
.641 .39718 m .67499 .40031 L .67499 .2629 L p .87 .71 .682 r
F P
0 g
s
.66737 .26631 m .641 .39718 L .67499 .2629 L .87 .71 .682 r
F
.66942 .26041 m .67101 .26468 L .67235 .26408 L .863 .947 .869 r
F
.67749 .2705 m .68148 .26376 L .67465 .26186 L p F P
0 g
s
.68767 .2126 m .68943 .22518 L p .67749 .23676 L .42 .343 .664 r
F P
0 g
s
.67749 .22453 m .68767 .2126 L .67749 .23676 L .42 .343 .664 r
F
.68943 .22518 m .68929 .22893 L p .68479 .22967 L F P
0 g
s
.68929 .22893 m .68895 .23829 L p .68479 .22967 L .42 .343 .664 r
F P
0 g
s
.60211 .22675 m .58187 .23425 L p .59754 .23862 L .289 .763 .934 r
F P
0 g
s
.60725 .23701 m .60211 .22675 L .59754 .23862 L .289 .763 .934 r
F
.58893 .24537 m .58488 .24072 L .58726 .24033 L .417 .341 .663 r
F
.58488 .24072 m .57793 .23275 L .58726 .24033 L F
.59585 .28698 m .60005 .2821 L .60063 .28242 L .748 .228 0 r
F
.60455 .29258 m .58893 .25746 L .58893 .24537 L .417 .341 .663 r
F
.58893 .25746 m .57793 .23275 L .58893 .24537 L F
.57915 .25796 m .57748 .24561 L p .58893 .26548 L F P
0 g
s
.58893 .27129 m .57915 .25796 L .58893 .26548 L .417 .341 .663 r
F
.58893 .27579 m .58288 .26929 L .58893 .27129 L F
.58187 .23425 m .58893 .27731 L .58457 .28276 L .959 .783 .339 r
F
.58893 .27731 m .58925 .27929 L .58893 .27953 L F
.58893 .27953 m .58853 .2791 L p .58893 .27944 L .417 .341 .663 r
F P
0 g
s
.58893 .27731 m .58893 .27953 L .58457 .28276 L .959 .783 .339 r
F
.58187 .23425 m .58893 .24005 L p .58893 .26395 L F P
0 g
s
.58187 .23425 m .59168 .27552 L .59112 .27639 L .959 .783 .339 r
F
.60455 .29258 m .58893 .27129 L .58893 .26548 L .417 .341 .663 r
F
.60455 .29258 m .58893 .27579 L .58893 .27129 L F
.60455 .29258 m .58893 .26548 L .58893 .25746 L F
.58187 .23425 m .58893 .26642 L .58893 .27731 L .959 .783 .339 r
F
.60455 .29258 m .59585 .28698 L .58893 .27953 L p .417 .341 .663 r
F P
0 g
s
.60455 .29258 m .58893 .27953 L .58893 .27944 L .417 .341 .663 r
F
.58476 .28627 m .58893 .28186 L .58545 .29858 L .959 .783 .339 r
F
.58893 .28186 m .58893 .28761 L .58545 .29858 L F
.60455 .29258 m .58893 .27944 L .58893 .27579 L .417 .341 .663 r
F
.62507 .41352 m .60116 .4114 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.60116 .4114 m .59168 .41055 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62507 .41352 m .6629 .41183 L .68375 .4064 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.59168 .41055 m .58187 .40456 L .58187 .23425 L p .959 .783 .339 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58187 .40456 m .59168 .41055 L .62507 .41352 L p .224 .73 .894 r
F P
0 g
s
.60211 .39897 m .58187 .40456 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.641 .39718 m .60211 .39897 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.67499 .40031 m .641 .39718 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.68375 .4064 m .67499 .40031 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.58187 .40456 m .60211 .39897 L .60211 .22675 L p .094 .077 .545 r
F P
0 g
s
.60211 .22675 m .58187 .23425 L .58187 .40456 L p .094 .077 .545 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.32786 .24896 m .32799 .2453 L p .33854 .26076 L .399 .326 .658 r
F P
0 g
s
.32799 .2453 m .32829 .23617 L p .33181 .24462 L .399 .326 .658 r
F P
0 g
s
.33854 .26076 m .32799 .2453 L .33181 .24462 L .399 .326 .658 r
F
.32829 .23617 m .32786 .24896 L .31426 .24561 L p .959 .799 .64 r
F P
0 g
s
.32829 .23617 m .33069 .22341 L p .33698 .24371 L .399 .326 .658 r
F P
0 g
s
.33476 .2441 m .32829 .23617 L .33698 .24371 L .399 .326 .658 r
F
.33854 .26076 m .32829 .23617 L .33854 .24873 L F
.33069 .22341 m .32829 .23617 L .31468 .23275 L p .941 .854 .728 r
F P
0 g
s
.31426 .24561 m .31468 .23275 L .32829 .23617 L p .959 .799 .64 r
F P
0 g
s
.33854 .29094 m .3421 .28459 L .36358 .41352 L .859 .702 .685 r
F
.36358 .24629 m .36358 .29588 L p .3421 .28459 L F P
0 g
s
.36358 .29588 m .36358 .41352 L p .3421 .28459 L .859 .702 .685 r
F P
0 g
s
.33817 .28229 m .33854 .28272 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.33069 .22341 m .33495 .21122 L p .33854 .22791 L .399 .326 .658 r
F P
0 g
s
.33854 .24344 m .36358 .24629 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33854 .24344 m .36358 .24629 L p .34657 .24202 L .289 .763 .934 r
F P
0 g
s
.34175 .24287 m .33854 .24344 L .33854 .22791 L .399 .326 .658 r
F
.33854 .24873 m .33069 .22341 L .33854 .22791 L F
.33495 .21122 m .34092 .20013 L p .3531 .29571 L F P
0 g
s
.36358 .24629 m .35463 .2406 L .34657 .24202 L .289 .763 .934 r
F
.34092 .20013 m .34833 .19061 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.36358 .24629 m .36609 .23858 L .35463 .2406 L .289 .763 .934 r
F
.34833 .19061 m .35689 .18307 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40051 .41183 m .36358 .41352 L .36358 .24629 L p .604 .493 .701 r
F P
0 g
s
.36358 .24629 m .40051 .24402 L .40051 .41183 L p .604 .493 .701 r
F P
0 g
s
.37594 .17522 m .38562 .17528 L p .36865 .23813 L .399 .326 .658 r
F P
0 g
s
.36358 .24629 m .39406 .23365 L .36609 .23858 L .289 .763 .934 r
F
.41844 .23673 m .40984 .23087 L p .36358 .24629 L F P
0 g
s
.36358 .24629 m .40984 .23087 L .39406 .23365 L .289 .763 .934 r
F
.36358 .24629 m .40051 .24402 L .41844 .23673 L p F P
0 g
s
.41844 .4064 m .40051 .41183 L .40051 .24402 L p .048 .04 .524 r
F P
0 g
s
.40051 .24402 m .41844 .23673 L .41844 .4064 L p .048 .04 .524 r
F P
0 g
s
.41844 .23673 m .40984 .23087 L p .40984 .2705 L .979 .8 .389 r
F P
0 g
s
.4151 .28215 m .40984 .2705 L .40984 .35363 L .979 .8 .389 r
F
.41844 .23673 m .40984 .2705 L .4151 .28215 L F
.41357 .26376 m .40737 .27496 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.41844 .4064 m .41844 .23673 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.41803 .25135 m .41357 .26376 L p .40984 .26573 L .399 .326 .658 r
F P
0 g
s
.3531 .29571 m .40984 .25695 L .40984 .26573 L .399 .326 .658 r
F
.40984 .25695 m .41803 .25135 L .40984 .26573 L F
.4064 .40031 m .40984 .40205 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.40984 .40205 m .41844 .4064 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.42054 .23829 m .41803 .25135 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40737 .27496 m .40984 .2705 L p .40364 .26408 L .863 .933 .868 r
F P
0 g
s
.40223 .26468 m .40737 .27496 L .40364 .26408 L .863 .933 .868 r
F
.3531 .29571 m .40984 .22453 L .40984 .23676 L .399 .326 .658 r
F
.41571 .20112 m .41935 .2126 L p .3531 .29571 L F P
0 g
s
.41022 .19127 m .41571 .20112 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40984 .23087 m .4064 .22854 L p .39406 .23365 L .289 .763 .934 r
F P
0 g
s
.3531 .29571 m .41666 .22967 L .42054 .23829 L .399 .326 .658 r
F
.4064 .2629 m .4064 .22854 L p .39841 .26631 L .864 .705 .684 r
F P
0 g
s
.40593 .26186 m .4001 .26041 L p .40984 .2705 L .863 .933 .868 r
F P
0 g
s
.40737 .27496 m .39972 .28447 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39972 .28447 m .40737 .27496 L .39389 .27168 L p .793 .946 .923 r
F P
0 g
s
.39389 .27168 m .40737 .27496 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.4064 .22854 m .39636 .24251 L .39841 .26631 L .864 .705 .684 r
F
.3531 .29571 m .36386 .23898 L .36865 .23813 L .399 .326 .658 r
F
.3531 .29571 m .33854 .24873 L .33854 .24344 L F
.3531 .29571 m .33854 .24344 L .34175 .24287 L F
.33854 .24873 m .33476 .2441 L .33698 .24371 L F
.33854 .26873 m .32786 .24896 L .33854 .26076 L F
.32942 .26125 m .32786 .24896 L p .3531 .29571 L F P
0 g
s
.3329 .27252 m .32942 .26125 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.33817 .28229 m .3329 .27252 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.3531 .29571 m .34499 .29013 L .33817 .28229 L p .399 .326 .658 r
F P
0 g
s
.3286 .24231 m .33854 .24344 L p .33854 .28298 L .859 .702 .685 r
F P
0 g
s
.33666 .28173 m .33854 .28298 L .33854 .29094 L .859 .702 .685 r
F
.3329 .27252 m .33817 .28229 L .33737 .2821 L p .887 .474 .217 r
F P
0 g
s
.32886 .27571 m .3329 .27252 L .33737 .2821 L .887 .474 .217 r
F
.32786 .24896 m .32942 .26125 L .31582 .25796 L p .962 .724 .532 r
F P
0 g
s
.3286 .41055 m .3286 .27895 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.32942 .26125 m .33223 .27034 L p .32077 .26964 L .942 .62 .395 r
F P
0 g
s
.33223 .27034 m .3329 .27252 L .33145 .27218 L p .942 .62 .395 r
F P
0 g
s
.33145 .27218 m .32077 .26964 L p .33223 .27034 L .942 .62 .395 r
F P
0 g
s
.32001 .26873 m .32942 .26125 L .32077 .26964 L .942 .62 .395 r
F
.3286 .27552 m .3286 .27895 L p .32786 .27639 L .988 .806 .415 r
F P
0 g
s
.3286 .27895 m .3286 .41055 L p .32495 .36112 L .988 .806 .415 r
F P
0 g
s
.32032 .29858 m .32495 .28761 L .32495 .36112 L .988 .806 .415 r
F
.32495 .28761 m .3286 .27895 L .32495 .36112 L F
.32077 .26964 m .3193 .26929 L p .32001 .26873 L .942 .62 .395 r
F P
0 g
s
.3193 .26929 m .31582 .25796 L .32942 .26125 L p .942 .62 .395 r
F P
0 g
s
.3286 .27895 m .3286 .27552 L p .33849 .2907 L .859 .702 .685 r
F P
0 g
s
.32077 .26964 m .33145 .27218 L p .32833 .27532 L .887 .474 .217 r
F P
0 g
s
.33662 .28154 m .33849 .2907 L .3286 .27552 L .859 .702 .685 r
F
.33145 .27218 m .3329 .27252 L p .32754 .27676 L .887 .474 .217 r
F P
0 g
s
.32457 .2791 m .33145 .27218 L .32754 .27676 L .887 .474 .217 r
F
.3286 .27552 m .3286 .24231 L p .33662 .28154 L .859 .702 .685 r
F P
0 g
s
.32457 .2791 m .3193 .26929 L .32077 .26964 L p .887 .474 .217 r
F P
0 g
s
.32457 .2791 m .32077 .26964 L .32833 .27532 L .887 .474 .217 r
F
.32457 .2791 m .3193 .26929 L p .32495 .27579 L .396 .324 .657 r
F P
0 g
s
.32495 .28186 m .3286 .27895 L .32495 .28761 L .988 .806 .415 r
F
.32538 .27929 m .32457 .2791 L p .32754 .27676 L .887 .474 .217 r
F P
0 g
s
.32495 .27944 m .32457 .2791 L .32495 .27579 L .396 .324 .657 r
F
.32495 .27731 m .32786 .27639 L .32538 .27929 L .988 .806 .415 r
F
.3193 .26929 m .31582 .25796 L p .32495 .27129 L .396 .324 .657 r
F P
0 g
s
.32495 .27579 m .3193 .26929 L .32495 .27129 L .396 .324 .657 r
F
.31582 .25796 m .31426 .24561 L .32786 .24896 L p .962 .724 .532 r
F P
0 g
s
.31426 .24561 m .31468 .23275 L p .32495 .25746 L .396 .324 .657 r
F P
0 g
s
.31915 .28276 m .32495 .27953 L .31941 .28627 L .988 .806 .415 r
F
.32495 .27953 m .32538 .27929 L .32495 .2798 L F
.32495 .27953 m .32495 .2798 L .31941 .28627 L F
.32786 .27639 m .3286 .27895 L .31941 .28627 L F
.33849 .2907 m .33854 .29094 L .3286 .27895 L .859 .702 .685 r
F
.33238 .28618 m .32495 .27953 L p .33737 .2821 L .772 .267 0 r
F P
0 g
s
.33737 .2821 m .33854 .28298 L .33666 .28173 L .859 .702 .685 r
F
.33141 .28698 m .33737 .2821 L .33798 .28242 L .772 .267 0 r
F
.34499 .29013 m .33141 .28698 L p .33798 .28242 L F P
0 g
s
.36358 .41352 m .33854 .4114 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33854 .4114 m .3286 .41055 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33953 .29258 m .33141 .28698 L .34499 .29013 L p .569 0 0 r
F P
0 g
s
.33953 .29258 m .33141 .28698 L .32495 .27953 L p .396 .324 .657 r
F P
0 g
s
.32495 .27953 m .32457 .2791 L .32538 .27929 L p .772 .267 0 r
F P
0 g
s
.32495 .27953 m .32457 .2791 L p .32495 .27944 L .396 .324 .657 r
F P
0 g
s
.32538 .27929 m .33737 .2821 L p .32495 .27953 L .772 .267 0 r
F P
0 g
s
.33953 .29258 m .32495 .27953 L .32495 .27944 L .396 .324 .657 r
F
.33662 .28154 m .33737 .2821 L .33666 .28173 L .859 .702 .685 r
F
.33737 .2821 m .32538 .27929 L p .32886 .27571 L .887 .474 .217 r
F P
0 g
s
.32495 .26548 m .31426 .24561 L .32495 .25746 L .396 .324 .657 r
F
.3286 .24231 m .3286 .27552 L p .32495 .26395 L .988 .806 .415 r
F P
0 g
s
.32495 .24005 m .3286 .24231 L p .32495 .26395 L .988 .806 .415 r
F P
0 g
s
.31468 .23275 m .31708 .21992 L .33069 .22341 L p .941 .854 .728 r
F P
0 g
s
.31468 .23275 m .31708 .21992 L p .32339 .24033 L .396 .324 .657 r
F P
0 g
s
.32116 .24072 m .31468 .23275 L .32339 .24033 L .396 .324 .657 r
F
.32495 .25746 m .31821 .24125 L .32495 .24537 L F
.31821 .24125 m .31468 .23275 L .32116 .24072 L F
.31821 .24125 m .32116 .24072 L .32495 .24537 L F
.3286 .24231 m .33854 .24344 L p .32849 .23942 L .289 .763 .934 r
F P
0 g
s
.32495 .24005 m .3286 .24231 L p .32849 .23942 L .289 .763 .934 r
F P
0 g
s
.33737 .2821 m .33817 .28229 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.3286 .24231 m .33854 .28298 L .33662 .28154 L .859 .702 .685 r
F
.33495 .21122 m .33069 .22341 L .31708 .21992 L p .909 .895 .803 r
F P
0 g
s
.31708 .21992 m .32136 .20767 L .33495 .21122 L p .909 .895 .803 r
F P
0 g
s
.31708 .21992 m .32136 .20767 L p .32816 .23948 L .396 .324 .657 r
F P
0 g
s
.33953 .29258 m .32339 .24033 L .32816 .23948 L .396 .324 .657 r
F
.32339 .24033 m .31708 .21992 L .32816 .23948 L F
.34657 .24202 m .33299 .23862 L .33854 .24344 L .289 .763 .934 r
F
.33299 .23862 m .32849 .23942 L .33854 .24344 L F
.33854 .28272 m .34499 .29013 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.34092 .20013 m .33495 .21122 L .32136 .20767 L p .862 .923 .867 r
F P
0 g
s
.32136 .20767 m .32733 .19651 L .34092 .20013 L p .862 .923 .867 r
F P
0 g
s
.32136 .20767 m .32733 .19651 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34657 .24202 m .34205 .23701 L .33299 .23862 L .289 .763 .934 r
F
.34833 .19061 m .34092 .20013 L .32733 .19651 L p .797 .937 .922 r
F P
0 g
s
.32733 .19651 m .33475 .18694 L .34833 .19061 L p .797 .937 .922 r
F P
0 g
s
.32733 .19651 m .33475 .18694 L p .33706 .2379 L .396 .324 .657 r
F P
0 g
s
.33953 .29258 m .33268 .23867 L .33706 .2379 L .396 .324 .657 r
F
.33268 .23867 m .32733 .19651 L .33706 .2379 L F
.36386 .23898 m .37594 .17522 L .36865 .23813 L .399 .326 .658 r
F
.36623 .17786 m .37594 .17522 L p .3531 .29571 L F P
0 g
s
.35689 .18307 m .36623 .17786 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.35689 .18307 m .34833 .19061 L .33475 .18694 L p .704 .932 .964 r
F P
0 g
s
.33475 .18694 m .34332 .17935 L .35689 .18307 L p .704 .932 .964 r
F P
0 g
s
.33475 .18694 m .34332 .17935 L p .34139 .23713 L .396 .324 .657 r
F P
0 g
s
.3531 .29571 m .33854 .26076 L .33854 .24873 L .399 .326 .658 r
F
.3531 .29571 m .33854 .26873 L .33854 .26076 L F
.33953 .29258 m .33706 .2379 L .34139 .23713 L .396 .324 .657 r
F
.33706 .2379 m .33475 .18694 L .34139 .23713 L F
.35463 .2406 m .34746 .23605 L .34657 .24202 L .289 .763 .934 r
F
.34746 .23605 m .34205 .23701 L .34657 .24202 L F
.35463 .2406 m .36163 .23353 L .34746 .23605 L F
.36623 .17786 m .35689 .18307 L .34332 .17935 L p .572 .897 .985 r
F P
0 g
s
.37594 .17522 m .36623 .17786 L .35268 .17411 L p .379 .811 .964 r
F P
0 g
s
.34332 .17935 m .35268 .17411 L .36623 .17786 L p .572 .897 .985 r
F P
0 g
s
.35268 .17411 m .36241 .17144 L .37594 .17522 L p .379 .811 .964 r
F P
0 g
s
.35268 .17411 m .36241 .17144 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34332 .17935 m .35268 .17411 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34746 .23605 m .33281 .22675 L .34205 .23701 L .289 .763 .934 r
F
.40316 .18347 m .41022 .19127 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39483 .17807 m .40316 .18347 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.38562 .17528 m .39483 .17807 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.4064 .22854 m .39636 .22735 L p .36609 .23858 L .289 .763 .934 r
F P
0 g
s
.38967 .17971 m .39636 .18711 L p .37238 .23162 L .396 .324 .657 r
F P
0 g
s
.36612 .23273 m .38967 .17971 L .37238 .23162 L .396 .324 .657 r
F
.36609 .23858 m .39636 .22735 L .36811 .23238 L .289 .763 .934 r
F
.39406 .23365 m .4064 .22854 L .36609 .23858 L F
.33953 .29258 m .39636 .18711 L .39636 .18825 L .396 .324 .657 r
F
.4064 .22854 m .39636 .22735 L p .39636 .24251 L .864 .705 .684 r
F P
0 g
s
.40589 .20897 m .40753 .22162 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40224 .19744 m .40589 .20897 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39675 .18754 m .40224 .19744 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39636 .22735 m .37073 .22434 L p .36811 .23238 L .289 .763 .934 r
F P
0 g
s
.36609 .23858 m .36811 .23238 L .35463 .2406 L .289 .763 .934 r
F
.38562 .17528 m .37594 .17522 L .36241 .17144 L p .112 .643 .867 r
F P
0 g
s
.36241 .17144 m .3721 .1715 L .38562 .17528 L p .112 .643 .867 r
F P
0 g
s
.38132 .17429 m .38967 .17971 L p .36612 .23273 L .396 .324 .657 r
F P
0 g
s
.36031 .23376 m .38132 .17429 L .36612 .23273 L .396 .324 .657 r
F
.36811 .23238 m .37073 .22434 L .36163 .23353 L .289 .763 .934 r
F
.36811 .23238 m .36163 .23353 L .35463 .2406 L F
.33953 .29258 m .36031 .23376 L .36612 .23273 L .396 .324 .657 r
F
.33953 .29258 m .36612 .23273 L .37238 .23162 L F
.39636 .18711 m .39675 .18754 L p .39636 .18825 L F P
0 g
s
.34499 .29013 m .3531 .29571 L .33953 .29258 L p .569 0 0 r
F P
0 g
s
.33953 .29258 m .39636 .26239 L .39389 .27168 L .396 .324 .657 r
F
.37073 .27601 m .37073 .27815 L p .37323 .27468 L .864 .705 .684 r
F P
0 g
s
.39636 .24251 m .39636 .26719 L .39841 .26631 L .864 .705 .684 r
F
.40456 .24793 m .4001 .26041 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40984 .35363 m .40745 .26663 L .4064 .40031 L .979 .8 .389 r
F
.4064 .22854 m .4064 .26334 L p .40745 .26663 L F P
0 g
s
.4064 .26334 m .4064 .40031 L p .40745 .26663 L .979 .8 .389 r
F P
0 g
s
.40984 .23087 m .4064 .22854 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.40456 .24793 m .40294 .25245 L p .41357 .26376 L .913 .905 .802 r
F P
0 g
s
.40294 .25245 m .4001 .26041 L .40593 .26186 L p .913 .905 .802 r
F P
0 g
s
.40593 .26186 m .41357 .26376 L p .40294 .25245 L .913 .905 .802 r
F P
0 g
s
.40708 .2348 m .40456 .24793 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40753 .22162 m .40708 .2348 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39636 .24251 m .37073 .27601 L .37323 .27468 L .864 .705 .684 r
F
.37073 .22434 m .37073 .27601 L p .39636 .24251 L F P
0 g
s
.39636 .22735 m .37073 .22434 L p .39636 .24251 L .864 .705 .684 r
F P
0 g
s
.3721 .1715 m .38132 .17429 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.36241 .17144 m .3721 .1715 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.37073 .22434 m .33281 .22675 L p .34746 .23605 L .289 .763 .934 r
F P
0 g
s
.36163 .23353 m .37073 .22434 L .34746 .23605 L .289 .763 .934 r
F
.33299 .23862 m .31557 .23425 L .32849 .23942 L F
.31557 .23425 m .32495 .24005 L p .32849 .23942 L F P
0 g
s
.33281 .22675 m .31557 .23425 L p .33299 .23862 L .289 .763 .934 r
F P
0 g
s
.34205 .23701 m .33281 .22675 L .33299 .23862 L .289 .763 .934 r
F
.32495 .24537 m .32116 .24072 L .32339 .24033 L .396 .324 .657 r
F
.33953 .29258 m .32495 .25746 L .32495 .24537 L F
.32495 .26642 m .3286 .27552 L .32786 .27639 L .988 .806 .415 r
F
.31582 .25796 m .31426 .24561 L p .32495 .26548 L .396 .324 .657 r
F P
0 g
s
.32495 .27129 m .31582 .25796 L .32495 .26548 L .396 .324 .657 r
F
.31557 .23425 m .32495 .26395 L .32495 .26642 L .988 .806 .415 r
F
.32495 .26395 m .3286 .27552 L .32495 .26642 L F
.31557 .23425 m .32495 .24005 L p .32495 .26395 L F P
0 g
s
.32495 .26642 m .32786 .27639 L .32495 .27731 L .988 .806 .415 r
F
.32754 .27676 m .32886 .27571 L .32538 .27929 L .887 .474 .217 r
F
.33953 .29258 m .32495 .27129 L .32495 .26548 L .396 .324 .657 r
F
.33953 .29258 m .32495 .26548 L .32495 .25746 L F
.31557 .23425 m .32495 .27731 L .31915 .28276 L .988 .806 .415 r
F
.32495 .27731 m .32538 .27929 L .32495 .27953 L F
.32495 .27731 m .32495 .27953 L .31915 .28276 L F
.31557 .23425 m .32495 .26642 L .32495 .27731 L F
.33953 .29258 m .32495 .27944 L .32495 .27579 L .396 .324 .657 r
F
.31941 .28627 m .32495 .28186 L .32032 .29858 L .988 .806 .415 r
F
.32495 .28186 m .32495 .28761 L .32032 .29858 L F
.33953 .29258 m .32495 .27579 L .32495 .27129 L .396 .324 .657 r
F
.39636 .26719 m .39389 .27168 L p .39636 .26239 L F P
0 g
s
.39636 .24251 m .37073 .27815 L .39636 .26719 L .864 .705 .684 r
F
.4001 .26041 m .39636 .26719 L p .39636 .26239 L .396 .324 .657 r
F P
0 g
s
.4001 .26041 m .39636 .26719 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.39636 .26719 m .39389 .27168 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.37176 .29914 m .36215 .29876 L .3531 .29571 L p .399 .326 .658 r
F P
0 g
s
.38151 .29681 m .37176 .29914 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39097 .29185 m .38151 .29681 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39972 .28447 m .39097 .29185 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.36215 .29876 m .37176 .29914 L .35822 .29601 L p .056 .608 .826 r
F P
0 g
s
.37176 .29914 m .38151 .29681 L .36798 .29366 L p .34 .796 .945 r
F P
0 g
s
.36798 .29366 m .35822 .29601 L .37176 .29914 L p .34 .796 .945 r
F P
0 g
s
.37746 .28867 m .36798 .29366 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.38622 .28124 m .37746 .28867 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39389 .27168 m .38622 .28124 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.38151 .29681 m .39097 .29185 L .37746 .28867 L p .548 .896 .979 r
F P
0 g
s
.37746 .28867 m .36798 .29366 L .38151 .29681 L p .548 .896 .979 r
F P
0 g
s
.39097 .29185 m .39972 .28447 L .38622 .28124 L p .693 .938 .964 r
F P
0 g
s
.38622 .28124 m .37746 .28867 L .39097 .29185 L p .693 .938 .964 r
F P
0 g
s
.39389 .27168 m .38622 .28124 L .39972 .28447 L p .793 .946 .923 r
F P
0 g
s
.37073 .27815 m .37073 .39718 L p .39841 .26631 L .864 .705 .684 r
F P
0 g
s
.37073 .39718 m .4064 .40031 L .4064 .2629 L p .864 .705 .684 r
F P
0 g
s
.39841 .26631 m .37073 .39718 L .4064 .2629 L .864 .705 .684 r
F
.4001 .26041 m .40223 .26468 L .40364 .26408 L .863 .933 .868 r
F
.40984 .2705 m .41357 .26376 L .40593 .26186 L p F P
0 g
s
.41935 .2126 m .42099 .22518 L p .40984 .23676 L .399 .326 .658 r
F P
0 g
s
.40984 .22453 m .41935 .2126 L .40984 .23676 L .399 .326 .658 r
F
.42099 .22518 m .42086 .22893 L p .41666 .22967 L F P
0 g
s
.42086 .22893 m .42054 .23829 L p .41666 .22967 L .399 .326 .658 r
F P
0 g
s
.3286 .41055 m .31557 .40456 L .31557 .23425 L p .988 .806 .415 r
F P
0 g
s
.63672 .29914 m .62644 .29876 L .61675 .29571 L p .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .62644 .29876 L .61426 .29564 L p .239 0 0 r
F P
0 g
s
.62644 .29876 m .63672 .29914 L .62456 .29601 L p .07 .617 .837 r
F P
0 g
s
.62456 .29601 m .61426 .29564 L .62644 .29876 L p .07 .617 .837 r
F P
0 g
s
.63502 .29366 m .62456 .29601 L .63672 .29914 L p .336 .794 .943 r
F P
0 g
s
.63502 .29366 m .62456 .29601 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.60211 .39897 m .641 .39718 L .641 .22434 L p .604 .493 .7 r
F P
0 g
s
.61426 .29564 m .60455 .29258 L .61675 .29571 L p .239 0 0 r
F P
0 g
s
.62456 .29601 m .61426 .29564 L .60455 .29258 L p .417 .341 .663 r
F P
0 g
s
.641 .22434 m .60211 .22675 L .60211 .39897 L p .604 .493 .7 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.31557 .40456 m .3286 .41055 L .36358 .41352 L p .224 .73 .894 r
F P
0 g
s
.33281 .39897 m .31557 .40456 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.37073 .39718 m .33281 .39897 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.4064 .40031 m .37073 .39718 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.41844 .4064 m .4064 .40031 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.36358 .41352 m .40051 .41183 L .41844 .4064 L p .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3531 .29571 m .36215 .29876 L .3486 .29564 L p .273 0 0 r
F P
0 g
s
.3486 .29564 m .33953 .29258 L .3531 .29571 L p .273 0 0 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31557 .40456 m .33281 .39897 L .33281 .22675 L p .014 .012 .507 r
F P
0 g
s
.33281 .22675 m .31557 .23425 L .31557 .40456 L p .014 .012 .507 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.35822 .29601 m .3486 .29564 L .36215 .29876 L p .056 .608 .826 r
F P
0 g
s
.35822 .29601 m .3486 .29564 L .33953 .29258 L p .396 .324 .657 r
F P
0 g
s
.36798 .29366 m .35822 .29601 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39483 .17807 m .38562 .17528 L .3721 .1715 L p .215 0 0 r
F P
0 g
s
.67033 .18347 m .66142 .17807 L .64931 .17429 L p .484 0 0 r
F P
0 g
s
.40316 .18347 m .39483 .17807 L .38132 .17429 L p .527 0 0 r
F P
0 g
s
.3721 .1715 m .38132 .17429 L .39483 .17807 L p .215 0 0 r
F P
0 g
s
.6779 .19127 m .67033 .18347 L .65825 .17971 L p .722 .191 0 r
F P
0 g
s
.64931 .17429 m .65825 .17971 L .67033 .18347 L p .484 0 0 r
F P
0 g
s
.41022 .19127 m .40316 .18347 L .38967 .17971 L p .752 .234 0 r
F P
0 g
s
.38132 .17429 m .38967 .17971 L .40316 .18347 L p .527 0 0 r
F P
0 g
s
.68377 .20112 m .6779 .19127 L .66583 .18754 L p .871 .43 .119 r
F P
0 g
s
.65825 .17971 m .66583 .18754 L .6779 .19127 L p .722 .191 0 r
F P
0 g
s
.41571 .20112 m .41022 .19127 L .39675 .18754 L p .882 .458 .179 r
F P
0 g
s
.38967 .17971 m .39675 .18754 L .41022 .19127 L p .752 .234 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.33281 .39897 m .37073 .39718 L .37073 .22434 L p .601 .491 .7 r
F P
0 g
s
.37073 .22434 m .33281 .22675 L .33281 .39897 L p .601 .491 .7 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.68148 .26376 m .68626 .25135 L .67421 .24793 L p .918 .921 .8 r
F P
0 g
s
.41357 .26376 m .41803 .25135 L .40456 .24793 L p .913 .905 .802 r
F P
0 g
s
.68767 .2126 m .68377 .20112 L .67171 .19744 L p .948 .605 .328 r
F P
0 g
s
.66583 .18754 m .67171 .19744 L .68377 .20112 L p .871 .43 .119 r
F P
0 g
s
.41935 .2126 m .41571 .20112 L .40224 .19744 L p .945 .615 .371 r
F P
0 g
s
.39675 .18754 m .40224 .19744 L .41571 .20112 L p .882 .458 .179 r
F P
0 g
s
.68626 .25135 m .68895 .23829 L .6769 .2348 L p .956 .878 .717 r
F P
0 g
s
.6769 .2348 m .67421 .24793 L .68626 .25135 L p .956 .878 .717 r
F P
0 g
s
.41803 .25135 m .42054 .23829 L .40708 .2348 L p .947 .863 .725 r
F P
0 g
s
.40708 .2348 m .40456 .24793 L .41803 .25135 L p .947 .863 .725 r
F P
0 g
s
.68943 .22518 m .68767 .2126 L .67563 .20897 L p .978 .728 .489 r
F P
0 g
s
.67171 .19744 m .67563 .20897 L .68767 .2126 L p .948 .605 .328 r
F P
0 g
s
.42099 .22518 m .41935 .2126 L .40589 .20897 L p .968 .726 .518 r
F P
0 g
s
.40224 .19744 m .40589 .20897 L .41935 .2126 L p .945 .615 .371 r
F P
0 g
s
.68895 .23829 m .68943 .22518 L .67738 .22162 L p .977 .816 .616 r
F P
0 g
s
.67738 .22162 m .6769 .2348 L .68895 .23829 L p .977 .816 .616 r
F P
0 g
s
.42054 .23829 m .42099 .22518 L .40753 .22162 L p .966 .805 .632 r
F P
0 g
s
.40753 .22162 m .40708 .2348 L .42054 .23829 L p .966 .805 .632 r
F P
0 g
s
.67563 .20897 m .67738 .22162 L .68943 .22518 L p .978 .728 .489 r
F P
0 g
s
.40589 .20897 m .40753 .22162 L .42099 .22518 L p .968 .726 .518 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .70383 .84123 L .70996 .765 L p .156 .364 .817 r
F P
0 g
s
.70996 .765 m .71107 .75129 L p .72726 .80432 L .156 .364 .817 r
F P
0 g
s
.74865 .87438 m .70996 .765 L .72726 .80432 L .156 .364 .817 r
F
.74865 .87438 m .70383 .84123 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.70996 .87484 m .70139 .8749 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.70996 .87438 m .70996 .87484 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.71107 .75129 m .75756 .78483 L .74865 .87438 L p .156 .364 .817 r
F P
0 g
s
.70996 .87384 m .717 .8739 L p .71303 .87482 L .012 .587 .719 r
F P
0 g
s
.74865 .87438 m .75038 .85691 L p .72128 .87397 L .884 .991 .792 r
F P
0 g
s
.75038 .85691 m .75756 .78483 L p .72244 .87113 L .884 .991 .792 r
F P
0 g
s
.72128 .87397 m .75038 .85691 L .72244 .87113 L .884 .991 .792 r
F
.71303 .87482 m .717 .8739 L .75582 .87449 L .012 .587 .719 r
F
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70739 .90811 m .74865 .87438 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.717 .8739 m .70996 .87384 L p .71436 .87524 L .96 .784 .62 r
F P
0 g
s
.70996 .87384 m .70996 .87748 L p .71436 .87524 L .96 .784 .62 r
F P
0 g
s
.75756 .78483 m .71489 .81897 L .70996 .87748 L p .884 .991 .792 r
F P
0 g
s
.70996 .87748 m .70739 .90811 L p .72244 .87113 L .884 .991 .792 r
F P
0 g
s
.72244 .87113 m .75756 .78483 L .70996 .87748 L .884 .991 .792 r
F
.70739 .90811 m .74865 .87438 L p .72128 .87397 L F P
0 g
s
.70996 1.10469 m .76566 .89165 L .71436 .87524 L .96 .784 .62 r
F
.70996 .87748 m .70996 1.10469 L p .71436 .87524 L F P
0 g
s
.717 .8739 m .77017 .87438 L p .75582 .87449 L .012 .587 .719 r
F P
0 g
s
.75802 .87427 m .717 .8739 L p .76566 .89165 L .96 .784 .62 r
F P
0 g
s
.76566 .89165 m .717 .8739 L .71436 .87524 L .96 .784 .62 r
F
.70996 .87384 m .70996 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .75802 .87427 L p .76566 .89165 L .96 .784 .62 r
F P
0 g
s
.70383 .84123 m .66253 .87438 L .66367 .85691 L p .888 .988 .798 r
F P
0 g
s
.66367 .85691 m .66836 .78483 L p .68592 .81275 L .888 .988 .798 r
F P
0 g
s
.70383 .84123 m .66367 .85691 L .68592 .81275 L .888 .988 .798 r
F
.70139 .8749 m .65491 .8745 L p .66487 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .66487 .87438 L .70559 .87438 L .012 .587 .719 r
F
.70383 .84123 m .66253 .87438 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.66836 .78483 m .71107 .75129 L .70383 .84123 L p .888 .988 .798 r
F P
0 g
s
.71489 .81897 m .66836 .78483 L .66367 .85691 L p .138 .355 .814 r
F P
0 g
s
.66367 .85691 m .66253 .87438 L p .6745 .86172 L .138 .355 .814 r
F P
0 g
s
.6745 .86172 m .71489 .81897 L .66367 .85691 L .138 .355 .814 r
F
.65491 .8745 m .64101 .87438 L p .65493 .87427 L .012 .587 .719 r
F P
0 g
s
.65868 .87446 m .65823 .87443 L p .70996 .87384 L .012 .587 .719 r
F P
0 g
s
.65823 .87443 m .70191 .8739 L .70996 .87384 L .012 .587 .719 r
F
.66253 .87438 m .70739 .90811 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.70559 .87438 m .66487 .87438 L .70996 .87384 L .012 .587 .719 r
F
.70996 .87384 m .70191 .8739 L p .70872 .87693 L .333 .272 .638 r
F P
0 g
s
.66253 .87438 m .70739 .90811 L .70996 .87748 L p .138 .355 .814 r
F P
0 g
s
.66253 .87438 m .70996 .87748 L .70191 .8739 L .138 .355 .814 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62095 1.28726 m .63485 1.26808 L .6489 1.29143 L p .252 .206 .61 r
F P
0 g
s
.6489 1.29143 m .63485 1.31058 L .62095 1.28726 L p .252 .206 .61 r
F P
0 g
s
.63485 1.26808 m .62713 1.27873 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62307 1.27263 m .63485 1.26808 L .60413 1.28899 L .774 .963 .927 r
F
.46484 1.31058 m .45185 1.28726 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.46795 1.30604 m .46484 1.31058 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.62095 1.28726 m .62713 1.29763 L p .61759 1.30188 L .796 .382 .262 r
F P
0 g
s
.61093 1.2955 m .62095 1.28726 L .61759 1.30188 L .796 .382 .262 r
F
.45185 1.28726 m .45892 1.29995 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.44093 1.2955 m .45185 1.28726 L .45717 1.31139 L .798 .39 .278 r
F
.45892 1.27682 m .45185 1.28726 L .43426 1.28899 L p .779 .957 .927 r
F P
0 g
s
.45185 1.28726 m .46484 1.26808 L .46795 1.27361 L p .223 .182 .599 r
F P
0 g
s
.46268 1.28899 m .45185 1.28726 L .46795 1.27361 L .223 .182 .599 r
F
.37209 1.3207 m .37211 1.31966 L p .45539 1.30965 L .694 .457 .559 r
F P
0 g
s
.37209 1.3207 m .45539 1.30965 L .45603 1.31027 L .694 .457 .559 r
F
.37211 1.31966 m .3726 1.28899 L .43426 1.28899 L p F P
0 g
s
.37211 1.31966 m .43426 1.28899 L .45539 1.30965 L .694 .457 .559 r
F
.46484 1.31058 m .45717 1.31139 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.45892 1.29995 m .46484 1.31058 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.46484 1.31058 m .46795 1.30604 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.43837 1.3207 m .37209 1.3207 L p .46054 1.30971 L .694 .457 .559 r
F P
0 g
s
.41389 1.31592 m .401 1.29226 L .43426 1.28899 L p .798 .39 .278 r
F P
0 g
s
.41389 1.31592 m .43426 1.28899 L .44093 1.2955 L .798 .39 .278 r
F
.45717 1.31139 m .41389 1.31592 L p .44093 1.2955 L F P
0 g
s
.42691 1.29654 m .41389 1.31592 L .45717 1.31139 L p .777 .96 .927 r
F P
0 g
s
.45717 1.31139 m .46484 1.31058 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.43426 1.28899 m .45185 1.28726 L p .44093 1.2955 L .798 .39 .278 r
F P
0 g
s
.43426 1.28899 m .50237 1.28899 L p .45539 1.30965 L .694 .457 .559 r
F P
0 g
s
.45539 1.30965 m .50237 1.28899 L .46236 1.30881 L .694 .457 .559 r
F
.45603 1.31027 m .45539 1.30965 L .60672 1.29147 L F
.60413 1.28899 m .62095 1.28726 L p .61093 1.2955 L .796 .382 .262 r
F P
0 g
s
.6068 1.29155 m .60672 1.29147 L .6274 1.28899 L .694 .457 .559 r
F
.45603 1.31027 m .60672 1.29147 L .6068 1.29155 L F
.50237 1.28899 m .6274 1.28899 L p .46236 1.30881 L F P
0 g
s
.47249 1.3207 m .6068 1.29155 L .62286 1.31372 L .694 .457 .559 r
F
.62791 1.3207 m .60892 1.3207 L p .62286 1.31372 L F P
0 g
s
.60892 1.3207 m .47249 1.3207 L p .62286 1.31372 L .694 .457 .559 r
F P
0 g
s
.46877 1.30869 m .6068 1.29155 L .47249 1.3207 L .694 .457 .559 r
F
.62776 1.31162 m .62791 1.3207 L p .62286 1.31372 L F P
0 g
s
.6068 1.29155 m .62752 1.31139 L .62286 1.31372 L .694 .457 .559 r
F
.62752 1.31139 m .62776 1.31162 L .62286 1.31372 L F
.58611 1.31592 m .60413 1.28899 L .61093 1.2955 L .796 .382 .262 r
F
.60008 1.29654 m .58611 1.31592 L p .60586 1.29967 L .772 .965 .926 r
F P
0 g
s
.58611 1.31592 m .61093 1.2955 L .61759 1.30188 L .796 .382 .262 r
F
.62775 1.31136 m .58611 1.31592 L p .62713 1.29763 L F P
0 g
s
.58611 1.31592 m .62752 1.31139 L p .60586 1.29967 L .772 .965 .926 r
F P
0 g
s
.62713 1.29763 m .63485 1.31058 L .62775 1.31136 L p .796 .382 .262 r
F P
0 g
s
.62095 1.28726 m .60413 1.28899 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62713 1.27873 m .62095 1.28726 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62791 1.2604 m .62776 1.26859 L p .6272 1.26866 L .691 .686 .84 r
F P
0 g
s
.46268 1.28899 m .49129 1.28404 L .49377 1.28514 L .691 .686 .84 r
F
.46268 1.28899 m .43426 1.28899 L p .46628 1.2785 L F P
0 g
s
.42186 1.28347 m .44324 1.28108 L .43426 1.28899 L .691 .686 .84 r
F
.43426 1.28899 m .3726 1.28899 L p .42186 1.28347 L F P
0 g
s
.3726 1.28899 m .46669 1.2604 L .44324 1.28108 L .691 .686 .84 r
F
.43426 1.28899 m .401 1.29226 L p .44336 1.28097 L .779 .957 .927 r
F P
0 g
s
.44336 1.28097 m .45892 1.27682 L .43426 1.28899 L .779 .957 .927 r
F
.3726 1.28899 m .37209 1.2604 L .46669 1.2604 L p .691 .686 .84 r
F P
0 g
s
.46484 1.26808 m .45892 1.27682 L p .44336 1.28097 L .779 .957 .927 r
F P
0 g
s
.45282 1.27263 m .46484 1.26808 L .44336 1.28097 L .779 .957 .927 r
F
.401 1.29226 m .41389 1.27286 L .46484 1.26808 L p F P
0 g
s
.46795 1.27361 m .46484 1.26808 L .45717 1.2688 L p .797 .387 .272 r
F P
0 g
s
.46669 1.2604 m .62791 1.2604 L p .44324 1.28108 L .691 .686 .84 r
F P
0 g
s
.44324 1.28108 m .46628 1.2785 L .43426 1.28899 L .691 .686 .84 r
F
.401 1.29226 m .45282 1.27263 L .44336 1.28097 L .779 .957 .927 r
F
.60413 1.28899 m .46268 1.28899 L p .62776 1.26859 L .691 .686 .84 r
F P
0 g
s
.46628 1.2785 m .62791 1.2604 L .46268 1.28899 L .691 .686 .84 r
F
.46795 1.27361 m .47797 1.29143 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.47797 1.29143 m .46795 1.27361 L p .41389 1.27286 L .797 .387 .272 r
F P
0 g
s
.45717 1.2688 m .41389 1.27286 L p .46795 1.27361 L .797 .387 .272 r
F P
0 g
s
.49377 1.28514 m .61418 1.26278 L .6272 1.26866 L .691 .686 .84 r
F
.49129 1.28404 m .61418 1.26278 L .49377 1.28514 L F
.61418 1.26278 m .62791 1.2604 L .6272 1.26866 L F
.62775 1.26878 m .63485 1.26808 L p .62762 1.27088 L .774 .963 .927 r
F P
0 g
s
.63485 1.26808 m .62775 1.26878 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.6489 1.29143 m .63818 1.27361 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.63818 1.27361 m .63485 1.26808 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.62851 1.2854 m .6489 1.29143 L .62775 1.26878 L .796 .378 .256 r
F
.63168 1.3093 m .62776 1.31126 L .63485 1.31058 L .772 .965 .926 r
F
.62775 1.31136 m .63485 1.31058 L p .62776 1.31126 L F P
0 g
s
.62752 1.31139 m .62775 1.31136 L p .62776 1.31126 L .772 .965 .926 r
F P
0 g
s
.6274 1.28899 m .62776 1.31162 L p .6068 1.29155 L .694 .457 .559 r
F P
0 g
s
.60008 1.29654 m .62752 1.31139 L .62776 1.31126 L .772 .965 .926 r
F
.62798 1.30781 m .62776 1.31126 L .63168 1.3093 L F
.62791 1.30886 m .62791 1.27225 L .62821 1.30413 L 0 0 .059 r
F
.62791 1.27225 m .62791 1.26622 L .62797 1.27351 L F
.62791 1.27225 m .62797 1.27351 L .62821 1.30413 L F
.62888 1.29353 m .6489 1.29143 L p .62851 1.2854 L .796 .378 .256 r
F P
0 g
s
.62821 1.30413 m .62791 1.26622 L .62917 1.25133 L 0 0 .059 r
F
.5723 1.29226 m .58611 1.27286 L .62775 1.26878 L p .774 .963 .927 r
F P
0 g
s
.5723 1.29226 m .62775 1.26878 L .62762 1.27088 L .774 .963 .927 r
F
.6274 1.28899 m .60413 1.28899 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.6274 1.28899 m .62776 1.26891 L p .62788 1.30936 L 0 0 .059 r
F P
0 g
s
.62788 1.30936 m .62776 1.26891 L .62776 1.26907 L 0 0 .059 r
F
.62781 1.31039 m .6274 1.28899 L .62788 1.30936 L F
.58611 1.31592 m .5723 1.29226 L .60413 1.28899 L p .796 .382 .262 r
F P
0 g
s
.62776 1.31162 m .62776 1.31126 L p .62789 1.3145 L 0 0 .059 r
F P
0 g
s
.62776 1.31126 m .6274 1.28899 L p .62781 1.31039 L 0 0 .059 r
F P
0 g
s
.62776 1.31126 m .62781 1.31039 L .62789 1.3145 L 0 0 .059 r
F
.6489 1.29143 m .62888 1.29353 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.62791 1.3207 m .62776 1.26859 L .62791 1.26622 L 0 0 .059 r
F
.62798 1.30781 m .63168 1.3093 L .62888 1.29353 L .772 .965 .926 r
F
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62888 1.29353 m .60008 1.29654 L p .62798 1.30781 L .772 .965 .926 r
F P
0 g
s
.60413 1.28899 m .5723 1.29226 L p .62307 1.27263 L .774 .963 .927 r
F P
0 g
s
.58611 1.27286 m .60008 1.29654 L .62888 1.29353 L p .796 .378 .256 r
F P
0 g
s
.62776 1.26891 m .6274 1.28899 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.58611 1.27286 m .62888 1.29353 L .62851 1.2854 L .796 .378 .256 r
F
.60008 1.29654 m .62776 1.31126 L .62798 1.30781 L .772 .965 .926 r
F
.62791 1.3207 m .62791 1.30886 L .62821 1.30413 L 0 0 .059 r
F
.62791 1.2604 m .62857 1.25566 L p .62791 1.26622 L F P
0 g
s
.62857 1.25566 m .62917 1.25133 L p .62791 1.26622 L 0 0 .059 r
F P
0 g
s
.58611 1.27286 m .62784 1.27079 L .62776 1.26891 L .796 .378 .256 r
F
.58611 1.27286 m .62851 1.2854 L .62784 1.27079 L F
.62775 1.26878 m .62752 1.2688 L p .62776 1.26891 L F P
0 g
s
.62752 1.2688 m .58611 1.27286 L p .62776 1.26891 L .796 .378 .256 r
F P
0 g
s
.62776 1.26859 m .62776 1.26891 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.62776 1.26891 m .62776 1.26859 L p .62776 1.26907 L 0 0 .059 r
F P
0 g
s
.62789 1.3145 m .62781 1.31039 L .62788 1.30936 L 0 0 .059 r
F
.63485 1.31058 m .63818 1.30604 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.63818 1.30604 m .6489 1.29143 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.42691 1.29654 m .45717 1.31139 L .46138 1.3093 L .777 .96 .927 r
F
.47249 1.3207 m .43837 1.3207 L p .46877 1.30869 L .694 .457 .559 r
F P
0 g
s
.46054 1.30971 m .46877 1.30869 L .43837 1.3207 L .694 .457 .559 r
F
.47797 1.29143 m .46795 1.30604 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.47797 1.29143 m .46176 1.29305 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.46795 1.30604 m .47797 1.29143 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.62917 1.25133 m .62801 1.25967 L p .58275 1.25967 L .365 .792 .97 r
F P
0 g
s
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.37083 1.25133 m .53229 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.548 1.25967 m .62917 1.25133 L .58275 1.25967 L F
.452 1.25967 m .54018 1.25552 L .548 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .548 1.25967 L F
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.41389 1.27286 m .42691 1.29654 L .47797 1.29143 L p .797 .387 .272 r
F P
0 g
s
.46771 1.29439 m .47032 1.25768 L p .484 1.29086 L .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.48371 1.25362 m .48371 1.10147 L p .47089 1.2543 L .063 .051 .53 r
F P
0 g
s
.47089 1.2543 m .46869 1.2806 L .47909 1.26192 L .063 .051 .53 r
F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L F
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.62776 1.26859 m .62791 1.2604 L p .62791 1.26622 L 0 0 .059 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.47468 1.25782 m .48371 1.26622 L .50936 1.26622 L .513 .022 .027 r
F
.48824 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47468 1.25782 m .50936 1.26622 L .52213 1.26079 L .513 .022 .027 r
F
.50936 1.26622 m .51486 1.26755 L .51629 1.26622 L F
.50936 1.26622 m .51629 1.26622 L .52213 1.26079 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.52783 1.09787 m .46368 1.10009 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.36257 1.04436 m .3516 1.04413 L .36228 1.04465 L .066 0 0 r
F
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .36099 1.04601 L p .34335 1.04519 L .066 0 0 r
F P
0 g
s
.34335 1.04519 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L F P
0 g
s
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L .09 0 0 r
F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.51629 1.26622 m .51629 1.10147 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.53926 1.09886 m .44328 1.10233 L .46043 1.10045 L .09 0 0 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L F
.53645 1.09918 m .44328 1.10233 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.26622 L p .52972 1.09994 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48146 1.10121 m .46869 1.2806 L .48371 1.10147 L F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.52972 1.09994 m .51629 1.26622 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L .09 0 0 r
F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52972 1.09994 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52972 1.09994 L .998 .815 .53 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70899 .87705 L .64101 1.04449 L .333 .272 .638 r
F
.70899 .87705 m .70872 .87693 L .64101 1.04449 L F
.64101 1.04449 m .70872 .87693 L .65493 .87427 L F
.64101 .90192 m .64101 1.04449 L p .65493 .87427 L F P
0 g
s
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .50936 1.26622 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .50936 1.26622 L .513 .022 .027 r
F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .52213 1.26079 L .513 .022 .027 r
F P
0 g
s
.47089 1.2543 m .47909 1.26192 L .48371 1.25362 L .063 .051 .53 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.46771 1.29439 m .48371 1.29798 L .48371 1.25362 L p .063 .051 .53 r
F P
0 g
s
.46869 1.2806 m .46771 1.29439 L .48371 1.25362 L .063 .051 .53 r
F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L .48514 1.26755 L p .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.46176 1.29305 m .42691 1.29654 L p .45419 1.30664 L .777 .96 .927 r
F P
0 g
s
.45419 1.30664 m .46138 1.3093 L .46176 1.29305 L .777 .96 .927 r
F
.62791 1.3207 m .62776 1.31162 L p .62789 1.3145 L 0 0 .059 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70899 .87705 m .70996 .87384 L .70872 .87693 L .333 .272 .638 r
F
.70996 .87748 m .71027 .8738 L p .70191 .8739 L .138 .355 .814 r
F P
0 g
s
.71027 .8738 m .71489 .81897 L p .66253 .87438 L .138 .355 .814 r
F P
0 g
s
.65823 .87443 m .65493 .87427 L p .70191 .8739 L .012 .587 .719 r
F P
0 g
s
.70191 .8739 m .65493 .87427 L p .70872 .87693 L .333 .272 .638 r
F P
0 g
s
.65493 .87427 m .64101 .87438 L .64101 .90192 L p .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.31198 .18889 m .31211 .18489 L p .32359 .20159 L .369 .301 .649 r
F P
0 g
s
.31211 .18489 m .31244 .17491 L p .31628 .18408 L .369 .301 .649 r
F P
0 g
s
.32359 .20159 m .31211 .18489 L .31628 .18408 L .369 .301 .649 r
F
.31244 .17491 m .31198 .18889 L .29702 .18489 L p .968 .807 .629 r
F P
0 g
s
.31244 .17491 m .31505 .16093 L p .3219 .18299 L .369 .301 .649 r
F P
0 g
s
.31949 .18346 m .31244 .17491 L .3219 .18299 L .369 .301 .649 r
F
.32359 .20159 m .31244 .17491 L .32359 .18845 L F
.31505 .16093 m .31244 .17491 L .29749 .17083 L p .948 .866 .724 r
F P
0 g
s
.29702 .18489 m .29749 .17083 L .31244 .17491 L p .968 .807 .629 r
F P
0 g
s
.32359 .23457 m .3275 .22767 L .35102 .3687 L .87 .71 .681 r
F
.35102 .18607 m .35102 .24023 L p .3275 .22767 L F P
0 g
s
.35102 .24023 m .35102 .3687 L p .3275 .22767 L .87 .71 .681 r
F P
0 g
s
.32319 .22512 m .32359 .22558 L p .32298 .22525 L .753 .236 0 r
F P
0 g
s
.31505 .16093 m .31969 .14754 L p .32359 .16571 L .369 .301 .649 r
F P
0 g
s
.32359 .18267 m .35102 .18607 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32359 .18267 m .35102 .18607 L p .33233 .18098 L .289 .763 .934 r
F P
0 g
s
.32709 .18199 m .32359 .18267 L .32359 .16571 L .369 .301 .649 r
F
.32359 .18845 m .31505 .16093 L .32359 .16571 L F
.31969 .14754 m .32618 .1353 L p .33945 .23954 L F P
0 g
s
.35102 .18607 m .34111 .17928 L .33233 .18098 L .289 .763 .934 r
F
.32618 .1353 m .33425 .12476 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.35102 .18607 m .3536 .17687 L .34111 .17928 L .289 .763 .934 r
F
.33425 .12476 m .34357 .11636 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39131 .36668 m .35102 .3687 L .35102 .18607 L p .594 .485 .699 r
F P
0 g
s
.35102 .18607 m .39131 .18336 L .39131 .36668 L p .594 .485 .699 r
F P
0 g
s
.36433 .1074 m .37489 .10728 L p .35638 .17633 L .369 .301 .649 r
F P
0 g
s
.35102 .18607 m .38409 .17097 L .3536 .17687 L .289 .763 .934 r
F
.41081 .17465 m .40132 .16764 L p .35102 .18607 L F P
0 g
s
.35102 .18607 m .40132 .16764 L .38409 .17097 L .289 .763 .934 r
F
.35102 .18607 m .39131 .18336 L .41081 .17465 L p F P
0 g
s
.41081 .3602 m .39131 .36668 L .39131 .18336 L p .001 .001 .501 r
F P
0 g
s
.39131 .18336 m .41081 .17465 L .41081 .3602 L p .001 .001 .501 r
F P
0 g
s
.41081 .17465 m .40132 .16764 L p .40132 .21102 L .971 .793 .367 r
F P
0 g
s
.40712 .22411 m .40132 .21102 L .40132 .302 L .971 .793 .367 r
F
.41081 .17465 m .40132 .21102 L .40712 .22411 L F
.40539 .20357 m .39862 .21594 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.41081 .3602 m .41081 .17465 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.41026 .18991 m .40539 .20357 L p .40132 .20579 L .369 .301 .649 r
F P
0 g
s
.33945 .23954 m .40132 .19618 L .40132 .20579 L .369 .301 .649 r
F
.40132 .19618 m .41026 .18991 L .40132 .20579 L F
.39752 .35291 m .40132 .35499 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.40132 .35499 m .41081 .3602 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.41301 .17557 m .41026 .18991 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39862 .21594 m .40132 .21102 L p .39449 .20373 L .863 .944 .869 r
F P
0 g
s
.39295 .20437 m .39862 .21594 L .39449 .20373 L .863 .944 .869 r
F
.33945 .23954 m .40132 .1607 L .40132 .17409 L .369 .301 .649 r
F
.40773 .13497 m .41171 .14746 L p .33945 .23954 L F P
0 g
s
.40174 .12429 m .40773 .13497 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.40132 .16764 m .39752 .16484 L p .38409 .17097 L .289 .763 .934 r
F P
0 g
s
.33945 .23954 m .40877 .1662 L .41301 .17557 L .369 .301 .649 r
F
.39752 .20246 m .39752 .16484 L p .38876 .20611 L .875 .714 .68 r
F P
0 g
s
.39701 .2013 m .39059 .19955 L p .40132 .21102 L .863 .944 .869 r
F P
0 g
s
.39862 .21594 m .39027 .22647 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39027 .22647 m .39862 .21594 L .38381 .212 L p .788 .954 .924 r
F P
0 g
s
.38381 .212 m .39862 .21594 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.39752 .16484 m .38651 .18002 L .38876 .20611 L .875 .714 .68 r
F
.33945 .23954 m .35116 .17734 L .35638 .17633 L .369 .301 .649 r
F
.33945 .23954 m .32359 .18845 L .32359 .18267 L F
.33945 .23954 m .32359 .18267 L .32709 .18199 L F
.32359 .18845 m .31949 .18346 L .3219 .18299 L F
.32359 .2103 m .31198 .18889 L .32359 .20159 L F
.31368 .20229 m .31198 .18889 L p .33945 .23954 L F P
0 g
s
.31746 .21454 m .31368 .20229 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.32319 .22512 m .31746 .21454 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.33945 .23954 m .33062 .23358 L .32319 .22512 L p .369 .301 .649 r
F P
0 g
s
.31271 .18132 m .32359 .18267 L p .32359 .22587 L .87 .71 .681 r
F P
0 g
s
.32153 .22448 m .32359 .22587 L .32359 .23457 L .87 .71 .681 r
F
.31746 .21454 m .32319 .22512 L .32232 .2249 L p .882 .455 .174 r
F P
0 g
s
.31299 .21783 m .31746 .21454 L .32232 .2249 L .882 .455 .174 r
F
.31198 .18889 m .31368 .20229 L .29872 .19836 L p .97 .727 .513 r
F P
0 g
s
.31271 .36517 m .31271 .22135 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.31368 .20229 m .31673 .21217 L p .30412 .21109 L .946 .614 .365 r
F P
0 g
s
.31673 .21217 m .31746 .21454 L .31587 .21413 L p .946 .614 .365 r
F P
0 g
s
.31587 .21413 m .30412 .21109 L p .31673 .21217 L .946 .614 .365 r
F P
0 g
s
.30329 .2101 m .31368 .20229 L .30412 .21109 L .946 .614 .365 r
F
.31271 .21761 m .31271 .22135 L p .31188 .21852 L .981 .801 .395 r
F P
0 g
s
.31271 .22135 m .31271 .36517 L p .30865 .31096 L .981 .801 .395 r
F P
0 g
s
.30352 .24233 m .30865 .23061 L .30865 .31096 L .981 .801 .395 r
F
.30865 .23061 m .31271 .22135 L .30865 .31096 L F
.30412 .21109 m .30251 .21068 L p .30329 .2101 L .946 .614 .365 r
F P
0 g
s
.30251 .21068 m .29872 .19836 L .31368 .20229 L p .946 .614 .365 r
F P
0 g
s
.31271 .22135 m .31271 .21761 L p .32354 .2343 L .87 .71 .681 r
F P
0 g
s
.30412 .21109 m .31587 .21413 L p .31241 .21739 L .882 .455 .174 r
F P
0 g
s
.32149 .22427 m .32354 .2343 L .31271 .21761 L .87 .71 .681 r
F
.30825 .22131 m .30251 .21068 L .30412 .21109 L p .882 .455 .174 r
F P
0 g
s
.30825 .22131 m .30412 .21109 L .31241 .21739 L .882 .455 .174 r
F
.30825 .22131 m .30251 .21068 L p .30865 .21768 L .366 .299 .648 r
F P
0 g
s
.30913 .22154 m .31271 .22135 L .30865 .22432 L .981 .801 .395 r
F
.30913 .22154 m .30865 .22432 L .30865 .22207 L F
.31188 .21852 m .3123 .21997 L .30913 .22154 L F
.3123 .21997 m .31271 .22135 L .30913 .22154 L F
.30251 .22882 m .30865 .22432 L .30352 .24233 L F
.30865 .22432 m .31271 .22135 L .30865 .23061 L F
.30865 .22432 m .30865 .23061 L .30352 .24233 L F
.30865 .22178 m .30825 .22131 L .30913 .22154 L p .753 .236 0 r
F P
0 g
s
.30865 .22178 m .30825 .22131 L p .30865 .22167 L .366 .299 .648 r
F P
0 g
s
.30825 .22131 m .31587 .21413 L .31153 .2189 L .882 .455 .174 r
F
.30913 .22154 m .30825 .22131 L p .31153 .2189 L F P
0 g
s
.30865 .22167 m .30825 .22131 L .30865 .21768 L .366 .299 .648 r
F
.30251 .21068 m .29872 .19836 L p .30865 .21277 L F P
0 g
s
.30865 .21768 m .30251 .21068 L .30865 .21277 L .366 .299 .648 r
F
.29872 .19836 m .29702 .18489 L .31198 .18889 L p .97 .727 .513 r
F P
0 g
s
.29702 .18489 m .29749 .17083 L p .30865 .19765 L .366 .299 .648 r
F P
0 g
s
.30865 .20641 m .29702 .18489 L .30865 .19765 L .366 .299 .648 r
F
.30865 .20744 m .31188 .21852 L .30865 .22207 L .981 .801 .395 r
F
.32354 .2343 m .32359 .23457 L .31271 .22135 L .87 .71 .681 r
F
.31681 .22898 m .30865 .22178 L p .32232 .2249 L .753 .236 0 r
F P
0 g
s
.30913 .22154 m .32232 .2249 L p .30865 .22178 L .753 .236 0 r
F P
0 g
s
.31153 .2189 m .3123 .21806 L .31243 .21824 L .882 .455 .174 r
F
.3123 .21806 m .31587 .21413 L .31243 .21824 L F
.31587 .21413 m .31746 .21454 L p .31243 .21824 L F P
0 g
s
.31271 .21761 m .31271 .18132 L p .32149 .22427 L .87 .71 .681 r
F P
0 g
s
.32149 .22427 m .32232 .2249 L .32153 .22448 L .87 .71 .681 r
F
.32232 .2249 m .30913 .22154 L p .31299 .21783 L .882 .455 .174 r
F P
0 g
s
.31153 .2189 m .31299 .21783 L .30913 .22154 L .882 .455 .174 r
F
.31271 .18132 m .31271 .21761 L p .30865 .20474 L .981 .801 .395 r
F P
0 g
s
.30865 .17862 m .31271 .18132 L p .30865 .20474 L .981 .801 .395 r
F P
0 g
s
.29749 .17083 m .3001 .15677 L .31505 .16093 L p .948 .866 .724 r
F P
0 g
s
.29749 .17083 m .3001 .15677 L p .30696 .17895 L .366 .299 .648 r
F P
0 g
s
.30454 .17942 m .29749 .17083 L .30696 .17895 L .366 .299 .648 r
F
.32232 .2249 m .32359 .22587 L .32153 .22448 L .87 .71 .681 r
F
.31569 .22981 m .32232 .2249 L .32298 .22525 L .753 .236 0 r
F
.32232 .2249 m .32319 .22512 L p .32298 .22525 L F P
0 g
s
.31271 .18132 m .32359 .22587 L .32149 .22427 L .87 .71 .681 r
F
.32327 .23173 m .31569 .22981 L p .32155 .22615 L .753 .236 0 r
F P
0 g
s
.32155 .22615 m .32298 .22525 L .32327 .23173 L .753 .236 0 r
F
.33062 .23358 m .32327 .23173 L p .32298 .22525 L F P
0 g
s
.31271 .18132 m .32359 .18267 L p .31251 .17787 L .289 .763 .934 r
F P
0 g
s
.31969 .14754 m .31505 .16093 L .3001 .15677 L p .913 .907 .802 r
F P
0 g
s
.3001 .15677 m .30474 .1433 L .31969 .14754 L p .913 .907 .802 r
F P
0 g
s
.3001 .15677 m .30474 .1433 L p .31215 .17794 L .366 .299 .648 r
F P
0 g
s
.30696 .17895 m .3001 .15677 L .31215 .17794 L .366 .299 .648 r
F
.30865 .17862 m .31271 .18132 L p .31251 .17787 L .289 .763 .934 r
F P
0 g
s
.32359 .22558 m .33062 .23358 L p .32298 .22525 L .753 .236 0 r
F P
0 g
s
.32618 .1353 m .31969 .14754 L .30474 .1433 L p .863 .934 .868 r
F P
0 g
s
.30474 .1433 m .31124 .13099 L .32618 .1353 L p .863 .934 .868 r
F P
0 g
s
.30474 .1433 m .31124 .13099 L p .31707 .17698 L .366 .299 .648 r
F P
0 g
s
.3174 .17691 m .31251 .17787 L .32359 .18267 L .289 .763 .934 r
F
.35102 .3687 m .32359 .36617 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32359 .36617 m .31271 .36517 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32453 .2358 m .31569 .22981 L .33062 .23358 L p .539 0 0 r
F P
0 g
s
.32453 .2358 m .31215 .17794 L .31707 .17698 L .366 .299 .648 r
F
.31215 .17794 m .30474 .1433 L .31707 .17698 L F
.33233 .18098 m .3174 .17691 L .32359 .18267 L .289 .763 .934 r
F
.33233 .18098 m .32727 .17499 L .3174 .17691 L F
.33425 .12476 m .32618 .1353 L .31124 .13099 L p .793 .945 .923 r
F P
0 g
s
.31124 .13099 m .31933 .12037 L .33425 .12476 L p .793 .945 .923 r
F P
0 g
s
.31124 .13099 m .31933 .12037 L p .32184 .17605 L .366 .299 .648 r
F P
0 g
s
.32453 .2358 m .31707 .17698 L .32184 .17605 L .366 .299 .648 r
F
.31707 .17698 m .31124 .13099 L .32184 .17605 L F
.35116 .17734 m .36433 .1074 L .35638 .17633 L .369 .301 .649 r
F
.35374 .11048 m .36433 .1074 L p .33945 .23954 L F P
0 g
s
.34357 .11636 m .35374 .11048 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.34357 .11636 m .33425 .12476 L .31933 .12037 L p .697 .936 .964 r
F P
0 g
s
.31933 .12037 m .32866 .11191 L .34357 .11636 L p .697 .936 .964 r
F P
0 g
s
.31933 .12037 m .32866 .11191 L p .32655 .17513 L .366 .299 .648 r
F P
0 g
s
.33945 .23954 m .32359 .20159 L .32359 .18845 L .369 .301 .649 r
F
.33945 .23954 m .32359 .2103 L .32359 .20159 L F
.32453 .2358 m .32184 .17605 L .32655 .17513 L .366 .299 .648 r
F
.32184 .17605 m .31933 .12037 L .32655 .17513 L F
.34111 .17928 m .33316 .17384 L .33233 .18098 L .289 .763 .934 r
F
.33316 .17384 m .32727 .17499 L .33233 .18098 L F
.34111 .17928 m .34862 .17082 L .33316 .17384 L F
.35374 .11048 m .34357 .11636 L .32866 .11191 L p .564 .897 .983 r
F P
0 g
s
.36433 .1074 m .35374 .11048 L .33885 .10599 L p .376 .81 .963 r
F P
0 g
s
.32866 .11191 m .33885 .10599 L .35374 .11048 L p .564 .897 .983 r
F P
0 g
s
.33885 .10599 m .34946 .10288 L .36433 .1074 L p .376 .81 .963 r
F P
0 g
s
.33885 .10599 m .34946 .10288 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.32866 .11191 m .33885 .10599 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.33316 .17384 m .3169 .1627 L .32727 .17499 L .289 .763 .934 r
F
.39402 .11589 m .40174 .12429 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.38493 .11014 m .39402 .11589 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.37489 .10728 m .38493 .11014 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39752 .16484 m .38651 .16342 L p .3536 .17687 L .289 .763 .934 r
F P
0 g
s
.3792 .11138 m .38651 .11936 L p .36033 .16853 L .366 .299 .648 r
F P
0 g
s
.3535 .16987 m .3792 .11138 L .36033 .16853 L .366 .299 .648 r
F
.3536 .17687 m .38651 .16342 L .35568 .16944 L .289 .763 .934 r
F
.38409 .17097 m .39752 .16484 L .3536 .17687 L F
.32453 .2358 m .38651 .11936 L .38651 .1206 L .366 .299 .648 r
F
.39752 .16484 m .38651 .16342 L p .38651 .18002 L .875 .714 .68 r
F P
0 g
s
.39692 .14311 m .39871 .15693 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.39293 .13055 m .39692 .14311 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38693 .11982 m .39293 .13055 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38651 .16342 m .35839 .1598 L p .35568 .16944 L .289 .763 .934 r
F P
0 g
s
.3536 .17687 m .35568 .16944 L .34111 .17928 L .289 .763 .934 r
F
.37489 .10728 m .36433 .1074 L .34946 .10288 L p .122 .65 .875 r
F P
0 g
s
.38493 .11014 m .37489 .10728 L .36003 .10274 L p 0 .402 .691 r
F P
0 g
s
.34946 .10288 m .36003 .10274 L .37489 .10728 L p .122 .65 .875 r
F P
0 g
s
.36003 .10274 m .37009 .10561 L .38493 .11014 L p 0 .402 .691 r
F P
0 g
s
.37009 .10561 m .3792 .11138 L p .3535 .16987 L .366 .299 .648 r
F P
0 g
s
.34717 .1711 m .37009 .10561 L .3535 .16987 L .366 .299 .648 r
F
.35568 .16944 m .35839 .1598 L .34862 .17082 L .289 .763 .934 r
F
.35568 .16944 m .34862 .17082 L .34111 .17928 L F
.32453 .2358 m .34717 .1711 L .3535 .16987 L .366 .299 .648 r
F
.32453 .2358 m .3535 .16987 L .36033 .16853 L F
.38651 .11936 m .38693 .11982 L p .38651 .1206 L F P
0 g
s
.32453 .2358 m .38651 .20179 L .38381 .212 L .366 .299 .648 r
F
.35839 .21722 m .35839 .21876 L p .36024 .21621 L .875 .714 .68 r
F P
0 g
s
.38651 .18002 m .38651 .20705 L .38876 .20611 L .875 .714 .68 r
F
.39547 .18581 m .39059 .19955 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.40132 .302 m .39868 .20661 L .39752 .35291 L .971 .793 .367 r
F
.39752 .16484 m .39752 .20294 L p .39868 .20661 L F P
0 g
s
.39752 .20294 m .39752 .35291 L p .39868 .20661 L .971 .793 .367 r
F P
0 g
s
.40132 .16764 m .39752 .16484 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.39547 .18581 m .3937 .19079 L p .40539 .20357 L .917 .917 .801 r
F P
0 g
s
.3937 .19079 m .39059 .19955 L .39701 .2013 L p .917 .917 .801 r
F P
0 g
s
.39701 .2013 m .40539 .20357 L p .3937 .19079 L .917 .917 .801 r
F P
0 g
s
.39822 .17138 m .39547 .18581 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.39871 .15693 m .39822 .17138 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38651 .18002 m .35839 .21722 L .36024 .21621 L .875 .714 .68 r
F
.35839 .1598 m .35839 .21722 L p .38651 .18002 L F P
0 g
s
.38651 .16342 m .35839 .1598 L p .38651 .18002 L .875 .714 .68 r
F P
0 g
s
.36003 .10274 m .37009 .10561 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.34946 .10288 m .36003 .10274 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.35839 .1598 m .3169 .1627 L p .33316 .17384 L .289 .763 .934 r
F P
0 g
s
.34862 .17082 m .35839 .1598 L .33316 .17384 L .289 .763 .934 r
F
.3174 .17691 m .29824 .17169 L .31251 .17787 L F
.29824 .17169 m .30865 .17862 L p .31251 .17787 L F P
0 g
s
.32453 .2358 m .30696 .17895 L .31215 .17794 L .366 .299 .648 r
F
.3169 .1627 m .29824 .17169 L p .3174 .17691 L .289 .763 .934 r
F P
0 g
s
.32727 .17499 m .3169 .1627 L .3174 .17691 L .289 .763 .934 r
F
.30865 .18444 m .30454 .17942 L .30696 .17895 L .366 .299 .648 r
F
.32453 .2358 m .30865 .19765 L .30865 .18444 L F
.30865 .19765 m .29749 .17083 L .30865 .18444 L F
.30865 .20744 m .31271 .21761 L .31188 .21852 L .981 .801 .395 r
F
.29872 .19836 m .29702 .18489 L p .30865 .20641 L .366 .299 .648 r
F P
0 g
s
.30865 .21277 m .29872 .19836 L .30865 .20641 L .366 .299 .648 r
F
.29824 .17169 m .30865 .20474 L .30865 .20744 L .981 .801 .395 r
F
.30865 .20474 m .31271 .21761 L .30865 .20744 L F
.29824 .17169 m .30865 .17862 L p .30865 .20474 L F P
0 g
s
.32453 .2358 m .30865 .21277 L .30865 .20641 L .366 .299 .648 r
F
.29824 .17169 m .30865 .20744 L .30251 .22882 L .981 .801 .395 r
F
.30865 .20744 m .30865 .22207 L .30251 .22882 L F
.32453 .2358 m .30865 .20641 L .30865 .19765 L .366 .299 .648 r
F
.32453 .2358 m .31569 .22981 L .30865 .22178 L p F P
0 g
s
.32453 .2358 m .30865 .22178 L .30865 .22167 L .366 .299 .648 r
F
.32453 .2358 m .30865 .22167 L .30865 .21768 L F
.30865 .22207 m .30865 .22432 L .30251 .22882 L .981 .801 .395 r
F
.32453 .2358 m .30865 .21768 L .30865 .21277 L .366 .299 .648 r
F
.38651 .20705 m .38381 .212 L p .38651 .20179 L F P
0 g
s
.38651 .18002 m .35839 .21876 L .38651 .20705 L .875 .714 .68 r
F
.39059 .19955 m .38651 .20705 L p .38651 .20179 L .366 .299 .648 r
F P
0 g
s
.39059 .19955 m .38651 .20705 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.38651 .20705 m .38381 .212 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.35977 .24299 m .34931 .24273 L .33945 .23954 L p .369 .301 .649 r
F P
0 g
s
.3704 .24028 m .35977 .24299 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.38072 .2347 m .3704 .24028 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39027 .22647 m .38072 .2347 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.34931 .24273 m .35977 .24299 L .34489 .23924 L p .067 .616 .835 r
F P
0 g
s
.35977 .24299 m .3704 .24028 L .35554 .23651 L p .337 .794 .943 r
F P
0 g
s
.35554 .23651 m .34489 .23924 L .35977 .24299 L p .337 .794 .943 r
F P
0 g
s
.33062 .23358 m .33945 .23954 L .32453 .2358 L p .539 0 0 r
F P
0 g
s
.36587 .23089 m .35554 .23651 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.37544 .2226 m .36587 .23089 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38381 .212 m .37544 .2226 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.3704 .24028 m .38072 .2347 L .36587 .23089 L p .539 .895 .976 r
F P
0 g
s
.36587 .23089 m .35554 .23651 L .3704 .24028 L p .539 .895 .976 r
F P
0 g
s
.38072 .2347 m .39027 .22647 L .37544 .2226 L p .685 .941 .963 r
F P
0 g
s
.37544 .2226 m .36587 .23089 L .38072 .2347 L p .685 .941 .963 r
F P
0 g
s
.38381 .212 m .37544 .2226 L .39027 .22647 L p .788 .954 .924 r
F P
0 g
s
.35839 .21876 m .35839 .34916 L p .38876 .20611 L .875 .714 .68 r
F P
0 g
s
.35839 .34916 m .39752 .35291 L .39752 .20246 L p .875 .714 .68 r
F P
0 g
s
.38876 .20611 m .35839 .34916 L .39752 .20246 L .875 .714 .68 r
F
.39059 .19955 m .39295 .20437 L .39449 .20373 L .863 .944 .869 r
F
.40132 .21102 m .40539 .20357 L .39701 .2013 L p F P
0 g
s
.41171 .14746 m .4135 .1612 L p .40132 .17409 L .369 .301 .649 r
F P
0 g
s
.40132 .1607 m .41171 .14746 L .40132 .17409 L .369 .301 .649 r
F
.4135 .1612 m .41336 .16532 L p .40877 .1662 L F P
0 g
s
.41336 .16532 m .41301 .17557 L p .40877 .1662 L .369 .301 .649 r
F P
0 g
s
.31271 .36517 m .29824 .358 L .29824 .17169 L p .981 .801 .395 r
F P
0 g
s
.29824 .358 m .3169 .35131 L .3169 .1627 L p 0 0 .481 r
F P
0 g
s
.3169 .1627 m .29824 .17169 L .29824 .358 L p 0 0 .481 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.29824 .358 m .31271 .36517 L .35102 .3687 L p .224 .73 .894 r
F P
0 g
s
.3169 .35131 m .29824 .358 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.35839 .34916 m .3169 .35131 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.39752 .35291 m .35839 .34916 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.41081 .3602 m .39752 .35291 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.35102 .3687 m .39131 .36668 L .41081 .3602 L p .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.33945 .23954 m .34931 .24273 L .33441 .23899 L p .246 0 0 r
F P
0 g
s
.33441 .23899 m .32453 .2358 L .33945 .23954 L p .246 0 0 r
F P
0 g
s
.34489 .23924 m .33441 .23899 L .34931 .24273 L p .067 .616 .835 r
F P
0 g
s
.34489 .23924 m .33441 .23899 L .32453 .2358 L p .366 .299 .648 r
F P
0 g
s
.35554 .23651 m .34489 .23924 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.3169 .35131 m .35839 .34916 L .35839 .1598 L p .59 .482 .699 r
F P
0 g
s
.35839 .1598 m .3169 .1627 L .3169 .35131 L p .59 .482 .699 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59802 .18889 m .59816 .18489 L p .61053 .20159 L .393 .321 .656 r
F P
0 g
s
.59816 .18489 m .59852 .17491 L p .60265 .18408 L .393 .321 .656 r
F P
0 g
s
.61053 .20159 m .59816 .18489 L .60265 .18408 L .393 .321 .656 r
F
.59852 .17491 m .59802 .18889 L .58466 .18489 L p .979 .818 .612 r
F P
0 g
s
.59852 .17491 m .60132 .16093 L p .6087 .18299 L .393 .321 .656 r
F P
0 g
s
.60132 .16093 m .59852 .17491 L .58517 .17083 L p .958 .881 .715 r
F P
0 g
s
.61053 .23457 m .61424 .22767 L .63659 .3687 L .877 .716 .679 r
F
.63659 .18607 m .63659 .24023 L p .61424 .22767 L F P
0 g
s
.63659 .24023 m .63659 .3687 L p .61424 .22767 L .877 .716 .679 r
F P
0 g
s
.61009 .22512 m .61053 .22558 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.60132 .16093 m .60632 .14754 L p .61053 .16571 L .393 .321 .656 r
F P
0 g
s
.61053 .18267 m .63659 .18607 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.61053 .18267 m .63659 .18607 L p .61994 .18098 L .289 .763 .934 r
F P
0 g
s
.62761 .23954 m .61053 .18845 L .61053 .16571 L .393 .321 .656 r
F
.61053 .18845 m .60132 .16093 L .61053 .16571 L F
.61053 .18845 m .6061 .18346 L .6087 .18299 L F
.6061 .18346 m .59852 .17491 L .6087 .18299 L F
.61053 .20159 m .59852 .17491 L .61053 .18845 L F
.61053 .2103 m .59802 .18889 L .61053 .20159 L F
.59984 .20229 m .59802 .18889 L p .62761 .23954 L F P
0 g
s
.60392 .21454 m .59984 .20229 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.61009 .22512 m .60392 .21454 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.60392 .21454 m .61009 .22512 L .60931 .2249 L p .87 .427 .113 r
F P
0 g
s
.60857 .22448 m .61053 .22587 L .61053 .23457 L .877 .716 .679 r
F
.60853 .22427 m .60931 .2249 L .60857 .22448 L F
.60931 .2249 m .61053 .22587 L .60857 .22448 L F
.60045 .21783 m .60392 .21454 L .60931 .2249 L .87 .427 .113 r
F
.60018 .36517 m .60018 .22135 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.59984 .20229 m .60313 .21217 L p .59202 .21109 L .948 .603 .32 r
F P
0 g
s
.60313 .21217 m .60392 .21454 L .6025 .21413 L p .948 .603 .32 r
F P
0 g
s
.6025 .21413 m .59202 .21109 L p .60313 .21217 L .948 .603 .32 r
F P
0 g
s
.59123 .2101 m .59984 .20229 L .59202 .21109 L .948 .603 .32 r
F
.60018 .21761 m .60018 .22135 L p .59957 .21852 L .947 .773 .313 r
F P
0 g
s
.60018 .22135 m .60018 .36517 L p .5972 .31096 L .947 .773 .313 r
F P
0 g
s
.59344 .24233 m .5972 .23061 L .5972 .31096 L .947 .773 .313 r
F
.5972 .23061 m .60018 .22135 L .5972 .31096 L F
.60018 .22135 m .60018 .21761 L p .61047 .2343 L .877 .716 .679 r
F P
0 g
s
.59202 .21109 m .6025 .21413 L p .5999 .21739 L .87 .427 .113 r
F P
0 g
s
.60853 .22427 m .61047 .2343 L .60018 .21761 L .877 .716 .679 r
F
.6025 .21413 m .60392 .21454 L p .59932 .2189 L .87 .427 .113 r
F P
0 g
s
.59677 .22131 m .6025 .21413 L .59932 .2189 L .87 .427 .113 r
F
.60018 .21761 m .60018 .18132 L p .60853 .22427 L .877 .716 .679 r
F P
0 g
s
.59677 .22131 m .59058 .21068 L .59202 .21109 L p .87 .427 .113 r
F P
0 g
s
.59677 .22131 m .59202 .21109 L .5999 .21739 L .87 .427 .113 r
F
.5972 .22432 m .60018 .22135 L .5972 .23061 L .947 .773 .313 r
F
.59677 .22131 m .59058 .21068 L p .5972 .21768 L .391 .319 .656 r
F P
0 g
s
.5972 .22178 m .59677 .22131 L .59755 .22154 L p .724 .193 0 r
F P
0 g
s
.59755 .22154 m .59677 .22131 L p .59932 .2189 L .87 .427 .113 r
F P
0 g
s
.5972 .22167 m .59677 .22131 L .5972 .21768 L .391 .319 .656 r
F
.59802 .18889 m .59984 .20229 L .5865 .19836 L p .979 .729 .483 r
F P
0 g
s
.5865 .19836 m .58466 .18489 L .59802 .18889 L p .979 .729 .483 r
F P
0 g
s
.58466 .18489 m .58517 .17083 L .59852 .17491 L p .979 .818 .612 r
F P
0 g
s
.59058 .21068 m .5865 .19836 L .59984 .20229 L p .948 .603 .32 r
F P
0 g
s
.58466 .18489 m .58517 .17083 L p .5972 .19765 L .391 .319 .656 r
F P
0 g
s
.59248 .22497 m .59755 .22154 L .59269 .22882 L .947 .773 .313 r
F
.59957 .21852 m .60018 .22135 L .5972 .22432 L F
.5972 .22207 m .5972 .22432 L .59269 .22882 L F
.59957 .21852 m .5972 .22432 L .5972 .22207 L F
.59202 .21109 m .59058 .21068 L p .59123 .2101 L .948 .603 .32 r
F P
0 g
s
.59058 .21068 m .5865 .19836 L p .5972 .21277 L .391 .319 .656 r
F P
0 g
s
.6076 .22676 m .60549 .22391 L .60931 .2249 L .724 .193 0 r
F
.61047 .2343 m .61053 .23457 L .60018 .22135 L .877 .716 .679 r
F
.60479 .22981 m .60549 .22391 L .6076 .22676 L .724 .193 0 r
F
.60479 .22981 m .5972 .22178 L p .60549 .22391 L F P
0 g
s
.5972 .21935 m .59957 .21852 L .59755 .22154 L .947 .773 .313 r
F
.5972 .20744 m .59957 .21852 L .5972 .21935 L F
.59755 .22154 m .60931 .2249 L p .5972 .22178 L .724 .193 0 r
F P
0 g
s
.60931 .2249 m .59755 .22154 L p .60045 .21783 L .87 .427 .113 r
F P
0 g
s
.59932 .2189 m .60045 .21783 L .59755 .22154 L .87 .427 .113 r
F
.5972 .20641 m .58466 .18489 L .5972 .19765 L .391 .319 .656 r
F
.60018 .18132 m .60018 .21761 L p .5972 .20474 L .947 .773 .313 r
F P
0 g
s
.5972 .17862 m .60018 .18132 L p .5972 .20474 L .947 .773 .313 r
F P
0 g
s
.58517 .17083 m .58798 .15677 L .60132 .16093 L p .958 .881 .715 r
F P
0 g
s
.58517 .17083 m .58798 .15677 L p .59537 .17895 L .391 .319 .656 r
F P
0 g
s
.60632 .14754 m .61331 .1353 L p .61959 .18104 L .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .61429 .18199 L .61959 .18104 L .393 .321 .656 r
F
.61429 .18199 m .60632 .14754 L .61959 .18104 L F
.63659 .18607 m .6294 .17928 L .61994 .18098 L .289 .763 .934 r
F
.61331 .1353 m .62201 .12476 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.63659 .18607 m .64285 .17687 L .6294 .17928 L .289 .763 .934 r
F
.62201 .12476 m .63205 .11636 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67797 .36668 m .63659 .3687 L .63659 .18607 L p .597 .488 .7 r
F P
0 g
s
.63659 .18607 m .67797 .18336 L .67797 .36668 L p .597 .488 .7 r
F P
0 g
s
.66579 .10728 m .67661 .11014 L p .65196 .17523 L .393 .321 .656 r
F P
0 g
s
.63659 .18607 m .6757 .17097 L .64285 .17687 L .289 .763 .934 r
F
.70095 .17465 m .69426 .16764 L p .63659 .18607 L F P
0 g
s
.63659 .18607 m .69426 .16764 L .6757 .17097 L .289 .763 .934 r
F
.63659 .18607 m .67797 .18336 L .70095 .17465 L p F P
0 g
s
.70095 .3602 m .67797 .36668 L .67797 .18336 L p .083 .068 .54 r
F P
0 g
s
.67797 .18336 m .70095 .17465 L .70095 .3602 L p .083 .068 .54 r
F P
0 g
s
.70095 .17465 m .69426 .16764 L p .69426 .21102 L .928 .758 .278 r
F P
0 g
s
.69835 .22411 m .69426 .21102 L .69426 .302 L .928 .758 .278 r
F
.70095 .17465 m .69426 .21102 L .69835 .22411 L F
.69865 .20357 m .69136 .21594 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.70095 .3602 m .70095 .17465 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.7039 .18991 m .69865 .20357 L p .69426 .20579 L .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .69426 .19618 L .69426 .20579 L .393 .321 .656 r
F
.69426 .19618 m .7039 .18991 L .69426 .20579 L F
.69159 .35291 m .69426 .35499 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.69426 .35499 m .70095 .3602 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.70686 .17557 m .7039 .18991 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.69136 .21594 m .69426 .21102 L p .68871 .20373 L .862 .958 .868 r
F P
0 g
s
.68725 .20437 m .69136 .21594 L .68871 .20373 L .862 .958 .868 r
F
.62761 .23954 m .69426 .1607 L .69426 .17409 L .393 .321 .656 r
F
.70117 .13497 m .70546 .14746 L p .62761 .23954 L F P
0 g
s
.69471 .12429 m .70117 .13497 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.69426 .16764 m .69159 .16484 L p .6757 .17097 L .289 .763 .934 r
F P
0 g
s
.62761 .23954 m .70229 .1662 L .70686 .17557 L .393 .321 .656 r
F
.69159 .20246 m .69159 .16484 L p .68327 .20611 L .882 .72 .677 r
F P
0 g
s
.69122 .2013 m .68554 .19955 L p .69426 .21102 L .862 .958 .868 r
F P
0 g
s
.69136 .21594 m .68236 .22647 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.68236 .22647 m .69136 .21594 L .67823 .212 L p .781 .963 .923 r
F P
0 g
s
.67823 .212 m .69136 .21594 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.69159 .16484 m .68114 .18002 L .68327 .20611 L .882 .72 .677 r
F
.62761 .23954 m .64585 .17633 L .65196 .17523 L .393 .321 .656 r
F
.62761 .23954 m .61053 .20159 L .61053 .18845 L F
.62761 .23954 m .61053 .2103 L .61053 .20159 L F
.62761 .23954 m .6181 .23358 L .61009 .22512 L p F P
0 g
s
.6181 .23358 m .62761 .23954 L .61432 .2358 L p .497 0 0 r
F P
0 g
s
.6864 .11589 m .69471 .12429 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67661 .11014 m .6864 .11589 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.65442 .1074 m .66579 .10728 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.64301 .11048 m .65442 .1074 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.63205 .11636 m .64301 .11048 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.61432 .2358 m .68114 .20179 L .67823 .212 L .391 .319 .656 r
F
.68114 .20705 m .67823 .212 L p .68114 .20179 L F P
0 g
s
.68114 .18002 m .68114 .20705 L .68327 .20611 L .882 .72 .677 r
F
.6908 .18581 m .68554 .19955 L p .68114 .20179 L .391 .319 .656 r
F P
0 g
s
.60018 .18132 m .61053 .18267 L p .61053 .22587 L .877 .716 .679 r
F P
0 g
s
.60931 .2249 m .61009 .22512 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.60018 .18132 m .61053 .22587 L .60853 .22427 L .877 .716 .679 r
F
.6181 .23358 m .60479 .22981 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.61053 .22558 m .6181 .23358 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.61432 .2358 m .60479 .22981 L .6181 .23358 L p .497 0 0 r
F P
0 g
s
.61432 .2358 m .68114 .19212 L .68114 .20179 L .391 .319 .656 r
F
.68114 .19212 m .6908 .18581 L .68114 .20179 L F
.64585 .17633 m .66579 .10728 L .65196 .17523 L .393 .321 .656 r
F
.69159 .16484 m .68114 .16342 L p .64285 .17687 L .289 .763 .934 r
F P
0 g
s
.64285 .17687 m .68114 .16342 L .64791 .16944 L .289 .763 .934 r
F
.6757 .17097 m .69159 .16484 L .64285 .17687 L F
.69159 .16484 m .68114 .16342 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.69236 .14311 m .6943 .15693 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.68806 .13055 m .69236 .14311 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.68159 .11982 m .68806 .13055 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.67326 .11138 m .68159 .11982 L p .65339 .16845 L .391 .319 .656 r
F P
0 g
s
.64556 .16987 m .67326 .11138 L .65339 .16845 L .391 .319 .656 r
F
.64285 .17687 m .64791 .16944 L .6294 .17928 L .289 .763 .934 r
F
.66579 .10728 m .65442 .1074 L .6412 .10288 L p .136 .657 .884 r
F P
0 g
s
.67661 .11014 m .66579 .10728 L .65259 .10274 L p 0 .43 .725 r
F P
0 g
s
.6412 .10288 m .65259 .10274 L .66579 .10728 L p .136 .657 .884 r
F P
0 g
s
.65259 .10274 m .66344 .10561 L .67661 .11014 L p 0 .43 .725 r
F P
0 g
s
.66344 .10561 m .67326 .11138 L p .64556 .16987 L .391 .319 .656 r
F P
0 g
s
.63873 .1711 m .66344 .10561 L .64556 .16987 L .391 .319 .656 r
F
.64791 .16944 m .65446 .1598 L .64029 .17082 L .289 .763 .934 r
F
.64791 .16944 m .64029 .17082 L .6294 .17928 L F
.6294 .17928 m .64029 .17082 L .62363 .17384 L F
.61432 .2358 m .63873 .1711 L .64556 .16987 L .391 .319 .656 r
F
.61432 .2358 m .64556 .16987 L .65339 .16845 L F
.61994 .18098 m .61728 .17499 L .60664 .17691 L .289 .763 .934 r
F
.61331 .1353 m .60632 .14754 L .59299 .1433 L p .863 .948 .869 r
F P
0 g
s
.62201 .12476 m .61331 .1353 L .6 .13099 L p .788 .955 .924 r
F P
0 g
s
.59299 .1433 m .6 .13099 L .61331 .1353 L p .863 .948 .869 r
F P
0 g
s
.63205 .11636 m .62201 .12476 L .60871 .12037 L p .688 .94 .963 r
F P
0 g
s
.6 .13099 m .60871 .12037 L .62201 .12476 L p .788 .955 .924 r
F P
0 g
s
.60871 .12037 m .61877 .11191 L .63205 .11636 L p .688 .94 .963 r
F P
0 g
s
.60871 .12037 m .61877 .11191 L p .6165 .17513 L .391 .319 .656 r
F P
0 g
s
.61994 .18098 m .60664 .17691 L .61053 .18267 L .289 .763 .934 r
F
.60632 .14754 m .60132 .16093 L .58798 .15677 L p .919 .923 .8 r
F P
0 g
s
.58798 .15677 m .59299 .1433 L .60632 .14754 L p .919 .923 .8 r
F P
0 g
s
.58798 .15677 m .59299 .1433 L p .60098 .17794 L .391 .319 .656 r
F P
0 g
s
.59537 .17895 m .58798 .15677 L .60098 .17794 L .391 .319 .656 r
F
.60664 .17691 m .60136 .17787 L .61053 .18267 L .289 .763 .934 r
F
.59299 .1433 m .6 .13099 L p .60628 .17698 L .391 .319 .656 r
F P
0 g
s
.60018 .18132 m .61053 .18267 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.5972 .17862 m .60018 .18132 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.61432 .2358 m .60098 .17794 L .60628 .17698 L .391 .319 .656 r
F
.60098 .17794 m .59299 .1433 L .60628 .17698 L F
.58956 .17169 m .5972 .17862 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.6 .13099 m .60871 .12037 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.60664 .17691 m .58956 .17169 L .60136 .17787 L .289 .763 .934 r
F
.61432 .2358 m .59537 .17895 L .60098 .17794 L .391 .319 .656 r
F
.61432 .2358 m .61142 .17605 L .6165 .17513 L F
.61142 .17605 m .60871 .12037 L .6165 .17513 L F
.6294 .17928 m .62363 .17384 L .61994 .18098 L .289 .763 .934 r
F
.62363 .17384 m .61728 .17499 L .61994 .18098 L F
.64301 .11048 m .63205 .11636 L .61877 .11191 L p .553 .896 .98 r
F P
0 g
s
.65442 .1074 m .64301 .11048 L .62976 .10599 L p .373 .808 .961 r
F P
0 g
s
.61877 .11191 m .62976 .10599 L .64301 .11048 L p .553 .896 .98 r
F P
0 g
s
.62976 .10599 m .6412 .10288 L .65442 .1074 L p .373 .808 .961 r
F P
0 g
s
.62976 .10599 m .6412 .10288 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.61877 .11191 m .62976 .10599 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.62363 .17384 m .61182 .1627 L .61728 .17499 L .289 .763 .934 r
F
.65259 .10274 m .66344 .10561 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.6412 .10288 m .65259 .10274 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .61182 .1627 L p .62363 .17384 L .289 .763 .934 r
F P
0 g
s
.64029 .17082 m .65446 .1598 L .62363 .17384 L .289 .763 .934 r
F
.68114 .16342 m .65446 .1598 L p .64791 .16944 L F P
0 g
s
.69426 .302 m .6924 .20661 L .69159 .35291 L .928 .758 .278 r
F
.69159 .16484 m .69159 .20294 L p .6924 .20661 L F P
0 g
s
.69159 .20294 m .69159 .35291 L p .6924 .20661 L .928 .758 .278 r
F P
0 g
s
.69426 .16764 m .69159 .16484 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.6908 .18581 m .68889 .19079 L p .69865 .20357 L .922 .933 .797 r
F P
0 g
s
.68889 .19079 m .68554 .19955 L .69122 .2013 L p .922 .933 .797 r
F P
0 g
s
.69122 .2013 m .69865 .20357 L p .68889 .19079 L .922 .933 .797 r
F P
0 g
s
.61432 .2358 m .68919 .16197 L .69377 .17138 L .391 .319 .656 r
F
.6943 .15693 m .69414 .16107 L p .68919 .16197 L F P
0 g
s
.69414 .16107 m .69377 .17138 L p .68919 .16197 L .391 .319 .656 r
F P
0 g
s
.69377 .17138 m .6908 .18581 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .65446 .21876 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.68114 .16342 m .65446 .1598 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.68114 .18002 m .65446 .21876 L .68114 .20705 L .882 .72 .677 r
F
.68554 .19955 m .68114 .20705 L p .68114 .20179 L .391 .319 .656 r
F P
0 g
s
.68554 .19955 m .68114 .20705 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.68114 .20705 m .67823 .212 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.66095 .24028 m .6495 .24299 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67207 .2347 m .66095 .24028 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.68236 .22647 m .67207 .2347 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.6495 .24299 m .66095 .24028 L .64775 .23651 L p .332 .793 .941 r
F P
0 g
s
.65889 .23089 m .64775 .23651 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.66921 .2226 m .65889 .23089 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.67823 .212 m .66921 .2226 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.66095 .24028 m .67207 .2347 L .65889 .23089 L p .527 .893 .972 r
F P
0 g
s
.65889 .23089 m .64775 .23651 L .66095 .24028 L p .527 .893 .972 r
F P
0 g
s
.67207 .2347 m .68236 .22647 L .66921 .2226 L p .673 .945 .961 r
F P
0 g
s
.66921 .2226 m .65889 .23089 L .67207 .2347 L p .673 .945 .961 r
F P
0 g
s
.67823 .212 m .66921 .2226 L .68236 .22647 L p .781 .963 .923 r
F P
0 g
s
.65446 .21876 m .65446 .34916 L p .68327 .20611 L .882 .72 .677 r
F P
0 g
s
.65446 .34916 m .69159 .35291 L .69159 .20246 L p .882 .72 .677 r
F P
0 g
s
.68327 .20611 m .65446 .34916 L .69159 .20246 L .882 .72 .677 r
F
.68554 .19955 m .68725 .20437 L .68871 .20373 L .862 .958 .868 r
F
.69426 .21102 m .69865 .20357 L .69122 .2013 L p F P
0 g
s
.70546 .14746 m .70738 .1612 L p .69426 .17409 L .393 .321 .656 r
F P
0 g
s
.69426 .1607 m .70546 .14746 L .69426 .17409 L .393 .321 .656 r
F
.70738 .1612 m .70723 .16532 L p .70229 .1662 L F P
0 g
s
.70723 .16532 m .70686 .17557 L p .70229 .1662 L .393 .321 .656 r
F P
0 g
s
.61182 .1627 m .58956 .17169 L p .60664 .17691 L .289 .763 .934 r
F P
0 g
s
.61728 .17499 m .61182 .1627 L .60664 .17691 L .289 .763 .934 r
F
.5972 .18444 m .59277 .17942 L .59537 .17895 L .391 .319 .656 r
F
.59277 .17942 m .58517 .17083 L .59537 .17895 L F
.60479 .22981 m .60931 .2249 L .60994 .22525 L .724 .193 0 r
F
.61432 .2358 m .5972 .19765 L .5972 .18444 L .391 .319 .656 r
F
.5972 .19765 m .58517 .17083 L .5972 .18444 L F
.5865 .19836 m .58466 .18489 L p .5972 .20641 L F P
0 g
s
.5972 .21277 m .5865 .19836 L .5972 .20641 L .391 .319 .656 r
F
.5972 .21768 m .59058 .21068 L .5972 .21277 L F
.58956 .17169 m .5972 .21935 L .59248 .22497 L .947 .773 .313 r
F
.5972 .21935 m .59755 .22154 L .5972 .22178 L F
.5972 .22178 m .59677 .22131 L p .5972 .22167 L .391 .319 .656 r
F P
0 g
s
.5972 .21935 m .5972 .22178 L .59248 .22497 L .947 .773 .313 r
F
.58956 .17169 m .5972 .17862 L p .5972 .20474 L F P
0 g
s
.58956 .17169 m .60018 .21761 L .59957 .21852 L .947 .773 .313 r
F
.61432 .2358 m .5972 .21277 L .5972 .20641 L .391 .319 .656 r
F
.61432 .2358 m .5972 .21768 L .5972 .21277 L F
.61432 .2358 m .5972 .20641 L .5972 .19765 L F
.58956 .17169 m .5972 .20744 L .5972 .21935 L .947 .773 .313 r
F
.61432 .2358 m .60479 .22981 L .5972 .22178 L p .391 .319 .656 r
F P
0 g
s
.61432 .2358 m .5972 .22178 L .5972 .22167 L .391 .319 .656 r
F
.59269 .22882 m .5972 .22432 L .59344 .24233 L .947 .773 .313 r
F
.5972 .22432 m .5972 .23061 L .59344 .24233 L F
.61432 .2358 m .5972 .22167 L .5972 .21768 L .391 .319 .656 r
F
.63659 .3687 m .61053 .36617 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.61053 .36617 m .60018 .36517 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.60018 .36517 m .58956 .358 L .58956 .17169 L p .947 .773 .313 r
F P
0 g
s
.58956 .358 m .61182 .35131 L .61182 .1627 L p .052 .042 .525 r
F P
0 g
s
.61182 .1627 m .58956 .17169 L .58956 .358 L p .052 .042 .525 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58956 .358 m .60018 .36517 L .63659 .3687 L p .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61182 .35131 m .58956 .358 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.65446 .34916 m .61182 .35131 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.69159 .35291 m .65446 .34916 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.70095 .3602 m .69159 .35291 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.63659 .3687 m .67797 .36668 L .70095 .3602 L p .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6495 .24299 m .63823 .24273 L .62761 .23954 L p .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .63823 .24273 L .62497 .23899 L p .211 0 0 r
F P
0 g
s
.63823 .24273 m .6495 .24299 L .63627 .23924 L p .081 .625 .846 r
F P
0 g
s
.62497 .23899 m .61432 .2358 L .62761 .23954 L p .211 0 0 r
F P
0 g
s
.63627 .23924 m .62497 .23899 L .63823 .24273 L p .081 .625 .846 r
F P
0 g
s
.64775 .23651 m .63627 .23924 L .6495 .24299 L p .332 .793 .941 r
F P
0 g
s
.64775 .23651 m .63627 .23924 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.61182 .35131 m .65446 .34916 L .65446 .1598 L p .593 .484 .699 r
F P
0 g
s
.63627 .23924 m .62497 .23899 L .61432 .2358 L p .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .61182 .1627 L .61182 .35131 L p .593 .484 .699 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.401 1.29226 m .41389 1.27286 L .42691 1.29654 L p .208 .17 .593 r
F P
0 g
s
.42691 1.29654 m .41389 1.31592 L .401 1.29226 L p .208 .17 .593 r
F P
0 g
s
.5723 1.29226 m .58611 1.27286 L .60008 1.29654 L p .238 .195 .605 r
F P
0 g
s
.60008 1.29654 m .58611 1.31592 L .5723 1.29226 L p .238 .195 .605 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.71872 .79305 m .71787 .7784 L .71828 .77752 L p 0 0 .217 r
F P
0 g
s
.72043 .81454 m .75756 .78483 L .73646 .76961 L p .651 .305 .374 r
F P
0 g
s
.73646 .76961 m .71701 .75558 L p .71828 .77752 L .651 .305 .374 r
F P
0 g
s
.71828 .77752 m .71913 .79217 L .73646 .76961 L .651 .305 .374 r
F
.72977 .72344 m .74563 .71885 L .71828 .77752 L p .765 .976 .918 r
F P
0 g
s
.71828 .77752 m .71787 .7784 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.71872 .79305 m .71828 .77752 L .71912 .79195 L 0 0 .217 r
F
.71107 .75129 m .67982 .77583 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.71107 .75129 m .69041 .78023 L .71269 .77995 L .651 .305 .374 r
F
.69041 .78023 m .68068 .79387 L .70147 .78483 L F
.69041 .78023 m .70147 .78483 L .71269 .77995 L F
.71269 .77995 m .70201 .78659 L .70086 .78283 L p .835 .924 .892 r
F P
0 g
s
.71789 .77869 m .7127 .78014 L .71854 .79267 L .752 .386 .361 r
F
.71872 .79305 m .7187 .79276 L p .71854 .79267 L F P
0 g
s
.7187 .79276 m .71789 .77869 L p .71854 .79267 L .752 .386 .361 r
F P
0 g
s
.71789 .77869 m .71787 .7784 L .71269 .77995 L p .752 .386 .361 r
F P
0 g
s
.71324 .78972 m .71872 .79305 L p .71854 .79267 L .752 .386 .361 r
F P
0 g
s
.7127 .78014 m .71324 .78972 L .71854 .79267 L .752 .386 .361 r
F
.70489 .7848 m .70201 .78659 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71318 .78864 m .70489 .7848 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71269 .77995 m .70147 .78483 L .71324 .78972 L .651 .305 .374 r
F
.71269 .77995 m .70228 .78306 L p .7127 .78014 L .752 .386 .361 r
F P
0 g
s
.71269 .77995 m .7127 .78014 L .71789 .77869 L .752 .386 .361 r
F
.71787 .7784 m .71269 .77995 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.74563 .71885 m .74661 .7336 L .71872 .79305 L p 0 0 .217 r
F P
0 g
s
.71324 .78972 m .71872 .79305 L .71913 .79217 L p .388 .543 .888 r
F P
0 g
s
.71701 .75558 m .71107 .75129 L p .71699 .79128 L .651 .305 .374 r
F P
0 g
s
.71699 .79128 m .72043 .81454 L .71913 .79217 L .651 .305 .374 r
F
.71699 .79128 m .71913 .79217 L .71701 .75558 L F
.71828 .77752 m .74563 .71885 L p .71912 .79195 L 0 0 .217 r
F P
0 g
s
.71489 .81897 m .72043 .81454 L p .71107 .75129 L .651 .305 .374 r
F P
0 g
s
.71324 .78972 m .71913 .79217 L .71885 .791 L .388 .543 .888 r
F
.71504 .77849 m .71507 .7786 L p .71802 .77663 L .538 .22 .377 r
F P
0 g
s
.68386 .72713 m .70025 .717 L .71802 .77663 L p .835 .924 .892 r
F P
0 g
s
.71802 .77663 m .70463 .73168 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.71804 .77762 m .71485 .77872 L .71804 .77692 L .765 .976 .918 r
F
.71802 .77663 m .71269 .77995 L p .68386 .72713 L .835 .924 .892 r
F P
0 g
s
.70086 .78283 m .68386 .72713 L p .71269 .77995 L .835 .924 .892 r
F P
0 g
s
.71269 .77995 m .70228 .78306 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.71804 .77762 m .71821 .77682 L .71828 .77752 L .765 .976 .918 r
F
.71821 .77682 m .72977 .72344 L .71846 .77668 L F
.71821 .77682 m .71846 .77668 L .71828 .77752 L F
.71507 .7786 m .71887 .79129 L .71804 .77692 L p .538 .22 .377 r
F P
0 g
s
.71804 .77692 m .71802 .77663 L p .71507 .7786 L .538 .22 .377 r
F P
0 g
s
.71804 .77692 m .71802 .77663 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.71821 .77682 m .71803 .77689 L .72977 .72344 L .765 .976 .918 r
F
.70228 .78306 m .71193 .76213 L p .71803 .77689 L F P
0 g
s
.71193 .76213 m .72977 .72344 L p .71803 .77689 L .765 .976 .918 r
F P
0 g
s
.71485 .77872 m .70228 .78306 L .71821 .77682 L .765 .976 .918 r
F
.71885 .791 m .71804 .77692 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.7196 .79117 m .74661 .7336 L p .71702 .78336 L .388 .543 .888 r
F P
0 g
s
.71766 .79073 m .71318 .78864 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71324 .78972 m .71885 .791 L .71702 .78336 L .388 .543 .888 r
F
.71885 .791 m .7196 .79117 L .71702 .78336 L F
.71814 .77717 m .71804 .77692 L .71821 .77682 L .765 .976 .918 r
F
.71804 .77762 m .71804 .77692 L .71814 .77717 L F
.70228 .78306 m .71324 .78972 L p .7127 .78014 L .752 .386 .361 r
F P
0 g
s
.70228 .78306 m .71324 .78972 L p .74661 .7336 L .388 .543 .888 r
F P
0 g
s
.74661 .7336 m .72977 .72344 L .70228 .78306 L p .388 .543 .888 r
F P
0 g
s
.71887 .79129 m .71885 .791 L p .71108 .76007 L .838 .598 .05 r
F P
0 g
s
.711 .75987 m .71108 .76007 L .70025 .717 L .838 .598 .05 r
F
.71887 .79129 m .71108 .76007 L .711 .75987 L F
.70463 .73168 m .70025 .717 L p .71885 .791 L F P
0 g
s
.71913 .79217 m .7196 .79117 L p .71885 .791 L .388 .543 .888 r
F P
0 g
s
.71887 .79129 m .71766 .79073 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71324 .78972 m .71887 .79129 L .71048 .78819 L .261 .542 .923 r
F
.71324 .78972 m .71048 .78819 L .70198 .78504 L F
.71887 .79129 m .70105 .73175 L p .70195 .78344 L F P
0 g
s
.70198 .78504 m .71048 .78819 L .70195 .78344 L .261 .542 .923 r
F
.71048 .78819 m .71887 .79129 L .70195 .78344 L F
.70201 .78659 m .71324 .78972 L p .70198 .78504 L F P
0 g
s
.68068 .79387 m .71489 .81897 L p .71324 .78972 L .651 .305 .374 r
F P
0 g
s
.70147 .78483 m .70201 .78659 L p .70198 .78504 L .261 .542 .923 r
F P
0 g
s
.70147 .78483 m .68068 .79387 L .71324 .78972 L .651 .305 .374 r
F
.70105 .73175 m .68386 .72713 L .70147 .78483 L p .261 .542 .923 r
F P
0 g
s
.70198 .78504 m .70105 .73175 L .70147 .78483 L .261 .542 .923 r
F
.66836 .78483 m .68068 .79387 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.67982 .77583 m .66836 .78483 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.71913 .79217 m .72043 .81454 L .72722 .79553 L .651 .305 .374 r
F
.71913 .79217 m .72722 .79553 L .73646 .76961 L F
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.70025 .717 m .70105 .73175 L .71887 .79129 L p .838 .598 .05 r
F P
0 g
s
.39402 .11589 m .38493 .11014 L .37009 .10561 L p .493 0 0 r
F P
0 g
s
.6864 .11589 m .67661 .11014 L .66344 .10561 L p .446 0 0 r
F P
0 g
s
.40174 .12429 m .39402 .11589 L .3792 .11138 L p .729 .2 0 r
F P
0 g
s
.37009 .10561 m .3792 .11138 L .39402 .11589 L p .493 0 0 r
F P
0 g
s
.69471 .12429 m .6864 .11589 L .67326 .11138 L p .693 .152 0 r
F P
0 g
s
.66344 .10561 m .67326 .11138 L .6864 .11589 L p .446 0 0 r
F P
0 g
s
.40773 .13497 m .40174 .12429 L .38693 .11982 L p .874 .436 .132 r
F P
0 g
s
.3792 .11138 m .38693 .11982 L .40174 .12429 L p .729 .2 0 r
F P
0 g
s
.70117 .13497 m .69471 .12429 L .68159 .11982 L p .858 .404 .064 r
F P
0 g
s
.67326 .11138 m .68159 .11982 L .69471 .12429 L p .693 .152 0 r
F P
0 g
s
.40539 .20357 m .41026 .18991 L .39547 .18581 L p .917 .917 .801 r
F P
0 g
s
.69865 .20357 m .7039 .18991 L .6908 .18581 L p .922 .933 .797 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.41171 .14746 m .40773 .13497 L .39293 .13055 L p .948 .607 .337 r
F P
0 g
s
.38693 .11982 m .39293 .13055 L .40773 .13497 L p .874 .436 .132 r
F P
0 g
s
.70546 .14746 m .70117 .13497 L .68806 .13055 L p .948 .593 .286 r
F P
0 g
s
.68159 .11982 m .68806 .13055 L .70117 .13497 L p .858 .404 .064 r
F P
0 g
s
.74563 .71885 m .72977 .72344 L .74661 .7336 L closepath p .751 .377 .347 r
F P
0 g
s
.41026 .18991 m .41301 .17557 L .39822 .17138 L p .954 .875 .719 r
F P
0 g
s
.39822 .17138 m .39547 .18581 L .41026 .18991 L p .954 .875 .719 r
F P
0 g
s
.7039 .18991 m .70686 .17557 L .69377 .17138 L p .963 .89 .709 r
F P
0 g
s
.69377 .17138 m .6908 .18581 L .7039 .18991 L p .963 .89 .709 r
F P
0 g
s
.4135 .1612 m .41171 .14746 L .39692 .14311 L p .976 .728 .496 r
F P
0 g
s
.39293 .13055 m .39692 .14311 L .41171 .14746 L p .948 .607 .337 r
F P
0 g
s
.70738 .1612 m .70546 .14746 L .69236 .14311 L p .984 .729 .462 r
F P
0 g
s
.68806 .13055 m .69236 .14311 L .70546 .14746 L p .948 .593 .286 r
F P
0 g
s
.70025 .717 m .68386 .72713 L .70105 .73175 L closepath p .529 .206 .363 r
F P
0 g
s
.41301 .17557 m .4135 .1612 L .39871 .15693 L p .975 .814 .619 r
F P
0 g
s
.39871 .15693 m .39822 .17138 L .41301 .17557 L p .975 .814 .619 r
F P
0 g
s
.70686 .17557 m .70738 .1612 L .6943 .15693 L p .985 .824 .6 r
F P
0 g
s
.6943 .15693 m .69377 .17138 L .70686 .17557 L p .985 .824 .6 r
F P
0 g
s
.39692 .14311 m .39871 .15693 L .4135 .1612 L p .976 .728 .496 r
F P
0 g
s
.69236 .14311 m .6943 .15693 L .70738 .1612 L p .984 .729 .462 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool:00000;40oooo2P00003M0?oo
o`00fP3oool4000000X0GDbU0`00002Z0?ooo`@000002P1TDJL400000=T0oooo003H0?ooo`800000
4@1MC:D300000:D0oooo0P00000B06AAY`<00000eP3oool00=H0oooo0P00000E05e<Y@@00000X03o
ool2000001H0I56W0`00003D0?ooo`00e@3oool00`000000GDbU05e<Y@0G05e<Y@030000001n0000
OP0000<00000VP3oool2000001X0I56W00@000000780000000000000d@3oool00=<0oooo0P00000K
05e<Y@8000000`1n0002000009H0oooo0P00000M06AAY`8000000P1b000200000<h0oooo003B0?oo
o`030000001MC:D0GDbU01d0GDbU0`00000207h000800000TP3oool200000240I56W0`0000000`1b
000000000000003<0?ooo`00d@3oool00`000000GDbU05e<Y@0O05e<Y@030000002j<`00000000D0
0000S`3oool00`000000I56W06AAY`0R06AAY`030000002a9P00000000@00000bP3oool00=00oooo
00<0000005e<Y@1MC:D08@1MC:D00`000000^S<00;Xc00030;Xc00<00000S03oool00`000000I56W
06AAY`0T06AAY`030000002a9P00/BH00080/BH00`0000380?ooo`00cP3oool2000002D0GDbU00<0
00000;Xc002j<`001@2j<`000`000000oooo0?ooo`270?ooo`800000:01TDJL2000000D0/BH000<0
00000?ooo`3oool0a@3oool00<d0oooo00<0000005e<Y@1MC:D09P1MC:D00`000000^S<00;Xc0005
0;Xc00030000003oool0oooo08D0oooo00<0000006AAY`1TDJL0:P1TDJL00`000000/BH00;4V0003
0;4V00030000003oool0oooo0<@0oooo003<0?ooo`030000001MC:D0GDbU02P0GDbU0P0000050;Xc
00030000003oool0oooo08@0oooo00<0000006AAY`1TDJL0;01TDJL2000000<0/BH000<000000?oo
o`3oool0a03oool00</0oooo00<0000005e<Y@1MC:D0:P1MC:D4000000<0^S<000<000000?ooo`3o
ool0PP3oool00`000000I56W06AAY`0^06AAY`<000000P2a9P000`000000oooo0?ooo`330?ooo`00
b`3oool00`000000GDbU05e<Y@0Z05e<Y@040000003OKb40gflQ0=m_8@D00000PP3oool00`000000
I56W06AAY`0_06AAY`030000003KIa00ffL@00@00000a03oool00<X0oooo00<0000005e<Y@1MC:D0
;01MC:D00`000000gflQ0=m_8@040=m_8@800000P03oool00`000000I56W06AAY`0a06AAY`030000
003KIa00ffL@0080ffL@0P0000330?ooo`00b@3oool00`000000GDbU05e<Y@0]05e<Y@030000003O
Kb40gflQ00D0gflQ00<000000?ooo`3oool0OP3oool00`000000I56W06AAY`0a06AAY`030000003K
Ia00ffL@00@0ffL@00<000000?ooo`3oool0`03oool00<P0oooo00<0000005e<Y@1MC:D0;`1MC:D0
0`000000gflQ0=m_8@050=m_8@030000003oool0oooo07`0oooo00<0000006AAY`1TDJL0<`1TDJL0
0`000000ffL@0=]W40030=]W40030000003oool0oooo0<00oooo00380?ooo`030000001MC:D0GDbU
02l0GDbU00<000000=m_8@3OKb401@3OKb400`000000oooo0?ooo`1k0?ooo`030000001TDJL0I56W
03@0I56W00<000000=]W403KIa00103KIa000`000000oooo0?ooo`2o0?ooo`00a`3oool00`000000
GDbU05e<Y@0a05e<Y@8000001P3OKb400`000000oooo0?ooo`1i0?ooo`030000001TDJL0I56W03H0
I56W0P0000040=]W40030000003oool0oooo0;l0oooo00360?ooo`030000001MC:D0GDbU0380GDbU
00<000000?:KEP0000000P0000030=m_8@030000003oool0oooo07P0oooo00<0000006AAY`1TDJL0
=`1TDJL010000000lYM90000000000030=]W40030000003oool0oooo0;h0oooo00360?ooo`030000
001MC:D0GDbU03<0GDbU00@000000?:KEP3bVeH0lY]F0`0000000`3OKb4000000?ooo`1h0?ooo`03
0000001TDJL0I56W03P0I56W00<000000?:GB@3bUdT0100000300?ooo`00a@3oool00`000000GDbU
05e<Y@0d05e<Y@030000003bVeH0lY]F00@0lY]F0P00001h0?ooo`030000001TDJL0I56W03T0I56W
00<000000?:GB@3bUdT00`3bUdT200000;l0oooo00350?ooo`030000001MC:D0GDbU02T0GDbU00<0
GTfV05e<Y@1MC:D0201MC:D00`000000lY]F0?:KEP050?:KEP030000003oool0oooo07H0oooo00<0
000006AAY`1TDJL0>@1TDJL00`000000lYM90?:GB@040?:GB@030000003oool0oooo0;d0oooo0034
0?ooo`030000001MC:D0GDbU03H0GDbU00<000000?:KEP3bVeH01@3bVeH00`000000oooo0?ooo`1d
0?ooo`030000001TDJL0I56W03/0I56W00<000000?:GB@3bUdT0103bUdT00`000000oooo0?ooo`2l
0?ooo`00a03oool00`000000GDbU05e<Y@0f05e<Y@030000003bVeH0lY]F00D0lY]F00<000000?oo
o`3oool0M03oool00`000000I56W06AAY`0k06AAY`030000003bUdT0lYM900@0lYM900<000000?oo
o`3oool0_03oool00<<0oooo00<0000005e<Y@1MC:D07P1MC:D00`1NCJH0GDbU05e<Y@0G05e<Y@03
0000003bVeH0lY]F00@0lY]F00<000000?ooo`3oool0L`3oool00`000000I56W06AAY`0206AAY`03
0=cbgP1TDJL0I56W03P0I56W00<000000?:GB@3bUdT00`3bUdT00`000000oooo0?ooo`2l0?ooo`00
``3oool00`000000GDbU05e<Y@0;05e<Y@0305i=YP1MC:D0GDbU02X0GDbU0P0000060?:KEP030000
003oool0oooo0780oooo00<0000006AAY`1TDJL0?@1TDJL2000000D0lYM900<000000?ooo`3oool0
^`3oool00<<0oooo00<0000005e<Y@1MC:D02`1MC:D00`1NCJH0GDbU05e<Y@0Z05e<Y@030000003i
^Wh00000008000000`3bVeH00`000000oooo0?ooo`1b0?ooo`030000001TDJL0I56W03d0I56W00@0
00000?^jMP00000000000`3bUdT00`000000oooo0?ooo`2k0?ooo`00`P3oool00`000000GDbU05e<
Y@0<05e<Y@0305i=YP1MC:D0GDbU00l0GDbU00<0GTfV05e<Y@1MC:D0601MC:D00`000000nKYn0?Vj
OP020?VjOP<0000000<0lY]F0000003oool0L@3oool00`000000I56W06AAY`0n06AAY`040000003k
^WH0nkYf0?^jMP<0000000<0lYM90000003oool0^`3oool00<80oooo00<0000005e<Y@1MC:D0301M
C:D00`1NCJH0GDbU05e<Y@0Z05e<Y@030000003i^Wh0nKYn00D0nKYn0P00001b0?ooo`030000001T
DJL0I56W03h0I56W00<000000?^jMP3k^WH0103k^WH200000;`0oooo00320?ooo`030000001MC:D0
GDbU00`0GDbU00<0GTfV05e<Y@1MC:D0:P1MC:D00`000000nKYn0?VjOP060?VjOP030000003oool0
oooo0700oooo00<0000006AAY`1TDJL0?P1TDJL00`000000nkYf0?^jMP050?^jMP030000003oool0
oooo0;X0oooo00310?ooo`030000001MC:D0GDbU00d0GDbU00<0GTfV05e<Y@1MC:D03P1MC:D00`1N
CJH0GDbU05e<Y@0J05e<Y@030000003i^Wh0nKYn00D0nKYn00<000000?ooo`3oool0K`3oool00`00
0000I56W06AAY`1006AAY`030000003k^WH0nkYf00@0nkYf00<000000?ooo`3oool0^P3oool00<40
oooo00<0000005e<Y@1MC:D03@1MC:D00`1NCJH0GDbU05e<Y@0[05e<Y@030000003i^Wh0nKYn00D0
nKYn00<000000?ooo`3oool0K`3oool00`000000I56W06AAY`0506AAY`030>_/c01TDJL0I56W03P0
I56W00<000000?^jMP3k^WH0103k^WH00`000000oooo0?ooo`2j0?ooo`00`@3oool00`000000GDbU
05e<Y@0W05e<Y@0305i=YP1MC:D0GDbU0140GDbU00<000000?VjOP3i^Wh01@3i^Wh00`000000oooo
0?ooo`1_0?ooo`030000001TDJL0I56W00D0I56W00<0jnc<06AAY`1TDJL0>01TDJL00`000000nkYf
0?^jMP040?^jMP030000003oool0oooo0;X0oooo00300?ooo`030000001MC:D0GDbU01h0GDbU00<0
GTfV05e<Y@1MC:D06`1MC:D00`000000nKYn0?VjOP060?VjOP030000003oool0oooo06d0oooo00<0
000006AAY`1TDJL0@@1TDJL00`000000nkYf0?^jMP050?^jMP030000003oool0oooo0;T0oooo0030
0?ooo`030000001MC:D0GDbU02L0GDbU00<0GTfV05e<Y@1MC:D04P1MC:D3000000H0nKYn00<00000
0?ooo`3oool0K@3oool00`000000I56W06AAY`1106AAY`8000001P3k^WH00`000000oooo0?ooo`2i
0?ooo`00`03oool00`000000GDbU05e<Y@0l05e<Y@030000003id9h0nM2N00@000000P3i^Wh00`00
0000oooo0?ooo`1]0?ooo`030000001TDJL0I56W0440I56W00<000000?cBV@0000000`0000020?^j
MP030000003oool0oooo0;T0oooo00300?ooo`030000001MC:D0GDbU01D0GDbU4P00000E05e<Y@03
0000003id9h0nM2N00@0nM2N0`00001_0?ooo`030000001TDJL0I56W01X0I56W4P00000E06AAY`03
0000003ldYT0o=:I00<0o=:I0`00002k0?ooo`00_`3oool00`000000GDbU05e<Y@0805e<Y@h00000
3@2GNk800`000000gkJ^0=nf[P020=nf[PT00000301MC:D00`000000nM2N0?W@WP060?W@WP030000
003oool0oooo06`0oooo00<0000006AAY`1TDJL0301TDJL?000000d0Ug^b00<000000>6h[@3Q^:d0
0P3Q^:d8000000d0I56W00<000000?cBV@3ldYT01@3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3o
ool00`000000GDbU05e<Y@0605e<Y@<000006P2GNk800`000000gkJ^0=nf[P0;0=nf[PD000001`1M
C:D00`000000nM2N0?W@WP060?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL0201T
DJL01P1TDZL0I56W0000000000003@Z6000001X0Ug^b00<000000>6h[@3Q^:d02P3Q^:d5000000P0
I56W00<000000?cBV@3ldYT01@3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3oool00`000000GDbU
05e<Y@0405e<Y@8000000P0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^
1`1MC:D00`000000nM2N0?W@WP070?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL0
201TDJL2000000<03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W
00<000000?cBV@3ldYT01P3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3oool00`000000GDbU05e<
Y@0205e<Y@800000100007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^1`1M
C:D00`000000nM2N0?W@WP070?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL01@1T
DJL3000000D03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<0
00000?cBV@3ldYT01P3ldYT00`000000oooo0?ooo`2i0?ooo`00_P3oool010000000GDbU05e<Y@1M
C:D2000000H0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[PL0GDbU00<0
00000?W@WP3id9h01`3id9h00`000000oooo0?ooo`1[0?ooo`030000001TDJL0I56W00@0I56W0P00
000800d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d806AAY`030000003l
dYT0o=:I00H0o=:I00<000000?ooo`3oool0^@3oool00;h0oooo00@0000005e<Y@00000000002000
07/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^1`1MC:D00`000000nM2N0?W@
WP070?W@WP030000003oool0oooo06/0oooo00<0000006AAY`1TDJL00P1TDJL2000000X03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<000000?cBV@3ldYT01P3l
dYT00`000000oooo0?ooo`2i0?ooo`00_P3oool2000000X0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0?0=nf[PL0GDbU0P0000080?W@WP030000003oool0oooo06/0oooo00<00000
06AAY`1TDJL00P00000<00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d8
06AAY`8000001`3ldYT00`000000oooo0?ooo`2i0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh705e<Y@030000003dgkP00000
008000001@3id9h00`000000oooo0?ooo`1[0?ooo`040000001TDJL0I56W000000d03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<000000?KS]@0000000P000004
0?cBV@030000003oool0oooo0;T0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[PL0GDbU00<000000?CO^03dgkP00P3dgkP40000
00030?W@WP000000oooo06`0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H
09Mk/P030000003Q^:d0hKR]00h0hKR]201TDJL00`000000m^>e0?KS]@020?KS]@<0000000<0o=:I
0000003oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1`1MC:D00`000000m=nh0?CO^0060?CO^0800000K@3oool01000
0000I56W06AAY`00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d8
06AAY`030000003fhkD0m^>e00D0m^>e0P00002k0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh705e<Y@030000003dgkP0m=nh
00L0m=nh00<000000?ooo`3oool0J`3oool010000000I56W06AAY`00000=00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d806AAY`030000003fhkD0m^>e00H0m^>e00<00000
0?ooo`3oool0^@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1P1MC:D00`000000m=nh0?CO^0080?CO^0030000003oool0oooo
06/0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1`1TDJL00`000000m^>e0?KS]@070?KS]@030000003oool0oooo0;T0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[PH0GDbU00<000000?CO^03dgkP01`3dgkP00`000000oooo0?ooo`1/0?ooo`040000001TDJL0I56W
000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@L0I56W00<00000
0?KS]@3fhkD01P3fhkD00`000000oooo0?ooo`2j0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh605e<Y@030000003dgkP0m=nh
00L0m=nh00<000000?ooo`3oool0K03oool010000000I56W06AAY`00000=00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d706AAY`030000003fhkD0m^>e00H0m^>e00<00000
0?ooo`3oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1P1MC:D00`000000m=nh0?CO^0070?CO^0030000003oool0oooo
06`0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1`1TDJL00`000000m^>e0?KS]@060?KS]@030000003oool0oooo0;X0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[PH0GDbU0P0000080?CO^0030000003oool0oooo06`0oooo00@0000006AAY`1TDJL000003@0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]1`1TDJL2000000L0m^>e00<00000
0?ooo`3oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1@1MC:D00`000000j^[=0>[Zc@03000000@0m=nh00<000000?oo
o`3oool0K@3oool010000000I56W06AAY`00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d03P3Q^:d606AAY`030000003/k/`0k>k<00800000103fhkD00`000000oooo0?ooo`2k
0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf
[P3O]Zh03`3O]Zh505e<Y@030000003Zj/d0j^[=00<0j^[=0`0000000`3dgkP000000?ooo`1^0?oo
o`040000001TDJL0I56W000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>
0>6h[@H0I56W00<000000>c^c03/k/`00P3/k/`3000000030?KS]@000000oooo0;`0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[P@0GDbU00<000000>[Zc@3Zj/d01`3Zj/d2000006l0oooo00@0000006AAY`1TDJL000003@0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]1@1TDJL00`000000k>k<0>c^c006
0>c^c0800000_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^101MC:D00`000000j^[=0>[Zc@080>[Zc@030000003oool0oooo
06d0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1@1TDJL00`000000k>k<0>c^c0070>c^c0030000003oool0oooo0;/0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[P<0GDbU00<000000>[Zc@3Zj/d0203Zj/d3000006l0oooo00<0000006AAY`0000003@0=2XH00`00
0000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]101TDJL00`000000k>k<0>c^c0070>c^
c0030000003oool0oooo0;`0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2G
Nk80602GNk800`000000gkJ^0=nf[P0?0=nf[P<0GDbU00<000000>[Zc@3Zj/d0203Zj/d3000006l0
oooo00<0000006AAY`0000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0
hKR]101TDJL00`000000k>k<0>c^c0070>c^c0030000003oool0oooo0;`0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P<0GDbU
00<000000>[Zc@3Zj/d0203Zj/d2000000030>5e;@000000oooo06d0oooo00<0000006AAY`000000
3@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]101TDJL00`000000k>k<
0>c^c0070>c^c0030000003oool0oooo0;`0oooo002n0?ooo`030000000007/0001k00T0001k00<0
000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P80GDbU00<000000>[Zc@3Zj/d0203Z
j/d00`000000n<]M000000020>5e;@030000003oool0oooo06/0oooo00<0000006AAY`0000003@0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]0`1TDJL00`000000k>k<0>c^
c0070>c^c0030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P80GDbU0`0000080>[Zc@060000003hbed0
00000000003QMBd00000K@3oool00`000000I56W0000000=00d:QP030000002GNk80Ug^b01P0Ug^b
00<000000>6h[@3Q^:d03P3Q^:d306AAY`800000203/k/`00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O
]Zh205e<Y@030000003LlMh0g?7N00@00000103Zj/d010000000n<]M0000003aWEh3000006`0oooo
00<0000006AAY`0000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]
0P1TDJL00`000000g?GN0=cegP04000000@0k>k<00<000000?ooo`3oool0_@3oool00;h0oooo00<0
00000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^00<0
GDbU0000003LlMh0103LlMh01P000000g?7N000000000000j^[=00000080n<]M00D000000?6MGP3a
WEh0lIeN0000001]0?ooo`8000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
00h0hKR]0P1TDJL00`000000g?GN0=cegP020=cegP050000003LmMh000000000003/k/`00P00002o
0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf
[P3O]Zh03`3O]Zh00`1MC:D000000=cagP020=cagP80gkJ^00@000000=cagP3LlMh0g?7N0P000002
0?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J@3oool3000000d03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@0306AAY`000000g?GN0080g?GN0P3Q^:d0
10000000g?GN0=cegP3LmMh300000;l0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P030000003O]Zh0gkJ^00@0gkJ^00D00000
0=cagP3LlMh0g?7N000000030?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J@3o
ool3000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@0306AAY`00
0000hKR]00@0hKR]00L000000=cegP3LmMh0g?GN0000000E4HX000000;l0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0g?7N008000000`3hbed00`000000lIeN0?6MGP020?6MGP030000003oool0oooo06P0oooo
00@0000006YGZ@00000000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0
hKR]00<000000>g2A`3LmMh00P0000000`3]`TL000000?ooo`2n0?ooo`00_P3oool00`000000001k
0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh010000000n<]M
0=cagP0000040?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J03oool010000000
JUNY06YGZ@00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d01000
0000kL970=cegP0000020>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k
00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P040000003hbed00000
000000@0n<]M100000020?6MGP030000003oool0oooo06H0oooo00D0000006YGZ@1ZEjT0JUNY0000
000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970000
00030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0000000D0n<]M00@00000
0?NiQ03g^H@0mkV40`00001X0?ooo`050000001ZEjT0JUNY06YGZ@0000003@0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo
0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<0
00000=nf[P3O]Zh05P3O]Zh00`000000n<]M000000050?S;G@030000003g^H@0mkV400<0mkV400<0
00000?ooo`3oool0I@3oool00`000000JUNY06YGZ@0206YGZ@030000000=2XH03@Z600/03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<0
00000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H
09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000mkV40?NiQ003
0?NiQ0030000003oool0oooo06D0oooo00<0000006YGZ@1ZEjT00P1ZEjT00`0000003@Z600d:QP0;
00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`03
0>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?Ni
Q03g^H@00`3g^H@00`000000oooo0?ooo`1U0?ooo`030000001ZEjT0JUNY0080JUNY00<0000000d:
QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2
A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`03
0000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@03
0000003g^H@0mkV400<0mkV400<000000?ooo`3oool0I03oool00`000000JUNY06YGZ@0306YGZ@03
0000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@03
0000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/0
2@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed0
1@3hbed00`000000mkV40?NiQ0040?NiQ0030000003oool0oooo06<0oooo00<0000006YGZ@1ZEjT0
0`1ZEjT00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d0
5@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?NiQ03g^H@0103g^H@00`000000oooo0?ooo`1S0?ooo`030000001Z
EjT0JUNY00<0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@D000000P3g^H@00`000000oooo0?ooo`1R0?ooo`030000001ZEjT0
JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`00
0000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`00
0000n<]M0?S;G@050?S;G@030000003gcZ40mljQ0080mljQ0`00001T0?ooo`030000001ZEjT0JUNY
00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`030000000007/0
001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0
n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1R0?ooo`030000001ZEjT0
JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1R0?ooo`030000001Z
EjT0JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1Q0?ooo`030000
001ZEjT0JUNY00D0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`03
0000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P03
0000003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1Q0?ooo`03
0000001ZEjT0JUNY00@0JUNY0P00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d01`000000kL970>g2A`3]`TL05A6:0>g2A`000000_`3oool00;h0oooo00<000000000
N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;
G@3hbed01@3hbed00`000000mljQ0?O>X@040?O>X@030000003oool0oooo0640oooo00<0000006YG
Z@1ZEjT00P1ZEjT20000000301PCR`0000003@Z600`03@Z600<0000009Mk/P2GNk80602GNk800`00
0000hKR]0>6h[@0E0>6h[@070000003]`TL0kL970>g2A`0E4HX0kL970000002o0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003gcZ40mljQ00@0mljQ00<000000?ooo`3oool0H@3oool0
0`000000JUNY06YGZ@02000000<061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H
09Mk/P030000003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo
002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf
[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?oo
o`1Q0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL00000
0;l0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000
gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M1@0000020?O>X@030000003oool0oooo0640
oooo00@0000006YGZ@1ZEjT00000100H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b
01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d01`000000kL970>g2A`3]`TL05A6:0>g2A`000000_`3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000l]bi0?;L^@020?;L^@<00000H`3oool0
10000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk803@2G
Nk800`000000Ug^b09Mk/P0809Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003bg;T0
l]bi00@0l]bi00<000000?ooo`3oool0H@3oool010000000JUNY06YGZ@00000401PCR`030000000=
2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]
`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/0
0`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed0
0`000000l]bi0?;L^@030?;L^@030000003oool0oooo0680oooo00@0000006YGZ@1ZEjT00000100H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0
001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0
n<]M00D0n<]M00<000000?;L^@3bg;T00`3bg;T00`000000oooo0?ooo`1R0?ooo`040000001ZEjT0
JUNY000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003bg;T0l]bi00<0l]bi00<000000?ooo`3oool0HP3oool0
10000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000l]bi0?;L^@030?;L^@030000003oool0
oooo0680oooo00@0000006YGZ@1ZEjT00000100H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?;L^@3bg;T00P3bg;T0
0`000000oooo0?ooo`1S0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@<000000P3bg;T0
0`000000oooo0?ooo`1S0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003Yild0
jNO=00<00000I@3oool010000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<0
00000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H
09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000jNO=0>WWc@02
0>WWc@030000003oool0oooo06@0oooo00<0000006YGZ@000000100H4h/00`0000003@Z600d:QP0;
00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`03
0>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00@000000>WW
c@3Yild0jNO=0P00001V0?ooo`030000001ZEjT0000000@061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@040000003Yild0jNO=
0>WWc@800000IP3oool00`000000JUNY0000000401PCR`030000000=2XH03@Z600/03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<00000
0?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed01P000000jNO=0>WWc@000000
n/aS000006H0oooo00<0000006YGZ@000000100H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00H000000>WWc@3Yild000000?[<
H`00001V0?ooo`030000001ZEjT0000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo
0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<0
00000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@060000003Yild0jNO=0000003jc6<0
0000I`3oool2000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P03
0000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00
_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh0
5P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003Yild000000080n/aS00<000000?ooo`3oool0
I@3oool2000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@<000000P3jc6<00`000000oooo0?ooo`1U0?ooo`800000100H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M0P0000030?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M0P0000030?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H
4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00@000000>g2A`3]`TL05A6:0P3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3o
ool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@040000003]`TL0kL9701DARP80kL9700<000000?ooo`3oool0
_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O
]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003o
ool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<0
0`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS
0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z6
00/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL97
00<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000
Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000
n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`000000
3@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000
kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k
00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M
00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;
00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]
00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000
N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;
G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PC
R`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h
[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<00000
0000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<00000
0?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<00000
01PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf
[P030000003hbed0n<]M00D0n<]M00H000000?[<H`3jc6<030Z60?[<H`00001X0?ooo`030000000H
4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool0
0`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk80
0`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool0
0;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^
01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo
06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b
01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo
0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000
gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000
oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000
Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000
oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b
00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS
00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z6
00<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL97
00<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk
/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<
H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:
QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2
A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<00000
0?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<00000
00d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<00000
0>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;
G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PC
R`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h
[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`00
07/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3h
bed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H
4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000
000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3o
ool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0
oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0
oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`00
0000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`00
0000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`00
0000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`00
0000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0
Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080
n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/0
3@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0
kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b
09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS
0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z6
00d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL97
0>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0
000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<0
00000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0
000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<0
00000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`09
0000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@05
0?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`02
01PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E
0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000
N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;
G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PC
R`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h
[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`03
0000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P03
0000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`03
0000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P03
0000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00
_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh0
5P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0
IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80
602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0
_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O
]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003o
ool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<0
0`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS
0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z6
00/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL97
00<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000
Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000
n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`000000
3@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000
kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k
00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M
00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;
00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]
00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000
N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;
G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PC
R`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h
[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<00000
0000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<00000
0?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<00000
01PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf
[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?oo
o`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk
/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?oo
o`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O
]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3o
ool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2G
Nk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3o
ool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000
003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000
003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000
002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000
003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602G
Nk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3j
c6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0
n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH0
3@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0
kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`00
0000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`00
0000n/aS0?[<H`020?[<H`030000003oool0oooo01@0oooo?000000F0?ooo`030000000H4h/061>;
008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000
001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000
n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool05000000909j1/`03
0000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D00000080oooo00<0000001PCR`0H
4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0E0=nf[Q400000
7@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0b:Bc01/0b:Bc4@00000400d:QP030000
002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000
003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602G
Nk800`000000gkJ^0=nf[P090=nf[P`000001P24K:l00`000000WX6c09j1/`0U09j1/`030000002d
Tk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`040=^b[``000004`2G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P`000004P24K:l0
0`000000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b[`0@0=^b[``000001`2GNk80
0`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool0
0;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0>09Mk/PX000006024K:lK0000
0500>;[T5@00000N0=^b[`X000005@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo
0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk801P2GNk88000000<0
He2W00<0000008A/[`24K:l04024K:l<000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0
Y`P000003@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`03
0000000007/0001k00T0001k2@00000;06=@Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`0
00001P3K/Zl00`000000k<2W0>c0Y`090>c0Y`P000001@3Q^:d00`000000kL970>g2A`030>g2A`03
0000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k0080001k2000000@06=@Y`X00000
]P0h^^@7000001<0k<2W200000030>g2A`030000003oool0oooo0;d0oooo002m0?ooo`H00000401S
D:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0
He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?oo
o`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<
V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D0
0000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo
002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool2
000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`0
000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rj
i1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0
001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0
om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000
V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F
0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool30000
00H0001l0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`00
04/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool0
0940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000
003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540
>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[T
E@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h
^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=
0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?oo
o`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000
S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2
000008`0oooo002<0?ooo`8000007@0h^^@403Vji900>;[T00<0000003Rji00h^^@0/00h^^@20000
08`0oooo002<0?ooo`800000>`0h^^@703Vji6H0>;[T2@2<L[400`000000eZna0=J_/@0=0=J_/J<0
>;[T0P00002<0?ooo`00S03oool00`000000>;[T03Rji01G03Rji0`0>K[T>P0h^^@00`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h^^@0W00h^^@2000008`0oooo
002<0?ooo`030000000h^^@0>;[T07D0>;[T3`0i^^@G03Rji080001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0U@0h
^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T03Rji02B03Rji0<0>K[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg400`3ncg4@03Rji0L0>K[TP`0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`00
0000>;[T03Rji02E03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07P0h^^@803Vj
i6l0>;[T00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0U00h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T0300>;[T2@0i^^AK03Rji0030000003oool0oooo08/0
oooo002>0?ooo`800000U00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00d0>;[T
400i^^@V03Rji0L0>K[TB00h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[T7@0h^^@503Vji3H0>;[T00<0
00000?ooo`3oool0SP3oool00940oooo00<0000003Rji00h^^@0T00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T04d0>;[T200i^^@C03Rji0@0>K[T900h^^@00`000000oooo0?ooo`2?
0?ooo`00TP3oool200000900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rj
i0@0>K[T2P0h^^@203Vji140>;[T0P00002B0?ooo`00U03oool00`000000>;[T03Rji02=03Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@03
08ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0S@0h^^@00`000000oooo0?ooo`2B0?ooo`00
UP3oool2000008`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji02:03Rji0800000
UP3oool009P0oooo0P00002:03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0R00h
^^@2000009P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0
>;[T08D0>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@00000O`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00Y@3oool5000007X0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000Y@3oool00:X0oooo1@00001e
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0L`0h^^@500000:X0oooo002_0?oo
o`D00000L00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04/0>;[T00<0000003Rj
i00h^^@0800h^^@500000:l0oooo002d0?ooo`D00000J`0h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000000h^^@0>;[T06T0>;[T1@00002d0?ooo`00^@3oool5000006H0>;[T00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000>;[T03Rji01T03Rji0D00000^@3oool00;h0oooo1@00001Q03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0G`0h^^@500000;h0oooo00330?ooo`D00000G00h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k40
0`2=Lk40eZna000000070?k?L@030000000h^^@0>;[T05X0>;[T1@0000330?ooo`00b03oool50000
05L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
00l0eZna00<0SG>a0=J_/@0000001`3ncg400`000000>;[T03Rji01E03Rji0D00000b03oool00<d0
oooo1`00001@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0?0=J_/@0308ec/@3F[k40000000L0o/ma00<0000003Rji00h^^@0CP0h^^@700000<d0
oooo003D0?ooo`X00000AP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04@0>;[T
2P00003D0?ooo`00gP3oool:000003`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i00j03Rji0X00000gP3oool00>P0oooo3@00000_03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0;@0h^^@=00000>P0oooo003e0?oooa0000007`0h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000000h^^@0>;[T01d0>;[T4000003e0?ooo`00o`3oool60?oooaT000001P0h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o0?oooal0oooo
1`0000070000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@L00000o`3ooolO0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@05
08ec/@3F[k40eZna0=J_/@0000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0
eZna00D0SG>a0=J_/@3F[k40eZna000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k403@3F[k401@2=Lk40eZna0=J_/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0<0=J_/@0308ec/@3F[k40eZna0080
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00`0eZna
00<0SG>a0=J_/@3F[k400P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k40303F[k400`2=Lk40eZna0=J_/@020=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0;
0=J_/@0308ec/@3F[k40eZna00<0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna00/0eZna00<0SG>a0=J_/@3F[k400`3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k402P3F[k400`2=Lk40eZna0=J_/@040=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0:0=J_/@0308ec/@3F[k40eZna00@0eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00X0eZna00<0SG>a0=J_/@3F[k40103F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k402@3F[k400`2=Lk40eZna0=J_/@050=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@090=J_/@0308ec/@3F[k40eZna
00D0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna00P0eZna00<0SG>a0=J_/@3F[k401P3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40203F[k400`2=Lk40eZna0=J_
/@060=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@070=J_/@0308ec/@3F[k40eZna00L0eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00L0eZna00<0SG>a0=J_
/@3F[k401`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k401P3F[k400`2=Lk40eZna0=J_/@080=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@060=J_/@0308ec/@3F
[k40eZna00P0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna00D0eZna00<0SG>a0=J_/@3F[k402@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k40103F[k400`2=Lk40eZna0=J_/@0:0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00``3oool3000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002`0?ooo`8000004@3oool00`000000NUVP07YIX005000005T0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj000000000000
3`3oool00`000000NUVP07YIX00607YIX0<00000EP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00
NUVP00L0NUVP0P00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Y`3oool00`000000Nfjj07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YI
X0800000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k400`3F[k400`2=Lk40eZna0=J_/@0;0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool0
2`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0
`7T00000003oool02`3oool00`000000NUVP07YIX00707YIX0800000E`3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2
000000`0oooo00<0000007YIX01jFJ001`1jFJ02000005L0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?oo
o`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00
oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^
^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YIX01jFJ001`1jFJ02000005P0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0
Nfjj00L0Nfjj00<0`7T00000003oool0203oool00`000000NUVP07YIX00807YIX0030000003oool0
oooo05L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?oo
o`030000001kK[X0Nfjj00L0Nfjj0P0000090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?oo
o`3oool0E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0
oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0
NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
ZP3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00L0oooo00<0000007YIX01jFJ00
1`1jFJ02000005T0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00L0NUVP00<0
gKjj0000003oool0F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k400P3F[k400`2=Lk40eZna0=J_/@0<0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool0
0`000000NUVP07YIX00807YIX0030000003oool0oooo05P0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000
003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00
00000?ooo`050?ooo`030000001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P800000
1@3oool00`000000NUVP07YIX00807YIX0800000FP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1I0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool0
0`000000NUVP07YIX00707YIX0800000F`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:`0oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YI
X01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0
NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YIX0030000
003oool0oooo05X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002]0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP0P00
001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool2
000000T0Nfjj00D0`7T00000003oool0oooo0000000907YIX0800000G03oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X2
000000030?ooo`000000NUVP00T0NUVP0P00001L0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P@00000201jFJ000`3M
_[X000000000001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[P3oool00`000000Nfjj07]^^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`8000002@1kK[X3000000T0NUVP
0P00001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3o
ool00`000000Nfjj07]^^P0707]^^P800000201jFJ00103M_[X0NUVP0<S7AP00001M0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^
^P0707]^^P8000002@1jFJ02000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001`1jFJ02
000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?oo
o`8000002@1kK[X00`000000NUVP07YIX00707YIX0800000GP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00;00oooo00<0000007]^^P1kK[X01`1kK[X00`000000
NUVP07YIX00707YIX0030<S7AP000000oooo05d0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ00
1@1jFJ02000005l0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002`0?ooo`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00000907]^^P030000001jFJ00
NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/@3oool00`000000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00D0NUVP00<0b<M60000
003oool0GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40
oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00307YIX0<00000G`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00@000000=J_/@3F[k40SG>a403F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P06
0000001jFJ00NUVP07YIX03M_[X0NUVP0P00001P0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`2m0?ooo`00/@3oool2000000T0Nfjj00<0000007YI
X01jFJ000`1jFJ0200000600oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1P0?oo
o`<000006`3oool200000:80oooo002b0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YIX01j
FJ000`1jFJ000`38adH000000?ooo`1O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0G`3oool00`000000QcAL08LdG002000001L0oooo0`0000000`30H5P000000?ooo`2Q0?ooo`00
/P3oool00`000000Nfjj07]^^P0807]^^P040000001jFJ00gKjj07YIX0<00000H03oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo0P00000308LdG08000004`3oool4000000@0
`61H00<000000?ooo`3oool0X03oool00;80oooo0P00000907]^^P040000001jFJ00NUVP07YIX080
0000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0oooo0P00000508LdG080
00004@3oool2000000P0`61H00<000000?ooo`3oool0X03oool00;80oooo0P00000907]^^P040000
001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05X0
oooo00<0000008LdG027=5`01@27=5`00`000000eYT<0?ooo`0@0?ooo`<000001`30H5P00`000000
oooo0?ooo`2P0?ooo`00/`3oool00`000000Nfjj07]^^P0707]^^P060000003M_[X0NUVP07YIX038
adH00000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0oooo0P00000808Ld
G0030000003FV@`0000000l0oooo00D0000006>;h`1SRn<0Hh_S000000060<1PF0030000003oool0
oooo0:00oooo002c0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX00000000P00001Q0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0E`3oool2000000T0QcAL00<000000=JI
300000003`3oool00`000000Hh_S06>;h`0206>;h`0300000030H5P0`61H00<0`61H00<000000?oo
o`3oool0X03oool00;<0oooo0P00000907]^^P040000001jFJ00000000000680oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1G0?ooo`0300000012R^`0000000<000001@27=5`00`00
0000eYT<0000000>0?ooo`030000001SRn<0Hh_S00@0Hh_S0P0000030<1PF0030000003oool0oooo
0:00oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0F03oool00`000000@X[/04::k00204::k0@0000000D0QcAL0000
003FV@`0eYT<0000000=0?ooo`030000001SRn<0Hh_S00H0Hh_S00@000000<1PF030H5P00000XP3o
ool00;@0oooo00<0000007]^^P1kK[X01`1kK[X010000000NUVP0<S7AP00001R0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0F03oool00`000000@X[/04::k00604::k08000000P3F
V@`00`000000oooo0?ooo`0:0?ooo`030000001SRn<0Hh_S00P0Hh_S0`00002R0?ooo`00]03oool0
0`000000Nfjj07]^^P0807]^^P<00000HP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05P0oooo00<0000004::k012R^`01`12R^`010000000eYT<0=JI3000000<0?ooo`030000001S
Rn<0Hh_S00X0Hh_S00<000000?ooo`3oool0X03oool00:h0oooo8`00001C0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0F@3oool00`000000@X[/04::k00704::k0030000003FV@`0
eYT<00/0oooo00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2P0?ooo`00X03oool>0000
00`0B3^N00<000000?74X`3aa:<0303aa:<?000004`0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1I0?ooo`0300000012R^`0@X[/00L0@X[/00@000000=JI303FV@`000002P3oool0
0`000000Hh_S06>;h`0:06>;h`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0F@3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<
000000T0oooo00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2Q0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo05T0oooo00<0000004::k012R^`02012R^`00`00
0000eYT<000000090?ooo`030000001SRn<0Hh_S00X0Hh_S00<000000?ooo`3oool0XP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1J0?ooo`0300000012R^`0@X[/00L0
@X[/00@000000=JI303FV@`000001`3oool00`000000Hh_S06>;h`0;06>;h`030000003oool0oooo
0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool00`000000
@X[/04::k00704::k0040000003FV@`0eYT<000000L0oooo00<0000006>;h`1SRn<02P1SRn<00`00
0000oooo0?ooo`2S0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05X0
oooo00<0000004::k012R^`02012R^`00`000000eYT<000000060?ooo`030000001SRn<0Hh_S00/0
Hh_S00<000000?ooo`3oool0X`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1K0?ooo`0300000012R^`0@X[/00L0@X[/00<000000=JI300000001P3oool00`000000Hh_S
06>;h`0:06>;h`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0F`3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<000000@0oooo
00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2T0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo05/0oooo00<0000004::k012R^`01`12R^`010000000eYT<0=JI
300000040?ooo`030000001SRn<0Hh_S00X0Hh_S00<000000?ooo`3oool0Y@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1L0?ooo`0300000012R^`0@X[/00L0@X[/00@0
00000=JI3000000000000P3oool00`000000Hh_S06>;h`0;06>;h`030000003oool0oooo0:D0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0G03oool00`000000@X[/04::
k00704::k0030000003FV@`0000000@00000301SRn<00`000000oooo0?ooo`2V0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo00<0000004::k012R^`01`12R^`0
1@000000eYT<0=JI30000000YTiO00800000301SRn<00`000000oooo0?ooo`2V0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo00<0000004::k012R^`02012R^`0
1@000000eYT<0000002VCUl0000000d0Hh_S00<000000?ooo`3oool0YP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`1M0?ooo`0300000012R^`0@X[/00L0@X[/00<00000
0=JI300000000P00000<06>;h`030000003oool0oooo0:L0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0G@3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<
000000d0Hh_S00<000000?ooo`3oool0Y`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1M0?ooo`0300000012R^`0@X[/00P0@X[/00<000000=JI30000000301SRn<00`00
0000oooo0?ooo`2X0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05h0
oooo00<0000004::k012R^`01`12R^`00`000000eYT<06>;h`0<06>;h`030000003oool0oooo0:P0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0GP3oool00`000000@X[/
04::k00704::k0030000003FV@`0Hh_S00/0Hh_S00<000000?ooo`3oool0Z@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1M0?ooo`8000002P12R^`00`000000Hh_S06>;
h`0:06>;h`030000003oool0oooo0:T0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0G03oool2000000030:I>G`000000@X[/00P0@X[/00<000000=JI301SRn<02@1SRn<3
00000:X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool20000
00<0YTiO00<0000004::k012R^`01`12R^`00`000000eYT<06>;h`0906>;h`040000002VCUl00000
00000:T0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F@3oool20000
00@0YTiO00<0000004::k012R^`02012R^`00`000000Hh_S06>;h`0706>;h`030000002VCUl0YTiO
0080YTiO0P00002W0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0
oooo0P0000060:I>G`0300000012R^`0@X[/00L0@X[/00<0000006>;h`1SRn<01`1SRn<00`000000
YTiO0:I>G`030:I>G`800000YP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1F0?ooo`<000001`2VCUl00`000000@X[/04::k00704::k0030000003FV@`0Hh_S00L0Hh_S
00<000000:I>G`2VCUl01@2VCUl200000:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000E03oool2000000T0YTiO00<0
000004::k012R^`02012R^`00`000000Hh_S06>;h`0506>;h`030000002VCUl0YTiO00L0YTiO0P00
002S0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool;000000T03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP07
0?o@QP/00000B03oool2000000X0YTiO00<0000004::k012R^`02012R^`00`000000Hh_S06>;h`05
06>;h`030000002VCUl0YTiO00T0YTiO00<000000?ooo`3oool0X03oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0A03oool3000000`0YTiO00<0000004::k012R^`01`12R^`00`000000Hh_S06>;h`0406>;
h`030000002VCUl0YTiO00/0YTiO0P00002P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`130?ooo`80
00003P2VCUl00`000000@X[/04::k00704::k0030000003FV@`0Hh_S00@0Hh_S00<000000:I>G`2V
CUl0302VCUl2000009l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0480oooo0P00000?0:I>G`030000
0012R^`0@X[/00P0@X[/00<0000006>;h`1SRn<00P1SRn<00`000000YTiO0:I>G`0?0:I>G`030000
003oool0oooo09`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0400oooo0P00000B0:I>G`X0@X[/00<0
000006>;h`1SRn<00P1SRn<00`000000YTiO0:I>G`020:I>G`0302MMd@2VCUl0YTiO00/0YTiO0P00
002L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`030000002VCUl0YTiO0180YTiO2P12R^`0
1@000000Hh_S06>;h`1SRn<0000001D0YTiO00<000000?ooo`3oool0V@3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0?`3oool2000001D0YTiO2@12R^`010000000Hh_S06>;h`00000D0:I>G`800000V`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0?`3oool0100000008e[@00000000000E0:I>G`L0@X[/00<0
000006>;h`0000001@2VCUl00`0WGM40YTiO0:I>G`0;0:I>G`80000000<0h_g:0000003oool0VP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0?`3oool01@0000008e[@02=Jd00SF]00000001H0YTiO00<0
000004::k012R^`00P12R^`00`000000Hh_S0000000B0:I>G`050000003RoLX0h_g:0>;mbP000000
V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=Jd00202=Jd0030000002V
CUl0YTiO01D0YTiO00D0000004::k012R^`0@X[/0000000B0:I>G`030000003RoLX0h_g:0080h_g:
00<000000?ooo`3oool0V@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=J
d00302=Jd08000006@2VCUl00`000000YTiO0:I>G`0?0:I>G`030000003RoLX0h_g:00<0h_g:00<0
00000?ooo`3oool0V@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=Jd005
02=Jd0030000002VCUl0YTiO02L0YTiO00<000000>;mbP3RoLX00`3RoLX00`000000oooo0?ooo`2J
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`030000000SF]008e[@00H08e[@0P00000K0:I>
G`0302MMd@2VCUl0YTiO00L0YTiO0P0000060>;mbP030000003oool0oooo09X0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03h0oooo00<0000002=Jd00SF]002@0SF]000`000000YTiO0:I>G`0Q0:I>G`03
0000003RoLX0h_g:00H0h_g:00<000000?ooo`3oool0VP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
?P3oool00`0000008e[@02=Jd00:02=Jd0030000002VCUl0YTiO01l0YTiO00<000000>;mbP3RoLX0
1`3RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000S
F]008e[@00/08e[@0P00000F0:I>G`0302MMd@2VCUl0YTiO00D0YTiO00<000000>;mbP3RoLX0203R
oLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]00
8e[@00d08e[@00<000000:I>G`2VCUl06P2VCUl00`000000h_g:0>;mbP090>;mbP030000003oool0
oooo09X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03h0oooo00<0000002=Jd00SF]003P0SF]000`00
0000YTiO0:I>G`0G0:I>G`800000303RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0n0?ooo`030000000SF]008e[@00l08e[@0P00000A0:I>G`0302MMd@2VCUl0YTiO0080
YTiO00<000000>;mbP3RoLX0303RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0n0?ooo`030000000SF]008e[@01408e[@00<000000:I>G`2VCUl04P2VCUl00`000000h_g:
0>;mbP0=0>;mbP030000003oool0oooo09X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03h0oooo00<0
000002=Jd00SF]004P0SF]0200000140YTiO00<000000>;mbP3RoLX03P3RoLX00`000000oooo0?oo
o`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]008e[@01@08e[@00<00000
0:I>G`2VCUl02P2VCUl0100WGM40YTiO0:I>G`00000A0>;mbP030000003oool0oooo09X0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03h0oooo00<0000002=Jd00SF]005@0SF]000`000000YTiO0:I>G`0:
0:I>G`8000004P3RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?oo
o`030000000SF]008e[@01H08e[@0P0000090:I>G`030000003RoLX0h_g:0140h_g:00<000000?oo
o`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0?P3oool00`0000008e[@02=Jd00H02=Jd003
0000002VCUl0YTiO00D0YTiO00<000000>;mbP3RoLX04P3RoLX00`000000oooo0?ooo`2K0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]008e[@01T08e[@00<000000:I>G`2VCUl0
0`2VCUl00`000000h_g:0>;mbP0C0>;mbP030000003oool0oooo09/0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03h0oooo00<0000002=Jd00SF]006P0SF]02000000030:I>G`000000000001H0h_g:00<0
00000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?P3oool00`0000008e[@02=Jd00L
02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0?P3oool00`0000008e[@02=Jd00L02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?oo
o`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00M02=Jd003
0000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
?@3oool00`0000008e[@02=Jd00M02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0
V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00M02=Jd0030000003R
oLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?@3oool0
0`0000008e[@02=Jd00M02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00L02=Jd0800000603RoLX00`00
0000oooo0?ooo`2K0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`0
8e[@00<000000>;mbP3RoLX05`3RoLX00`000000oooo0?ooo`2K0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo
0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<0
00000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m
0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;m
bP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`03
0000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX0
5P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000S
F]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX0
0`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@
01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000
oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0l0?ooo`030000000SF]008e[@01`08e[@
0P00000H0>;mbP030000003oool0oooo09`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0
000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0G0>;mbP030000003oool0oooo09`0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F
0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=J
d00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP03
0000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00
700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003o
ool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo7`0SF]000`000000h_g:0>;mbP0F
0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=J
d00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP03
0000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00
700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003o
ool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]006`0SF]02
000001P0h_g:00<000000?ooo`3oool0W@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
00008e[@02=Jd00L02=Jd08000005`3RoLX00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0k0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000
oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000SF]008e[@01`08e[@
00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0k0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?oo
o`2N0?ooo`00X03oool00`000000B3^N04PkWP0404PkWRP00000203aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03/0oooo00<0000002=Jd00SF]002@0SF]0?000000@08e[@00@00000
0>;mbP3RoLX0h_g:4@0000040>;mbP030000003oool0oooo09h0oooo002C0?oooa@000004P17>Yh0
0`000000lLFS0?75X`0C0?75XaL00000<03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oooaT00000401EAJ<3
02=Jd0030000003RoLX0h_g:00l0mLRN5@00002C0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02P0EDFS00<08e[@0000003RoLX0903eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02P0EDFS00<08e[@0000003e
b9h0903eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0
EDFS02L0EDFS00<08e[@05E5X`0000009@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02H0EDFS00@08e[@05E5X`1EAJ<000009@3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02D0EDFS00D08e[@
05E5X`1EAJ<0EDFS0000000R0?G8WP0405Q8Y03eb9h0mLRN000009<0oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<00`0SF]00
EDFS05E5X`0205E5X`030000003eb9h0mLRN01l0mLRN00D0F4RT0?G8WP3eb9h0mLRN0000002C0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02<0EDFS00<0000005E5X`1EAJ<00`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0N0?G8WP0305Q8Y03eb9h0
mLRN0080mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0R05E5X`030?C7X01EAJ<0EDFS00@0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h07@3eb9h00`1HB:@0mLRN0?G8WP030?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<08@1EAJ<00`3daj00EDFS05E5X`05
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN01`0mLRN00<0F4RT0?G8WP3eb9h0
103eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS0200EDFS00<0m<NP05E5X`1EAJ<01P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<07`1EAJ<00`3daj00
EDFS05E5X`0705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0N05E5X`030?C7X01EAJ<0EDFS00P0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS01d0EDFS00<0m<NP05E5X`1EAJ<02@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0701EAJ<00`3daj00EDFS05E5X`0:05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0K
05E5X`030?C7X01EAJ<0EDFS00/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h05`3eb9h00`1HB:@0mLRN0?G8WP090?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
6P1EAJ<00`3daj00EDFS05E5X`0<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02l000004`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26;`00
00020?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS=000000A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H9000000P01@008@00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d
02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2000002/0EDFS00<000000?G8WP3eb9h05P3eb9h0
0`1HB:@0mLRN0?G8WP0:0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC
]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2
000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440
[FAk0P00000[05E5X`030000003eb9h0mLRN01D0mLRN00<0F4RT0?G8WP3eb9h02`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000I
05E5X`030?C7X01EAJ<0EDFS00l0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eT
N`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]I7/0@@2]I7/2000002/0EDFS00<000000?G8
WP3eb9h0503eb9h00`1HB:@0mLRN0?G8WP0<0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002d
Tk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000
601EAJ<00`3daj00EDFS05E5X`0@05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC
]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000
]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000
/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000E05E5X`030?C7X01EAJ<0EDFS01<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00
002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000001@0EDFS00<0m<NP05E5
X`1EAJ<0501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2a0:eTN`80
0000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1M0:eTN`030:jf
g`2]I7/0[FAk0580[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0I02]I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1_0:eTN`030:jfg`2]I7/0[FAk0400[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h03P3eb9h00`1HB:@0mLRN0?G8WP0B0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1f
0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00l0EDFS00<0m<NP05E5
X`1EAJ<05`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1m0:eTN`03
0:jfg`2]I7/0[FAk0380[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
3@3eb9h00`1HB:@0mLRN0?G8WP0C0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`240:eTN`030:jfg`2]
I7/0[FAk02/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0R`2]I7/00`2^]]l0[FAk0:eTN`0T0:eTN`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<02`1E
AJ<00`3daj00EDFS05E5X`0K05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fh
h@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80
[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<G00000;@0[KSQ
6`00000A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0[VEl00<000000:fhh@2]^>40/P2]
^>400`000000[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`0
0`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^IG`D05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000
[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^IG`00`000000[KSQ
0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0403a
aJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05`2^IG`B05E5X`030000003e
b9h0mLRN00D0mLRN00<0F4RT0?G8WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fhh@2`
0:fhh@8000006P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75Xa/0[VEl00<000000:fh
h@2]^>40/02]^>42000001X0[VEl4@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03P3aaJ<E0:iUO003
0?75X`2^IG`0[VEl00@0[VEl00<000000:fhh@2]^>40/02]^>42000001/0[VEl401EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<03P3aaJ<L0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000K0:iUO100EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00d0lLFS7@2^IG`00`000000[KSQ0:fhh@2`0:fhh@800000702^
IG`?05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0<0?75Xah0[VEl00<000000:fhh@2]^>40/02]^>42
000001d0[VEl3P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0702^IG`>05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0;0?75Xal0
[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M0:iUO0d0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00/0lLFS7`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0[VEl
3@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02P3aaJ<P0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`07P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75Xb40[VEl00<00000
0:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01l0[VEl2`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0203aaJ<R0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^
IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]^>40
/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00L0lLFS8`2^
IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240[VEl2@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08P2^IG`8
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>400`00
0000[VEl0:iUO0050:iUO00305E5X`2^IG`0[VEl01X0[VEl201EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<01@3aaJ<U0:iUO0030000002]^>40[KSQ0380[KSQ00<0^iT60:fhh@2]^>40AP2]^>400`000000
[KSQ0:fhh@0b0:fhh@030000002^IG`0[VEl02<0[VEl1`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
1@3aaJ=J0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl
0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00@0lLFS?`2^IG`00`2]^>40[VEl0:iU
O00I0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iU
O00=0:iUO00305E5X`2^IG`0[VEl01@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ=>
0:iUO0030:fhh@2^IG`0[VEl00/0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b
0:iUO0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ=50:iU
O0030:fhh@2^IG`0[VEl01@0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iUO003
0;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00E0:iUO003
05E5X`2^IG`0[VEl00h0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=;0:iUO0030:fh
h@2^IG`0[VEl00l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000
002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00@000000?75X`3aaJ<0lLFSGP2^IG`00`2kV@H0[KSQ
0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09`2^IG`305E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`1H0:iUO0030:fhh@2^IG`0[VEl00@0[VEl00<0^iT60:fhh@2]^>40AP2]
^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02P0[VEl0P1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<00000
0:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`00
0000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0EDFS0000003eb9h07P3eb9h70000
09<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ04H0
[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN0180
mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iUO02^IG`0G`2^IG`00`2kV@H00000
00000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`000000mLRN0?G8WP040?G8WPd00000
YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006000000000000I`00
002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fh
hP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fh
hP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00
^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003o
ool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`00
0000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0
oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fh
hP1N0:fhhP8000003P3oool00`00000040f7010=Q`06010=Q`030?o@R@000000]9>d01<0]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<0
00000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?oo
o`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000
002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3o
ool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]
^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]
^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool0
0;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`00
00H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0
[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000
oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<0
00000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fh
hP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>
0?ooo`030000000@3HL040f700D040f700<0om29010=Q`000000502dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h
0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`05010=
Q`030?o@R@0@3HL0000001@0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]
^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP03
0000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3o
ool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0
oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000
[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0
[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo
002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<00000
0?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]
^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL0100@3HL0103od8T040f7010=Q`00000D0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?oo
o`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`0=0?ooo`03
0000000@3HL040f700@040f700@0om29010=Q`0@3HL00000502dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`2i0?oo
o`00^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0oooo003o0?ooob`0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3o
ool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`03010=Q`050?o@R@0@3HL040f7010=Q`000000502dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`03010=
Q`050?o@R@0@3HL040f7010=Q`000000502dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`03010=Q`050?o@R@0@3HL040f7
010=Q`000000502dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00P3o
d8L00`0D48T0om270?o@Q`020?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@01@000000om270?o@Q`3od8L0512900D0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@3HL0
40f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00@000000?o@Q`3od8L051291P3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00@00000010=Q`0@3HL0om291P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`040000000@3HL040f70?o@
R@H040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00@00000010=Q`0@3HL0om291P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0512900L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL0om2900L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00>d0oooo?`0000000`0@3HL0
0000010=Q`06010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8Lo00000>d0
oooo003]0?ooo`03000000231@H0P`D603`0P`D600<040f708<51P0@3HL01P0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700H0om27?`231@H00`000000oooo0?ooo`3[0?ooo`00k@3o
ool00`000000P`D608<51P0m08<51PP040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`050?o@Qd00P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H0?P231@H7
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0103od8M108<51P030000003oool0
oooo0>/0oooo003]0?ooo`03000000231@H0P`D603l0P`D61P0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700<0om27@P231@H00`000000oooo0?ooo`3[0?ooo`00k03oool00`000000
P`D608<51P1208<51P@040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`020?o@Qd<0
P`D600<000000?ooo`3oool0j`3oool00>`0oooo00<0000008<51P231@H0@`231@H3010=Q`030000
002dTk@0]9>d0180]9>d00@000000?o@Q`3od8L0om27A@231@H00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000P`D608<51P1408<51P8040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`1608<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D604D0P`D600<0
40f70000002dTk@04`2dTk@00`000000om2708<51P1608<51P030000003oool0oooo0>X0oooo003/
0?ooo`03000000231@H0P`D604H0P`D600<000000;BC]02dTk@04P2dTk@00`000000P`D608<51P16
08<51P030000003oool0oooo0>X0oooo003/0?ooojP00000k03oool00>`0oooo00<000000;5cSP2a
Lhh0Y02aLhh400000>T0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00D000000<]P@@3;H440
bf110000003X0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP050000003;H440bf110<]P@@00
0000j03oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@020<]P@@030000
003oool0oooo0>D0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<]P@@3;H4400`3;
H4400`000000oooo0?ooo`3T0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003;H440
bf1100<0bf1100<000000?ooo`3oool0i03oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`00
0000bf110<]P@@040<]P@@030000003oool0oooo0><0oooo003/0?ooo`030000002aLhh0/G>>0:@0
/G>>00<000000<]P@@3;H440103;H4400`000000oooo0?ooo`3S0?ooo`00k03oool00`000000/G>>
0;5cSP2T0;5cSP030000003;H440bf1100D0bf1100<000000?ooo`3oool0hP3oool00>`0oooo00<0
00000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@050<]P@@030000003oool0oooo0>80oooo003/
0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<]P@@3;H4401P3;H4400`000000oooo0?ooo`3Q
0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003;H440bf1100L0bf1100<000000?oo
o`3oool0h03oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@070<]P@@03
0000003oool0oooo0>00oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<]P@@3;H440
203;H4400`000000oooo0?ooo`3O0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003;
H440bf1100T0bf11h@3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@03
0<]P@@L00000h03oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh6000000D0aOO]00<000000?oo
o`3oool0g`3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000aOO]0<Ggk@070<Ggk@03
0000003oool0oooo0>00oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<Ggk@35mnd0
1`35mnd00`000000oooo0?ooo`3P0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP0300000035
mnd0aOO]00H0aOO]00<000000?ooo`3oool0h@3oool00>`0ooooZ00000070<Ggk@030000003oool0
oooo0>80oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000<Ggk@35mnd01035mnd00`00
0000oooo0?ooo`3S0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`0300000035mnd0aOO]00@0
aOO]00<000000?ooo`3oool0h`3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000aOO]
0<Ggk@030<Ggk@030000003oool0oooo0>@0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<0
00000<Ggk@35mnd00P35mnd00`000000oooo0?ooo`3U0?ooo`00k03oool00`000000/;3G0;2`e`2T
0;2`e`0500000035mnd0aOO]0<Ggk@000000j03oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L0
1@000000aOO]0<Ggk@35mnd000000>P0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G1000003Y
0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`03
0000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0
Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003o
ool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G
00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?oo
o`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0ooooZ000003/0?ooo`00
k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo003/0?ooo`030000001F
b?D0E/Se0:@0E/Se00<000000?ooo`3oool0jP3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D0
0`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000E/Se05K8m@2R05K8m@030000003oool0oooo
0>/0oooo003]0?ooojH00000k@3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo0000\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.64046 .2356 m .6404 .24848 L .6202 .24848 L p .706 .605 .74 r
F P
0 g
s
.6404 .24848 m .64046 .26081 L .62025 .26081 L p .706 .548 .671 r
F P
0 g
s
.62025 .26081 m .6202 .24848 L .6404 .24848 L p .706 .548 .671 r
F P
0 g
s
.64046 .26081 m .64064 .27207 L .62041 .27207 L p .698 .477 .584 r
F P
0 g
s
.62041 .27207 m .62025 .26081 L .64046 .26081 L p .698 .477 .584 r
F P
0 g
s
.66736 .41123 m .63073 .41357 L .63073 .28045 L p .561 .458 .694 r
F P
0 g
s
.63101 .28056 m .66736 .41123 L .63073 .28045 L .561 .458 .694 r
F
.64093 .2818 m .64105 .28428 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64064 .27207 m .64093 .2818 L .63436 .2818 L p .676 .382 .468 r
F P
0 g
s
.62835 .27805 m .64064 .27207 L .63947 .27389 L .676 .382 .468 r
F
.63073 .27953 m .63947 .27389 L .63436 .2818 L F
.62835 .27805 m .63947 .27389 L .63073 .27953 L F
.6202 .24848 m .62025 .2356 L .64046 .2356 L p .706 .605 .74 r
F P
0 g
s
.62025 .26081 m .6202 .24848 L .62025 .2356 L p 0 0 .058 r
F P
0 g
s
.64064 .22269 m .64046 .2356 L .62025 .2356 L p .7 .653 .8 r
F P
0 g
s
.62025 .2356 m .62041 .22269 L .64064 .22269 L p .7 .653 .8 r
F P
0 g
s
.62025 .2356 m .62041 .22269 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62041 .27207 m .64064 .27207 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62065 .2818 m .62043 .27311 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62043 .27311 m .62041 .27207 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.64046 .26081 m .6404 .24848 L .64046 .2356 L p 0 0 .068 r
F P
0 g
s
.64046 .2356 m .64064 .22269 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64093 .2818 m .64064 .27207 L .64046 .26081 L p 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64105 .28068 L .64093 .2818 L 0 0 .068 r
F
.66736 .30238 m .66736 .41123 L p .64105 .29283 L .561 .458 .694 r
F P
0 g
s
.63929 .28487 m .64105 .28597 L .64105 .29283 L .561 .458 .694 r
F
.64105 .28597 m .66736 .30238 L .64105 .29283 L F
.64046 .26081 m .64105 .27605 L .64105 .28068 L 0 0 .068 r
F
.64105 .28428 m .64093 .2818 L p .64105 .28068 L F P
0 g
s
.64046 .26081 m .64105 .27259 L .64105 .27605 L 0 0 .068 r
F
.64105 .26215 m .66736 .30238 L .64105 .28597 L .561 .458 .694 r
F
.64291 .29822 m .64233 .29799 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.6435 .29571 m .64291 .29822 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64409 .29053 m .6435 .29571 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64465 .28287 m .64409 .29053 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64514 .27307 m .64465 .28287 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.66736 .24321 m .66736 .30238 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64105 .24547 m .66736 .24321 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64046 .26081 m .64542 .26151 L .64514 .27307 L 0 0 .068 r
F
.63929 .28487 m .66736 .41123 L .63101 .28056 L .561 .458 .694 r
F
.63436 .2818 m .63101 .28056 L .63073 .27953 L F
.63929 .28487 m .63101 .28056 L .63436 .2818 L F
.62025 .26081 m .62076 .28068 L .62065 .2818 L 0 0 .058 r
F
.62076 .28597 m .62722 .2818 L .62076 .36555 L .831 .679 .694 r
F
.62076 .36555 m .62722 .2818 L .63073 .41357 L F
.63073 .28045 m .63073 .41357 L p .62722 .2818 L F P
0 g
s
.62076 .28428 m .62065 .2818 L .62722 .2818 L p .628 .248 .303 r
F P
0 g
s
.63073 .27953 m .63073 .28045 L p .62722 .2818 L .831 .679 .694 r
F P
0 g
s
.63073 .28045 m .63073 .27953 L p .63101 .28056 L .561 .458 .694 r
F P
0 g
s
.63436 .2818 m .62065 .2818 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62076 .28428 m .62065 .2818 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.62065 .2818 m .62041 .27207 L .62025 .26081 L p 0 0 .058 r
F P
0 g
s
.62076 .2693 m .63073 .27953 L .62076 .28597 L .831 .679 .694 r
F
.62098 .28958 m .62076 .28428 L p .62085 .28426 L .628 .248 .303 r
F P
0 g
s
.6212 .28945 m .62103 .28423 L p .63436 .2818 L .628 .248 .303 r
F P
0 g
s
.62722 .2818 m .63436 .2818 L p .62076 .28428 L .628 .248 .303 r
F P
0 g
s
.63436 .2818 m .64093 .2818 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.63073 .27953 m .63073 .24636 L p .63898 .28351 L .561 .458 .694 r
F P
0 g
s
.63898 .28351 m .63929 .28487 L .63436 .2818 L .561 .458 .694 r
F
.63898 .28351 m .63436 .2818 L .63073 .27953 L F
.62098 .28958 m .63436 .2818 L .63773 .28305 L .628 .248 .303 r
F
.63073 .24636 m .63073 .27953 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.62025 .26081 m .62076 .27605 L .62076 .28068 L 0 0 .058 r
F
.64132 .28958 m .62098 .28958 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64132 .28958 m .64179 .29506 L .62139 .29506 L p .528 .047 .057 r
F P
0 g
s
.62139 .29506 m .62098 .28958 L .64132 .28958 L p .528 .047 .057 r
F P
0 g
s
.62185 .29799 m .62139 .29506 L .64179 .29506 L p .33 0 0 r
F P
0 g
s
.62185 .29799 m .62139 .29506 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.64179 .29506 m .64233 .29799 L .62185 .29799 L p .33 0 0 r
F P
0 g
s
.62234 .29822 m .62185 .29799 L .64233 .29799 L p .027 0 0 r
F P
0 g
s
.62234 .29822 m .62185 .29799 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62076 .24547 m .63073 .24636 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.62285 .29571 m .62234 .29822 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62336 .29053 m .62285 .29571 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62383 .28287 m .62336 .29053 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62426 .27307 m .62383 .28287 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62025 .26081 m .6245 .26151 L .62426 .27307 L 0 0 .058 r
F
.64105 .24547 m .66736 .24321 L p .64154 .24321 L .289 .763 .934 r
F P
0 g
s
.6435 .1725 m .64409 .17222 L p .6411 .24525 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64098 .24581 L .6411 .24525 L 0 0 .068 r
F
.64098 .24581 m .6435 .1725 L .6411 .24525 L F
.66736 .24321 m .64203 .24094 L .64154 .24321 L .289 .763 .934 r
F
.64514 .17995 m .64555 .18767 L p .64176 .2422 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64146 .24358 L .64176 .2422 L 0 0 .068 r
F
.64146 .24358 m .64514 .17995 L .64176 .2422 L F
.66736 .24321 m .64273 .23769 L .64203 .24094 L .289 .763 .934 r
F
.64555 .18767 m .64586 .19756 L p .64224 .23995 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64176 .2422 L .64224 .23995 L 0 0 .068 r
F
.64176 .2422 m .64555 .18767 L .64224 .23995 L F
.66736 .24321 m .64445 .22973 L .64273 .23769 L .289 .763 .934 r
F
.64586 .19756 m .64605 .20917 L p .6432 .23549 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64224 .23995 L .6432 .23549 L 0 0 .068 r
F
.64224 .23995 m .64586 .19756 L .6432 .23549 L F
.67134 .22759 m .64542 .22521 L p .66736 .24321 L .289 .763 .934 r
F P
0 g
s
.64605 .20917 m .64612 .22197 L p .6432 .23549 L 0 0 .068 r
F P
0 g
s
.64465 .17473 m .64514 .17995 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64409 .17222 m .64465 .17473 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64291 .17553 m .6435 .1725 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64233 .18113 m .64291 .17553 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64179 .18905 m .64233 .18113 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64132 .19891 m .64179 .18905 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64093 .21029 m .64132 .19891 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64064 .22269 m .64093 .21029 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64542 .22521 m .63515 .22426 L p .64445 .22973 L .289 .763 .934 r
F P
0 g
s
.66736 .24321 m .64542 .22521 L .64445 .22973 L .289 .763 .934 r
F
.63515 .22426 m .6245 .22521 L p .64273 .23769 L F P
0 g
s
.64273 .23769 m .6245 .22521 L .62301 .23328 L .289 .763 .934 r
F
.64093 .21029 m .64064 .22269 L .62041 .22269 L p .687 .697 .853 r
F P
0 g
s
.62041 .22269 m .62065 .21029 L .64093 .21029 L p .687 .697 .853 r
F P
0 g
s
.64132 .19891 m .64093 .21029 L .62065 .21029 L p .667 .737 .902 r
F P
0 g
s
.62504 .20917 m .62509 .22197 L p .6226 .23549 L 0 0 .058 r
F P
0 g
s
.62065 .21029 m .62098 .19891 L .64132 .19891 L p .667 .737 .902 r
F P
0 g
s
.64179 .18905 m .64132 .19891 L .62098 .19891 L p .634 .774 .948 r
F P
0 g
s
.62178 .23995 m .62487 .19756 L .6226 .23549 L 0 0 .058 r
F
.62098 .19891 m .62139 .18905 L .64179 .18905 L p .634 .774 .948 r
F P
0 g
s
.64233 .18113 m .64179 .18905 L .62139 .18905 L p .579 .804 .985 r
F P
0 g
s
.62139 .18905 m .62185 .18113 L .64233 .18113 L p .579 .804 .985 r
F P
0 g
s
.62461 .18767 m .62487 .19756 L p .62178 .23995 L 0 0 .058 r
F P
0 g
s
.62136 .2422 m .62461 .18767 L .62178 .23995 L 0 0 .058 r
F
.64291 .17553 m .64233 .18113 L .62185 .18113 L p .483 .816 .999 r
F P
0 g
s
.62185 .18113 m .62234 .17553 L .64291 .17553 L p .483 .816 .999 r
F P
0 g
s
.62111 .24358 m .62426 .17995 L .62136 .2422 L 0 0 .058 r
F
.6435 .1725 m .64291 .17553 L .62234 .17553 L p .311 .772 .946 r
F P
0 g
s
.62234 .17553 m .62285 .1725 L .6435 .1725 L p .311 .772 .946 r
F P
0 g
s
.62383 .17473 m .62426 .17995 L p .62111 .24358 L 0 0 .058 r
F P
0 g
s
.62093 .24454 m .62383 .17473 L .62111 .24358 L 0 0 .058 r
F
.63073 .24636 m .64105 .24547 L p .62094 .24447 L .289 .763 .934 r
F P
0 g
s
.64409 .17222 m .6435 .1725 L .62285 .1725 L p .033 .603 .739 r
F P
0 g
s
.62285 .1725 m .62336 .17222 L .64409 .17222 L p .033 .603 .739 r
F P
0 g
s
.62336 .17222 m .62383 .17473 L p .62093 .24454 L 0 0 .058 r
F P
0 g
s
.6208 .24525 m .62336 .17222 L .62093 .24454 L 0 0 .058 r
F
.62076 .24547 m .63073 .24636 L p .62094 .24447 L .289 .763 .934 r
F P
0 g
s
.62285 .1725 m .62336 .17222 L p .6208 .24525 L 0 0 .058 r
F P
0 g
s
.62025 .26081 m .6207 .24581 L .6208 .24525 L 0 0 .058 r
F
.6207 .24581 m .62285 .1725 L .6208 .24525 L F
.64154 .24321 m .62118 .24321 L .64105 .24547 L .289 .763 .934 r
F
.62234 .17553 m .62285 .1725 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62185 .18113 m .62234 .17553 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62139 .18905 m .62185 .18113 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62098 .19891 m .62139 .18905 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62065 .21029 m .62098 .19891 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62041 .22269 m .62065 .21029 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62118 .24321 m .59536 .24321 L .62094 .24447 L .289 .763 .934 r
F
.62118 .24321 m .62094 .24447 L .64105 .24547 L F
.59536 .24321 m .62076 .24547 L p .62094 .24447 L F P
0 g
s
.62025 .26081 m .6208 .24525 L .62093 .24454 L 0 0 .058 r
F
.62025 .26081 m .62093 .24454 L .62111 .24358 L F
.64203 .24094 m .62193 .23913 L .64154 .24321 L .289 .763 .934 r
F
.62426 .17995 m .62461 .18767 L p .62136 .2422 L 0 0 .058 r
F P
0 g
s
.62193 .23913 m .58139 .23549 L .62165 .24066 L .289 .763 .934 r
F
.62193 .23913 m .62165 .24066 L .64154 .24321 L F
.58139 .23549 m .59536 .24321 L p .62118 .24321 L F P
0 g
s
.64154 .24321 m .62165 .24066 L .62118 .24321 L .289 .763 .934 r
F
.62165 .24066 m .58139 .23549 L .62118 .24321 L F
.62025 .26081 m .62111 .24358 L .62136 .2422 L 0 0 .058 r
F
.62025 .26081 m .62136 .2422 L .62178 .23995 L F
.64273 .23769 m .62301 .23328 L .64203 .24094 L .289 .763 .934 r
F
.62487 .19756 m .62504 .20917 L p .6226 .23549 L 0 0 .058 r
F P
0 g
s
.62301 .23328 m .59762 .22759 L .62267 .23512 L .289 .763 .934 r
F
.62301 .23328 m .62267 .23512 L .64203 .24094 L F
.59762 .22759 m .58139 .23549 L p .62193 .23913 L F P
0 g
s
.64203 .24094 m .62267 .23512 L .62193 .23913 L .289 .763 .934 r
F
.62267 .23512 m .59762 .22759 L .62193 .23913 L F
.62025 .26081 m .62178 .23995 L .6226 .23549 L 0 0 .058 r
F
.63073 .24636 m .64105 .26215 L .63929 .28487 L .561 .458 .694 r
F
.64105 .26215 m .64105 .28597 L .63929 .28487 L F
.64233 .29799 m .64179 .29506 L p .64105 .27605 L 0 0 .068 r
F P
0 g
s
.64105 .27259 m .64233 .29799 L .64105 .27605 L 0 0 .068 r
F
.64179 .29506 m .64132 .28958 L p .64105 .28068 L F P
0 g
s
.64105 .27605 m .64179 .29506 L .64105 .28068 L 0 0 .068 r
F
.64132 .28958 m .64105 .28428 L p .64105 .28068 L F P
0 g
s
.64465 .28287 m .64514 .27307 L .62426 .27307 L p .627 .779 .954 r
F P
0 g
s
.62426 .27307 m .62383 .28287 L .64465 .28287 L p .627 .779 .954 r
F P
0 g
s
.67134 .22759 m .64542 .22521 L p .64542 .26522 L .835 .682 .693 r
F P
0 g
s
.66141 .27411 m .64542 .26522 L .64542 .34901 L .835 .682 .693 r
F
.68441 .40548 m .66736 .41123 L .66736 .24321 L p 0 0 .497 r
F P
0 g
s
.66736 .24321 m .68441 .23549 L .68441 .40548 L p 0 0 .497 r
F P
0 g
s
.66736 .24321 m .68441 .23549 L .67134 .22759 L p .289 .763 .934 r
F P
0 g
s
.67134 .22759 m .64542 .26522 L .66141 .27411 L .835 .682 .693 r
F
.64542 .26522 m .64514 .27307 L p .64542 .26151 L 0 0 .068 r
F P
0 g
s
.64514 .27307 m .64542 .26522 L p .63139 .26153 L .663 .742 .908 r
F P
0 g
s
.64555 .26153 m .64542 .26522 L p .64542 .26151 L 0 0 .068 r
F P
0 g
s
.63877 .26153 m .63139 .26153 L p .64542 .26522 L .663 .742 .908 r
F P
0 g
s
.62792 .26339 m .64514 .27307 L .63139 .26153 L .663 .742 .908 r
F
.64445 .22973 m .63515 .22426 L .64273 .23769 L .289 .763 .934 r
F
.64046 .26081 m .6432 .23549 L .64612 .22197 L 0 0 .068 r
F
.64586 .24877 m .64555 .26153 L p .64046 .26081 L F P
0 g
s
.64605 .23538 m .64586 .24877 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64612 .22197 m .64605 .23538 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.63073 .24636 m .64105 .24547 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64105 .28428 m .64132 .28958 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64233 .29799 m .64291 .29822 L .62234 .29822 L p .027 0 0 r
F P
0 g
s
.64291 .29822 m .6435 .29571 L .62285 .29571 L p .266 .752 .921 r
F P
0 g
s
.62285 .29571 m .62234 .29822 L .64291 .29822 L p .266 .752 .921 r
F P
0 g
s
.6435 .29571 m .64409 .29053 L .62336 .29053 L p .458 .814 .997 r
F P
0 g
s
.62336 .29053 m .62285 .29571 L .6435 .29571 L p .458 .814 .997 r
F P
0 g
s
.64409 .29053 m .64465 .28287 L .62383 .28287 L p .566 .808 .99 r
F P
0 g
s
.62383 .28287 m .62336 .29053 L .64409 .29053 L p .566 .808 .99 r
F P
0 g
s
.63515 .22426 m .6245 .22521 L p .6245 .26522 L .556 .454 .694 r
F P
0 g
s
.63515 .22426 m .6245 .26522 L .62663 .26408 L .556 .454 .694 r
F
.62426 .27307 m .64514 .27307 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.6245 .26522 m .62426 .27307 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62139 .29506 m .62098 .28958 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.62076 .27605 m .62139 .29506 L .62076 .28068 L 0 0 .058 r
F
.60619 .29538 m .62076 .28597 L .62076 .36555 L .831 .679 .694 r
F
.63073 .41357 m .59536 .41123 L .59536 .24321 L p F P
0 g
s
.63515 .25857 m .63515 .22426 L p .62632 .26553 L .556 .454 .694 r
F P
0 g
s
.64542 .22521 m .63515 .22426 L p .63818 .26104 L .835 .682 .693 r
F P
0 g
s
.62485 .25014 m .62461 .26153 L .63877 .26153 L p .686 .701 .858 r
F P
0 g
s
.64542 .26697 m .63818 .26104 L .64542 .34901 L .835 .682 .693 r
F
.64542 .22521 m .63818 .26104 L .64542 .26697 L F
.63515 .22426 m .63515 .39713 L p .64542 .34901 L F P
0 g
s
.62487 .24877 m .62485 .25014 L p .64555 .26153 L .686 .701 .858 r
F P
0 g
s
.63877 .26153 m .64555 .26153 L p .62485 .25014 L .686 .701 .858 r
F P
0 g
s
.59762 .3996 m .63515 .39713 L .63515 .25857 L p .556 .454 .694 r
F P
0 g
s
.62632 .26553 m .59762 .3996 L .63515 .25857 L .556 .454 .694 r
F
.64586 .24877 m .62487 .24877 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.64555 .26153 m .64583 .25014 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.64583 .25014 m .64586 .24877 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.62461 .26153 m .6245 .26522 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62025 .26081 m .6226 .23549 L .6245 .22521 L 0 0 .058 r
F
.62025 .26081 m .6245 .22521 L .6245 .22676 L F
.6245 .22521 m .59762 .22759 L p .62301 .23328 L .289 .763 .934 r
F P
0 g
s
.62487 .24877 m .62461 .26153 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62504 .23538 m .62487 .24877 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62509 .22197 m .62504 .23538 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.59536 .24321 m .62076 .24547 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.6245 .22521 m .59762 .22759 L p .6206 .26731 L .556 .454 .694 r
F P
0 g
s
.6245 .26522 m .62426 .27307 L p .6245 .26151 L 0 0 .058 r
F P
0 g
s
.6245 .26522 m .6206 .26731 L .6245 .27403 L .556 .454 .694 r
F
.6245 .22521 m .6206 .26731 L .6245 .26522 L F
.64542 .26522 m .64555 .26153 L .63877 .26153 L p .663 .742 .908 r
F P
0 g
s
.63139 .26153 m .62461 .26153 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62663 .26408 m .6245 .26522 L .6245 .27403 L .556 .454 .694 r
F
.6245 .22676 m .6245 .22521 L .62509 .22197 L 0 0 .058 r
F
.62461 .26153 m .6245 .26522 L p .6245 .26151 L F P
0 g
s
.59536 .24321 m .62076 .2693 L .60619 .29538 L .831 .679 .694 r
F
.62076 .2693 m .62076 .28597 L .60619 .29538 L F
.62098 .28958 m .62076 .28428 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.59762 .22759 m .59762 .3996 L p .6245 .27403 L .556 .454 .694 r
F P
0 g
s
.67134 .3996 m .68441 .40548 L .68441 .23549 L p .989 .808 .421 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59536 .41123 m .63073 .41357 L .66736 .41123 L p .224 .73 .894 r
F P
0 g
s
.59536 .41123 m .58139 .40548 L .58139 .23549 L p .995 .812 .445 r
F P
0 g
s
.58139 .23549 m .59536 .24321 L .59536 .41123 L p .995 .812 .445 r
F P
0 g
s
.58139 .40548 m .59536 .41123 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.59762 .3996 m .58139 .40548 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.63515 .39713 m .59762 .3996 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.67134 .3996 m .63515 .39713 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.66736 .41123 m .68441 .40548 L .67134 .3996 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.37975 .2356 m .3798 .24848 L .3596 .24848 L p .706 .605 .74 r
F P
0 g
s
.3798 .24848 m .37975 .26081 L .35954 .26081 L p .706 .548 .671 r
F P
0 g
s
.35954 .26081 m .3596 .24848 L .3798 .24848 L p .706 .548 .671 r
F P
0 g
s
.37975 .26081 m .37959 .27207 L .35936 .27207 L p .698 .477 .584 r
F P
0 g
s
.35936 .27207 m .35954 .26081 L .37975 .26081 L p .698 .477 .584 r
F P
0 g
s
.37959 .27207 m .37935 .2818 L .37278 .2818 L p .676 .382 .468 r
F P
0 g
s
.36927 .41357 m .36927 .28045 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.36927 .28045 m .36927 .27953 L p .37024 .28082 L .556 .454 .694 r
F P
0 g
s
.37024 .28082 m .37924 .29283 L .36927 .28045 L .556 .454 .694 r
F
.37935 .2818 m .37924 .28428 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.36698 .27805 m .37959 .27207 L .37832 .27389 L .676 .382 .468 r
F
.36927 .27953 m .37832 .27389 L .37278 .2818 L F
.36698 .27805 m .37832 .27389 L .36927 .27953 L F
.3596 .24848 m .35954 .2356 L .37975 .2356 L p .706 .605 .74 r
F P
0 g
s
.35954 .26081 m .3596 .24848 L .35954 .2356 L p .772 .63 .068 r
F P
0 g
s
.35954 .2356 m .35936 .22269 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35907 .2818 m .35936 .27207 L .35954 .26081 L p .772 .63 .068 r
F P
0 g
s
.35954 .26081 m .35895 .28068 L .35907 .2818 L .772 .63 .068 r
F
.35895 .36555 m .36916 .2805 L .36927 .41357 L .828 .676 .694 r
F
.36927 .28045 m .36927 .41357 L p .36916 .2805 L F P
0 g
s
.34386 .29538 m .35895 .28597 L .35895 .36555 L .828 .676 .694 r
F
.35895 .28597 m .36927 .27953 L .35895 .36555 L F
.35895 .28428 m .35907 .2818 L .36564 .2818 L p .628 .248 .303 r
F P
0 g
s
.35954 .26081 m .35895 .27605 L .35895 .28068 L .772 .63 .068 r
F
.35895 .28428 m .35907 .2818 L p .35895 .28068 L F P
0 g
s
.36927 .27953 m .36927 .28045 L p .36916 .2805 L .828 .676 .694 r
F P
0 g
s
.37753 .28487 m .37924 .29283 L .37024 .28082 L .556 .454 .694 r
F
.37278 .2818 m .37024 .28082 L .36927 .27953 L F
.37753 .28487 m .37024 .28082 L .37278 .2818 L F
.35907 .2818 m .36698 .27805 L .36927 .27953 L .676 .382 .468 r
F
.37278 .2818 m .36564 .2818 L p .36927 .27953 L F P
0 g
s
.36564 .2818 m .35907 .2818 L p .36927 .27953 L .676 .382 .468 r
F P
0 g
s
.34276 .29028 m .35895 .28428 L .34386 .29538 L .828 .676 .694 r
F
.35895 .28428 m .36564 .2818 L .35895 .28597 L F
.35895 .28428 m .35895 .28597 L .34386 .29538 L F
.33264 .24321 m .35895 .2693 L .35895 .27397 L F
.35954 .26081 m .35895 .27259 L .35895 .27605 L .772 .63 .068 r
F
.33264 .24321 m .35895 .27397 L .34276 .29028 L .828 .676 .694 r
F
.35936 .27207 m .37959 .27207 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.35907 .2818 m .35933 .27311 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.35933 .27311 m .35936 .27207 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.37975 .26081 m .37924 .27605 L .37924 .28068 L .763 .623 .058 r
F
.37975 .26081 m .3798 .24848 L .37975 .2356 L p F P
0 g
s
.37959 .22269 m .37975 .2356 L .35954 .2356 L p .7 .653 .8 r
F P
0 g
s
.37975 .2356 m .37959 .22269 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37935 .2818 m .37959 .27207 L .37975 .26081 L p .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .37924 .28068 L .37935 .2818 L .763 .623 .058 r
F
.40464 .30238 m .40464 .41123 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.37753 .28487 m .37924 .28597 L .37924 .29283 L .556 .454 .694 r
F
.37924 .28597 m .40464 .30238 L .37924 .29283 L F
.37975 .26081 m .37924 .27259 L .37924 .27605 L .763 .623 .058 r
F
.37724 .28351 m .37924 .28489 L .37753 .28487 L .556 .454 .694 r
F
.37924 .28489 m .37924 .28597 L .37753 .28487 L F
.37975 .26081 m .37924 .26985 L .37924 .27259 L .763 .623 .058 r
F
.37278 .2818 m .37935 .2818 L p .37436 .28241 L .628 .248 .303 r
F P
0 g
s
.37924 .28428 m .37935 .2818 L p .37924 .28068 L .763 .623 .058 r
F P
0 g
s
.37603 .28305 m .37436 .28241 L .37935 .2818 L .628 .248 .303 r
F
.36927 .24636 m .37924 .26215 L .37724 .28351 L .556 .454 .694 r
F
.37924 .26215 m .37924 .28428 L .37724 .28351 L F
.37924 .28428 m .37924 .28489 L .37724 .28351 L F
.36927 .27953 m .36927 .24636 L p .37724 .28351 L F P
0 g
s
.37724 .28351 m .37753 .28487 L .37278 .2818 L .556 .454 .694 r
F
.37724 .28351 m .37278 .2818 L .36927 .27953 L F
.37902 .28958 m .35868 .28958 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.37924 .28428 m .37902 .28958 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.37902 .28958 m .37861 .29506 L .35821 .29506 L p .528 .047 .057 r
F P
0 g
s
.35821 .29506 m .35868 .28958 L .37902 .28958 L p .528 .047 .057 r
F P
0 g
s
.37861 .29506 m .37815 .29799 L .35767 .29799 L p .33 0 0 r
F P
0 g
s
.35767 .29799 m .35821 .29506 L .37861 .29506 L p .33 0 0 r
F P
0 g
s
.37815 .29799 m .37766 .29822 L .35709 .29822 L p .027 0 0 r
F P
0 g
s
.35709 .29822 m .35767 .29799 L .37815 .29799 L p .027 0 0 r
F P
0 g
s
.37715 .29571 m .37766 .29822 L p .37924 .26985 L .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .37924 .26759 L .37924 .26985 L .763 .623 .058 r
F
.37924 .26759 m .37715 .29571 L .37924 .26985 L F
.39769 .29136 m .40464 .30238 L .37924 .28489 L .556 .454 .694 r
F
.39769 .29136 m .37924 .28489 L .37924 .28428 L F
.37664 .29053 m .37715 .29571 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37617 .28287 m .37664 .29053 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37574 .27307 m .37617 .28287 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.36927 .24636 m .37924 .24547 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.37975 .26081 m .3755 .26151 L .37574 .27307 L .763 .623 .058 r
F
.36564 .2818 m .37278 .2818 L p .35895 .28428 L .628 .248 .303 r
F P
0 g
s
.35895 .28428 m .37278 .2818 L .37436 .28241 L .628 .248 .303 r
F
.35868 .28958 m .35895 .28428 L p .37436 .28241 L F P
0 g
s
.35868 .28958 m .37436 .28241 L .37603 .28305 L .628 .248 .303 r
F
.35954 .26081 m .35895 .26759 L .35895 .26985 L .772 .63 .068 r
F
.35954 .26081 m .35895 .26985 L .35895 .27259 L F
.36927 .24636 m .36927 .27953 L p .35895 .2693 L .828 .676 .694 r
F P
0 g
s
.35895 .27397 m .35895 .28428 L .34276 .29028 L .828 .676 .694 r
F
.33264 .24321 m .35895 .24547 L p .35895 .2693 L F P
0 g
s
.35591 .29053 m .3565 .29571 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35535 .28287 m .35591 .29053 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35486 .27307 m .35535 .28287 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35954 .26081 m .35458 .26151 L .35486 .27307 L .772 .63 .068 r
F
.35458 .26522 m .35486 .27307 L p .35458 .26151 L F P
0 g
s
.35445 .18767 m .35414 .19756 L p .35458 .20272 L .772 .63 .068 r
F P
0 g
s
.33264 .24321 m .35895 .24547 L p .35846 .24321 L .289 .763 .934 r
F P
0 g
s
.35486 .17995 m .35445 .18767 L p .35824 .2422 L .772 .63 .068 r
F P
0 g
s
.31559 .23549 m .33264 .24321 L p .35846 .24321 L .289 .763 .934 r
F P
0 g
s
.35758 .23913 m .31559 .23549 L .35846 .24321 L .289 .763 .934 r
F
.35954 .26081 m .35854 .24358 L .35824 .2422 L .772 .63 .068 r
F
.35854 .24358 m .35486 .17995 L .35824 .2422 L F
.35776 .23995 m .35458 .18956 L .35458 .20272 L F
.35824 .2422 m .35458 .18956 L .35776 .23995 L F
.35954 .2356 m .35936 .22269 L .37959 .22269 L p .7 .653 .8 r
F P
0 g
s
.37935 .21029 m .37959 .22269 L .35936 .22269 L p .687 .697 .853 r
F P
0 g
s
.35936 .22269 m .35907 .21029 L .37935 .21029 L p .687 .697 .853 r
F P
0 g
s
.37902 .19891 m .37935 .21029 L .35907 .21029 L p .667 .737 .902 r
F P
0 g
s
.35907 .21029 m .35868 .19891 L .37902 .19891 L p .667 .737 .902 r
F P
0 g
s
.37861 .18905 m .37902 .19891 L .35868 .19891 L p .634 .774 .948 r
F P
0 g
s
.37513 .19756 m .37496 .20917 L p .3774 .23549 L .763 .623 .058 r
F P
0 g
s
.35414 .19756 m .35395 .20917 L p .3568 .23549 L .772 .63 .068 r
F P
0 g
s
.32866 .22759 m .31559 .23549 L p .35758 .23913 L .289 .763 .934 r
F P
0 g
s
.35632 .23328 m .32866 .22759 L .35758 .23913 L .289 .763 .934 r
F
.35954 .26081 m .35776 .23995 L .3568 .23549 L .772 .63 .068 r
F
.35776 .23995 m .35414 .19756 L .3568 .23549 L F
.37822 .23995 m .37513 .19756 L .3774 .23549 L .763 .623 .058 r
F
.35868 .19891 m .35821 .18905 L .37861 .18905 L p .634 .774 .948 r
F P
0 g
s
.37815 .18113 m .37861 .18905 L .35821 .18905 L p .579 .804 .985 r
F P
0 g
s
.37539 .18767 m .37513 .19756 L p .37822 .23995 L .763 .623 .058 r
F P
0 g
s
.35458 .22521 m .32866 .22759 L p .35632 .23328 L .289 .763 .934 r
F P
0 g
s
.35954 .26081 m .3568 .23549 L .35458 .22521 L .772 .63 .068 r
F
.35954 .26081 m .35458 .22521 L .35458 .22676 L F
.35954 .26081 m .35824 .2422 L .35776 .23995 L F
.35458 .22521 m .35083 .26731 L .35458 .26522 L .55 .449 .693 r
F
.35414 .24877 m .35445 .26153 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35395 .23538 m .35414 .24877 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35458 .22521 m .32866 .22759 L p .35083 .26731 L .55 .449 .693 r
F P
0 g
s
.35388 .22197 m .35395 .23538 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35535 .17473 m .35486 .17995 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35591 .17222 m .35535 .17473 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.3565 .1725 m .35591 .17222 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35709 .17553 m .3565 .1725 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35767 .18113 m .35709 .17553 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35821 .18905 m .35767 .18113 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35868 .19891 m .35821 .18905 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35907 .21029 m .35868 .19891 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35936 .22269 m .35907 .21029 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35895 .25288 m .36927 .24636 L .35895 .2693 L .828 .676 .694 r
F
.35395 .20917 m .35388 .22197 L p .3568 .23549 L .772 .63 .068 r
F P
0 g
s
.37864 .2422 m .37539 .18767 L .37822 .23995 L .763 .623 .058 r
F
.37496 .20917 m .37491 .22197 L p .3774 .23549 L F P
0 g
s
.36485 .22426 m .35458 .22521 L p .37699 .23327 L .289 .763 .934 r
F P
0 g
s
.35821 .18905 m .35767 .18113 L .37815 .18113 L p .579 .804 .985 r
F P
0 g
s
.37766 .17553 m .37815 .18113 L .35767 .18113 L p .483 .816 .999 r
F P
0 g
s
.37574 .17995 m .37539 .18767 L p .37864 .2422 L .763 .623 .058 r
F P
0 g
s
.37889 .24358 m .37574 .17995 L .37864 .2422 L .763 .623 .058 r
F
.35767 .18113 m .35709 .17553 L .37766 .17553 L p .483 .816 .999 r
F P
0 g
s
.37715 .1725 m .37766 .17553 L .35709 .17553 L p .311 .772 .946 r
F P
0 g
s
.37617 .17473 m .37574 .17995 L p .37889 .24358 L .763 .623 .058 r
F P
0 g
s
.37911 .24548 m .37924 .24547 L p .37911 .24545 L .289 .763 .934 r
F P
0 g
s
.37911 .24545 m .35846 .24321 L .37911 .24548 L .289 .763 .934 r
F
.36927 .24636 m .37911 .24548 L p .35846 .24321 L F P
0 g
s
.37882 .24321 m .35846 .24321 L .37924 .24547 L .289 .763 .934 r
F
.37975 .26081 m .37907 .24454 L .37889 .24358 L .763 .623 .058 r
F
.37907 .24454 m .37617 .17473 L .37889 .24358 L F
.37781 .23769 m .35458 .22521 L .35632 .23328 L .289 .763 .934 r
F
.35709 .17553 m .3565 .1725 L .37715 .1725 L p .311 .772 .946 r
F P
0 g
s
.37664 .17222 m .37715 .1725 L .3565 .1725 L p .033 .603 .739 r
F P
0 g
s
.37664 .17222 m .37617 .17473 L p .37907 .24454 L .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .3792 .24525 L .37907 .24454 L .763 .623 .058 r
F
.3792 .24525 m .37664 .17222 L .37907 .24454 L F
.37715 .1725 m .37664 .17222 L p .37975 .26081 L F P
0 g
s
.37766 .17553 m .37715 .1725 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37815 .18113 m .37766 .17553 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37861 .18905 m .37815 .18113 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37902 .19891 m .37861 .18905 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37935 .21029 m .37902 .19891 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37959 .22269 m .37935 .21029 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.40238 .22759 m .3755 .22521 L p .40464 .24321 L .289 .763 .934 r
F P
0 g
s
.3755 .22521 m .36485 .22426 L p .37634 .22973 L .289 .763 .934 r
F P
0 g
s
.40464 .24321 m .3755 .22521 L .37634 .22973 L .289 .763 .934 r
F
.40464 .24321 m .37699 .23327 L .37781 .23769 L F
.37699 .23327 m .35458 .22521 L .37781 .23769 L F
.40464 .24321 m .37634 .22973 L .37699 .23327 L F
.37634 .22973 m .36485 .22426 L .37699 .23327 L F
.37882 .24321 m .35758 .23913 L .35846 .24321 L F
.37841 .24094 m .35758 .23913 L .37882 .24321 L F
.37975 .26081 m .37889 .24358 L .37864 .2422 L .763 .623 .058 r
F
.37841 .24094 m .37264 .23894 L .37234 .24041 L .289 .763 .934 r
F
.37264 .23894 m .35632 .23328 L .37234 .24041 L F
.37234 .24041 m .35632 .23328 L .35758 .23913 L F
.37781 .23769 m .35632 .23328 L .37841 .24094 L F
.35895 .24547 m .36927 .24636 L p .35846 .24321 L F P
0 g
s
.36045 .2456 m .36927 .24636 L p .35895 .25288 L .828 .676 .694 r
F P
0 g
s
.3755 .22521 m .36485 .22426 L p .36799 .26104 L .831 .678 .694 r
F P
0 g
s
.3755 .22521 m .36799 .26104 L .36803 .26107 L .831 .678 .694 r
F
.35895 .24547 m .36045 .2456 L p .35895 .25288 L .828 .676 .694 r
F P
0 g
s
.36485 .22426 m .35458 .22521 L p .35458 .26522 L .55 .449 .693 r
F P
0 g
s
.35458 .26522 m .35486 .27307 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35506 .26495 m .35458 .26522 L .35458 .26697 L .55 .449 .693 r
F
.36485 .22426 m .35458 .26522 L .35506 .26495 L F
.3565 .29571 m .35709 .29822 L p .35895 .26985 L .772 .63 .068 r
F P
0 g
s
.35895 .26759 m .3565 .29571 L .35895 .26985 L .772 .63 .068 r
F
.35709 .29822 m .35767 .29799 L p .35895 .27259 L F P
0 g
s
.35895 .26985 m .35709 .29822 L .35895 .27259 L .772 .63 .068 r
F
.35895 .27259 m .35767 .29799 L .35895 .27605 L F
.35895 .2693 m .36927 .27953 L .35895 .27397 L .828 .676 .694 r
F
.35486 .27307 m .37574 .27307 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.36485 .22426 m .35458 .26697 L .35633 .26553 L .55 .449 .693 r
F
.35445 .26153 m .35458 .26522 L p .35458 .26151 L .772 .63 .068 r
F P
0 g
s
.36123 .26153 m .36861 .26153 L p .36485 .25857 L .686 .701 .858 r
F P
0 g
s
.37574 .27307 m .3755 .26522 L p .36123 .26153 L .663 .742 .908 r
F P
0 g
s
.36861 .26153 m .36123 .26153 L p .3755 .26522 L .663 .742 .908 r
F P
0 g
s
.35788 .26339 m .37574 .27307 L .36123 .26153 L .663 .742 .908 r
F
.35895 .27397 m .36564 .2818 L .35895 .28428 L .828 .676 .694 r
F
.35767 .29799 m .35821 .29506 L p .35895 .27605 L .772 .63 .068 r
F P
0 g
s
.35895 .27397 m .36927 .27953 L .36564 .2818 L .828 .676 .694 r
F
.35821 .29506 m .35868 .28958 L p .35895 .28068 L .772 .63 .068 r
F P
0 g
s
.35895 .27605 m .35821 .29506 L .35895 .28068 L .772 .63 .068 r
F
.35868 .28958 m .35895 .28428 L p .35895 .28068 L F P
0 g
s
.36927 .41357 m .33264 .41123 L .33264 .24321 L p .828 .676 .694 r
F P
0 g
s
.37766 .29822 m .37715 .29571 L .3565 .29571 L p .266 .752 .921 r
F P
0 g
s
.3565 .29571 m .35709 .29822 L .37766 .29822 L p .266 .752 .921 r
F P
0 g
s
.37715 .29571 m .37664 .29053 L .35591 .29053 L p .458 .814 .997 r
F P
0 g
s
.35591 .29053 m .3565 .29571 L .37715 .29571 L p .458 .814 .997 r
F P
0 g
s
.37664 .29053 m .37617 .28287 L .35535 .28287 L p .566 .808 .99 r
F P
0 g
s
.35535 .28287 m .35591 .29053 L .37664 .29053 L p .566 .808 .99 r
F P
0 g
s
.37617 .28287 m .37574 .27307 L .35486 .27307 L p .627 .779 .954 r
F P
0 g
s
.35486 .27307 m .35535 .28287 L .37617 .28287 L p .627 .779 .954 r
F P
0 g
s
.36485 .39713 m .36485 .25857 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.36485 .25857 m .36485 .22426 L p .35633 .26553 L .55 .449 .693 r
F P
0 g
s
.35633 .26553 m .35458 .27403 L .36485 .25857 L .55 .449 .693 r
F
.37924 .41291 m .36927 .41357 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.36485 .22426 m .36485 .39713 L p .3755 .34901 L .831 .678 .694 r
F P
0 g
s
.35414 .24877 m .35417 .25014 L p .36684 .25694 L .686 .701 .858 r
F P
0 g
s
.3755 .22521 m .36803 .26107 L .3755 .26522 L .831 .678 .694 r
F
.36803 .26107 m .36801 .26121 L .36861 .26153 L F
.36803 .26107 m .36861 .26153 L .3755 .26522 L F
.36722 .25663 m .36684 .25694 L .37539 .26153 L .686 .701 .858 r
F
.35414 .24877 m .36684 .25694 L .36722 .25663 L F
.35445 .26153 m .35458 .26522 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35417 .25014 m .35445 .26153 L .36123 .26153 L p .686 .701 .858 r
F P
0 g
s
.35417 .25014 m .36123 .26153 L .36485 .25857 L .686 .701 .858 r
F
.35633 .26553 m .35458 .26697 L .35458 .27403 L .55 .449 .693 r
F
.36861 .26153 m .37539 .26153 L p .35417 .25014 L .686 .701 .858 r
F P
0 g
s
.36803 .26107 m .36799 .26104 L .36801 .26121 L .831 .678 .694 r
F
.3755 .26522 m .36801 .26121 L .3755 .34901 L F
.3755 .26522 m .37539 .26153 L .36861 .26153 L p .663 .742 .908 r
F P
0 g
s
.36123 .26153 m .35445 .26153 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35458 .26522 m .35083 .26731 L .35458 .27403 L .55 .449 .693 r
F
.35458 .22676 m .35458 .22521 L .35388 .22197 L .772 .63 .068 r
F
.37975 .26081 m .37864 .2422 L .37822 .23995 L .763 .623 .058 r
F
.40464 .24321 m .37781 .23769 L .37841 .24094 L .289 .763 .934 r
F
.37975 .26081 m .37822 .23995 L .3774 .23549 L .763 .623 .058 r
F
.40464 .24321 m .37841 .24094 L .37882 .24321 L .289 .763 .934 r
F
.37975 .26081 m .3774 .23549 L .37491 .22197 L .763 .623 .058 r
F
.37924 .24547 m .40464 .24321 L p .37882 .24321 L .289 .763 .934 r
F P
0 g
s
.35458 .18956 m .35445 .18767 L .35458 .20272 L .772 .63 .068 r
F
.33264 .41123 m .31559 .40548 L .31559 .23549 L p 1 .816 .497 r
F P
0 g
s
.31559 .23549 m .33264 .24321 L .33264 .41123 L p 1 .816 .497 r
F P
0 g
s
.32866 .22759 m .32866 .3996 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.32866 .3996 m .35458 .39783 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.35458 .39783 m .36485 .39713 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.37539 .26153 m .3755 .26522 L p .3755 .26151 L .763 .623 .058 r
F P
0 g
s
.3755 .26522 m .37574 .27307 L p .3755 .26151 L .763 .623 .058 r
F P
0 g
s
.37924 .26215 m .39769 .29136 L .37924 .28428 L .556 .454 .694 r
F
.37766 .29822 m .37815 .29799 L p .37924 .27259 L .763 .623 .058 r
F P
0 g
s
.37924 .26985 m .37766 .29822 L .37924 .27259 L .763 .623 .058 r
F
.37924 .28489 m .40464 .30238 L .37924 .28597 L .556 .454 .694 r
F
.37815 .29799 m .37861 .29506 L p .37924 .27605 L .763 .623 .058 r
F P
0 g
s
.37924 .27259 m .37815 .29799 L .37924 .27605 L .763 .623 .058 r
F
.37902 .28958 m .37924 .28428 L p .37924 .28068 L F P
0 g
s
.40464 .24321 m .40464 .30238 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.37513 .24877 m .37539 .26153 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37496 .23538 m .37513 .24877 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37491 .22197 m .37496 .23538 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37924 .24547 m .40464 .24321 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.40464 .41123 m .37924 .41291 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.37861 .29506 m .37902 .28958 L p .37924 .28068 L .763 .623 .058 r
F P
0 g
s
.37924 .27605 m .37861 .29506 L .37924 .28068 L .763 .623 .058 r
F
.40238 .22759 m .3755 .22521 L p .3755 .34901 L .831 .678 .694 r
F P
0 g
s
.58139 .40548 m .59762 .3996 L .59762 .22759 L p 0 0 .479 r
F P
0 g
s
.59762 .22759 m .58139 .23549 L .58139 .40548 L p 0 0 .479 r
F P
0 g
s
.68441 .23549 m .67134 .22759 L .67134 .3996 L p .989 .808 .421 r
F P
0 g
s
.63515 .39713 m .67134 .3996 L .67134 .22759 L p .835 .682 .693 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.41861 .40548 m .40464 .41123 L .40464 .24321 L p 0 0 .445 r
F P
0 g
s
.40464 .24321 m .41861 .23549 L .41861 .40548 L p 0 0 .445 r
F P
0 g
s
.40238 .3996 m .41861 .40548 L .41861 .23549 L p .999 .816 .479 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.33264 .41123 m .36927 .41357 L .40464 .41123 L p .224 .73 .894 r
F P
0 g
s
.31559 .40548 m .33264 .41123 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.32866 .3996 m .31559 .40548 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.36485 .39713 m .32866 .3996 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.40238 .3996 m .36485 .39713 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.40464 .41123 m .41861 .40548 L .40238 .3996 L p .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40464 .24321 m .41861 .23549 L .40238 .22759 L p .289 .763 .934 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31559 .40548 m .32866 .3996 L .32866 .22759 L p 0 0 .421 r
F P
0 g
s
.32866 .22759 m .31559 .23549 L .31559 .40548 L p 0 0 .421 r
F P
0 g
s
.41861 .23549 m .40238 .22759 L .40238 .3996 L p .999 .816 .479 r
F P
0 g
s
.36485 .39713 m .40238 .3996 L .40238 .22759 L p .831 .678 .694 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3565 .1725 m .35591 .17222 L .37664 .17222 L p .033 .603 .739 r
F P
0 g
s
.64465 .17473 m .64409 .17222 L .62336 .17222 L p .283 0 0 r
F P
0 g
s
.37617 .17473 m .37664 .17222 L .35591 .17222 L p .283 0 0 r
F P
0 g
s
.62336 .17222 m .62383 .17473 L .64465 .17473 L p .283 0 0 r
F P
0 g
s
.35591 .17222 m .35535 .17473 L .37617 .17473 L p .283 0 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64514 .17995 m .64465 .17473 L .62383 .17473 L p .505 .008 .009 r
F P
0 g
s
.37574 .17995 m .37617 .17473 L .35535 .17473 L p .505 .008 .009 r
F P
0 g
s
.62383 .17473 m .62426 .17995 L .64514 .17995 L p .505 .008 .009 r
F P
0 g
s
.35535 .17473 m .35486 .17995 L .37574 .17995 L p .505 .008 .009 r
F P
0 g
s
.64555 .18767 m .64514 .17995 L .62426 .17995 L p .619 .226 .277 r
F P
0 g
s
.37539 .18767 m .37574 .17995 L .35486 .17995 L p .619 .226 .277 r
F P
0 g
s
.62426 .17995 m .62461 .18767 L .64555 .18767 L p .619 .226 .277 r
F P
0 g
s
.35486 .17995 m .35445 .18767 L .37539 .18767 L p .619 .226 .277 r
F P
0 g
s
.64586 .19756 m .64555 .18767 L .62461 .18767 L p .673 .371 .455 r
F P
0 g
s
.37513 .19756 m .37539 .18767 L .35445 .18767 L p .673 .371 .455 r
F P
0 g
s
.62461 .18767 m .62487 .19756 L .64586 .19756 L p .673 .371 .455 r
F P
0 g
s
.35445 .18767 m .35414 .19756 L .37513 .19756 L p .673 .371 .455 r
F P
0 g
s
.37539 .26153 m .37513 .24877 L .35414 .24877 L p .686 .701 .858 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.70277 .73937 m .74865 .73714 L .74865 .87438 L p .345 .281 .642 r
F P
0 g
s
.74865 .87438 m .70277 .87473 L .70277 .73937 L p .345 .281 .642 r
F P
0 g
s
.70849 .87402 m .74865 .87438 L .74865 .73714 L p .959 .783 .621 r
F P
0 g
s
.70996 .87384 m .77017 .87438 L .70139 .8749 L p .012 .587 .719 r
F P
0 g
s
.66253 .73714 m .70277 .73937 L .70277 .87473 L p .955 .78 .625 r
F P
0 g
s
.70277 .87473 m .66253 .87438 L .66253 .73714 L p .955 .78 .625 r
F P
0 g
s
.7105 .73763 m .73164 .65308 L p .71176 .73667 L 0 0 0 r
F P
0 g
s
.71372 .73515 m .74865 .73714 L .72778 .73816 L p .074 .635 .777 r
F P
0 g
s
.72778 .73816 m .70861 .73909 L p .7105 .73763 L .074 .635 .777 r
F P
0 g
s
.7105 .73763 m .71372 .73515 L .72778 .73816 L .074 .635 .777 r
F
.71668 .64842 m .73164 .65308 L .71087 .73616 L p .873 .753 .727 r
F P
0 g
s
.7106 .73622 m .71668 .64842 L .71087 .73616 L .873 .753 .727 r
F
.71027 .73762 m .71033 .73686 L .7105 .73763 L F
.71033 .73686 m .71668 .64842 L .7105 .73763 L F
.72887 .66474 m .73304 .65159 L .71145 .73796 L p 0 0 0 r
F P
0 g
s
.73304 .65159 m .73086 .65635 L p .73164 .65308 L 0 0 0 r
F P
0 g
s
.71018 .73633 m .69391 .67126 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.7102 .73631 m .71018 .73633 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.67362 .65364 m .68872 .65048 L .71018 .73633 L p .875 .674 .628 r
F P
0 g
s
.71018 .73633 m .70518 .73747 L p .67362 .65364 L .875 .674 .628 r
F P
0 g
s
.6945 .73714 m .69376 .73418 L p .70518 .73747 L .875 .674 .628 r
F P
0 g
s
.69376 .73418 m .67362 .65364 L p .70518 .73747 L .875 .674 .628 r
F P
0 g
s
.7102 .73631 m .71018 .73633 L .70518 .73747 L p .22 .739 .734 r
F P
0 g
s
.71027 .73762 m .70282 .70386 L .71033 .73686 L .873 .753 .727 r
F
.7099 .73761 m .70282 .70386 L .71027 .73762 L F
.70861 .73909 m .70277 .73937 L p .70753 .73754 L .074 .635 .777 r
F P
0 g
s
.7099 .73761 m .70518 .73747 L .70966 .73644 L .873 .753 .727 r
F
.70282 .70386 m .71668 .64842 L p .71033 .73686 L F P
0 g
s
.71087 .73616 m .7105 .73763 L p .7106 .73622 L .873 .753 .727 r
F P
0 g
s
.69515 .73453 m .70282 .70386 L p .70966 .73644 L .873 .753 .727 r
F P
0 g
s
.70518 .73747 m .69515 .73453 L p .70966 .73644 L .873 .753 .727 r
F P
0 g
s
.71142 .73536 m .7102 .73631 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.7102 .73631 m .7052 .73746 L .706 .73682 L .22 .739 .734 r
F
.69515 .73453 m .706 .73682 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.70753 .73754 m .7105 .73763 L .70861 .73909 L .074 .635 .777 r
F
.70518 .73747 m .69515 .73453 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.70518 .73747 m .7052 .73746 L .7102 .73631 L .22 .739 .734 r
F
.70277 .73937 m .706 .73682 L .70967 .73671 L .074 .635 .777 r
F
.71018 .73893 m .70518 .73747 L p .7099 .73761 L .873 .753 .727 r
F P
0 g
s
.70518 .73747 m .7052 .73746 L .7102 .73891 L 0 .493 .774 r
F
.70277 .73937 m .69798 .73911 L p .70518 .73747 L .074 .635 .777 r
F P
0 g
s
.7017 .69894 m .7018 .69937 L .68872 .65048 L 0 0 .28 r
F
.71215 .73517 m .73304 .65159 L p .706 .73682 L .495 .367 .634 r
F P
0 g
s
.70519 .71255 m .70917 .72684 L .70528 .71236 L .495 .367 .634 r
F
.70519 .71255 m .70913 .72696 L .70917 .72684 L F
.73164 .65308 m .71668 .64842 L .73304 .65159 L closepath p 0 .521 .807 r
F P
0 g
s
.73304 .65159 m .71668 .64842 L .69515 .73453 L p .495 .367 .634 r
F P
0 g
s
.69391 .67126 m .68872 .65048 L p .71142 .73536 L 0 0 .28 r
F P
0 g
s
.70528 .71236 m .70917 .72684 L .73304 .65159 L .495 .367 .634 r
F
.71136 .73501 m .68872 .65048 L .71137 .73501 L 0 0 .28 r
F
.68872 .65048 m .68985 .64897 L .71137 .73501 L p F P
0 g
s
.68872 .65048 m .67362 .65364 L .68985 .64897 L closepath p .259 .767 .77 r
F P
0 g
s
.68985 .64897 m .67362 .65364 L .6945 .73714 L p .498 .444 .727 r
F P
0 g
s
.69798 .73911 m .67337 .73774 L p .70518 .73747 L .074 .635 .777 r
F P
0 g
s
.67337 .73774 m .68772 .73733 L .70518 .73747 L .074 .635 .777 r
F
.69499 .73713 m .68985 .64897 L .6945 .73714 L .498 .444 .727 r
F
.69515 .73453 m .706 .73682 L p .70913 .72696 L .495 .367 .634 r
F P
0 g
s
.71145 .73534 m .71142 .73536 L p .7018 .69937 L 0 0 .28 r
F P
0 g
s
.71145 .73534 m .7018 .69937 L .7017 .69894 L 0 0 .28 r
F
.69515 .73453 m .70913 .72696 L .70519 .71255 L .495 .367 .634 r
F
.71137 .73501 m .71145 .73534 L p .71136 .73501 L 0 0 .28 r
F P
0 g
s
.71145 .73534 m .68985 .64897 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.706 .73682 m .71145 .73534 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.66253 .73714 m .70849 .73485 L p .706 .73682 L .074 .635 .777 r
F P
0 g
s
.70518 .73747 m .68772 .73733 L .706 .73682 L .074 .635 .777 r
F
.68772 .73733 m .66253 .73714 L .706 .73682 L F
.70518 .73747 m .69515 .73975 L .6945 .73714 L p .875 .674 .628 r
F P
0 g
s
.69515 .73975 m .706 .73682 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.6945 .73714 m .69515 .73975 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.67337 .73774 m .66253 .73714 L p .68772 .73733 L .074 .635 .777 r
F P
0 g
s
.70518 .73747 m .69515 .73975 L p .7052 .73746 L .22 .739 .734 r
F P
0 g
s
.69515 .73975 m .706 .73682 L p .7052 .73746 L .22 .739 .734 r
F P
0 g
s
.71018 .73893 m .71017 .7389 L .71018 .73891 L .873 .753 .727 r
F
.71017 .7389 m .7099 .73761 L .71018 .73891 L F
.71018 .73891 m .7099 .73761 L .71027 .73762 L F
.7105 .73763 m .71018 .73893 L p .71027 .73762 L F P
0 g
s
.71145 .73796 m .71018 .73893 L .7105 .73763 L p 0 0 0 r
F P
0 g
s
.71145 .73796 m .7102 .73891 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.71142 .73536 m .7102 .73631 L p .706 .73682 L .22 .739 .734 r
F P
0 g
s
.71177 .73665 m .71215 .73517 L p .706 .73682 L .495 .367 .634 r
F P
0 g
s
.70753 .73754 m .71372 .73515 L .7105 .73763 L .074 .635 .777 r
F
.706 .73682 m .71145 .73796 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.706 .73682 m .71145 .73534 L .71142 .73536 L p .22 .739 .734 r
F P
0 g
s
.7102 .73891 m .71018 .73893 L .70518 .73747 L p 0 .493 .774 r
F P
0 g
s
.71145 .73796 m .7105 .73763 L .71176 .73667 L 0 0 0 r
F
.706 .73682 m .71145 .73796 L .71177 .73665 L p .495 .367 .634 r
F P
0 g
s
.70849 .73485 m .71372 .73515 L p .70967 .73671 L .074 .635 .777 r
F P
0 g
s
.706 .73682 m .70849 .73485 L .70967 .73671 L .074 .635 .777 r
F
.70849 .73485 m .66253 .73714 L .66253 .87438 L p .335 .274 .639 r
F P
0 g
s
.74865 .73714 m .70849 .73485 L .70849 .87402 L p .959 .783 .621 r
F P
0 g
s
.66253 .87438 m .70849 .87402 L .70849 .73485 L p .335 .274 .639 r
F P
0 g
s
.70139 .8749 m .64101 .87438 L .70996 .87384 L p .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70849 .87402 m .74865 .87438 L .70277 .87473 L p .012 .587 .719 r
F P
0 g
s
.70277 .87473 m .66253 .87438 L .70849 .87402 L p .012 .587 .719 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 1.04449 L p .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.39456 1.28634 m .41565 1.26525 L .43673 1.28634 L p .707 .577 .707 r
F P
0 g
s
.43673 1.28634 m .41565 1.30743 L .39456 1.28634 L p .707 .577 .707 r
F P
0 g
s
.56327 1.28634 m .58435 1.26525 L .60544 1.28634 L p .707 .577 .707 r
F P
0 g
s
.60544 1.28634 m .58435 1.30743 L .56327 1.28634 L p .707 .577 .707 r
F P
0 g
s
.60544 1.28634 m .58435 1.26525 L .58517 1.2688 L p .587 .075 0 r
F P
0 g
s
.58435 1.30743 m .60544 1.28634 L .60616 1.28899 L p 0 0 0 r
F P
0 g
s
.56327 1.28634 m .58435 1.30743 L .58469 1.30906 L p .6 .086 0 r
F P
0 g
s
.57519 1.29998 m .56327 1.28634 L .58469 1.30906 L .6 .086 0 r
F
.57199 1.29763 m .56327 1.28634 L .58517 1.31139 L F
.58517 1.31139 m .58584 1.31208 L .57644 1.3207 L .694 .457 .559 r
F
.58584 1.31208 m .5875 1.31382 L .57644 1.3207 L F
.6274 1.28899 m .62791 1.3207 L .57644 1.3207 L p F P
0 g
s
.5637 1.28899 m .56327 1.28634 L p .57199 1.29763 L .6 .086 0 r
F P
0 g
s
.58469 1.30906 m .58517 1.31139 L p .57519 1.29998 L .6 .086 0 r
F P
0 g
s
.59388 1.30209 m .58435 1.30743 L .60616 1.28899 L 0 0 0 r
F
.60844 1.29134 m .61413 1.29725 L .5875 1.31382 L .694 .457 .559 r
F
.60844 1.29134 m .5875 1.31382 L .58584 1.31208 L F
.60337 1.29197 m .60844 1.29134 L .58584 1.31208 L F
.60337 1.29197 m .58584 1.31208 L .58517 1.31139 L F
.60764 1.29439 m .58611 1.31592 L .58435 1.30743 L p 0 0 0 r
F P
0 g
s
.57644 1.3207 m .42356 1.3207 L p .60337 1.29197 L .694 .457 .559 r
F P
0 g
s
.41047 1.31593 m .41819 1.31498 L .4059 1.3207 L .694 .457 .559 r
F
.41483 1.31139 m .41565 1.30743 L p .42374 1.30209 L 0 0 0 r
F P
0 g
s
.39456 1.28634 m .41565 1.30743 L .41531 1.30906 L p .645 .129 0 r
F P
0 g
s
.41531 1.30906 m .41483 1.31139 L p .40559 1.29998 L .645 .129 0 r
F P
0 g
s
.40559 1.29998 m .39456 1.28634 L .41531 1.30906 L .645 .129 0 r
F
.40194 1.29763 m .40014 1.29488 L .41483 1.31139 L F
.40014 1.29488 m .39456 1.28634 L .40559 1.29998 L F
.40014 1.29488 m .40559 1.29998 L .41483 1.31139 L F
.58435 1.26525 m .56327 1.28634 L .5637 1.28899 L p 0 0 0 r
F P
0 g
s
.57626 1.27718 m .58435 1.26525 L .5637 1.28899 L 0 0 0 r
F
.43673 1.28634 m .41565 1.26525 L .41483 1.2688 L p .634 .118 0 r
F P
0 g
s
.42801 1.28119 m .43673 1.28634 L .41483 1.2688 L .634 .118 0 r
F
.37209 1.3207 m .3726 1.28899 L .39384 1.28899 L p .694 .457 .559 r
F P
0 g
s
.39384 1.28899 m .39456 1.28634 L p .40194 1.29763 L .645 .129 0 r
F P
0 g
s
.41565 1.30743 m .43673 1.28634 L .4363 1.28899 L p 0 0 0 r
F P
0 g
s
.4363 1.28899 m .5637 1.28899 L p .41483 1.31139 L .694 .457 .559 r
F P
0 g
s
.5637 1.28899 m .6274 1.28899 L p .55667 1.29644 L .694 .457 .559 r
F P
0 g
s
.41483 1.31139 m .5637 1.28899 L .55667 1.29644 L .694 .457 .559 r
F
.41819 1.31498 m .41483 1.31139 L .6274 1.28899 L F
.41819 1.31498 m .60337 1.29197 L .42356 1.3207 L F
.58611 1.31592 m .56458 1.29439 L .5637 1.28899 L p .6 .086 0 r
F P
0 g
s
.58611 1.31592 m .5637 1.28899 L .57199 1.29763 L .6 .086 0 r
F
.60616 1.28899 m .5637 1.28899 L p .58517 1.2688 L .691 .686 .84 r
F P
0 g
s
.60616 1.28899 m .60544 1.28634 L p .59986 1.28245 L .587 .075 0 r
F P
0 g
s
.58611 1.27286 m .60616 1.28899 L .59986 1.28245 L .587 .075 0 r
F
.59806 1.28119 m .60544 1.28634 L .58517 1.2688 L F
.58517 1.2688 m .62791 1.2604 L .60616 1.28899 L .691 .686 .84 r
F
.58517 1.2688 m .58469 1.26671 L p .57887 1.27472 L 0 0 0 r
F P
0 g
s
.58469 1.26671 m .58435 1.26525 L p .57995 1.27175 L 0 0 0 r
F P
0 g
s
.57626 1.27718 m .58469 1.26671 L .57995 1.27175 L 0 0 0 r
F
.56458 1.29439 m .57887 1.27472 L .57626 1.27718 L F
.57887 1.27472 m .58469 1.26671 L .57626 1.27718 L F
.4363 1.28899 m .43673 1.28634 L p .42801 1.28119 L .634 .118 0 r
F P
0 g
s
.42952 1.28261 m .58953 1.2647 L .4363 1.28899 L .691 .686 .84 r
F
.58953 1.2647 m .62791 1.2604 L .58773 1.2664 L F
.58953 1.2647 m .58773 1.2664 L .4363 1.28899 L F
.58335 1.26705 m .58773 1.2664 L .58517 1.2688 L F
.58773 1.2664 m .62791 1.2604 L .58517 1.2688 L F
.56458 1.29439 m .58611 1.27286 L .58517 1.2688 L p 0 0 0 r
F P
0 g
s
.56458 1.29439 m .58517 1.2688 L .57887 1.27472 L 0 0 0 r
F
.4363 1.28899 m .43542 1.29439 L p .42374 1.30209 L F P
0 g
s
.42374 1.30209 m .41565 1.30743 L .4363 1.28899 L 0 0 0 r
F
.39384 1.28899 m .4363 1.28899 L p .41483 1.31139 L .694 .457 .559 r
F P
0 g
s
.37209 1.3207 m .39384 1.28899 L .41819 1.31498 L .694 .457 .559 r
F
.41389 1.31592 m .39236 1.29439 L .39384 1.28899 L p .645 .129 0 r
F P
0 g
s
.41389 1.31592 m .39384 1.28899 L .40194 1.29763 L .645 .129 0 r
F
.41565 1.26525 m .39456 1.28634 L .39384 1.28899 L p 0 0 0 r
F P
0 g
s
.40612 1.27718 m .41565 1.26525 L .39384 1.28899 L 0 0 0 r
F
.39663 1.2863 m .41483 1.2688 L .42952 1.28261 L .691 .686 .84 r
F
.4363 1.28899 m .39384 1.28899 L p .42952 1.28261 L F P
0 g
s
.39156 1.28686 m .42952 1.28261 L .39384 1.28899 L .691 .686 .84 r
F
.39236 1.29439 m .41389 1.27286 L .41483 1.2688 L p 0 0 0 r
F P
0 g
s
.41483 1.2688 m .41565 1.26525 L p .40612 1.27718 L 0 0 0 r
F P
0 g
s
.39236 1.29439 m .41483 1.2688 L .40612 1.27718 L 0 0 0 r
F
.42952 1.28261 m .41483 1.2688 L .62791 1.2604 L .691 .686 .84 r
F
.4059 1.2604 m .42356 1.2604 L p .41483 1.2688 L F P
0 g
s
.42356 1.2604 m .62791 1.2604 L p .41483 1.2688 L .691 .686 .84 r
F P
0 g
s
.39156 1.28686 m .4059 1.2604 L .41483 1.2688 L .691 .686 .84 r
F
.39156 1.28686 m .41483 1.2688 L .39663 1.2863 L F
.39384 1.28899 m .39236 1.29439 L p .40612 1.27718 L 0 0 0 r
F P
0 g
s
.41389 1.27286 m .43542 1.29439 L .4363 1.28899 L p .634 .118 0 r
F P
0 g
s
.41389 1.27286 m .4363 1.28899 L .42801 1.28119 L .634 .118 0 r
F
.37209 1.2604 m .4059 1.2604 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37224 1.2688 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.37224 1.2688 m .37209 1.2604 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.39384 1.28899 m .3726 1.28899 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.43542 1.29439 m .41389 1.31592 L .41483 1.31139 L p 0 0 0 r
F P
0 g
s
.43542 1.29439 m .41483 1.31139 L .42374 1.30209 L 0 0 0 r
F
.42356 1.3207 m .4059 1.3207 L p .41819 1.31498 L .694 .457 .559 r
F P
0 g
s
.4059 1.3207 m .37209 1.3207 L p .41047 1.31593 L .694 .457 .559 r
F P
0 g
s
.41483 1.31139 m .41389 1.31592 L p .40194 1.29763 L .645 .129 0 r
F P
0 g
s
.5637 1.28899 m .56458 1.29439 L p .57626 1.27718 L 0 0 0 r
F P
0 g
s
.5637 1.28899 m .58335 1.26705 L .58517 1.2688 L .691 .686 .84 r
F
.5637 1.28899 m .4363 1.28899 L p .54651 1.27255 L F P
0 g
s
.54651 1.27255 m .58335 1.26705 L .5637 1.28899 L .691 .686 .84 r
F
.58517 1.31139 m .58611 1.31592 L p .57199 1.29763 L .6 .086 0 r
F P
0 g
s
.60844 1.29134 m .6274 1.28899 L .61413 1.29725 L .694 .457 .559 r
F
.60616 1.28899 m .60764 1.29439 L p .59388 1.30209 L 0 0 0 r
F P
0 g
s
.58611 1.27286 m .60764 1.29439 L .60616 1.28899 L p .587 .075 0 r
F P
0 g
s
.58517 1.2688 m .58611 1.27286 L p .59806 1.28119 L .587 .075 0 r
F P
0 g
s
.62791 1.2604 m .6274 1.28899 L .60616 1.28899 L p .691 .686 .84 r
F P
0 g
s
.41483 1.2688 m .41389 1.27286 L p .42801 1.28119 L .634 .118 0 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52783 1.09787 m .51885 1.09818 L .516 1.09787 L .09 0 0 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.51434 1.25793 m .54175 1.25635 L .52667 1.25967 L F
.54175 1.25635 m .62917 1.25133 L .54517 1.25817 L F
.54175 1.25635 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.484 1.25967 m .51434 1.25793 L .52667 1.25967 L .365 .792 .97 r
F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.4813 1.25829 m .54018 1.25552 L .484 1.25967 L .365 .792 .97 r
F
.54018 1.25552 m .62917 1.25133 L .54175 1.25635 L F
.54018 1.25552 m .54175 1.25635 L .484 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.45621 1.25744 m .62917 1.25133 L .452 1.25967 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.452 1.25967 m .4813 1.25829 L .484 1.25967 L .365 .792 .97 r
F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.53645 1.09918 m .47146 1.10147 L .4687 1.10147 L .09 0 0 r
F
.53616 1.09921 m .47166 1.10147 L .53645 1.09918 L F
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L F P
0 g
s
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L F
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L F
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.29653 1.043 m .29225 1.04601 L .36099 1.04601 L p F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36099 1.04601 m .29225 1.04601 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36032 1.07254 m .29225 1.04601 L .35951 1.10469 L .68 .398 .487 r
F
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.3605 1.10246 m .35851 1.02865 L .3605 .95121 L p .767 .626 .063 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44284 1.10469 m .36099 1.04601 L .36032 1.07254 L .68 .398 .487 r
F
.3605 1.04653 m .3605 .95121 L .36159 1.02223 L .767 .626 .063 r
F
.36099 1.04601 m .36159 1.02223 L .36194 1.04502 L F
.3605 1.04653 m .36159 1.02223 L .36099 1.04601 L F
.35951 1.10469 m .44284 1.10469 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L F P
0 g
s
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.35899 .98856 m .35899 .87438 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.29225 1.04601 m .29004 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.32488 1.04601 m .35899 .98856 L .30737 1.04679 L F
.29004 1.10469 m .35951 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .47146 1.10147 L .09 0 0 r
F
.47166 1.10147 m .47146 1.10147 L .53645 1.09918 L F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L .09 0 0 r
F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.55676 1.10246 m .44324 1.10246 L p .53019 1.09942 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L .09 0 0 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.516 1.09787 m .46368 1.10009 L .484 1.09787 L F
.51885 1.09818 m .46368 1.10009 L .516 1.09787 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.47146 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.55566 1.09853 m .53616 1.09921 L .53645 1.09918 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.59496 1.09076 m .61173 1.08458 L .57144 1.08458 L .676 .72 .882 r
F
.6395 1.10246 m .61173 1.08458 L .59496 1.09076 L F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .61173 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.37496 .20917 m .37513 .19756 L .35414 .19756 L p .697 .472 .578 r
F P
0 g
s
.35414 .19756 m .35395 .20917 L .37496 .20917 L p .697 .472 .578 r
F P
0 g
s
.37513 .24877 m .37496 .23538 L .35395 .23538 L p .699 .656 .803 r
F P
0 g
s
.35395 .23538 m .35414 .24877 L .37513 .24877 L p .699 .656 .803 r
F P
0 g
s
.37491 .22197 m .37496 .20917 L .35395 .20917 L p .706 .546 .669 r
F P
0 g
s
.35395 .20917 m .35388 .22197 L .37491 .22197 L p .706 .546 .669 r
F P
0 g
s
.37496 .23538 m .37491 .22197 L .35388 .22197 L p .706 .606 .742 r
F P
0 g
s
.35388 .22197 m .35395 .23538 L .37496 .23538 L p .706 .606 .742 r
F P
0 g
s
.3687 .17459 m .36877 .18869 L .34671 .18869 L p .706 .607 .743 r
F P
0 g
s
.36877 .18869 m .3687 .20212 L .34664 .20212 L p .706 .545 .667 r
F P
0 g
s
.34664 .20212 m .34671 .18869 L .36877 .18869 L p .706 .545 .667 r
F P
0 g
s
.3687 .20212 m .36852 .21434 L .34643 .21434 L p .696 .466 .571 r
F P
0 g
s
.34643 .21434 m .34664 .20212 L .3687 .20212 L p .696 .466 .571 r
F P
0 g
s
.36852 .21434 m .36823 .22483 L .36106 .22483 L p .67 .361 .442 r
F P
0 g
s
.35723 .36876 m .35723 .22339 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.35723 .22339 m .35723 .22238 L p .35828 .22378 L .541 .442 .691 r
F P
0 g
s
.35828 .22378 m .3681 .23682 L .35723 .22339 L .541 .442 .691 r
F
.36823 .22483 m .3681 .22748 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.35473 .22078 m .36852 .21434 L .36713 .21629 L .67 .361 .442 r
F
.35723 .22238 m .36713 .21629 L .36106 .22483 L F
.35473 .22078 m .36713 .21629 L .35723 .22238 L F
.34671 .18869 m .34664 .17459 L .3687 .17459 L p .706 .607 .743 r
F P
0 g
s
.34664 .20212 m .34671 .18869 L .34664 .17459 L p .772 .63 .068 r
F P
0 g
s
.34664 .17459 m .34643 .16041 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34608 .22483 m .34643 .21434 L .34664 .20212 L p .772 .63 .068 r
F P
0 g
s
.34664 .20212 m .34593 .22355 L .34608 .22483 L .772 .63 .068 r
F
.34593 .31625 m .3571 .22343 L .35723 .36876 L .837 .683 .692 r
F
.35723 .22339 m .35723 .36876 L p .3571 .22343 L F P
0 g
s
.32942 .23949 m .34593 .22933 L .34593 .31625 L .837 .683 .692 r
F
.34593 .22933 m .35723 .22238 L .34593 .31625 L F
.34593 .22748 m .34608 .22483 L .35325 .22483 L p .613 .212 .26 r
F P
0 g
s
.34664 .20212 m .34593 .21849 L .34593 .22355 L .772 .63 .068 r
F
.34593 .22748 m .34608 .22483 L p .34593 .22355 L F P
0 g
s
.35723 .22238 m .35723 .22339 L p .3571 .22343 L .837 .683 .692 r
F P
0 g
s
.36624 .22814 m .3681 .23682 L .35828 .22378 L .541 .442 .691 r
F
.36106 .22483 m .35828 .22378 L .35723 .22238 L F
.36624 .22814 m .35828 .22378 L .36106 .22483 L F
.34608 .22483 m .35473 .22078 L .35723 .22238 L .67 .361 .442 r
F
.36106 .22483 m .35325 .22483 L p .35723 .22238 L F P
0 g
s
.35325 .22483 m .34608 .22483 L p .35723 .22238 L .67 .361 .442 r
F P
0 g
s
.32822 .23391 m .34593 .22748 L .32942 .23949 L .837 .683 .692 r
F
.34593 .22748 m .35325 .22483 L .34593 .22933 L F
.34593 .22748 m .34593 .22933 L .32942 .23949 L F
.31714 .1824 m .34593 .21112 L .34593 .21623 L F
.34664 .20212 m .34593 .21471 L .34593 .21849 L .772 .63 .068 r
F
.31714 .1824 m .34593 .21623 L .32822 .23391 L .837 .683 .692 r
F
.34643 .21434 m .36852 .21434 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.34608 .22483 m .34639 .21545 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.34639 .21545 m .34643 .21434 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.3687 .20212 m .3681 .21849 L .3681 .22355 L .763 .623 .058 r
F
.3687 .20212 m .36877 .18869 L .3687 .17459 L p F P
0 g
s
.36852 .16041 m .3687 .17459 L .34664 .17459 L p .699 .659 .807 r
F P
0 g
s
.3687 .17459 m .36852 .16041 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36823 .22483 m .36852 .21434 L .3687 .20212 L p .763 .623 .058 r
F P
0 g
s
.3687 .20212 m .3681 .22355 L .36823 .22483 L .763 .623 .058 r
F
.39581 .24704 m .39581 .36597 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.36624 .22814 m .3681 .22933 L .3681 .23682 L .541 .442 .691 r
F
.3681 .22933 m .39581 .24704 L .3681 .23682 L F
.3687 .20212 m .3681 .21471 L .3681 .21849 L .763 .623 .058 r
F
.36592 .22666 m .3681 .22815 L .36624 .22814 L .541 .442 .691 r
F
.3681 .22815 m .3681 .22933 L .36624 .22814 L F
.3687 .20212 m .3681 .21172 L .3681 .21471 L .763 .623 .058 r
F
.36106 .22483 m .36823 .22483 L p .36278 .22548 L .613 .212 .26 r
F P
0 g
s
.3681 .22748 m .36823 .22483 L p .3681 .22355 L .763 .623 .058 r
F P
0 g
s
.3646 .22616 m .36278 .22548 L .36823 .22483 L .613 .212 .26 r
F
.35723 .18615 m .3681 .20331 L .36592 .22666 L .541 .442 .691 r
F
.3681 .20331 m .3681 .22748 L .36592 .22666 L F
.3681 .22748 m .3681 .22815 L .36592 .22666 L F
.35723 .22238 m .35723 .18615 L p .36592 .22666 L F P
0 g
s
.36592 .22666 m .36624 .22814 L .36106 .22483 L .541 .442 .691 r
F
.36592 .22666 m .36106 .22483 L .35723 .22238 L F
.36783 .23315 m .34562 .23315 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.3681 .22748 m .36783 .23315 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.36783 .23315 m .36735 .23894 L .34506 .23894 L p .498 0 0 r
F P
0 g
s
.34506 .23894 m .34562 .23315 L .36783 .23315 L p .498 0 0 r
F P
0 g
s
.36735 .23894 m .3668 .24191 L .34441 .24191 L p .289 0 0 r
F P
0 g
s
.34441 .24191 m .34506 .23894 L .36735 .23894 L p .289 0 0 r
F P
0 g
s
.3668 .24191 m .36621 .24192 L .34372 .24192 L p 0 0 0 r
F P
0 g
s
.34372 .24192 m .34441 .24191 L .3668 .24191 L p 0 0 0 r
F P
0 g
s
.3656 .23891 m .36621 .24192 L p .3681 .21172 L .763 .623 .058 r
F P
0 g
s
.3687 .20212 m .3681 .20925 L .3681 .21172 L .763 .623 .058 r
F
.3681 .20925 m .3656 .23891 L .3681 .21172 L F
.38823 .23507 m .39581 .24704 L .3681 .22815 L .541 .442 .691 r
F
.38823 .23507 m .3681 .22815 L .3681 .22748 L F
.36499 .23298 m .3656 .23891 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.34562 .23315 m .36278 .22548 L .3646 .22616 L .613 .212 .26 r
F
.36442 .22436 m .36499 .23298 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36392 .2134 m .36442 .22436 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.35723 .18615 m .3681 .18509 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.3687 .20212 m .36363 .20061 L .36392 .2134 L .763 .623 .058 r
F
.35325 .22483 m .36106 .22483 L p .34593 .22748 L .613 .212 .26 r
F P
0 g
s
.34593 .22748 m .36106 .22483 L .36278 .22548 L .613 .212 .26 r
F
.34562 .23315 m .34593 .22748 L p .36278 .22548 L F P
0 g
s
.34664 .20212 m .34593 .20925 L .34593 .21172 L .772 .63 .068 r
F
.34664 .20212 m .34593 .21172 L .34593 .21471 L F
.35723 .18615 m .35723 .22238 L p .34593 .21112 L .837 .683 .692 r
F P
0 g
s
.34593 .21623 m .34593 .22748 L .32822 .23391 L .837 .683 .692 r
F
.31714 .1824 m .34593 .18509 L p .34593 .21112 L F P
0 g
s
.3423 .23298 m .34301 .23891 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34164 .22436 m .3423 .23298 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34105 .2134 m .34164 .22436 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34664 .20212 m .34071 .20061 L .34105 .2134 L .772 .63 .068 r
F
.34071 .20468 m .34105 .2134 L p .34071 .20061 L F P
0 g
s
.34164 .10596 m .34105 .11142 L p .34545 .18284 L .772 .63 .068 r
F P
0 g
s
.31714 .1824 m .34593 .18509 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34664 .20212 m .34569 .18398 L .34545 .18284 L .772 .63 .068 r
F
.34569 .18398 m .34164 .10596 L .34545 .18284 L F
.29829 .17317 m .31714 .1824 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34105 .11142 m .34071 .11702 L p .34522 .18178 L .772 .63 .068 r
F P
0 g
s
.34545 .18284 m .34105 .11142 L .34522 .18178 L .772 .63 .068 r
F
.3443 .17752 m .29829 .17317 L .34535 .1824 L .289 .763 .934 r
F
.34509 .18119 m .34071 .11702 L .34071 .12181 L .772 .63 .068 r
F
.34664 .20212 m .34522 .18178 L .34509 .18119 L F
.34522 .18178 m .34071 .11702 L .34509 .18119 L F
.31238 .16371 m .29829 .17317 L p .3443 .17752 L .289 .763 .934 r
F P
0 g
s
.34664 .17459 m .34643 .16041 L .36852 .16041 L p .699 .659 .807 r
F P
0 g
s
.36823 .14672 m .36852 .16041 L .34643 .16041 L p .684 .704 .862 r
F P
0 g
s
.34643 .16041 m .34608 .14672 L .36823 .14672 L p .684 .704 .862 r
F P
0 g
s
.36783 .13411 m .36823 .14672 L .34608 .14672 L p .661 .745 .912 r
F P
0 g
s
.34608 .14672 m .34562 .13411 L .36783 .13411 L p .661 .745 .912 r
F P
0 g
s
.36735 .12309 m .36783 .13411 L .34562 .13411 L p .625 .78 .956 r
F P
0 g
s
.36318 .13034 m .36298 .14297 L p .3659 .17317 L .763 .623 .058 r
F P
0 g
s
.34279 .17052 m .31238 .16371 L .3443 .17752 L .289 .763 .934 r
F
.34071 .16085 m .31238 .16371 L p .34279 .17052 L F P
0 g
s
.34664 .20212 m .34337 .17317 L .34071 .16085 L .772 .63 .068 r
F
.34664 .20212 m .34071 .16085 L .34071 .16256 L F
.34664 .20212 m .34545 .18284 L .34522 .18178 L F
.34071 .16085 m .33661 .207 L .34071 .20468 L .534 .436 .69 r
F
.34018 .18646 m .34055 .20057 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.33995 .17169 m .34018 .18646 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34071 .16085 m .31238 .16371 L p .33661 .207 L .534 .436 .69 r
F P
0 g
s
.33987 .15697 m .33995 .17169 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34018 .13034 m .33995 .14297 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34055 .11966 m .34018 .13034 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.3423 .1035 m .34164 .10596 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34301 .10412 m .3423 .1035 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34372 .10774 m .34301 .10412 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34441 .11417 m .34372 .10774 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34506 .12309 m .34441 .11417 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34562 .13411 m .34506 .12309 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34608 .14672 m .34562 .13411 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34643 .16041 m .34608 .14672 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34593 .18894 m .35723 .18615 L .34593 .21112 L .837 .683 .692 r
F
.33995 .14297 m .33987 .15697 L p .34337 .17317 L .772 .63 .068 r
F P
0 g
s
.36689 .1785 m .36318 .13034 L .3659 .17317 L .763 .623 .058 r
F
.36298 .14297 m .36291 .15697 L p .3659 .17317 L F P
0 g
s
.35194 .15972 m .34071 .16085 L p .36541 .17051 L .289 .763 .934 r
F P
0 g
s
.34562 .13411 m .34506 .12309 L .36735 .12309 L p .625 .78 .956 r
F P
0 g
s
.3668 .11417 m .36735 .12309 L .34506 .12309 L p .567 .808 .989 r
F P
0 g
s
.36349 .11966 m .36318 .13034 L p .36689 .1785 L .763 .623 .058 r
F P
0 g
s
.36738 .18119 m .36349 .11966 L .36689 .1785 L .763 .623 .058 r
F
.34506 .12309 m .34441 .11417 L .3668 .11417 L p .567 .808 .989 r
F P
0 g
s
.36621 .10774 m .3668 .11417 L .34441 .11417 L p .472 .815 .999 r
F P
0 g
s
.36392 .11142 m .36349 .11966 L p .36738 .18119 L .763 .623 .058 r
F P
0 g
s
.36769 .18284 m .36392 .11142 L .36738 .18119 L .763 .623 .058 r
F
.3676 .1824 m .3443 .17752 L .34535 .1824 L .289 .763 .934 r
F
.34441 .11417 m .34372 .10774 L .36621 .10774 L p .472 .815 .999 r
F P
0 g
s
.3656 .10412 m .36621 .10774 L .34372 .10774 L p .311 .772 .946 r
F P
0 g
s
.36442 .10596 m .36392 .11142 L p .36769 .18284 L .763 .623 .058 r
F P
0 g
s
.3679 .18398 m .36442 .10596 L .36769 .18284 L .763 .623 .058 r
F
.35723 .18615 m .3681 .18509 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34372 .10774 m .34301 .10412 L .3656 .10412 L p .311 .772 .946 r
F P
0 g
s
.36499 .1035 m .3656 .10412 L .34301 .10412 L p .059 .624 .764 r
F P
0 g
s
.36499 .1035 m .36442 .10596 L p .3679 .18398 L .763 .623 .058 r
F P
0 g
s
.3676 .1824 m .34535 .1824 L .3681 .18509 L .289 .763 .934 r
F
.3687 .20212 m .36805 .18483 L .3679 .18398 L .763 .623 .058 r
F
.36805 .18483 m .36499 .1035 L .3679 .18398 L F
.3656 .10412 m .36499 .1035 L p .36805 .18483 L F P
0 g
s
.3687 .20212 m .36818 .1855 L .36805 .18483 L .763 .623 .058 r
F
.36818 .1855 m .3656 .10412 L .36805 .18483 L F
.36621 .10774 m .3656 .10412 L p .3687 .20212 L F P
0 g
s
.3668 .11417 m .36621 .10774 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36735 .12309 m .3668 .11417 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36783 .13411 m .36735 .12309 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36823 .14672 m .36783 .13411 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36852 .16041 m .36823 .14672 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.3931 .16371 m .36363 .16085 L p .39581 .1824 L .289 .763 .934 r
F P
0 g
s
.36363 .16085 m .35194 .15972 L p .36463 .16628 L .289 .763 .934 r
F P
0 g
s
.39581 .1824 m .36363 .16085 L .36463 .16628 L .289 .763 .934 r
F
.39581 .1824 m .3671 .17968 L .3676 .1824 L F
.3671 .17968 m .3443 .17752 L .3676 .1824 L F
.3687 .20212 m .3679 .18398 L .36769 .18284 L .763 .623 .058 r
F
.3687 .20212 m .36769 .18284 L .36738 .18119 L F
.36639 .17581 m .34071 .16085 L .34279 .17052 L .289 .763 .934 r
F
.39581 .1824 m .36541 .17051 L .36639 .17581 L F
.36541 .17051 m .34071 .16085 L .36639 .17581 L F
.39581 .1824 m .36463 .16628 L .36541 .17051 L F
.36463 .16628 m .35194 .15972 L .36541 .17051 L F
.3671 .17968 m .34279 .17052 L .3443 .17752 L F
.36639 .17581 m .34279 .17052 L .3671 .17968 L F
.3687 .20212 m .36738 .18119 L .36689 .1785 L .763 .623 .058 r
F
.34593 .18509 m .35723 .18615 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34671 .18516 m .35723 .18615 L p .34593 .18894 L .837 .683 .692 r
F P
0 g
s
.36363 .16085 m .35194 .15972 L p .35539 .20004 L .841 .686 .691 r
F P
0 g
s
.36363 .16085 m .35539 .20004 L .35543 .20007 L .841 .686 .691 r
F
.35194 .15972 m .34071 .16085 L p .34071 .20468 L .534 .436 .69 r
F P
0 g
s
.34071 .20468 m .34105 .2134 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34124 .20438 m .34071 .20468 L .34071 .20659 L .534 .436 .69 r
F
.35194 .15972 m .34071 .20468 L .34124 .20438 L F
.34301 .23891 m .34372 .24192 L p .34593 .21172 L .772 .63 .068 r
F P
0 g
s
.34593 .20925 m .34301 .23891 L .34593 .21172 L .772 .63 .068 r
F
.34593 .21172 m .34372 .24192 L .34593 .21471 L F
.34593 .21112 m .35723 .22238 L .34593 .21623 L .837 .683 .692 r
F
.34105 .2134 m .36392 .2134 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34593 .18509 m .34671 .18516 L p .34593 .18894 L .837 .683 .692 r
F P
0 g
s
.35194 .15972 m .34071 .20659 L .34263 .205 L .534 .436 .69 r
F
.34055 .20057 m .34071 .20468 L p .34071 .20061 L .772 .63 .068 r
F P
0 g
s
.34798 .20057 m .35606 .20057 L p .35194 .1973 L .682 .709 .868 r
F P
0 g
s
.36392 .2134 m .36363 .20468 L p .34798 .20057 L .657 .75 .919 r
F P
0 g
s
.35606 .20057 m .34798 .20057 L p .36363 .20468 L .657 .75 .919 r
F P
0 g
s
.34432 .20264 m .36392 .2134 L .34798 .20057 L .657 .75 .919 r
F
.34593 .21623 m .35325 .22483 L .34593 .22748 L .837 .683 .692 r
F
.34372 .24192 m .34441 .24191 L p .34593 .21471 L .772 .63 .068 r
F P
0 g
s
.34441 .24191 m .34506 .23894 L p .34593 .21849 L .772 .63 .068 r
F P
0 g
s
.34593 .21471 m .34441 .24191 L .34593 .21849 L .772 .63 .068 r
F
.34593 .21623 m .35723 .22238 L .35325 .22483 L .837 .683 .692 r
F
.34506 .23894 m .34562 .23315 L p .34593 .22355 L .772 .63 .068 r
F P
0 g
s
.34593 .21849 m .34506 .23894 L .34593 .22355 L .772 .63 .068 r
F
.34562 .23315 m .34593 .22748 L p .34593 .22355 L F P
0 g
s
.35723 .36876 m .31714 .36597 L .31714 .1824 L p .837 .683 .692 r
F P
0 g
s
.36621 .24192 m .3656 .23891 L .34301 .23891 L p .266 .752 .921 r
F P
0 g
s
.34301 .23891 m .34372 .24192 L .36621 .24192 L p .266 .752 .921 r
F P
0 g
s
.3656 .23891 m .36499 .23298 L .3423 .23298 L p .446 .812 .995 r
F P
0 g
s
.3423 .23298 m .34301 .23891 L .3656 .23891 L p .446 .812 .995 r
F P
0 g
s
.36499 .23298 m .36442 .22436 L .34164 .22436 L p .553 .811 .994 r
F P
0 g
s
.34164 .22436 m .3423 .23298 L .36499 .23298 L p .553 .811 .994 r
F P
0 g
s
.36442 .22436 m .36392 .2134 L .34105 .2134 L p .617 .786 .963 r
F P
0 g
s
.34105 .2134 m .34164 .22436 L .36442 .22436 L p .617 .786 .963 r
F P
0 g
s
.35194 .34909 m .35194 .1973 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.35194 .1973 m .35194 .15972 L p .34263 .205 L .534 .436 .69 r
F P
0 g
s
.34263 .205 m .34071 .21433 L .35194 .1973 L .534 .436 .69 r
F
.3681 .36797 m .35723 .36876 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.35194 .15972 m .35194 .34909 L p .36363 .29646 L .841 .686 .691 r
F P
0 g
s
.34018 .18646 m .34022 .18797 L p .35412 .1955 L .682 .709 .868 r
F P
0 g
s
.36363 .16085 m .35543 .20007 L .36363 .20468 L .841 .686 .691 r
F
.35543 .20007 m .3554 .20022 L .35606 .20057 L F
.35543 .20007 m .35606 .20057 L .36363 .20468 L F
.35454 .19515 m .35412 .1955 L .36349 .20057 L .682 .709 .868 r
F
.34018 .18646 m .35412 .1955 L .35454 .19515 L F
.34055 .20057 m .34071 .20468 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34022 .18797 m .34055 .20057 L .34798 .20057 L p .682 .709 .868 r
F P
0 g
s
.34022 .18797 m .34798 .20057 L .35194 .1973 L .682 .709 .868 r
F
.34263 .205 m .34071 .20659 L .34071 .21433 L .534 .436 .69 r
F
.35606 .20057 m .36349 .20057 L p .34022 .18797 L .682 .709 .868 r
F P
0 g
s
.35543 .20007 m .35539 .20004 L .3554 .20022 L .841 .686 .691 r
F
.36363 .20468 m .3554 .20022 L .36363 .29646 L F
.36363 .20468 m .36349 .20057 L .35606 .20057 L p .657 .75 .919 r
F P
0 g
s
.34798 .20057 m .34055 .20057 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34071 .20468 m .33661 .207 L .34071 .21433 L .534 .436 .69 r
F
.34071 .16256 m .34071 .16085 L .33987 .15697 L .772 .63 .068 r
F
.3687 .20212 m .36689 .1785 L .3659 .17317 L .763 .623 .058 r
F
.39581 .1824 m .36639 .17581 L .3671 .17968 L .289 .763 .934 r
F
.34071 .11702 m .34055 .11966 L p .34071 .12181 L .772 .63 .068 r
F P
0 g
s
.31714 .36597 m .29829 .35911 L .29829 .17317 L p .999 .816 .478 r
F P
0 g
s
.29829 .17317 m .31714 .1824 L .31714 .36597 L p .999 .816 .478 r
F P
0 g
s
.31238 .16371 m .31238 .35206 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.3687 .20212 m .3659 .17317 L .36291 .15697 L .763 .623 .058 r
F
.3681 .18509 m .39581 .1824 L p .3676 .1824 L .289 .763 .934 r
F P
0 g
s
.31238 .35206 m .34071 .34994 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.34071 .34994 m .35194 .34909 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.36349 .20057 m .36363 .20468 L p .36363 .20061 L .763 .623 .058 r
F P
0 g
s
.36363 .20468 m .36392 .2134 L p .36363 .20061 L .763 .623 .058 r
F P
0 g
s
.3681 .20331 m .38823 .23507 L .3681 .22748 L .541 .442 .691 r
F
.36621 .24192 m .3668 .24191 L p .3681 .21471 L .763 .623 .058 r
F P
0 g
s
.3681 .21172 m .36621 .24192 L .3681 .21471 L .763 .623 .058 r
F
.3681 .22815 m .39581 .24704 L .3681 .22933 L .541 .442 .691 r
F
.3668 .24191 m .36735 .23894 L p .3681 .21849 L .763 .623 .058 r
F P
0 g
s
.3681 .21471 m .3668 .24191 L .3681 .21849 L .763 .623 .058 r
F
.36783 .23315 m .3681 .22748 L p .3681 .22355 L F P
0 g
s
.39581 .1824 m .39581 .24704 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.36318 .18646 m .36349 .20057 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36298 .17169 m .36318 .18646 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36291 .15697 m .36298 .17169 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.3681 .18509 m .39581 .1824 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.39581 .36597 m .3681 .36797 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.36735 .23894 m .36783 .23315 L p .3681 .22355 L .763 .623 .058 r
F P
0 g
s
.3681 .21849 m .36735 .23894 L .3681 .22355 L .763 .623 .058 r
F
.3931 .16371 m .36363 .16085 L p .36363 .29646 L .841 .686 .691 r
F P
0 g
s
.41098 .35911 m .39581 .36597 L .39581 .1824 L p 0 0 .419 r
F P
0 g
s
.29829 .35911 m .31238 .35206 L .31238 .16371 L p 0 0 .392 r
F P
0 g
s
.31238 .16371 m .29829 .17317 L .29829 .35911 L p 0 0 .392 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.31714 .36597 m .35723 .36876 L .39581 .36597 L p .224 .73 .894 r
F P
0 g
s
.29829 .35911 m .31714 .36597 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.64605 .20917 m .64586 .19756 L .62487 .19756 L p .697 .472 .578 r
F P
0 g
s
.62487 .19756 m .62504 .20917 L .64605 .20917 L p .697 .472 .578 r
F P
0 g
s
.64586 .24877 m .64605 .23538 L .62504 .23538 L p .699 .656 .803 r
F P
0 g
s
.62504 .23538 m .62487 .24877 L .64586 .24877 L p .699 .656 .803 r
F P
0 g
s
.64612 .22197 m .64605 .20917 L .62504 .20917 L p .706 .546 .669 r
F P
0 g
s
.62504 .20917 m .62509 .22197 L .64612 .22197 L p .706 .546 .669 r
F P
0 g
s
.64605 .23538 m .64612 .22197 L .62509 .22197 L p .706 .606 .742 r
F P
0 g
s
.62509 .22197 m .62504 .23538 L .64605 .23538 L p .706 .606 .742 r
F P
0 g
s
.39581 .1824 m .41098 .17317 L .41098 .35911 L p 0 0 .419 r
F P
0 g
s
.3931 .35206 m .41098 .35911 L .41098 .17317 L p .997 .814 .457 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.31238 .35206 m .29829 .35911 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.35194 .34909 m .31238 .35206 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.3931 .35206 m .35194 .34909 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.39581 .36597 m .41098 .35911 L .3931 .35206 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.39581 .1824 m .41098 .17317 L .3931 .16371 L p .289 .763 .934 r
F P
0 g
s
.41098 .17317 m .3931 .16371 L .3931 .35206 L p .997 .814 .457 r
F P
0 g
s
.35194 .34909 m .3931 .35206 L .3931 .16371 L p .841 .686 .691 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65336 .17459 m .65329 .18869 L .63123 .18869 L p .706 .607 .743 r
F P
0 g
s
.65329 .18869 m .65336 .20212 L .6313 .20212 L p .706 .545 .667 r
F P
0 g
s
.6313 .20212 m .63123 .18869 L .65329 .18869 L p .706 .545 .667 r
F P
0 g
s
.65336 .20212 m .65357 .21434 L .63148 .21434 L p .696 .466 .571 r
F P
0 g
s
.63148 .21434 m .6313 .20212 L .65336 .20212 L p .696 .466 .571 r
F P
0 g
s
.68286 .36597 m .64277 .36876 L .64277 .22339 L p .548 .447 .692 r
F P
0 g
s
.64308 .2235 m .68286 .36597 L .64277 .22339 L .548 .447 .692 r
F
.65392 .22483 m .65407 .22748 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65357 .21434 m .65392 .22483 L .64675 .22483 L p .67 .361 .442 r
F P
0 g
s
.64017 .22078 m .65357 .21434 L .6523 .21629 L .67 .361 .442 r
F
.64277 .22238 m .6523 .21629 L .64675 .22483 L F
.64017 .22078 m .6523 .21629 L .64277 .22238 L F
.63123 .18869 m .6313 .17459 L .65336 .17459 L p .706 .607 .743 r
F P
0 g
s
.6313 .20212 m .63123 .18869 L .6313 .17459 L p 0 0 .058 r
F P
0 g
s
.65357 .16041 m .65336 .17459 L .6313 .17459 L p .699 .659 .807 r
F P
0 g
s
.6313 .17459 m .63148 .16041 L .65357 .16041 L p .699 .659 .807 r
F P
0 g
s
.6313 .17459 m .63148 .16041 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63148 .21434 m .65357 .21434 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.63177 .22483 m .63151 .21545 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.63151 .21545 m .63148 .21434 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.65336 .20212 m .65329 .18869 L .65336 .17459 L p 0 0 .068 r
F P
0 g
s
.65336 .17459 m .65357 .16041 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65392 .22483 m .65357 .21434 L .65336 .20212 L p 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65407 .22355 L .65392 .22483 L 0 0 .068 r
F
.68286 .24704 m .68286 .36597 L p .65407 .23682 L .548 .447 .692 r
F P
0 g
s
.65213 .22814 m .65407 .22933 L .65407 .23682 L .548 .447 .692 r
F
.65407 .22933 m .68286 .24704 L .65407 .23682 L F
.65336 .20212 m .65407 .21849 L .65407 .22355 L 0 0 .068 r
F
.65407 .22748 m .65392 .22483 L p .65407 .22355 L F P
0 g
s
.65336 .20212 m .65407 .21471 L .65407 .21849 L 0 0 .068 r
F
.65407 .20331 m .68286 .24704 L .65407 .22933 L .548 .447 .692 r
F
.65628 .24192 m .65559 .24191 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65699 .23891 m .65628 .24192 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.6577 .23298 m .65699 .23891 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65836 .22436 m .6577 .23298 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65895 .2134 m .65836 .22436 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.68286 .1824 m .68286 .24704 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65407 .18509 m .68286 .1824 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65336 .20212 m .65929 .20061 L .65895 .2134 L 0 0 .068 r
F
.65213 .22814 m .68286 .36597 L .64308 .2235 L .548 .447 .692 r
F
.64675 .22483 m .64308 .2235 L .64277 .22238 L F
.65213 .22814 m .64308 .2235 L .64675 .22483 L F
.6313 .20212 m .6319 .22355 L .63177 .22483 L 0 0 .058 r
F
.6319 .22933 m .63894 .22483 L .6319 .31625 L .841 .687 .691 r
F
.6319 .31625 m .63894 .22483 L .64277 .36876 L F
.64277 .22339 m .64277 .36876 L p .63894 .22483 L F P
0 g
s
.6319 .22748 m .63177 .22483 L .63894 .22483 L p .613 .212 .26 r
F P
0 g
s
.64277 .22238 m .64277 .22339 L p .63894 .22483 L .841 .687 .691 r
F P
0 g
s
.64277 .22339 m .64277 .22238 L p .64308 .2235 L .548 .447 .692 r
F P
0 g
s
.64675 .22483 m .63177 .22483 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.6319 .22748 m .63177 .22483 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.63177 .22483 m .63148 .21434 L .6313 .20212 L p 0 0 .058 r
F P
0 g
s
.6319 .21112 m .64277 .22238 L .6319 .22933 L .841 .687 .691 r
F
.63217 .23315 m .6319 .22748 L p .63201 .22746 L .613 .212 .26 r
F P
0 g
s
.63243 .233 m .63223 .22742 L p .64675 .22483 L .613 .212 .26 r
F P
0 g
s
.63894 .22483 m .64675 .22483 L p .6319 .22748 L .613 .212 .26 r
F P
0 g
s
.64675 .22483 m .65392 .22483 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.64277 .22238 m .64277 .18615 L p .6518 .22666 L .548 .447 .692 r
F P
0 g
s
.6518 .22666 m .65213 .22814 L .64675 .22483 L .548 .447 .692 r
F
.6518 .22666 m .64675 .22483 L .64277 .22238 L F
.63217 .23315 m .64675 .22483 L .65043 .22616 L .613 .212 .26 r
F
.64277 .18615 m .64277 .22238 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.6313 .20212 m .6319 .21849 L .6319 .22355 L 0 0 .058 r
F
.65438 .23315 m .63217 .23315 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65438 .23315 m .65494 .23894 L .63265 .23894 L p .498 0 0 r
F P
0 g
s
.63265 .23894 m .63217 .23315 L .65438 .23315 L p .498 0 0 r
F P
0 g
s
.6332 .24191 m .63265 .23894 L .65494 .23894 L p .289 0 0 r
F P
0 g
s
.6332 .24191 m .63265 .23894 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.65494 .23894 m .65559 .24191 L .6332 .24191 L p .289 0 0 r
F P
0 g
s
.63379 .24192 m .6332 .24191 L .65559 .24191 L p 0 0 0 r
F P
0 g
s
.63379 .24192 m .6332 .24191 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6319 .18509 m .64277 .18615 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.6344 .23891 m .63379 .24192 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63501 .23298 m .6344 .23891 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63558 .22436 m .63501 .23298 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63608 .2134 m .63558 .22436 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6313 .20212 m .63637 .20061 L .63608 .2134 L 0 0 .058 r
F
.65392 .14672 m .65357 .16041 L .63148 .16041 L p .684 .704 .862 r
F P
0 g
s
.65407 .18509 m .68286 .1824 L p .65465 .1824 L .289 .763 .934 r
F P
0 g
s
.65699 .10412 m .6577 .1035 L p .65412 .18483 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65398 .1855 L .65412 .18483 L 0 0 .068 r
F
.65398 .1855 m .65699 .10412 L .65412 .18483 L F
.68286 .1824 m .65523 .17968 L .65465 .1824 L .289 .763 .934 r
F
.65895 .11142 m .65945 .11966 L p .65491 .18119 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65455 .18284 L .65491 .18119 L 0 0 .068 r
F
.65455 .18284 m .65895 .11142 L .65491 .18119 L F
.68286 .1824 m .65607 .17581 L .65523 .17968 L .289 .763 .934 r
F
.65945 .11966 m .65982 .13034 L p .65549 .1785 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65491 .18119 L .65549 .1785 L 0 0 .068 r
F
.65491 .18119 m .65945 .11966 L .65549 .1785 L F
.68286 .1824 m .65812 .16628 L .65607 .17581 L .289 .763 .934 r
F
.65982 .13034 m .66005 .14297 L p .65663 .17317 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65549 .1785 L .65663 .17317 L 0 0 .068 r
F
.65549 .1785 m .65982 .13034 L .65663 .17317 L F
.68762 .16371 m .65929 .16085 L p .68286 .1824 L .289 .763 .934 r
F P
0 g
s
.66005 .14297 m .66013 .15697 L p .65663 .17317 L 0 0 .068 r
F P
0 g
s
.65836 .10596 m .65895 .11142 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.6577 .1035 m .65836 .10596 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65628 .10774 m .65699 .10412 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65559 .11417 m .65628 .10774 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65494 .12309 m .65559 .11417 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65438 .13411 m .65494 .12309 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65392 .14672 m .65438 .13411 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65357 .16041 m .65392 .14672 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65929 .16085 m .64806 .15972 L p .65812 .16628 L .289 .763 .934 r
F P
0 g
s
.68286 .1824 m .65929 .16085 L .65812 .16628 L .289 .763 .934 r
F
.64806 .15972 m .63637 .16085 L p .65607 .17581 L F P
0 g
s
.65607 .17581 m .63637 .16085 L .63459 .17052 L .289 .763 .934 r
F
.63148 .16041 m .63177 .14672 L .65392 .14672 L p .684 .704 .862 r
F P
0 g
s
.65438 .13411 m .65392 .14672 L .63177 .14672 L p .661 .745 .912 r
F P
0 g
s
.63177 .14672 m .63217 .13411 L .65438 .13411 L p .661 .745 .912 r
F P
0 g
s
.63702 .14297 m .63709 .15697 L p .6341 .17317 L 0 0 .058 r
F P
0 g
s
.65494 .12309 m .65438 .13411 L .63217 .13411 L p .625 .78 .956 r
F P
0 g
s
.63217 .13411 m .63265 .12309 L .65494 .12309 L p .625 .78 .956 r
F P
0 g
s
.63311 .1785 m .63682 .13034 L .6341 .17317 L 0 0 .058 r
F
.65559 .11417 m .65494 .12309 L .63265 .12309 L p .567 .808 .989 r
F P
0 g
s
.63265 .12309 m .6332 .11417 L .65559 .11417 L p .567 .808 .989 r
F P
0 g
s
.63651 .11966 m .63682 .13034 L p .63311 .1785 L 0 0 .058 r
F P
0 g
s
.63262 .18119 m .63651 .11966 L .63311 .1785 L 0 0 .058 r
F
.65628 .10774 m .65559 .11417 L .6332 .11417 L p .472 .815 .999 r
F P
0 g
s
.6332 .11417 m .63379 .10774 L .65628 .10774 L p .472 .815 .999 r
F P
0 g
s
.63231 .18284 m .63608 .11142 L .63262 .18119 L 0 0 .058 r
F
.65699 .10412 m .65628 .10774 L .63379 .10774 L p .311 .772 .946 r
F P
0 g
s
.63379 .10774 m .6344 .10412 L .65699 .10412 L p .311 .772 .946 r
F P
0 g
s
.63558 .10596 m .63608 .11142 L p .63231 .18284 L 0 0 .058 r
F P
0 g
s
.6321 .18398 m .63558 .10596 L .63231 .18284 L 0 0 .058 r
F
.64277 .18615 m .65407 .18509 L p .63212 .1839 L .289 .763 .934 r
F P
0 g
s
.6577 .1035 m .65699 .10412 L .6344 .10412 L p .059 .624 .764 r
F P
0 g
s
.6344 .10412 m .63501 .1035 L .6577 .1035 L p .059 .624 .764 r
F P
0 g
s
.63501 .1035 m .63558 .10596 L p .6321 .18398 L 0 0 .058 r
F P
0 g
s
.63195 .18483 m .63501 .1035 L .6321 .18398 L 0 0 .058 r
F
.6319 .18509 m .64277 .18615 L p .63212 .1839 L .289 .763 .934 r
F P
0 g
s
.6344 .10412 m .63501 .1035 L p .63195 .18483 L 0 0 .058 r
F P
0 g
s
.6313 .20212 m .63182 .1855 L .63195 .18483 L 0 0 .058 r
F
.63182 .1855 m .6344 .10412 L .63195 .18483 L F
.65465 .1824 m .6324 .1824 L .65407 .18509 L .289 .763 .934 r
F
.63379 .10774 m .6344 .10412 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6332 .11417 m .63379 .10774 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63265 .12309 m .6332 .11417 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63217 .13411 m .63265 .12309 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63177 .14672 m .63217 .13411 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63148 .16041 m .63177 .14672 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6324 .1824 m .60419 .1824 L .63212 .1839 L .289 .763 .934 r
F
.6324 .1824 m .63212 .1839 L .65407 .18509 L F
.60419 .1824 m .6319 .18509 L p .63212 .1839 L F P
0 g
s
.6313 .20212 m .63195 .18483 L .6321 .18398 L 0 0 .058 r
F
.6313 .20212 m .6321 .18398 L .63231 .18284 L F
.65523 .17968 m .63329 .17752 L .65465 .1824 L .289 .763 .934 r
F
.63608 .11142 m .63651 .11966 L p .63262 .18119 L 0 0 .058 r
F P
0 g
s
.63329 .17752 m .58902 .17317 L .63296 .17935 L .289 .763 .934 r
F
.63329 .17752 m .63296 .17935 L .65465 .1824 L F
.58902 .17317 m .60419 .1824 L p .6324 .1824 L F P
0 g
s
.65465 .1824 m .63296 .17935 L .6324 .1824 L .289 .763 .934 r
F
.63296 .17935 m .58902 .17317 L .6324 .1824 L F
.6313 .20212 m .63231 .18284 L .63262 .18119 L 0 0 .058 r
F
.6313 .20212 m .63262 .18119 L .63311 .1785 L F
.65607 .17581 m .63459 .17052 L .65523 .17968 L .289 .763 .934 r
F
.63682 .13034 m .63702 .14297 L p .6341 .17317 L 0 0 .058 r
F P
0 g
s
.63459 .17052 m .6069 .16371 L .63418 .17272 L .289 .763 .934 r
F
.63459 .17052 m .63418 .17272 L .65523 .17968 L F
.6069 .16371 m .58902 .17317 L p .63329 .17752 L F P
0 g
s
.65523 .17968 m .63418 .17272 L .63329 .17752 L .289 .763 .934 r
F
.63418 .17272 m .6069 .16371 L .63329 .17752 L F
.6313 .20212 m .63311 .1785 L .6341 .17317 L 0 0 .058 r
F
.64277 .18615 m .65407 .20331 L .65213 .22814 L .548 .447 .692 r
F
.65407 .20331 m .65407 .22933 L .65213 .22814 L F
.65559 .24191 m .65494 .23894 L p .65407 .21849 L 0 0 .068 r
F P
0 g
s
.65407 .21471 m .65559 .24191 L .65407 .21849 L 0 0 .068 r
F
.65407 .21849 m .65494 .23894 L .65407 .22355 L F
.65836 .22436 m .65895 .2134 L .63608 .2134 L p .617 .786 .963 r
F P
0 g
s
.65494 .23894 m .65438 .23315 L p .65407 .22355 L 0 0 .068 r
F P
0 g
s
.65438 .23315 m .65407 .22748 L p .65407 .22355 L 0 0 .068 r
F P
0 g
s
.63608 .2134 m .63558 .22436 L .65836 .22436 L p .617 .786 .963 r
F P
0 g
s
.65929 .20468 m .65895 .2134 L p .65929 .20061 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65663 .17317 L .65929 .16085 L 0 0 .068 r
F
.65336 .20212 m .65929 .16085 L .65929 .16256 L F
.68762 .16371 m .65929 .16085 L p .65929 .20468 L .845 .69 .69 r
F P
0 g
s
.65982 .18646 m .65945 .20057 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.66005 .17169 m .65982 .18646 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.66013 .15697 m .66005 .17169 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.64277 .18615 m .65407 .18509 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65895 .2134 m .65929 .20468 L p .64394 .20057 L .657 .75 .919 r
F P
0 g
s
.65945 .20057 m .65929 .20468 L p .65929 .20061 L 0 0 .068 r
F P
0 g
s
.65202 .20057 m .64394 .20057 L p .65929 .20468 L .657 .75 .919 r
F P
0 g
s
.64013 .20264 m .65895 .2134 L .64394 .20057 L .657 .75 .919 r
F
.65812 .16628 m .64806 .15972 L .65607 .17581 L .289 .763 .934 r
F
.65407 .22748 m .65438 .23315 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65559 .24191 m .65628 .24192 L .63379 .24192 L p 0 0 0 r
F P
0 g
s
.65628 .24192 m .65699 .23891 L .6344 .23891 L p .266 .752 .921 r
F P
0 g
s
.6344 .23891 m .63379 .24192 L .65628 .24192 L p .266 .752 .921 r
F P
0 g
s
.65699 .23891 m .6577 .23298 L .63501 .23298 L p .446 .812 .995 r
F P
0 g
s
.63501 .23298 m .6344 .23891 L .65699 .23891 L p .446 .812 .995 r
F P
0 g
s
.6577 .23298 m .65836 .22436 L .63558 .22436 L p .553 .811 .994 r
F P
0 g
s
.63558 .22436 m .63501 .23298 L .6577 .23298 L p .553 .811 .994 r
F P
0 g
s
.64806 .15972 m .63637 .16085 L p .63637 .20468 L .541 .442 .691 r
F P
0 g
s
.64806 .15972 m .63637 .20468 L .63871 .20341 L .541 .442 .691 r
F
.63608 .2134 m .65895 .2134 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63637 .20468 m .63608 .2134 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63265 .23894 m .63217 .23315 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.6319 .21849 m .63265 .23894 L .6319 .22355 L 0 0 .058 r
F
.61601 .23949 m .6319 .22933 L .6319 .31625 L .841 .687 .691 r
F
.64277 .36876 m .60419 .36597 L .60419 .1824 L p F P
0 g
s
.64806 .1973 m .64806 .15972 L p .63837 .205 L .541 .442 .691 r
F P
0 g
s
.65929 .16085 m .64806 .15972 L p .65137 .20004 L .845 .69 .69 r
F P
0 g
s
.63679 .18797 m .63651 .20057 L .65202 .20057 L p .682 .709 .868 r
F P
0 g
s
.65929 .20659 m .65137 .20004 L .65929 .29646 L .845 .69 .69 r
F
.65929 .16085 m .65137 .20004 L .65929 .20659 L F
.64806 .15972 m .64806 .34909 L p .65929 .29646 L F P
0 g
s
.63682 .18646 m .63679 .18797 L p .65945 .20057 L .682 .709 .868 r
F P
0 g
s
.65202 .20057 m .65945 .20057 L p .63679 .18797 L .682 .709 .868 r
F P
0 g
s
.6069 .35206 m .64806 .34909 L .64806 .1973 L p .541 .442 .691 r
F P
0 g
s
.63837 .205 m .6069 .35206 L .64806 .1973 L .541 .442 .691 r
F
.65982 .18646 m .63682 .18646 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.65945 .20057 m .65978 .18797 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.65978 .18797 m .65982 .18646 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.63651 .20057 m .63637 .20468 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.6313 .20212 m .6341 .17317 L .63637 .16085 L 0 0 .058 r
F
.6313 .20212 m .63637 .16085 L .63637 .16256 L F
.63637 .16085 m .6069 .16371 L p .63459 .17052 L .289 .763 .934 r
F P
0 g
s
.63682 .18646 m .63651 .20057 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63702 .17169 m .63682 .18646 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63709 .15697 m .63702 .17169 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.60419 .1824 m .6319 .18509 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.63637 .16085 m .6069 .16371 L p .6321 .207 L .541 .442 .691 r
F P
0 g
s
.63637 .20468 m .63608 .2134 L p .63637 .20061 L 0 0 .058 r
F P
0 g
s
.63637 .20468 m .6321 .207 L .63637 .21433 L .541 .442 .691 r
F
.63637 .16085 m .6321 .207 L .63637 .20468 L F
.65929 .20468 m .65945 .20057 L .65202 .20057 L p .657 .75 .919 r
F P
0 g
s
.67677 .21456 m .65929 .20468 L .65929 .29646 L .845 .69 .69 r
F
.70171 .35911 m .68286 .36597 L .68286 .1824 L p 0 0 .478 r
F P
0 g
s
.68286 .1824 m .70171 .17317 L .70171 .35911 L p 0 0 .478 r
F P
0 g
s
.68286 .1824 m .70171 .17317 L .68762 .16371 L p .289 .763 .934 r
F P
0 g
s
.68762 .16371 m .65929 .20468 L .67677 .21456 L .845 .69 .69 r
F
.65929 .16256 m .65929 .16085 L .66013 .15697 L 0 0 .068 r
F
.64394 .20057 m .63651 .20057 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63871 .20341 m .63637 .20468 L .63637 .21433 L .541 .442 .691 r
F
.63637 .16256 m .63637 .16085 L .63709 .15697 L 0 0 .058 r
F
.63651 .20057 m .63637 .20468 L p .63637 .20061 L F P
0 g
s
.60419 .1824 m .6319 .21112 L .61601 .23949 L .841 .687 .691 r
F
.6319 .21112 m .6319 .22933 L .61601 .23949 L F
.63217 .23315 m .6319 .22748 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.6069 .16371 m .6069 .35206 L p .63637 .21433 L .541 .442 .691 r
F P
0 g
s
.60419 .36597 m .58902 .35911 L .58902 .17317 L p .989 .807 .419 r
F P
0 g
s
.58902 .17317 m .60419 .1824 L .60419 .36597 L p .989 .807 .419 r
F P
0 g
s
.58902 .35911 m .6069 .35206 L .6069 .16371 L p 0 0 .457 r
F P
0 g
s
.6069 .16371 m .58902 .17317 L .58902 .35911 L p 0 0 .457 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.60419 .36597 m .64277 .36876 L .68286 .36597 L p .224 .73 .894 r
F P
0 g
s
.58902 .35911 m .60419 .36597 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6069 .35206 m .58902 .35911 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64806 .34909 m .6069 .35206 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64806 .34909 m .68762 .35206 L .68762 .16371 L p .845 .69 .69 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.68762 .35206 m .64806 .34909 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.68286 .36597 m .70171 .35911 L .68762 .35206 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.68762 .35206 m .70171 .35911 L .70171 .17317 L p .981 .801 .392 r
F P
0 g
s
.70171 .17317 m .68762 .16371 L .68762 .35206 L p .981 .801 .392 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.39236 1.29439 m .41389 1.27286 L .43542 1.29439 L p .707 .577 .707 r
F P
0 g
s
.43542 1.29439 m .41389 1.31592 L .39236 1.29439 L p .707 .577 .707 r
F P
0 g
s
.56458 1.29439 m .58611 1.27286 L .60764 1.29439 L p .707 .577 .707 r
F P
0 g
s
.60764 1.29439 m .58611 1.31592 L .56458 1.29439 L p .707 .577 .707 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.34301 .10412 m .3423 .1035 L .36499 .1035 L p .059 .624 .764 r
F P
0 g
s
.36442 .10596 m .36499 .1035 L .3423 .1035 L p .238 0 0 r
F P
0 g
s
.65836 .10596 m .6577 .1035 L .63501 .1035 L p .238 0 0 r
F P
0 g
s
.3423 .1035 m .34164 .10596 L .36442 .10596 L p .238 0 0 r
F P
0 g
s
.63501 .1035 m .63558 .10596 L .65836 .10596 L p .238 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.36392 .11142 m .36442 .10596 L .34164 .10596 L p .47 0 0 r
F P
0 g
s
.65895 .11142 m .65836 .10596 L .63558 .10596 L p .47 0 0 r
F P
0 g
s
.34164 .10596 m .34105 .11142 L .36392 .11142 L p .47 0 0 r
F P
0 g
s
.63558 .10596 m .63608 .11142 L .65895 .11142 L p .47 0 0 r
F P
0 g
s
.36349 .11966 m .36392 .11142 L .34105 .11142 L p .601 .186 .228 r
F P
0 g
s
.65945 .11966 m .65895 .11142 L .63608 .11142 L p .601 .186 .228 r
F P
0 g
s
.34105 .11142 m .34055 .11966 L .36349 .11966 L p .601 .186 .228 r
F P
0 g
s
.63608 .11142 m .63651 .11966 L .65945 .11966 L p .601 .186 .228 r
F P
0 g
s
.36318 .13034 m .36349 .11966 L .34055 .11966 L p .665 .348 .426 r
F P
0 g
s
.65982 .13034 m .65945 .11966 L .63651 .11966 L p .665 .348 .426 r
F P
0 g
s
.34055 .11966 m .34018 .13034 L .36318 .13034 L p .665 .348 .426 r
F P
0 g
s
.63651 .11966 m .63682 .13034 L .65982 .13034 L p .665 .348 .426 r
F P
0 g
s
.36349 .20057 m .36318 .18646 L .34018 .18646 L p .682 .709 .868 r
F P
0 g
s
.36298 .14297 m .36318 .13034 L .34018 .13034 L p .695 .46 .564 r
F P
0 g
s
.66005 .14297 m .65982 .13034 L .63682 .13034 L p .695 .46 .564 r
F P
0 g
s
.34018 .13034 m .33995 .14297 L .36298 .14297 L p .695 .46 .564 r
F P
0 g
s
.63682 .13034 m .63702 .14297 L .66005 .14297 L p .695 .46 .564 r
F P
0 g
s
.36318 .18646 m .36298 .17169 L .33995 .17169 L p .698 .662 .811 r
F P
0 g
s
.33995 .17169 m .34018 .18646 L .36318 .18646 L p .698 .662 .811 r
F P
0 g
s
.65982 .18646 m .66005 .17169 L .63702 .17169 L p .698 .662 .811 r
F P
0 g
s
.63702 .17169 m .63682 .18646 L .65982 .18646 L p .698 .662 .811 r
F P
0 g
s
.36291 .15697 m .36298 .14297 L .33995 .14297 L p .706 .543 .665 r
F P
0 g
s
.66013 .15697 m .66005 .14297 L .63702 .14297 L p .706 .543 .665 r
F P
0 g
s
.33995 .14297 m .33987 .15697 L .36291 .15697 L p .706 .543 .665 r
F P
0 g
s
.63702 .14297 m .63709 .15697 L .66013 .15697 L p .706 .543 .665 r
F P
0 g
s
.36298 .17169 m .36291 .15697 L .33987 .15697 L p .706 .608 .745 r
F P
0 g
s
.33987 .15697 m .33995 .17169 L .36298 .17169 L p .706 .608 .745 r
F P
0 g
s
.66005 .17169 m .66013 .15697 L .63709 .15697 L p .706 .608 .745 r
F P
0 g
s
.63709 .15697 m .63702 .17169 L .66005 .17169 L p .706 .608 .745 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00f`3oool?00000:`0oooo3`00003K0?oo
o`00fP3oool00`000000?00003`0000<03`000030000003oool0oooo0:T0oooo0P00000=03`00003
0000003oool0oooo0=T0oooo003J0?oooa000000Z`3ooolA00000=X0oooo003J0?ooo`030000001h
0000N00000`0N0000P00002Z0?ooo`8000003P1h00000`000000oooo0?ooo`3H0?ooo`00fP3oool0
0`000000N00007P0000;07P0000300000033W`h000000:X0oooo0P00000>07P000030000003oool0
oooo0=P0oooo003J0?ooo`030000001h0000N00000/0N00000<000000<>O3P000000ZP3oool00`00
0000000>0000000=07P000030000003oool0oooo0=P0oooo003J0?ooo`l0000000<0`il>0000003o
ool0Z@3oool00`000000000>0000000>00000=X0oooo003J0?ooo`030000002I;cX0VBlj00/0VBlj
00<000000<>O3P000000ZP3oool00`000000000>0000000=09T_>P030000003oool0oooo0=P0oooo
003J0?ooo`030000002I;cX0VBlj00/0VBlj00<000000<>O3P000000ZP3oool00`000000000>0000
000=09T_>P030000003oool0oooo0=P0oooo003I0?ooo`030000002I;cX0VBlj00`0VBlj00<00000
0<>O3P000000ZP3oool00`000000000>0000000>09T_>P030000003oool0oooo0=L0oooo003I0?oo
o`030000002I;cX0VBlj00`0VBlj00<000000<>O3P000000Z@3oool010000000000>00003P00000>
09T_>P030000003oool0oooo0=L0oooo003I0?oooa0000000P33W`h00`000000oooo0?ooo`2V0?oo
o`030000000000h0000>01000000f@3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000
`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool0
0=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?ooo`040000000000h0
000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd0
10000000`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0
e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?ooo`040000
000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0
302ZFFd010000000`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?oo
o`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?oo
o`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo400000020<>O
3P030000003oool0oooo0:H0oooo00<0000000003P0000h04000003I0?ooo`00f@3oool00`000000
/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI00
0`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>
00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool0
0`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P0000h00000
3P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033
W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00
f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P00
00h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT004
00000033W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G
0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@00000
00003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool@00000080`il>00<00000
0?ooo`3oool0YP3oool00`000000000>00003P0@00000=T0oooo003I0?ooo`030000002dRjX0]8^Z
00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003o
ool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03o
ool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002d
RjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP03
0000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h0
0000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`03
0000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>
0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O
3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I
0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>0000
3P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@0
00000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0
oooo003I0?oooa0000000P33W`h00`000000oooo0?ooo`2V0?ooo`030000000000h0000>01000000
f@3oool00=T0oooo00<000000;BK_P2dVkh0302dVkh010000000`il>0<>O3P00002X0?ooo`040000
000000h0000>000000h0]9^n00<000000?ooo`3oool0e`3oool00=H0oooo1000000>0;BK_PD00000
YP3oool5000000h0]9^n1000003F0?ooo`00c03oool:000000<0R6n`00<000000;BK_P2dVkh0302d
Vkh00`000000ejn`0=N_/0020=N_/0X00000TP3oool:000000@0RW6`00<000000;BK_P2dVkh0302d
Vkh010000000f;2`0=R`/03H/;0:00000<`0oooo00370?ooo`D000003@28Kk000`000000]9^n0;BK
_P0<0;BK_P030000003G[k00ejn`00`0ejn`1@0000280?ooo`D000003P2:LK000`000000]9^n0;BK
_P0<0;BK_P030000003H/;00f;2`00/0f;2`1@0000370?ooo`00a@3oool300000140R6n`00<00000
0;BK_P2dVkh0302dVkh00`000000ejn`0=N_/00@0=N_/0<00000Q03oool300000180RW6`00<00000
0;BK_P2dVkh0302dVkh00`000000f;2`0=R`/00?0=R`/0<00000a@3oool00<@0oooo00@000000000
I00006@000004@28Kk000`000000]9^n0;BK_P0<0;BK_P030000003G[k00ejn`0100ejn`00<00000
0?o@M03od7@00P0000200?ooo`8000000P0007@00`000000RW6`08Ya/00@08Ya/0030000002dVkh0
]9^n00`0]9^n00<000000=R`/03H/;003`3H/;0010000000nleT0?_=I00000340?ooo`00`P3oool2
000000<0001T00<0000008Q_/028Kk003`28Kk000`000000]9^n0;BK_P0<0;BK_P030000003G[k00
ejn`0100ejn`00<000000?o@M03od7@00P3od7@2000007`0oooo0P0000040000M0030000002:LK00
RW6`0100RW6`00<000000;BK_P2dVkh0302dVkh00`000000f;2`0=R`/00?0=R`/0040000003kcF@0
nleT0?_=I0800000`P3oool00<40oooo00<000000000I00006@00`0006@00`000000R6n`08Q_/00?
08Q_/0030000002dVkh0]9^n00`0]9^n00<000000=N_/03G[k00403G[k000`000000om1d0?o@M004
0?o@M0800000N03oool2000000H0001d00<0000008Ya/02:LK00402:LK000`000000]9^n0;BK_P0<
0;BK_P030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@00`3kcF@00`000000oooo0?ooo`2o
0?ooo`00_`3oool2000000H0001T00<0000008Q_/028Kk003`28Kk0@00000180ejn`00<000000?o@
M03od7@01P3od7@2000007@0oooo0P0000080000M0030000002:LK00RW6`0100RW6`4000000A0=R`
/0030000003kcF@0nleT00@0nleT0P00002o0?ooo`00_P3oool00`000000001T0000I0060000I003
00000028Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/003
0000003od7@0om1d00P0om1d0P00001`0?ooo`8000002P0007@00`000000RW6`08Ya/00@08Ya/003
0000002bZLl0/ZW?00`0/ZW?00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
3`28Kk000`000000/ZW?0;:Yc`0<0;:Yc`030000003G[k00ejn`0100ejn`00<000000?o@M03od7@0
2@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK00
402:LK000`000000/ZW?0;:Yc`0<0;:Yc`030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@0
1P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028
Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/0030000003o
d7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:
LK00RW6`0100RW6`00<000000;:Yc`2bZLl0302bZLl00`000000f;2`0=R`/00?0=R`/0030000003k
cF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@0
0`000000R6n`08Q_/00?08Q_/0030000002bZLl0/ZW?00`0/ZW?00<000000=N_/03G[k003P3G[k00
0`19`nl0ejn`0000000;0?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00@08Ya/0030000002bZLl0/ZW?00`0/ZW?00<000000=R`/03H/;003`3H/;00
0`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T
00H0001T00<0000008Q_/028Kk003`28Kk000`000000/ZW?0;:Yc`0<0;:Yc`030000003G[k00ejn`
0100ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d
00T0001d00<0000008Ya/02:LK00402:LK000`000000/ZW?0;:Yc`0<0;:Yc`030000003H/;00f;2`
00l0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000
ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000
001d0000M0090000M0030000002:LK00RW6`0100RW6`00<000000;:Yc`2bZLl0302bZLl00`000000
f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002bZLl0/ZW?00`0/ZW?
00<000000=N_/03G[k00403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo
00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002bZLl0/ZW?00`0/ZW?
00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk003`28Kk000`000000/ZW?0;:Y
c`0<0;:Yc`030000003G[k00ejn`0100ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?oo
o`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK00402:LK000`000000/ZW?0;:Y
c`0<0;:Yc`030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`00l0R6n`00<00000
0;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<00000
0?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00RW6`0100RW6`00<00000
0;:Yc`2bZLl0302bZLl00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_
/10000004P3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000
M00007@02@0007@00`000000RW6`08Ya/00@08Ya/10000004@3H/;000`000000nleT0?_=I0060?_=
I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028
Kk003`28Kk000`000000[[GN0:jegP0<0:jegP030000003G[k00ejn`0100ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK00402:LK000`000000[[GN0:jegP0<0:jegP030000003H/;00f;2`00l0f;2`00<000000?_=I03k
cF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I0030000
0028Kk00R6n`00l0R6n`00<000000:jegP28Kk00302^]Mh00`000000ejn`0=N_/00@0=N_/0030000
003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000
002:LK00RW6`0100RW6`00<000000:jegP2^]Mh0302^]Mh00`000000f;2`0=R`/00?0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00?08Q_/0050000002^]Mh0[[GN0:jegP28Kk002P2^]Mh00`000000ejn`
0=N_/00<0=N_/00508Ya/03G[k00ejn`0=N_/00000002`3od7@00`000000oooo0?ooo`1^0?ooo`03
0000000007@0001d00T0001d00<0000008Ya/02:LK00402:LK000`000000[[GN0:jegP020:jegP03
08Ya/02^]Mh0[[GN00L0[[GN00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
3`28Kk000`000000[[GN0:jegP030:jegP0308Q_/02^]Mh0[[GN00H0[[GN00<000000=N_/03G[k00
403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@0
2@0007@00`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN00@0[[GN00<000000:jegP2^]Mh0
1@2^]Mh00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002^
]Mh0[[GN00D0[[GN00<000000:jegP2^]Mh0102^]Mh00`000000ejn`0=N_/00@0=N_/0030000003o
d7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:
LK00RW6`0100RW6`00<000000:jegP2^]Mh0302^]Mh00`000000f;2`0=R`/00?0=R`/0030000003k
cF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@0
0`000000R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN00`0[[GN00<000000=N_/03G[k00403G[k00
0`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN00L0[[GN00<0f;2`0:jegP2^]Mh00P2^]Mh0
0`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool0
0;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN
00`0[[GN00<000000=N_/03G[k00403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo
06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN
00@0[[GN00<000000:jegP2^]Mh01@2^]Mh00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT
00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000
R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN00@0[[GN00@0R6n`0000002^]Mh0ejn`102^]Mh00`00
0000ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`00
0000001d0000M0090000M0030000002:LK00RW6`0100RW6`00<000000:jegP2^]Mh00`2^]Mh00`2:
LK0000000=R`/0060:jegP030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@01P3kcF@00`00
0000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`00l0
R6n`1P00000208Q_/0030000003G[k00000000D000004P3G[k000`000000om1d0?o@M0090?o@M003
0000003oool0oooo06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0H0
000000@0RW6`0000003H/;00f;2`1P00000A0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/003
0000002X_n/0Z;o[00D0R6n`00<000000=N_/03G[k000P3G[k020:Roja<0ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK00402:LK000`000000Z;o[08Ya/00408Ya/0030000003H/;00f;2`0080f;2`0P2X_n/00`000000
f;2`0=R`/00@0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00@08Q_/00300000028Kk00R6n`00@0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo
00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002:LK00RW6`00@0RW6`
00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_
/00A0=N_/00308Ya/03G[k00ejn`00<0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?oo
o`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`
/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<00000
0000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<00000
0?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_
/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?oo
o`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3o
ool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000
003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000
000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`0100ejn`00<0RW6`0=N_/03G[k00103G
[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@00
07@00`000000RW6`08Ya/00@08Ya/0030000002:LK00RW6`00@0RW6`00<000000=R`/03H/;005`3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0
om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00
RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0
oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`00
0000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`00
0000001d0000M0090000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00RW6`01L0
RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0
oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`
0=N_/00?0=N_/00308Ya/03G[k00ejn`00D0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo
0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<0
00000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^
0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G
0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000
I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@
M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya
/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/003
0000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`03
0000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/003
0000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@0
1P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00h0ejn`00<0RW6`0=N_/03G[k00
1P3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@0
2@0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@0
1P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028
Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003o
ool0oooo06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000003H
/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k00
0`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo
06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k003@3G[k000`2:LK00
ejn`0=N_/0070=N_/0030000003od7@0om1d00T0om1d0`00001/0?ooo`<000002`0007@00`000000
RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003od7X0om1j00800000
J03oool200000080001j00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000
003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3o
ool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G
[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j
0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/003
0000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@0
1P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@0
2@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000
M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=
I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028
Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3o
d7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G
08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l
0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_
/03G[k00303G[k000`2:LK00ejn`0=N_/0080=N_/0030000003od7@0om1d00T0om1d00D000000?o@
NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya
/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<00000
0=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<0
00000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0
001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000
nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T
00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d
00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`00
0000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`00
0000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0
R6n`00<000000=N_/03G[k002`3G[k000`2:LK00ejn`0=N_/0090=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j
0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:
LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03o
ool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00
ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
5`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`0300000000
06@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003o
d7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP00
00002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03k
cF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I0030000
0028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000
003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya
/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/003
0000003G[k00ejn`00X0ejn`00<0RW6`0=N_/03G[k002P3G[k000`000000om1d0?o@M0090?o@M005
0000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00:0=R`/00308ab/@3H/;00f;2`00X0f;2`00<00000
0?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000
I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@
M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3o
d7X0000006P0oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`
00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_
/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000
000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0
f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T
0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k002@3G[k000`2:LK00ejn`
0=N_/00;0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`05
0000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k002@3G[k000`2:LK00
ejn`0=N_/00;0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?oo
o`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00
f;2`00T0f;2`00<0S7:a0=R`/03H/;002`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0
oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`00
0000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X
0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H
/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k00
0`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000
NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3o
d7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000M003
0000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
5`28Kk000`000000ejn`0=N_/0080=N_/00308Ya/03G[k00ejn`00`0ejn`00<000000?o@M03od7@0
2@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000
M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00203H/;000`2<L[40f;2`0=R`/00<0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;
0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I006
0?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_
/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@
NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya
/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<00000
0=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00L0ejn`00<0
RW6`0=N_/03G[k003@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000
J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000
f;2`0=R`/0070=R`/00308ab/@3H/;00f;2`00d0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k001`3G[k000`2:LK00ejn`0=N_/00=0=N_/0030000003od7@0om1d00T0om1d
00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`00
0000RW6`08Ya/00G08Ya/0030000003H/;00f;2`00L0f;2`00<0S7:a0=R`/03H/;003@3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j
0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:
LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03o
ool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00
ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
5`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`0300000000
06@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/0060=N_/00308Ya/03G
[k00ejn`00h0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo
00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H
/;001P3H/;000`2<L[40f;2`0=R`/00>0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3o
ool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000
003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0
oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`
/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`03
0000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/003
0000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j
0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<00000
0?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000
I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@
M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`00D0ejn`00<0RW6`0=N_/03G[k003`3G[k000`000000om1d0?o@M009
0?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d
00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/0050=R`/00308ab/@3H/;00f;2`00l0f;2`
00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000
I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k001@3G[k000`2:LK00ejn`0=N_
/00?0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000
000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`00D0
f;2`00<0S7:a0=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0
oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`
0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`05
0000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000
om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0
000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0
nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`00
0000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00@0ejn`00<0RW6`0=N_/03G[k00403G[k000`00
0000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP00
07X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/0040=R`/00308ab/@3H
/;00f;2`0100f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k00103G[k00
0`2:LK00ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000
001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000
003H/;00f;2`00@0f;2`00<0S7:a0=R`/03H/;00403H/;000`000000nleT0?_=I0060?_=I0030000
003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28
Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j
0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/003
0000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00
_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k00
5`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000
001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;
0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I006
0?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_
/028Kk005`28Kk000`000000ejn`0=N_/0030=N_/00308Ya/03G[k00ejn`0140ejn`00<000000?o@
M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000
000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;000`3H/;000`2<L[40f;2`0=R`
/00A0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<00000
0000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00<0ejn`00<0RW6`
0=N_/03G[k004@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/0030=R`/00308ab/@3H/;00f;2`0140f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo
0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<0
00000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000
J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000
f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`
00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP00
07X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k000P3G[k000`2:LK00ejn`0=N_/00B0=N_/0030000003od7@0om1d
00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`00
07@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`0080f;2`00<0S7:a0=R`/03H/;004P3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/0020=N_/00308Ya/03G[k00
ejn`0180ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
0P3H/;000`2<L[40f;2`0=R`/00B0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G
[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo
00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H
/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000
000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000
003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000
NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=
I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I003
00000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M005
0000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_
/0050000003G[k00ejn`0=N_/02:LK005@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0
om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK00
5`2:LK001@000000f;2`0=R`/03H/;00S7:a01D0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP00
0000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`00
0000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0
oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0
ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000
NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;00
0`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T
00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d
00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`00
07@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3k
cF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00
R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0
om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK00
5`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0040000003G
[k00ejn`000001H0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0
oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00@000000=R`
/03H/;00S7:a5P3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?oo
o`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_
/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0
001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<0
00000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I006
0000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M009
0?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d
00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT
00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_
/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@
NP3od7X0000001H0oooo?000000F0?ooo`050000000007X0001j0000NP0000002`0007@00`000000
RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP00
00000P3ooolD000000T0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@0
00000P3oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`00
0000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0
oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0
ejn`00<000000?o@M00000004000000M09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38
Y;<06`38Y;<A000000030000M0000000RW6`01P0RW6`00<000000=R`/03H/;005`3H/;000`000000
nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T
00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00=0=N_/0`000001P24K:l00`000000WX6c
09j1/`0U09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_
0=^b[`040=^b[``000003`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT
00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_
/00G08Q_/0040000003G[k00ejn`0=N_/0`000004P24K:l00`000000WX6c09j1/`0B09j1/e000000
5038Y;<00`000000fk:_0=^b[`0@0=^b[``000000`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00A08Q_/0X000006024K:lK00000500>;[T5@00000N0=^b[`X000004`3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk002@28Kk08000000<0He2W00<0000008A/[`24K:l04024K:l<
000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0Y`P000002`3H/;000`000000nleT0?_=
I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00@00000
08Q_/028Kk00R6n`2000000;06=@Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`000001P3K
/Zl00`000000k<2W0>c0Y`090>c0Y`P000000`3H/;000`000000nleT0?_=I0060?_=I0030000003o
ool0oooo0;`0oooo002n0?ooo`030000000006@0001T0080001T2000000@06=@Y`X00000]P0h^^@7
000001<0k<2W200000040?_=I0030000003oool0oooo0;`0oooo002m0?ooo`H00000401SD:L80000
0<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0He2W00T0
He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?ooo`D00000
1`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<V03jc9P0
1@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D00000[`3o
ool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo002U0?oo
o`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool200000003
0000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`000000080
0000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rji1h0>;[T
100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0001l00<0
000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0om1l0P00
002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000V`3oool0
09P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F0?ooo`80
0000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3000000H0001l
0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`0004/00000
100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool00940oooo
0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000003`a4/0
0P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540>;[T0P00
00050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[TE@0h^^@2
000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h^^@0>;[T
0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=0?ooo`04
0000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?ooo`2;0?oo
o`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000S@3oool0
08d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2000008`0
oooo002<0?ooo`8000005@0h^^@203Vji9X0>;[T00<0000003Rji00h^^@03@0h^^@00`3F[k40>;[T
03Rji02P03Rji0800000S03oool008`0oooo0P00000[03Rji0@0>K[TJ@0h^^@2000000<0001a2`0h
^^@908ab/@030000003F[k40eZna00L0eZna200h^^@00`3F[k40>;[T03Rji02N03Rji0800000S03o
ool008`0oooo00<0000003Rji00h^^@0?`0h^^@603Vji5P0>;[T00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0>;[T0P00002<0?ooo`00S03oool00`00
0000>;[T03Rji02K03Rji080001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma09d0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h
^^@0V00h^^@50000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@030?k?LIX0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h^^@0
U@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T09D0>;[T00<000000?ooo`3oool0
RP3oool008d0oooo00<0000003Rji00h^^@0<@0h^^@=03Vji5H0>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>K[T03Vji02D03Rji0030000003oool0oooo08/0oooo002>0?ooo`800000IP0h^^@I
03Vji1D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00=03Rji100>K[TM@0h^^@2
000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji00]03Rji0`0>K[TF00h^^@00`000000oooo0?ooo`2>0?ooo`00T@3oool00`000000
>;[T03Rji02@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@09P0h^^@00`0i^^@0
>;[T03Rji00T03Rji0P0>K[T>`0h^^@00`000000oooo0?ooo`2?0?ooo`00TP3oool200000900>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rji0@0>K[T7@0h^^@200000980oooo
002D0?ooo`030000000h^^@0>;[T08d0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i02=03Rji0030000003oool0oooo0980oooo002F0?ooo`800000S00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T08X0>;[T0P00002F0?ooo`00V03oool2000008X0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji02803Rji0800000V03oool009X0oooo0`00002703Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h^^@3000009X0oooo002M0?ooo`800000
Q@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08<0>;[T0P00002M0?ooo`00W`3o
ool2000008<0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02103Rji0800000W`3o
ool00:40oooo1000001o03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0O@0h^^@4
00000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T
07P0>;[T1@00002U0?ooo`00ZP3oool5000007D0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00001`03Rji003000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<0000003Rji00h^^@0KP0h^^@500000:l0oooo002d0?ooo`D00000J`0h^^@00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000000h^^@0>;[T06T0>;[T1@00002d0?ooo`00^@3oool5000006H0>;[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000>;[T03Rji01T03Rji0D00000^@3oool00;h0oooo1@00001Q03Rj
i003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0G`0h^^@500000;h0oooo00330?ooo`D0
0000G00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05X0>;[T1@0000330?ooo`00
b03oool5000005L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01E03Rji0D00000
b03oool00<d0oooo1`00001@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0CP0h
^^@700000<d0oooo003D0?ooo`X00000AP0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T04@0>;[T2P00003D0?ooo`00gP3oool:000003`0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji00j03Rji0X00000gP3oool00>P0oooo3@00000_03Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0;@0h^^@=00000>P0oooo003e0?oooa0000007`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T01d0>;[T4000003e0?ooo`00o`3oool60?oooaT000001P0h
^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o
0?oooal0oooo1`0000070000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@L00000o`3ooolO0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00``3oool3000005h0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1/0?ooo`<00000/`3oool00;00oooo0P00000A
0?ooo`030000001jFJ00NUVP00D00000F@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05X0oooo0P00000@0?ooo`030000001nGJ80OUfR00H00000[@3oool00:d0oooo0`0000000`1k
K[X000000000000?0?ooo`030000001jFJ00NUVP00H0NUVP0`00001F0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0E`3oool30000000307ma^P000000oooo00h0oooo00<0000007iM
XP1nGJ801`1nGJ8300000:X0oooo002Y0?ooo`@000001@1kK[X00`000000oooo0?ooo`0=0?ooo`03
0000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E03oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo05<0oooo1000000507ma^P030000003oool0oooo00`0oooo00<0000007iMXP1n
GJ802@1nGJ800`000000oooo0?ooo`2X0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000
001jFJ00NUVP00L0NUVP0P00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
D@3oool2000000T0Og6j00<000000?ooo`3oool0303oool00`000000OUfR07iMXP0907iMXZ/0oooo
002W0?ooo`030000001kK[X0Nfjj00P0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00
001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0D@3oool00`000000Og6j07ma
^P0807ma^P030000003oool0oooo00`0oooo00<0000007iMXP1nGJ80201nGJ800`000000oooo0?oo
o`2Y0?ooo`00Z03oool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000NUVP07YIX008
07YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1A
0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool02`3oool00`000000OUfR07iMXP09
07iMXP030000003oool0oooo0:T0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?oo
o`3oool02`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?oo
o`3oool02P3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:T0oooo002X0?ooo`03
0000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool00`000000NUVP07YIX00707YIX080
0000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0580oooo00<0000007ma^P1o
LKX0201oLKX00`000000oooo0?ooo`0:0?ooo`030000001nGJ80OUfR00P0OUfR00<000000?ooo`3o
ool0ZP3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YIX01jFJ00
1`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000
001oLKX0Og6j00P0Og6j00<000000?ooo`3oool02P3oool00`000000OUfR07iMXP0807iMXP030000
003oool0oooo0:X0oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001j
FJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0580oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo0?ooo`090?ooo`030000001n
GJ80OUfR00T0OUfR00<000000?ooo`3oool0ZP3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X0
0`30N@00oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05<0oooo00<0000007ma^P1oLKX0201oLKX0
0`000000oooo0?ooo`080?ooo`030000001nGJ80OUfR00P0OUfR0P00002/0?ooo`00Z@3oool00`00
0000Nfjj07]^^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YIX01jFJ001`1jFJ020000
05P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1C0?ooo`030000001oLKX0Og6j
00P0Og6j00<000000?ooo`3oool0203oool00`000000OUfR07iMXP0807iMXP030000003oool0oooo
0:/0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02@3oool00`000000
NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05<0
oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo0?ooo`080?ooo`030000001nGJ80OUfR00P0
OUfR00<000000?ooo`3oool0Z`3oool00:X0oooo00<0000007]^^P1kK[X01`1kK[X00`30N@000000
0?ooo`080?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05<0oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo
0?ooo`070?ooo`030000001nGJ80OUfR00P0OUfR0P00002]0?ooo`00ZP3oool00`000000Nfjj07]^
^P0707]^^P8000002@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1D0?ooo`030000001oLKX0Og6j00P0Og6j00<0
00000?ooo`3oool01P3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:/0oooo002Z
0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX007
07YIX0800000F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05@0oooo00<00000
07ma^P1oLKX0201oLKX00`000000oooo0?ooo`060?ooo`030000001nGJ80OUfR00P0OUfR00<00000
0?ooo`3oool0[03oool00:X0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`070?oo
o`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0E03oool00`000000Og6j07ma^P0807ma^P030000003oool0oooo00H0oooo00<0000007iM
XP1nGJ801@1nGJ80103O`;X0OUfR00000000002^0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^
^P8000001`3oool00`000000NUVP07YIX00707YIX0030=fn^P000000oooo05T0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1D0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?oo
o`3oool01@3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:`0oooo002[0?ooo`03
0000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3o
ool0F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05D0oooo00<0000007ma^P1o
LKX0201oLKX00`000000oooo0?ooo`040?ooo`030000001nGJ80OUfR00D0OUfR00D0gl2j07iMXP1n
GJ80OUfR0000002^0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00D0
oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`1E0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool0103oool00`000000
OUfR07iMXP0707iMXP030=o0^P000000oooo0:h0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj
00<0`7T00000003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05D0oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo
0?ooo`040?ooo`030000001nGJ80OUfR00P0OUfR00<000000?ooo`3oool0[@3oool00:`0oooo00<0
000007]^^P1kK[X01`1kK[X2000000D0oooo00<0000007YIX01jFJ00201jFJ02000005X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1E0?ooo`030000001oLKX0Og6j00P0Og6j00<0
00000?ooo`3oool00`3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:d0oooo002/
0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000001jFJ00NUVP00P0NUVP00<00000
0?ooo`3oool0F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05D0oooo0P00000:
07ma^P030000003oool0oooo0080oooo00<0000007iMXP1nGJ801`1nGJ800`3O`;X0OUfR0000002_
0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool00`000000NUVP07YIX00707YI
X0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05H0oooo00<0000007ma
^P1oLKX0201oLKX00`000000oooo0?ooo`020?ooo`030000001nGJ80OUfR00P0OUfR00<000000?oo
o`3oool0[P3oool00:`0oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YIX01j
FJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1F0?ooo`03
0000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool00P3oool00`000000OUfR07iMXP0807iMXP03
0000003oool0oooo0:h0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000
001jFJ00NUVP00P0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
EP3oool00`000000Og6j07ma^P0807ma^P050000003oool0oooo0?ooo`0000002@1nGJ800`3O`;X0
OUfR0000002`0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP
07YIX00807YIX0030000003oool0oooo05X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1F0?ooo`8000002P1oLKX010000000oooo0?ooo`00000;07iMXP030000003oool0oooo0:h0
oooo002]0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP
0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0E`3oool00`000000Og6j
07ma^P0807ma^P040000003oool0oooo000000X0OUfR00<000000?ooo`3oool0[`3oool00:d0oooo
0P00000907]^^P050<1i00000000oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1G0?ooo`030000001oLKX0Og6j00P0Og6j00@000000?ooo`3o
ool00000201nGJ800`3O`;X0OUfR0000002a0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P80
000000<0oooo0000001jFJ002@1jFJ02000005`0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`1G0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`0000001@1nGJ800`3O`;X0
OUfR07iMXP0307iMXP030000003oool0oooo0:l0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj
1000000807YIX0030=fn^P000000000005d0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1G0?ooo`8000002P1oLKX2000000X0OUfR0P00002a0?ooo`00[P3oool00`000000Nfjj07]^
^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`1H0?ooo`030000001oLKX0Og6j00P0Og6j0P00000407iMXP070=o0^P1nGJ80OUfR07iMXP3O`;X0
OUfR0000002b0?ooo`00[P3oool2000000T0Nfjj0`00000907YIX0800000G@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05P0oooo00<0000007ma^P1oLKX0201oLKX2000000X0OUfR
00<000000?ooo`3oool0/03oool00:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000P0NUVP00@0
gKjj07YIX038adH00000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0oooo
00<0000007ma^P1oLKX0201oLKX00`000000OUfR07iMXP0207iMXP030=o0^P1nGJ80OUfR00@0OUfR
00<000000?ooo`3oool0/03oool00:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000T0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F03oool2000000X0Og6j00<0
000007iMXP1nGJ801@1nGJ80103O`;X0OUfR00000000002b0?ooo`00[`3oool00`000000Nfjj07]^
^P0807]^^P030000001jFJ00NUVP00L0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0F@3oool00`000000Og6j07ma^P0807ma^P040000001nGJ80OUfR0=o0^PH0OUfR
00<000000?ooo`3oool0/@3oool00:l0oooo0P00000907]^^P030000001jFJ00NUVP00L0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F@3oool00`000000Og6j07ma
^P0807ma^P030000001nGJ80OUfR00L0OUfR00<000000?ooo`3oool0/@3oool00;00oooo00<00000
07]^^P1kK[X01`1kK[X00`000000NUVP07YIX00707YIX0030<S7AP000000oooo05d0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`1I0?ooo`030000001oLKX0Og6j00P0Og6j00<00000
07iMXP1nGJ80101nGJ80103O`;X0OUfR07iMXP00002c0?ooo`00/03oool00`000000Nfjj07]^^P08
07]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0F@3oool2000000X0Og6j00<0000007iMXP1nGJ801@1nGJ8200000;<0oooo002`0?oo
o`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo05T0oooo0P00000:07ma^P030000001nGJ80OUfR00D0OUfR00<000000?oo
o`3oool0/P3oool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool00`000000Og6j07ma^P0807ma^P03
0000001nGJ80OUfR0080OUfR00@0gl2j07iMXP1nGJ800000]03oool00;40oooo00<0000007]^^P1k
K[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7AP000000oooo05h0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1J0?ooo`030000001oLKX0Og6j00P0Og6j00<0000007iMXP1n
GJ801@1nGJ800`000000oooo0?ooo`2b0?ooo`00/@3oool00`000000Nfjj07]^^P0807]^^P030000
001jFJ00NUVP00<0NUVP0`00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
FP3oool2000000X0Og6j00<0000007iMXP1nGJ800`1nGJ8200000;@0oooo002a0?ooo`8000002@1k
K[X01P000000NUVP07YIX01jFJ00gKjj07YIX0800000H03oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo05X0oooo0P00000:07ma^P040000001nGJ80OUfR0=o0^P80OUfR00<000000?oo
o`3oool0/`3oool00;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00001P0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F`3oool00`000000Og6j07ma^P0807ma^P03
0000001nGJ80OUfR00<0OUfR00<000000?ooo`3oool0/`3oool00;80oooo00<0000007]^^P1kK[X0
1`1kK[X00`000000NUVP07YIX00307YIX0030<S7AP000000oooo05l0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`1K0?ooo`030000001oLKX0Og6j00P0Og6j00<0000007iMXP1nGJ80
0`1nGJ800`000000oooo0?ooo`2c0?ooo`00/P3oool00`000000Nfjj07]^^P0807]^^P040000001j
FJ00gKjj07YIX0<00000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0oooo
0P00000:07ma^P040000003O`;X0OUfR07iMXP800000]@3oool00;80oooo0P00000907]^^P040000
001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0
oooo0P00000:07ma^P050000001nGJ80OUfR07iMXP000000]P3oool00;80oooo0P00000907]^^P04
0000001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
05`0oooo00<0000007ma^P1oLKX0201oLKX01@000000OUfR07iMXP1nGJ8000000;H0oooo002c0?oo
o`030000001kK[X0Nfjj00L0Nfjj00H000000=fn^P1jFJ00NUVP0<S7AP00001Q0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0G03oool00`000000Og6j07ma^P0807ma^P050000001n
GJ80OUfR07iMXP000000]P3oool00;<0oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP0000
000200000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1L0?ooo`8000002P1o
LKX010000000OUfR00000000002f0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo0P00000:07ma^P030000
001nGJ8000000;L0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0G@3oool00`000000Og6j07ma^P0807ma^P030000
001nGJ8000000;L0oooo002d0?ooo`030000001kK[X0Nfjj00L0Nfjj00@0000007YIX038adH00000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo00<0000007ma^P1oLKX0
201oLKX00`000000OUfR0000002g0?ooo`00]03oool00`000000Nfjj07]^^P0807]^^P<00000HP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo00<0000007ma^P1oLKX02@1o
LKX200000;L0oooo002^0?ooob<00000D`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05T0oooo7@00002/0?ooo`00X03oool>000000`0B3^N00<000000?74X`3aa:<0303aa:<?0000
04`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?oooa0000003P1EAZ<00`00
0000mLRN0?G8WP0:0?G8WPh00000X03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000
oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo
00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<00000
0?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8
WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000
001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1E
AZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`00
0000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0
oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<0
00000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G
0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`03
0000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<0
6`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h0
0`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo
09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS
00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8
WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000B03oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo2`00000900d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H01`3od8H;000003d0oooo00<0000005E6
X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@09`2dTk@2000001<0om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih01018>ihX000000P0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0k0?ooo`030000001EAZ<0EDJS00L0EDJS:00000060?G8WP030000
003oool0oooo09h0oooo002C0?oooa@000004P17>Yh00`000000lLFS0?75X`0C0?75XaL00000<03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?oooaL000005@1EAJ<00`000000mLRN0?G8WP0@0?G8WQ@00000T`3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo
02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo
02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02l000004`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om26;`0000020?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
<@00000300d;QPh000000`0=2hH00`000000]9>d0;BC]00X0;BC]1@0om262@00000800D002400000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC
]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26
@02]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<0
00000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/2
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440
[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000
003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]
I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000002]I7/0
[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=
2hH000000;BC]00Y0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440
[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d
0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`80
0000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;40[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk05d0[FAk00<0[[KO0:eTN`2]I7/0DP2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1T0:eTN`030:jfg`2]I7/0[FAk04/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk06l0[FAk00<0[[KO0:eT
N`2]I7/0@02]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`1f0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/0
0`2^]]l0[FAk0:eTN`0b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk08@0[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80
[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ
0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<04`3aaJ<G00000;@0[KSQ6`00000A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0
[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl
501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<0
00000:iUO02^IG`05@2^IG`D05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<00000
0:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
0140lLFS602^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0403aaJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^
IG`05`2^IG`B05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75XaX0[VEl0P00002b0:fhh@800000
6P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75XaX0[VEl0P00002b0:fhh@8000006P2^
IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75Xa/0[VEl0P00002b0:fhh@8000006`2^IG`@
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75Xa/0[VEl0P00002b0:fhh@8000006`2^IG`@05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0=0?75Xa`0[VEl0P00002b0:fhh@800000702^IG`?05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0=0?75Xa`0[VEl0P00002b0:fhh@8000007@2^IG`>05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0<0?75X`80[VEl00<0lLFS0:iUO02^IG`06@2^IG`00`000000[KSQ0:fh
h@2`0:fhh@030000002^IG`0[VEl01`0[VEl3P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<4
0:iUO0030?75X`2^IG`0[VEl01P0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M
0:iUO0d0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0lLFS1@2^IG`00`3aaJ<0[VEl0:iUO00G0:iU
O0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0:0?75X`L0[VEl00<0lLFS0:iUO02^IG`05P2^IG`00`000000[KSQ0:fhh@2`0:fhh@03
0000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<90:iUO0030?75
X`2^IG`0[VEl01D0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^
IG`0[VEl01l0[VEl2`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0203aaJ<=0:iUO0030?75X`2^IG`0
[VEl0180[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00P0lLFS3P2^IG`00`3aaJ<0[VEl0:iUO00A0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`070?75Xa00
[VEl00<0lLFS0:iUO02^IG`0402^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240
[VEl2@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3aaJ<B0:iUO0030?75X`2^IG`0[VEl00l0[VEl
00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00R0:iUO0P0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl00D0[VEl00<0
EDFS0:iUO02^IG`06P2^IG`805E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XbD0[VEl00<00000
0:fhh@2]^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@030000002]^>40[KSQ0380[KSQ00<00000
0:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XaL0[VEl00<0lLFS0:iU
O02^IG`0@02^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iU
O02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`040?75XaT0[VEl00<0lLFS0:iUO02^
IG`0?`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^
IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0lLFS
6`2^IG`00`3aaJ<0[VEl0:iUO00`0:iUO0030:fhh@2^IG`0[VEl00/0[VEl00<0^iT60:fhh@2]^>40
AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<00`3aaJ=L0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^
IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`0
0`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`05@2^IG`0
0`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`00`2k
V@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09P2^IG`405E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh010000000lLFS0?75X`3aaJ<R0:iUO0030?75X`2^IG`0[VEl03T0[VEl00<0^iT60:fh
h@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0902^IG`00`3aaJ<0[VEl0:iUO00a0:iUO0030:fhh@2^IG`0[VEl00@0
[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02P0
[VEl0P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000
002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0
^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0
EDFS0000003eb9h07P3eb9h7000009<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O
0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y
0:iUO00305E5X`000000mLRN0180mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iU
O02^IG`0G`2^IG`00`2kV@H0000000000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`00
0000mLRN0?G8WP040?G8WPd00000YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<00006000000000000I`00002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0
]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80
[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>80
0`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0
oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo
0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<00000
0:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P
0:fhhP030000003oool0oooo0;L0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?oo
o`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo
0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?oo
o`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fh
hP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00
^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3o
ool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2
000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`0=0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`2i0?ooo`00^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL00`0@3HL01@3od8T040f7010=Q`0@3HL0000001@0]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
1000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`06010=Q`030?o@R@000000]9>d
01<0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00k@3ooolo000000T040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Qcl00000k@3oool00>d0oooo00<0000008<51P231@H01023
1@H00`1Mb_P0P`D608<51P0e08<51PL040f700<0P`D6010=Q`000000502dTk@00`000000om270?o@
Q`060?o@Qcl0P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H02`231@H0
0`1Mb_P0P`D608<51P0_08<51PP040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`05
0?o@Qd00P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H04P231@H00`1M
b_P0P`D608<51P0Y08<51PL040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`040?o@
Qd40P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H060231@H305g:n2@0
P`D60`0@3HL010231@H040f7010=Q`00000D0;BC]0030000003od8L0om2700<0om27@P231@H00`00
0000oooo0?ooo`3[0?ooo`00k03oool00`000000P`D608<51P0P08<51P<0GL[h7`231@H4010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00P3od8M308<51P030000003oool0oooo0>/0
oooo003/0?ooo`03000000231@H0P`D602L0P`D60`00000I08<51P<040f700<000000;BC]02dTk@0
4P2dTk@010000000om270?o@Q`3od8M508<51P030000003oool0oooo0>X0oooo003/0?ooo`030000
00231@H0P`D602d0P`D61@2`[mLB08<51P8040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`1608<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D603@0P`D61@2`
[mL<08<51P03010=Q`000000]9>d01<0]9>d00<000000?o@Q`231@H07@231@H50;2_eb@0P`D600<0
00000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0>`231@H00`2`[mL00000010=Q`02
010=Q`H0P`D600<000000;BC]02dTk@04P2dTk@00`000000P`D608<51P0[08<51P030?ooo`2`[mL0
/:oG00H0/:oG4P231@H00`000000oooo0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003/0?ooo`03
0000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>
00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?oo
o`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2a
Lhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000
003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3o
ool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`00
0000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0
/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/
0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5c
SP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003/0?ooo`030000
002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`
/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0
oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0
oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<0
00000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`03
0000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0
Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003o
ool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G
00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?oo
ojP00000k03oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo003]0?ooo`030000001F
b?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D0
0`000000oooo0?ooo`3[0?ooo`00k@3ooonV00000>d0oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.63642 .41352 m .63642 .24629 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.6714 .41055 m .66146 .4114 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.66146 .4114 m .63642 .41352 L p .66146 .36389 L .511 .417 .685 r
F P
0 g
s
.66183 .20472 m .66984 .24491 L .67214 .24168 L .917 .749 .658 r
F
.67171 .25432 m .67201 .2453 L p .66984 .24491 L F P
0 g
s
.67201 .2453 m .67214 .24168 L p .66984 .24491 L .917 .749 .658 r
F P
0 g
s
.63642 .24629 m .66146 .24344 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.66931 .26624 m .67171 .25432 L .68532 .251 L p .238 .097 .478 r
F P
0 g
s
.66931 .26624 m .67171 .25432 L p .66984 .24491 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .66665 .24435 L .66984 .24491 L .917 .749 .658 r
F
.66665 .24435 m .66931 .26624 L .66984 .24491 L F
.59949 .24402 m .63642 .24629 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.63642 .24629 m .66146 .24344 L p .66146 .28232 L .511 .417 .685 r
F P
0 g
s
.64617 .29211 m .66146 .28232 L .66146 .36389 L .511 .417 .685 r
F
.63642 .24629 m .66146 .28232 L .64617 .29211 L F
.66146 .28232 m .66505 .27692 L .6709 .27553 L p .131 0 .124 r
F P
0 g
s
.6709 .27553 m .67275 .2751 L p .6714 .27596 L .131 0 .124 r
F P
0 g
s
.66146 .28232 m .6709 .27553 L .6714 .27596 L .131 0 .124 r
F
.6714 .41055 m .6714 .27596 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.67431 .27849 m .67505 .2878 L .6714 .27596 L 0 0 .415 r
F
.67505 .2878 m .68443 .40456 L .67505 .31202 L F
.67505 .2878 m .67505 .31202 L .6714 .27596 L F
.64311 .29734 m .65167 .29282 L p .65745 .24273 L .917 .749 .658 r
F P
0 g
s
.66146 .20794 m .65443 .2422 L .65745 .24273 L .917 .749 .658 r
F
.65443 .2422 m .64311 .29734 L .65745 .24273 L F
.66146 .20656 m .65426 .24217 L .66146 .20794 L F
.65426 .24217 m .64311 .29734 L .65443 .2422 L F
.65426 .24217 m .65443 .2422 L .66146 .20794 L F
.58156 .23673 m .59949 .24402 L p .63899 .23948 L .289 .763 .934 r
F P
0 g
s
.68418 .22538 m .68574 .23829 L .67214 .24168 L p .296 .298 .693 r
F P
0 g
s
.67214 .24168 m .67058 .22884 L .68418 .22538 L p .296 .298 .693 r
F P
0 g
s
.6807 .21282 m .68418 .22538 L .67058 .22884 L p .316 .382 .773 r
F P
0 g
s
.67058 .22884 m .6671 .21634 L .6807 .21282 L p .316 .382 .773 r
F P
0 g
s
.67543 .20113 m .6807 .21282 L .6671 .21634 L p .331 .461 .841 r
F P
0 g
s
.67543 .20113 m .67505 .21216 L .6767 .24034 L .918 .75 .657 r
F
.67543 .20113 m .6767 .24034 L .67717 .24043 L F
.67505 .27595 m .67505 .27551 L .67864 .27371 L .131 0 .124 r
F
.66146 .36389 m .6685 .27782 L .6714 .41055 L .511 .417 .685 r
F
.68532 .251 m .68292 .26297 L .66931 .26624 L p .238 .097 .478 r
F P
0 g
s
.66931 .26624 m .68292 .26297 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.66505 .27692 m .66777 .2701 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.66777 .2701 m .66931 .26624 L p .66964 .27334 L .193 0 .325 r
F P
0 g
s
.67171 .25432 m .67214 .24168 L .68574 .23829 L p .271 .205 .597 r
F P
0 g
s
.68574 .23829 m .68532 .251 L .67171 .25432 L p .271 .205 .597 r
F P
0 g
s
.68292 .26297 m .68137 .26686 L p .66505 .27692 L .193 0 .325 r
F P
0 g
s
.68137 .26686 m .67864 .27371 L .67275 .2751 L p .193 0 .325 r
F P
0 g
s
.67275 .2751 m .66505 .27692 L p .68137 .26686 L .193 0 .325 r
F P
0 g
s
.66505 .27692 m .66931 .26624 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.65908 .28591 m .66505 .27692 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66146 .24344 m .6714 .24231 L p .66838 .27928 L .511 .417 .685 r
F P
0 g
s
.66146 .2859 m .66838 .27928 L .66146 .36389 L .511 .417 .685 r
F
.66146 .24344 m .66838 .27928 L .66146 .2859 L F
.67717 .24043 m .6767 .24034 L .67864 .27371 L .918 .75 .657 r
F
.67275 .2751 m .67864 .27371 L p .6724 .27684 L .131 0 .124 r
F P
0 g
s
.6714 .27596 m .6714 .41055 L p .6685 .27782 L .511 .417 .685 r
F P
0 g
s
.66146 .28232 m .6714 .27596 L .6724 .27684 L .131 0 .124 r
F
.6714 .27596 m .67275 .2751 L .6724 .27684 L F
.67214 .24168 m .67058 .22884 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.65167 .29282 m .65908 .28591 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.63899 .23948 m .59949 .24402 L .65343 .24202 L .289 .763 .934 r
F
.59949 .24402 m .63642 .24629 L .63642 .41352 L p .797 .651 .701 r
F P
0 g
s
.63377 .29926 m .64311 .29734 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.6714 .24231 m .67505 .24005 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.67505 .21216 m .67505 .24005 L .6767 .24034 L .918 .75 .657 r
F
.66701 .23862 m .65343 .24202 L .67505 .24005 L .289 .763 .934 r
F
.6714 .24231 m .67505 .24005 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.67267 .28274 m .65908 .28591 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67864 .27371 m .67505 .27914 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67431 .27849 m .68443 .29898 L .67458 .2819 L 0 0 .415 r
F
.68107 .28436 m .68443 .29898 L .67431 .27849 L F
.67505 .27914 m .67267 .28274 L p .67292 .27728 L .131 0 .124 r
F P
0 g
s
.67505 .27914 m .67864 .27371 L p .6767 .24034 L .918 .75 .657 r
F P
0 g
s
.65908 .28591 m .67505 .27551 L .67505 .27595 L .131 0 .124 r
F
.65908 .28591 m .66146 .28232 L p .67505 .27551 L F P
0 g
s
.6714 .24231 m .67505 .2582 L .67431 .27849 L 0 0 .415 r
F
.67505 .24005 m .67505 .27914 L .6767 .24034 L .918 .75 .657 r
F
.67505 .2582 m .68107 .28436 L .67505 .27914 L 0 0 .415 r
F
.67505 .2582 m .67505 .27914 L .67431 .27849 L F
.67864 .27371 m .68292 .26297 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.6714 .24231 m .68443 .28728 L .68107 .28436 L 0 0 .415 r
F
.67326 .26543 m .67431 .27849 L .67286 .27723 L F
.67326 .26543 m .67286 .27723 L .6714 .27596 L F
.6714 .27596 m .6714 .24231 L p .67326 .26543 L F P
0 g
s
.67267 .28274 m .67505 .27914 L p .67505 .21216 L .918 .75 .657 r
F P
0 g
s
.6714 .24231 m .6714 .27596 L p .6685 .27782 L .511 .417 .685 r
F P
0 g
s
.65167 .29282 m .65908 .28591 L .67267 .28274 L p .046 0 0 r
F P
0 g
s
.67267 .28274 m .66525 .28968 L .65167 .29282 L p .046 0 0 r
F P
0 g
s
.66525 .28968 m .67267 .28274 L p .67412 .23988 L .918 .75 .657 r
F P
0 g
s
.67505 .21216 m .6716 .23944 L .67412 .23988 L .918 .75 .657 r
F
.66146 .24344 m .6714 .24231 L p .65343 .24202 L .289 .763 .934 r
F P
0 g
s
.6716 .23944 m .66525 .28968 L .67412 .23988 L .918 .75 .657 r
F
.62406 .29847 m .63377 .29926 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.61438 .295 m .62406 .29847 L p .64724 .24093 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .64317 .24022 L .64724 .24093 L .917 .749 .658 r
F
.64317 .24022 m .61438 .295 L .64724 .24093 L F
.67505 .20437 m .66525 .28968 L .67505 .21216 L .918 .75 .657 r
F
.61836 .23584 m .58156 .23673 L .63899 .23948 L .289 .763 .934 r
F
.63642 .41352 m .59949 .41183 L .59949 .24402 L p .797 .651 .701 r
F P
0 g
s
.60517 .28897 m .61438 .295 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58156 .23673 m .59949 .24402 L .59949 .41183 L p .999 .816 .524 r
F P
0 g
s
.59684 .28063 m .60517 .28897 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .59016 .26999 L .59684 .28063 L .917 .749 .658 r
F
.59016 .2709 m .59684 .28063 L p .59016 .26999 L F P
0 g
s
.59949 .41183 m .58156 .4064 L .58156 .23673 L p .999 .816 .524 r
F P
0 g
s
.58156 .23673 m .58156 .4064 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.59016 .23087 m .58156 .23673 L p .61836 .23584 L .289 .763 .934 r
F P
0 g
s
.66183 .20472 m .59016 .25448 L .59016 .26999 L .917 .749 .658 r
F
.59016 .23087 m .58156 .23673 L p .58893 .27321 L 0 0 .389 r
F P
0 g
s
.59016 .2709 m .58893 .27321 L .59016 .27929 L 0 0 .389 r
F
.59016 .23087 m .58893 .27321 L .59016 .2709 L F
.59684 .28063 m .61033 .27738 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.59016 .2709 m .59684 .28063 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.58065 .2458 m .58429 .25856 L p .59016 .25448 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .59016 .24098 L .59016 .25448 L .917 .749 .658 r
F
.59016 .24098 m .58065 .2458 L .59016 .25448 L F
.57901 .23264 m .58065 .2458 L p .66183 .20472 L F P
0 g
s
.68532 .251 m .68574 .23829 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.68292 .26297 m .68532 .251 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67058 .22884 m .6671 .21634 L .66183 .20472 L p .917 .749 .658 r
F P
0 g
s
.64311 .29734 m .65167 .29282 L .66525 .28968 L p 0 0 0 r
F P
0 g
s
.66525 .28968 m .65668 .29421 L .64311 .29734 L p 0 0 0 r
F P
0 g
s
.65668 .29421 m .66525 .28968 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64746 .23514 m .59016 .23087 L .61836 .23584 L .289 .763 .934 r
F
.67543 .20113 m .66447 .23817 L .66784 .23877 L .918 .75 .657 r
F
.66701 .23862 m .63899 .23948 L .65343 .24202 L .289 .763 .934 r
F
.65894 .23718 m .63899 .23948 L .66701 .23862 L F
.63759 .29534 m .64732 .29613 L p .66447 .23817 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .66081 .23752 L .66447 .23817 L .918 .75 .657 r
F
.66081 .23752 m .63759 .29534 L .66447 .23817 L F
.5936 .22854 m .59343 .23099 L p .63185 .23237 L .289 .763 .934 r
F P
0 g
s
.65894 .23718 m .61836 .23584 L .63899 .23948 L .289 .763 .934 r
F
.64746 .23514 m .61836 .23584 L .65894 .23718 L F
.6279 .29184 m .63759 .29534 L p .66081 .23752 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .65674 .23679 L .66081 .23752 L .918 .75 .657 r
F
.65674 .23679 m .6279 .29184 L .66081 .23752 L F
.6671 .21634 m .66183 .20472 L .67543 .20113 L p .331 .461 .841 r
F P
0 g
s
.61868 .28577 m .6279 .29184 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.63185 .23237 m .59016 .23087 L .64746 .23514 L .289 .763 .934 r
F
.61033 .27738 m .61868 .28577 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .60364 .26668 L .61033 .27738 L .918 .75 .657 r
F
.60364 .26759 m .61033 .27738 L p .60364 .26668 L F P
0 g
s
.59684 .28063 m .60517 .28897 L .61868 .28577 L p .324 .605 .949 r
F P
0 g
s
.61868 .28577 m .61033 .27738 L .59684 .28063 L p .324 .605 .949 r
F P
0 g
s
.5936 .22854 m .59016 .23087 L p .59016 .2709 L 0 0 .389 r
F P
0 g
s
.61033 .27738 m .60364 .26759 L p .59054 .27019 L .319 .529 .901 r
F P
0 g
s
.59036 .27054 m .61033 .27738 L .59054 .27019 L .319 .529 .901 r
F
.5936 .22854 m .59016 .2709 L .59057 .27015 L 0 0 .389 r
F
.59057 .27015 m .60246 .26723 L p .59351 .26267 L .309 .451 .841 r
F P
0 g
s
.59351 .26267 m .60246 .26723 L .59652 .26402 L .309 .451 .841 r
F
.60246 .26723 m .59057 .27015 L p .60364 .26759 L .319 .529 .901 r
F P
0 g
s
.59054 .27019 m .60364 .26759 L .59057 .27015 L .319 .529 .901 r
F
.5936 .40031 m .5936 .26446 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.60364 .22735 m .5936 .22854 L p .61945 .23016 L .289 .763 .934 r
F P
0 g
s
.61945 .23016 m .5936 .22854 L .63185 .23237 L .289 .763 .934 r
F
.60364 .22735 m .5936 .22854 L p .59651 .26402 L .504 .412 .684 r
F P
0 g
s
.59685 .2642 m .59651 .26402 L .59663 .2654 L .504 .412 .684 r
F
.60364 .22735 m .59651 .26402 L .59685 .2642 L F
.5936 .26244 m .5936 .22854 L p .59083 .26949 L 0 0 .389 r
F P
0 g
s
.5936 .22854 m .59057 .27015 L .59083 .26949 L 0 0 .389 r
F
.59016 .25448 m .58429 .25856 L .59016 .26999 L .917 .749 .658 r
F
.58429 .25856 m .59351 .26267 L .5936 .26244 L .309 .451 .841 r
F
.5936 .22854 m .5936 .26244 L p .59651 .26402 L .504 .412 .684 r
F P
0 g
s
.59631 .25554 m .58573 .2582 L p .5936 .26244 L .309 .451 .841 r
F P
0 g
s
.58573 .2582 m .58429 .25856 L p .5936 .26244 L .309 .451 .841 r
F P
0 g
s
.60364 .22735 m .59685 .2642 L .60364 .26759 L .504 .412 .684 r
F
.59685 .2642 m .59663 .2654 L .60246 .26723 L F
.59685 .2642 m .60246 .26723 L .60364 .26759 L F
.5936 .26244 m .60325 .26703 L .59631 .25554 L .309 .451 .841 r
F
.59351 .26267 m .59652 .26402 L .5936 .26244 L F
.59652 .26402 m .60325 .26703 L .5936 .26244 L F
.60325 .26703 m .59776 .25518 L .59631 .25554 L p F P
0 g
s
.5936 .26446 m .5936 .26244 L p .59081 .26968 L 0 0 .389 r
F P
0 g
s
.59083 .26949 m .59081 .26968 L .5936 .26244 L 0 0 .389 r
F
.59081 .26968 m .59016 .27929 L .5936 .26446 L F
.59057 .27015 m .58978 .27034 L p .59054 .27019 L .319 .529 .901 r
F P
0 g
s
.60364 .26759 m .59663 .2654 L .60364 .35076 L .504 .412 .684 r
F
.60246 .26723 m .60325 .26703 L p .59652 .26402 L .309 .451 .841 r
F P
0 g
s
.59663 .2654 m .59651 .26402 L .5936 .26446 L .504 .412 .684 r
F
.5936 .26244 m .5936 .26446 L p .59651 .26402 L F P
0 g
s
.59083 .26949 m .59057 .27015 L .59081 .26968 L 0 0 .389 r
F
.58429 .25856 m .58978 .27034 L p .59016 .26999 L .917 .749 .658 r
F P
0 g
s
.58429 .25856 m .58978 .27034 L .59057 .27015 L p .309 .451 .841 r
F P
0 g
s
.58429 .25856 m .59057 .27015 L .59351 .26267 L .309 .451 .841 r
F
.59081 .26968 m .59016 .2709 L .59016 .27929 L 0 0 .389 r
F
.58978 .27034 m .59016 .2709 L p .59016 .26999 L .917 .749 .658 r
F P
0 g
s
.58978 .27034 m .59036 .27054 L .59054 .27019 L .319 .529 .901 r
F
.60364 .26759 m .60325 .26703 L .60246 .26723 L p F P
0 g
s
.60364 .35076 m .59663 .2654 L .5936 .40031 L .504 .412 .684 r
F
.5936 .26446 m .5936 .40031 L p .59663 .2654 L F P
0 g
s
.67543 .20113 m .60364 .25109 L .60364 .26668 L .918 .75 .657 r
F
.59411 .24235 m .59776 .25518 L p .67543 .20113 L F P
0 g
s
.66183 .20472 m .66146 .20656 L .66146 .20794 L .917 .749 .658 r
F
.59247 .22912 m .59411 .24235 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.62927 .22434 m .62823 .22945 L p .68443 .23425 L .289 .763 .934 r
F P
0 g
s
.68443 .23425 m .60364 .22735 L .61945 .23016 L .289 .763 .934 r
F
.68443 .23425 m .61945 .23016 L .63185 .23237 L F
.61438 .295 m .62406 .29847 L .63759 .29534 L p .297 .732 .968 r
F P
0 g
s
.63759 .29534 m .6279 .29184 L .61438 .295 L p .297 .732 .968 r
F P
0 g
s
.60517 .28897 m .61438 .295 L .6279 .29184 L p .318 .675 .977 r
F P
0 g
s
.6279 .29184 m .61868 .28577 L .60517 .28897 L p .318 .675 .977 r
F P
0 g
s
.62927 .22434 m .60364 .22735 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.59776 .25518 m .60325 .26703 L p .60364 .26668 L .918 .75 .657 r
F P
0 g
s
.60364 .25109 m .59776 .25518 L .60364 .26668 L .918 .75 .657 r
F
.60325 .26703 m .60364 .26759 L p .60364 .26668 L F P
0 g
s
.62406 .29847 m .63377 .29926 L .64732 .29613 L p .249 .752 .89 r
F P
0 g
s
.64732 .29613 m .63759 .29534 L .62406 .29847 L p .249 .752 .89 r
F P
0 g
s
.62927 .39718 m .62927 .22434 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.5936 .40031 m .60364 .39943 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.60364 .39943 m .62927 .39718 L p .60364 .35076 L .504 .412 .684 r
F P
0 g
s
.68443 .23425 m .63185 .23237 L .64746 .23514 L .289 .763 .934 r
F
.64732 .29613 m .65668 .29421 L p .66784 .23877 L .918 .75 .657 r
F P
0 g
s
.66447 .23817 m .64732 .29613 L .66784 .23877 L .918 .75 .657 r
F
.58978 .27034 m .59016 .2709 L p .59036 .27054 L .319 .529 .901 r
F P
0 g
s
.58156 .4064 m .59016 .40205 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.59016 .40205 m .5936 .40031 L p .59016 .27929 L 0 0 .389 r
F P
0 g
s
.68443 .23425 m .64746 .23514 L .65894 .23718 L .289 .763 .934 r
F
.67505 .24005 m .68443 .23425 L p .66701 .23862 L F P
0 g
s
.68443 .23425 m .68443 .28728 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.67505 .24005 m .68443 .23425 L p .67505 .25492 L 0 0 .415 r
F P
0 g
s
.68443 .28728 m .68443 .29898 L p .68107 .28436 L 0 0 .415 r
F P
0 g
s
.68443 .29898 m .68443 .40456 L p .67458 .2819 L 0 0 .415 r
F P
0 g
s
.68443 .23425 m .65894 .23718 L .66701 .23862 L .289 .763 .934 r
F
.67543 .20113 m .67505 .20437 L .67505 .21216 L .918 .75 .657 r
F
.68443 .40456 m .67505 .40887 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.67505 .40887 m .6714 .41055 L p .67505 .31202 L 0 0 .415 r
F P
0 g
s
.66719 .39897 m .68443 .40456 L .68443 .23425 L p 1 .816 .507 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.63642 .41352 m .6714 .41055 L .68443 .40456 L p .224 .73 .894 r
F P
0 g
s
.59949 .41183 m .63642 .41352 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58156 .4064 m .59949 .41183 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.5936 .40031 m .58156 .4064 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.62927 .39718 m .5936 .40031 L p .68443 .40456 L .224 .73 .894 r
F P
0 g
s
.68443 .40456 m .66719 .39897 L .62927 .39718 L p .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.37493 .41352 m .37493 .24629 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.40832 .41055 m .39884 .4114 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.39884 .4114 m .37493 .41352 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.39923 .20472 m .4078 .24491 L .41026 .24168 L .908 .741 .664 r
F
.40981 .25432 m .41013 .2453 L p .4078 .24491 L F P
0 g
s
.41013 .2453 m .41026 .24168 L p .4078 .24491 L .908 .741 .664 r
F P
0 g
s
.37493 .24629 m .39884 .24344 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.40724 .26624 m .40981 .25432 L .42207 .251 L p .188 .048 .447 r
F P
0 g
s
.40724 .26624 m .40981 .25432 L p .4078 .24491 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .40439 .24435 L .4078 .24491 L .908 .741 .664 r
F
.40439 .24435 m .40724 .26624 L .4078 .24491 L F
.3371 .24402 m .37493 .24629 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.37493 .24629 m .39884 .24344 L p .39884 .28232 L .501 .409 .683 r
F P
0 g
s
.38425 .29211 m .39884 .28232 L .39884 .36389 L .501 .409 .683 r
F
.37493 .24629 m .39884 .28232 L .38425 .29211 L F
.39884 .28232 m .40268 .27692 L .40795 .27553 L p .071 0 .064 r
F P
0 g
s
.40795 .27553 m .40961 .2751 L p .40832 .27596 L .071 0 .064 r
F P
0 g
s
.39884 .28232 m .40795 .27553 L .40832 .27596 L .071 0 .064 r
F
.37919 .29734 m .38835 .29282 L p .39454 .24273 L .908 .741 .664 r
F P
0 g
s
.39884 .20794 m .39131 .2422 L .39454 .24273 L .908 .741 .664 r
F
.39131 .2422 m .37919 .29734 L .39454 .24273 L F
.39884 .20656 m .39113 .24217 L .39884 .20794 L F
.39113 .24217 m .37919 .29734 L .39131 .2422 L F
.39113 .24217 m .39131 .2422 L .39884 .20794 L F
.31625 .23673 m .3371 .24402 L p .37478 .23948 L .289 .763 .934 r
F P
0 g
s
.42085 .22538 m .42252 .23829 L .41026 .24168 L p .256 .27 .683 r
F P
0 g
s
.41026 .24168 m .4086 .22884 L .42085 .22538 L p .256 .27 .683 r
F P
0 g
s
.41712 .21282 m .42085 .22538 L .4086 .22884 L p .28 .362 .769 r
F P
0 g
s
.4086 .22884 m .40487 .21634 L .41712 .21282 L p .28 .362 .769 r
F P
0 g
s
.41147 .20113 m .41712 .21282 L .40487 .21634 L p .299 .447 .841 r
F P
0 g
s
.41147 .20113 m .41107 .21216 L .41283 .24034 L .909 .742 .663 r
F
.41147 .20113 m .41283 .24034 L .41334 .24043 L F
.40832 .41055 m .40832 .27596 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.41051 .27849 m .41107 .2878 L .40832 .27596 L 0 0 .339 r
F
.41107 .2878 m .41813 .40456 L .41107 .31202 L F
.41107 .2878 m .41107 .31202 L .40832 .27596 L F
.40981 .25432 m .41026 .24168 L .42252 .23829 L p .226 .167 .578 r
F P
0 g
s
.42252 .23829 m .42207 .251 L .40981 .25432 L p .226 .167 .578 r
F P
0 g
s
.42207 .251 m .4195 .26297 L .40724 .26624 L p .188 .048 .447 r
F P
0 g
s
.40268 .27692 m .40724 .26624 L .4195 .26297 L p .138 0 .279 r
F P
0 g
s
.39884 .36389 m .40544 .27928 L .40832 .41055 L .501 .409 .683 r
F
.4195 .26297 m .41784 .26686 L p .40268 .27692 L .138 0 .279 r
F P
0 g
s
.40961 .2751 m .40268 .27692 L p .41784 .26686 L .138 0 .279 r
F P
0 g
s
.40268 .27692 m .40724 .26624 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.40832 .24231 m .40832 .27639 L p .40544 .27928 L .501 .409 .683 r
F P
0 g
s
.40832 .27639 m .40832 .41055 L p .40544 .27928 L .501 .409 .683 r
F P
0 g
s
.41784 .26686 m .41492 .27371 L .40961 .2751 L p .138 0 .279 r
F P
0 g
s
.41334 .24043 m .41283 .24034 L .41492 .27371 L .909 .742 .663 r
F
.40946 .27728 m .40908 .27684 L .41492 .27371 L .071 0 .064 r
F
.39629 .28591 m .40268 .27692 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.39884 .24344 m .40832 .24231 L p .39884 .36389 L .501 .409 .683 r
F P
0 g
s
.40961 .2751 m .41492 .27371 L p .39884 .28232 L .071 0 .064 r
F P
0 g
s
.41813 .28728 m .41813 .40456 L p .41051 .27849 L 0 0 .339 r
F P
0 g
s
.41492 .27371 m .40852 .28274 L .39629 .28591 L p .071 0 .064 r
F P
0 g
s
.41107 .27914 m .41492 .27371 L p .41283 .24034 L .909 .742 .663 r
F P
0 g
s
.41107 .21216 m .41107 .24005 L .41283 .24034 L .909 .742 .663 r
F
.41107 .24005 m .41107 .27914 L .41283 .24034 L F
.41026 .24168 m .4086 .22884 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.38835 .29282 m .39629 .28591 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37478 .23948 m .3371 .24402 L .39024 .24202 L .289 .763 .934 r
F
.3371 .24402 m .37493 .24629 L .37493 .41352 L p .795 .649 .701 r
F P
0 g
s
.3692 .29926 m .37919 .29734 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.40832 .24231 m .41107 .24005 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.40246 .23862 m .39024 .24202 L .41107 .24005 L .289 .763 .934 r
F
.4195 .26297 m .42207 .251 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41492 .27371 m .4195 .26297 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.40832 .24231 m .41813 .23425 L .41813 .28728 L p 0 0 .339 r
F P
0 g
s
.40832 .24231 m .41813 .28728 L .41051 .27849 L 0 0 .339 r
F
.39629 .28591 m .40873 .27702 L .4087 .27778 L .071 0 .064 r
F
.39629 .28591 m .39884 .28232 L p .40873 .27702 L F P
0 g
s
.40936 .25951 m .41051 .27849 L .40875 .27646 L 0 0 .339 r
F
.40936 .25951 m .40875 .27646 L .40832 .27596 L F
.40832 .27596 m .40832 .24231 L p .40936 .25951 L F P
0 g
s
.3588 .29847 m .3692 .29926 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37493 .41352 m .3371 .41183 L .3371 .24402 L p .795 .649 .701 r
F P
0 g
s
.34844 .295 m .3588 .29847 L p .38361 .24093 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .37926 .24022 L .38361 .24093 L .908 .741 .664 r
F
.37926 .24022 m .34844 .295 L .38361 .24093 L F
.41107 .21216 m .40738 .23944 L .41007 .23988 L .909 .742 .663 r
F
.39884 .24344 m .40832 .24231 L p .39024 .24202 L .289 .763 .934 r
F P
0 g
s
.4086 .22884 m .40487 .21634 L .39923 .20472 L p .908 .741 .664 r
F P
0 g
s
.38835 .29282 m .39629 .28591 L .40852 .28274 L p 0 0 0 r
F P
0 g
s
.40852 .28274 m .40057 .28968 L .38835 .29282 L p 0 0 0 r
F P
0 g
s
.41107 .20437 m .40057 .28968 L .41107 .21216 L .909 .742 .663 r
F
.4087 .27778 m .40873 .27702 L .40908 .27684 L .071 0 .064 r
F
.4087 .27778 m .40908 .27684 L .40946 .27728 L F
.40852 .28274 m .41107 .27914 L p .41107 .24005 L .909 .742 .663 r
F P
0 g
s
.41107 .21216 m .41007 .23988 L .41107 .24005 L .909 .742 .663 r
F
.41007 .23988 m .40852 .28274 L .41107 .24005 L F
.32251 .23087 m .31625 .23673 L p .3527 .23584 L .289 .763 .934 r
F P
0 g
s
.3527 .23584 m .31625 .23673 L .37478 .23948 L .289 .763 .934 r
F
.3371 .41183 m .31625 .4064 L .31625 .23673 L p .992 .81 .557 r
F P
0 g
s
.31625 .23673 m .3371 .24402 L .3371 .41183 L p .992 .81 .557 r
F P
0 g
s
.39923 .20472 m .32251 .25448 L .32251 .26999 L .908 .741 .664 r
F
.31625 .23673 m .31625 .4064 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.39923 .20472 m .32251 .24098 L .32251 .25448 L .908 .741 .664 r
F
.32251 .23087 m .31625 .23673 L p .32162 .27321 L 0 0 .305 r
F P
0 g
s
.32251 .2709 m .32162 .27321 L .32251 .27929 L 0 0 .305 r
F
.32251 .23087 m .32162 .27321 L .32251 .2709 L F
.32967 .28063 m .33858 .28897 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.3221 .27034 m .32967 .28063 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.32967 .28063 m .34175 .27738 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.32251 .2709 m .32967 .28063 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.31057 .23264 m .31233 .2458 L p .32251 .24098 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .32251 .22888 L .32251 .24098 L .908 .741 .664 r
F
.32251 .22888 m .31057 .23264 L .32251 .24098 L F
.33858 .28897 m .34844 .295 L p .39923 .20472 L F P
0 g
s
.37919 .29734 m .38835 .29282 L .40057 .28968 L p 0 0 0 r
F P
0 g
s
.40057 .28968 m .39139 .29421 L .37919 .29734 L p 0 0 0 r
F P
0 g
s
.39139 .29421 m .40057 .28968 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.38151 .23514 m .32251 .23087 L .3527 .23584 L .289 .763 .934 r
F
.41147 .20113 m .39974 .23817 L .40335 .23877 L .909 .742 .663 r
F
.40246 .23862 m .37478 .23948 L .39024 .24202 L .289 .763 .934 r
F
.39381 .23718 m .37478 .23948 L .40246 .23862 L F
.37095 .29534 m .38137 .29613 L p .39974 .23817 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .39582 .23752 L .39974 .23817 L .909 .742 .663 r
F
.39582 .23752 m .37095 .29534 L .39974 .23817 L F
.39381 .23718 m .3527 .23584 L .37478 .23948 L .289 .763 .934 r
F
.38151 .23514 m .3527 .23584 L .39381 .23718 L F
.40487 .21634 m .39923 .20472 L .41147 .20113 L p .299 .447 .841 r
F P
0 g
s
.36056 .29184 m .37095 .29534 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.35069 .28577 m .36056 .29184 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.3648 .23237 m .32251 .23087 L .38151 .23514 L .289 .763 .934 r
F
.34175 .27738 m .35069 .28577 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .33458 .26668 L .34175 .27738 L .909 .742 .663 r
F
.33458 .26759 m .34175 .27738 L p .33458 .26668 L F P
0 g
s
.32501 .22854 m .32489 .23096 L p .3648 .23237 L .289 .763 .934 r
F P
0 g
s
.32501 .22854 m .32251 .23087 L p .32251 .2709 L 0 0 .305 r
F P
0 g
s
.34175 .27738 m .33458 .26759 L p .32279 .27019 L .289 .519 .902 r
F P
0 g
s
.32265 .27054 m .34175 .27738 L .32279 .27019 L .289 .519 .902 r
F
.32501 .22854 m .32251 .2709 L .32281 .27015 L 0 0 .305 r
F
.32281 .27015 m .33346 .26723 L p .32495 .26267 L .274 .436 .841 r
F P
0 g
s
.32495 .26267 m .33346 .26723 L .32779 .26402 L .274 .436 .841 r
F
.33346 .26723 m .32281 .27015 L p .33458 .26759 L .289 .519 .902 r
F P
0 g
s
.32279 .27019 m .33458 .26759 L .32281 .27015 L .289 .519 .902 r
F
.32501 .40031 m .32501 .26446 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.33458 .22735 m .32501 .22854 L p .35151 .23016 L .289 .763 .934 r
F P
0 g
s
.35151 .23016 m .32501 .22854 L .3648 .23237 L .289 .763 .934 r
F
.33458 .22735 m .32501 .22854 L p .32779 .26402 L .494 .403 .682 r
F P
0 g
s
.32811 .2642 m .32779 .26402 L .3279 .2654 L .494 .403 .682 r
F
.33458 .22735 m .32779 .26402 L .32811 .2642 L F
.33458 .22735 m .3279 .2654 L .33458 .26759 L F
.32501 .22854 m .32501 .26244 L p .32779 .26402 L F P
0 g
s
.32501 .26244 m .33417 .26703 L .32699 .25554 L .274 .436 .841 r
F
.32495 .26267 m .32779 .26402 L .32501 .26244 L F
.32779 .26402 m .33417 .26703 L .32501 .26244 L F
.33417 .26703 m .32829 .25518 L .32699 .25554 L p F P
0 g
s
.32501 .26244 m .32501 .22854 L p .323 .26949 L 0 0 .305 r
F P
0 g
s
.32501 .22854 m .32281 .27015 L .323 .26949 L 0 0 .305 r
F
.32251 .25448 m .31623 .25856 L .32251 .26999 L .908 .741 .664 r
F
.32699 .25554 m .31623 .25856 L p .32495 .26267 L .274 .436 .841 r
F P
0 g
s
.32501 .26446 m .32501 .26244 L p .32299 .26968 L 0 0 .305 r
F P
0 g
s
.323 .26949 m .32299 .26968 L .32501 .26244 L 0 0 .305 r
F
.32299 .26968 m .32251 .27929 L .32501 .26446 L F
.32281 .27015 m .3221 .27034 L p .32279 .27019 L .289 .519 .902 r
F P
0 g
s
.32967 .28063 m .33858 .28897 L .35069 .28577 L p .298 .597 .948 r
F P
0 g
s
.35069 .28577 m .34175 .27738 L .32967 .28063 L p .298 .597 .948 r
F P
0 g
s
.33458 .26759 m .3279 .2654 L .33458 .35076 L .494 .403 .682 r
F
.33346 .26723 m .33417 .26703 L p .32779 .26402 L .274 .436 .841 r
F P
0 g
s
.3279 .2654 m .32779 .26402 L .32501 .26446 L .494 .403 .682 r
F
.32501 .26244 m .32501 .26446 L p .32779 .26402 L F P
0 g
s
.323 .26949 m .32281 .27015 L .32299 .26968 L 0 0 .305 r
F
.31623 .25856 m .3221 .27034 L p .32251 .26999 L .908 .741 .664 r
F P
0 g
s
.31623 .25856 m .3221 .27034 L .32281 .27015 L p .274 .436 .841 r
F P
0 g
s
.31623 .25856 m .32281 .27015 L .32495 .26267 L .274 .436 .841 r
F
.32299 .26968 m .32251 .2709 L .32251 .27929 L 0 0 .305 r
F
.3221 .27034 m .32265 .27054 L .32279 .27019 L .289 .519 .902 r
F
.33458 .26759 m .33417 .26703 L .33346 .26723 L p F P
0 g
s
.33458 .35076 m .3279 .2654 L .32501 .40031 L .494 .403 .682 r
F
.32501 .26446 m .32501 .40031 L p .3279 .2654 L F P
0 g
s
.41147 .20113 m .33458 .25109 L .33458 .26668 L .909 .742 .663 r
F
.39923 .20472 m .39884 .20656 L .39884 .20794 L .908 .741 .664 r
F
.32437 .24235 m .32829 .25518 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.32262 .22912 m .32437 .24235 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.359 .22434 m .35805 .22929 L p .41813 .23425 L .289 .763 .934 r
F P
0 g
s
.41813 .23425 m .33458 .22735 L .35151 .23016 L .289 .763 .934 r
F
.41813 .23425 m .35151 .23016 L .3648 .23237 L F
.33858 .28897 m .34844 .295 L .36056 .29184 L p .299 .67 .974 r
F P
0 g
s
.36056 .29184 m .35069 .28577 L .33858 .28897 L p .299 .67 .974 r
F P
0 g
s
.359 .22434 m .33458 .22735 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.32829 .25518 m .33417 .26703 L p .33458 .26668 L .909 .742 .663 r
F P
0 g
s
.33458 .25109 m .32829 .25518 L .33458 .26668 L .909 .742 .663 r
F
.33417 .26703 m .33458 .26759 L p .33458 .26668 L F P
0 g
s
.3588 .29847 m .3692 .29926 L .38137 .29613 L p .254 .755 .893 r
F P
0 g
s
.38137 .29613 m .37095 .29534 L .3588 .29847 L p .254 .755 .893 r
F P
0 g
s
.34844 .295 m .3588 .29847 L .37095 .29534 L p .287 .729 .964 r
F P
0 g
s
.37095 .29534 m .36056 .29184 L .34844 .295 L p .287 .729 .964 r
F P
0 g
s
.359 .39718 m .359 .22434 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.32501 .40031 m .33458 .39943 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.33458 .39943 m .359 .39718 L p .33458 .35076 L .494 .403 .682 r
F P
0 g
s
.41813 .23425 m .3648 .23237 L .38151 .23514 L .289 .763 .934 r
F
.38137 .29613 m .39139 .29421 L p .40335 .23877 L .909 .742 .663 r
F P
0 g
s
.39974 .23817 m .38137 .29613 L .40335 .23877 L .909 .742 .663 r
F
.3221 .27034 m .32251 .2709 L p .32265 .27054 L .289 .519 .902 r
F P
0 g
s
.31233 .2458 m .31623 .25856 L p .32251 .25448 L .908 .741 .664 r
F P
0 g
s
.32251 .24098 m .31233 .2458 L .32251 .25448 L .908 .741 .664 r
F
.31625 .4064 m .32251 .40205 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.32251 .40205 m .32501 .40031 L p .32251 .27929 L 0 0 .305 r
F P
0 g
s
.41813 .23425 m .38151 .23514 L .39381 .23718 L .289 .763 .934 r
F
.40057 .28968 m .40852 .28274 L p .41007 .23988 L .909 .742 .663 r
F P
0 g
s
.40738 .23944 m .40057 .28968 L .41007 .23988 L .909 .742 .663 r
F
.41107 .24005 m .41813 .23425 L p .40246 .23862 L .289 .763 .934 r
F P
0 g
s
.41147 .20113 m .41107 .20437 L .41107 .21216 L .909 .742 .663 r
F
.41813 .23425 m .39381 .23718 L .40246 .23862 L .289 .763 .934 r
F
.41813 .40456 m .41107 .40887 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.41107 .40887 m .40832 .41055 L p .41107 .31202 L 0 0 .339 r
F P
0 g
s
.68443 .23425 m .66719 .22675 L .62927 .22434 L p .289 .763 .934 r
F P
0 g
s
.68443 .23425 m .66719 .22675 L .66719 .39897 L p 1 .816 .507 r
F P
0 g
s
.63377 .29926 m .64311 .29734 L .65668 .29421 L p .167 .701 .709 r
F P
0 g
s
.65668 .29421 m .64732 .29613 L .63377 .29926 L p .167 .701 .709 r
F P
0 g
s
.62927 .39718 m .66719 .39897 L .66719 .22675 L p .799 .653 .7 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37493 .41352 m .40832 .41055 L .41813 .40456 L p .224 .73 .894 r
F P
0 g
s
.3371 .41183 m .37493 .41352 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67882 .75036 m .66446 .74536 L .67945 .73601 L closepath p .754 .814 .9 r
F P
0 g
s
.70373 .79883 m .70499 .74247 L .70399 .79891 L .835 .44 .3 r
F
.70349 .79915 m .70499 .74247 L .70371 .79976 L F
.70499 .74247 m .71963 .7518 L .70399 .79891 L p F P
0 g
s
.71963 .7518 m .70499 .74247 L .72041 .73745 L closepath p .566 .654 .895 r
F P
0 g
s
.69445 .7735 m .70499 .74247 L p .70349 .79915 L .835 .44 .3 r
F P
0 g
s
.70405 .78482 m .70333 .79901 L .68466 .76195 L p 0 0 .434 r
F P
0 g
s
.66446 .74536 m .67882 .75036 L .70333 .79901 L p .758 .258 .031 r
F P
0 g
s
.70333 .79901 m .69847 .79735 L p .66446 .74536 L .758 .258 .031 r
F P
0 g
s
.68799 .79253 m .68714 .79083 L p .69847 .79735 L .758 .258 .031 r
F P
0 g
s
.68714 .79083 m .66446 .74536 L p .69847 .79735 L .758 .258 .031 r
F P
0 g
s
.70334 .79872 m .70333 .79901 L .69847 .79735 L p .754 .82 .904 r
F P
0 g
s
.6885 .79103 m .69445 .7735 L p .70281 .79857 L .835 .44 .3 r
F P
0 g
s
.70311 .79949 m .70033 .79788 L .70281 .79857 L .835 .44 .3 r
F
.70033 .79788 m .6885 .79103 L .70281 .79857 L F
.69847 .79735 m .6885 .79103 L p .70311 .79949 L F P
0 g
s
.72041 .73745 m .70499 .74247 L .69445 .7735 L p .243 0 .096 r
F P
0 g
s
.74033 .79253 m .7207 .80757 L p .71033 .78269 L .662 .743 .91 r
F P
0 g
s
.69709 .77661 m .72041 .73745 L .69445 .7735 L .243 0 .096 r
F
.71963 .7518 m .72041 .73745 L .70444 .78528 L p .862 .789 .293 r
F P
0 g
s
.70348 .79966 m .69445 .7735 L .70349 .79915 L .835 .44 .3 r
F
.70311 .79949 m .69445 .7735 L .70348 .79966 L F
.70334 .79872 m .69848 .79717 L .69895 .7877 L .754 .82 .904 r
F
.70405 .78482 m .70334 .79872 L p .69895 .7877 L F P
0 g
s
.69847 .79735 m .6885 .79103 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.6885 .79103 m .69895 .7877 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.6885 .79103 m .69895 .7877 L p .72041 .73745 L .243 0 .096 r
F P
0 g
s
.69942 .77832 m .69941 .77848 L .69324 .77005 L 0 0 .434 r
F
.70473 .78443 m .72041 .73745 L p .69895 .7877 L .243 0 .096 r
F P
0 g
s
.70406 .78453 m .69941 .77848 L .69942 .77832 L 0 0 .434 r
F
.70406 .78453 m .70405 .78482 L p .69941 .77848 L F P
0 g
s
.69312 .76972 m .69324 .77005 L .67882 .75036 L 0 0 .434 r
F
.70406 .78453 m .69324 .77005 L .69312 .76972 L F
.68466 .76195 m .67882 .75036 L p .70405 .78482 L F P
0 g
s
.69445 .7735 m .6885 .79103 L p .69709 .77661 L .243 0 .096 r
F P
0 g
s
.68532 .74757 m .70406 .78453 L p .69312 .76972 L 0 0 .434 r
F P
0 g
s
.69312 .76972 m .67882 .75036 L .68532 .74757 L 0 0 .434 r
F
.67882 .75036 m .67945 .73601 L .68532 .74757 L p F P
0 g
s
.67945 .73601 m .66446 .74536 L .68799 .79253 L p .389 .092 .335 r
F P
0 g
s
.69706 .82569 m .66781 .80142 L p .69895 .7877 L .662 .743 .91 r
F P
0 g
s
.69847 .79735 m .68874 .79404 L .68799 .79253 L p .758 .258 .031 r
F P
0 g
s
.68799 .79253 m .68874 .79404 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.68846 .79232 m .67945 .73601 L .68799 .79253 L .389 .092 .335 r
F
.70406 .78453 m .67945 .73601 L p .68846 .79232 L F P
0 g
s
.68874 .79404 m .69895 .7877 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.69895 .7877 m .70406 .78453 L p .68846 .79232 L .389 .092 .335 r
F P
0 g
s
.69895 .7877 m .70406 .78453 L .70405 .78482 L p .754 .82 .904 r
F P
0 g
s
.70444 .78528 m .70473 .78443 L p .69895 .7877 L .243 0 .096 r
F P
0 g
s
.70112 .78675 m .70039 .75882 L .70521 .77038 L .662 .743 .91 r
F
.69847 .79735 m .69848 .79717 L .70334 .79872 L .754 .82 .904 r
F
.69847 .79735 m .69895 .7877 L .70112 .78675 L .662 .743 .91 r
F
.69895 .7877 m .70039 .75882 L .70112 .78675 L F
.6571 .79253 m .70039 .75882 L p .69895 .7877 L F P
0 g
s
.66781 .80142 m .6571 .79253 L p .69895 .7877 L .662 .743 .91 r
F P
0 g
s
.69847 .79735 m .68874 .79404 L p .69848 .79717 L .754 .82 .904 r
F P
0 g
s
.69847 .79735 m .70112 .78675 L .70371 .79976 L .662 .743 .91 r
F
.69706 .82569 m .69847 .79735 L .70371 .79976 L F
.7207 .80757 m .7026 .82145 L p .70371 .79976 L F P
0 g
s
.7026 .82145 m .69706 .82569 L p .70371 .79976 L .662 .743 .91 r
F P
0 g
s
.70112 .78675 m .70444 .78528 L .70371 .79976 L .662 .743 .91 r
F
.70371 .79976 m .70346 .80051 L p .70349 .79915 L .835 .44 .3 r
F P
0 g
s
.70419 .78603 m .70346 .80051 L .70371 .79976 L p .862 .789 .293 r
F P
0 g
s
.70399 .79891 m .70371 .79976 L p .70373 .79883 L .835 .44 .3 r
F P
0 g
s
.70371 .79976 m .71963 .7518 L p .70443 .7855 L .862 .789 .293 r
F P
0 g
s
.70419 .78603 m .70371 .79976 L .70443 .7855 L .862 .789 .293 r
F
.70346 .80051 m .69847 .79735 L .70333 .80015 L .835 .44 .3 r
F
.70333 .80015 m .69973 .79793 L p .70311 .79949 L F P
0 g
s
.69847 .79735 m .69848 .79717 L .70347 .80023 L .56 .655 .899 r
F
.70346 .80051 m .70311 .79949 L .70348 .79966 L .835 .44 .3 r
F
.70419 .78603 m .70347 .80023 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.69895 .7877 m .70419 .78603 L p .69848 .79717 L .56 .655 .899 r
F P
0 g
s
.68874 .79404 m .69895 .7877 L p .69848 .79717 L .754 .82 .904 r
F P
0 g
s
.70112 .78675 m .70521 .77038 L .70444 .78528 L .662 .743 .91 r
F
.69895 .7877 m .70419 .78603 L .70444 .78528 L p .243 0 .096 r
F P
0 g
s
.70444 .78528 m .70419 .78603 L p .70443 .7855 L .862 .789 .293 r
F P
0 g
s
.70443 .7855 m .71963 .7518 L .70444 .78528 L .862 .789 .293 r
F
.70371 .79976 m .70521 .77038 L .7207 .80757 L .662 .743 .91 r
F
.70039 .75882 m .72238 .77738 L p .71033 .78269 L F P
0 g
s
.72238 .77738 m .74033 .79253 L p .71033 .78269 L .662 .743 .91 r
F P
0 g
s
.70347 .80023 m .70346 .80051 L .69847 .79735 L p .56 .655 .899 r
F P
0 g
s
.31625 .4064 m .3371 .41183 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.66859 .19082 m .67543 .20113 L .66183 .20472 L p .343 .537 .9 r
F P
0 g
s
.66183 .20472 m .65501 .19447 L .66859 .19082 L p .343 .537 .9 r
F P
0 g
s
.57946 .21968 m .57901 .23264 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58197 .20751 m .57946 .21968 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.58643 .19667 m .58197 .20751 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.59263 .18765 m .58643 .19667 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.60028 .18085 m .59263 .18765 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.60903 .17655 m .60028 .18085 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.61849 .17492 m .60903 .17655 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.62824 .17603 m .61849 .17492 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.63785 .17979 m .62824 .17603 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.6469 .18603 m .63785 .17979 L p .66183 .20472 L .917 .749 .658 r
F P
0 g
s
.66183 .20472 m .65501 .19447 L .6469 .18603 L p .917 .749 .658 r
F P
0 g
s
.40415 .19082 m .41147 .20113 L .39923 .20472 L p .315 .528 .902 r
F P
0 g
s
.39923 .20472 m .39193 .19447 L .40415 .19082 L p .315 .528 .902 r
F P
0 g
s
.31105 .21968 m .31057 .23264 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.31374 .20751 m .31105 .21968 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.31852 .19667 m .31374 .20751 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.32515 .18765 m .31852 .19667 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.33334 .18085 m .32515 .18765 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.34271 .17655 m .33334 .18085 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.35284 .17492 m .34271 .17655 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.36328 .17603 m .35284 .17492 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.37356 .17979 m .36328 .17603 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.38325 .18603 m .37356 .17979 L p .39923 .20472 L .908 .741 .664 r
F P
0 g
s
.39923 .20472 m .39193 .19447 L .38325 .18603 L p .908 .741 .664 r
F P
0 g
s
.66047 .18233 m .66859 .19082 L .65501 .19447 L p .349 .611 .948 r
F P
0 g
s
.65501 .19447 m .6469 .18603 L .66047 .18233 L p .349 .611 .948 r
F P
0 g
s
.39545 .18233 m .40415 .19082 L .39193 .19447 L p .326 .605 .949 r
F P
0 g
s
.39193 .19447 m .38325 .18603 L .39545 .18233 L p .326 .605 .949 r
F P
0 g
s
.68574 .23829 m .68418 .22538 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.42252 .23829 m .42085 .22538 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.42207 .251 m .42252 .23829 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.42085 .22538 m .41712 .21282 L .41147 .20113 L p .909 .742 .663 r
F P
0 g
s
.68418 .22538 m .6807 .21282 L .67543 .20113 L p .918 .75 .657 r
F P
0 g
s
.6514 .17605 m .66047 .18233 L .6469 .18603 L p .348 .683 .979 r
F P
0 g
s
.6469 .18603 m .63785 .17979 L .6514 .17605 L p .348 .683 .979 r
F P
0 g
s
.38574 .17605 m .39545 .18233 L .38325 .18603 L p .331 .679 .978 r
F P
0 g
s
.38325 .18603 m .37356 .17979 L .38574 .17605 L p .331 .679 .978 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.39789 .39897 m .41813 .40456 L .41813 .23425 L p .996 .813 .545 r
F P
0 g
s
.66719 .22675 m .62927 .22434 L .62927 .39718 L p .799 .653 .7 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32501 .40031 m .31625 .4064 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.359 .39718 m .32501 .40031 L p .41813 .40456 L .224 .73 .894 r
F P
0 g
s
.41813 .40456 m .39789 .39897 L .359 .39718 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3692 .29926 m .37919 .29734 L .39139 .29421 L p .193 .721 .734 r
F P
0 g
s
.59292 .2161 m .59247 .22912 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.59544 .20386 m .59292 .2161 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.5999 .19297 m .59544 .20386 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.60611 .18391 m .5999 .19297 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.61378 .17708 m .60611 .18391 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.63785 .17979 m .62824 .17603 L .64178 .17226 L p .334 .744 .98 r
F P
0 g
s
.63202 .17114 m .64178 .17226 L .62824 .17603 L p .297 .777 .921 r
F P
0 g
s
.62824 .17603 m .61849 .17492 L .63202 .17114 L p .297 .777 .921 r
F P
0 g
s
.62254 .17276 m .63202 .17114 L .61849 .17492 L p .225 .745 .764 r
F P
0 g
s
.61849 .17492 m .60903 .17655 L .62254 .17276 L p .225 .745 .764 r
F P
0 g
s
.62254 .17276 m .61378 .17708 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64178 .17226 m .6514 .17605 L .63785 .17979 L p .334 .744 .98 r
F P
0 g
s
.63202 .17114 m .62254 .17276 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.64178 .17226 m .63202 .17114 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.6514 .17605 m .64178 .17226 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.66047 .18233 m .6514 .17605 L p .67543 .20113 L .918 .75 .657 r
F P
0 g
s
.67543 .20113 m .66859 .19082 L .66047 .18233 L p .918 .75 .657 r
F P
0 g
s
.3231 .2161 m .32262 .22912 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.32579 .20386 m .3231 .2161 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.33058 .19297 m .32579 .20386 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.33723 .18391 m .33058 .19297 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.34544 .17708 m .33723 .18391 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.36328 .17603 m .35284 .17492 L .36498 .17114 L p .302 .779 .923 r
F P
0 g
s
.35483 .17276 m .36498 .17114 L .35284 .17492 L p .251 .763 .787 r
F P
0 g
s
.35284 .17492 m .34271 .17655 L .35483 .17276 L p .251 .763 .787 r
F P
0 g
s
.35483 .17276 m .34544 .17708 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.37544 .17226 m .38574 .17605 L .37356 .17979 L p .325 .742 .977 r
F P
0 g
s
.37356 .17979 m .36328 .17603 L .37544 .17226 L p .325 .742 .977 r
F P
0 g
s
.36498 .17114 m .37544 .17226 L .36328 .17603 L p .302 .779 .923 r
F P
0 g
s
.36498 .17114 m .35483 .17276 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.37544 .17226 m .36498 .17114 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.38574 .17605 m .37544 .17226 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.39545 .18233 m .38574 .17605 L p .41147 .20113 L .909 .742 .663 r
F P
0 g
s
.41147 .20113 m .40415 .19082 L .39545 .18233 L p .909 .742 .663 r
F P
0 g
s
.39139 .29421 m .38137 .29613 L .3692 .29926 L p .193 .721 .734 r
F P
0 g
s
.69706 .82569 m .74033 .79253 L .74865 .87438 L p .148 0 .23 r
F P
0 g
s
.70111 .87494 m .69706 .82569 L p .71679 .84432 L .148 0 .23 r
F P
0 g
s
.70331 .87416 m .70111 .87494 L .71679 .84432 L .148 0 .23 r
F
.70914 .87485 m .70111 .87494 L .73606 .8625 L F
.77017 .87438 m .77017 1.10042 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.70914 .87485 m .77017 .87438 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.77017 .87438 m .70914 .87485 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.75802 .87427 m .77017 .87438 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 1.10042 m .70139 1.09633 L .70139 .8784 L p .347 .283 .642 r
F P
0 g
s
.70139 .8784 m .70111 .87494 L p .70548 .87653 L .148 0 .23 r
F P
0 g
s
.70139 .8784 m .70139 .8749 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.77017 1.10042 m .70139 .8784 L .70233 .87797 L .347 .283 .642 r
F
.70556 .87489 m .70548 .87653 L p .70111 .87494 L .148 0 .23 r
F P
0 g
s
.70548 .87653 m .70383 .90798 L .70139 .8784 L p .148 0 .23 r
F P
0 g
s
.74865 .87438 m .70914 .87485 L .73606 .8625 L .148 0 .23 r
F
.70139 .8749 m .70914 .87485 L p .70233 .87797 L .347 .283 .642 r
F P
0 g
s
.73606 .8625 m .70331 .87416 L .71679 .84432 L .148 0 .23 r
F
.70739 .8402 m .74865 .87438 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.70739 .8402 m .74865 .87438 L .74033 .79253 L p .882 .449 .124 r
F P
0 g
s
.70996 .87384 m .75802 .87427 L p .74817 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74817 .87438 L .012 .587 .719 r
F
.70559 .87438 m .70996 .87384 L .74817 .87438 L F
.6571 .79253 m .69706 .82569 L .70111 .87494 L p .886 .458 .145 r
F P
0 g
s
.6996 .87492 m .6571 .79253 L .70111 .87494 L .886 .458 .145 r
F
.68929 .87208 m .6571 .79253 L .70139 .8784 L F
.69459 .87485 m .64101 .87438 L .65493 .87427 L p .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .69459 .87485 L p .70139 .8784 L .954 .779 .626 r
F P
0 g
s
.70139 .8784 m .70139 1.04154 L p .66439 .96031 L .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .66439 .96031 L .70139 1.04154 L .954 .779 .626 r
F
.55483 1.09633 m .55502 1.07831 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44517 1.09633 L .36524 1.09633 L p .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.63508 1.08393 m .6913 1.07831 L .70139 1.09633 L .678 .717 .878 r
F
.60506 1.07831 m .63522 1.07831 L .63508 1.08393 L F
.63522 1.07831 m .6913 1.07831 L .63508 1.08393 L F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L .678 .717 .878 r
F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L 0 0 .063 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.5554 1.043 m .63614 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.63614 1.043 m .70347 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.60506 1.07831 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63614 1.043 m .63772 1.04435 L .67151 1.043 L .066 0 0 r
F
.63772 1.04435 m .63806 1.04464 L .64101 1.04449 L F
.63772 1.04435 m .64101 1.04449 L .67151 1.043 L F
.70139 1.09633 m .64101 1.04449 L .64101 .98856 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04449 L p .954 .779 .626 r
F P
0 g
s
.66439 .96031 m .64101 .87438 L .70139 .8784 L .954 .779 .626 r
F
.70139 .8784 m .70383 .90798 L p .68929 .87208 L .886 .458 .145 r
F P
0 g
s
.64101 .87438 m .64101 1.04449 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.70383 .90798 m .66253 .87438 L .6571 .79253 L p .886 .458 .145 r
F P
0 g
s
.66276 .87421 m .70739 .8402 L p .70562 .87387 L .657 .749 .918 r
F P
0 g
s
.70559 .87438 m .66276 .87421 L .70562 .87387 L .657 .749 .918 r
F
.66253 .87438 m .66276 .87421 L p .70559 .87438 L F P
0 g
s
.70139 .8749 m .69459 .87485 L p .70996 .87384 L .012 .587 .719 r
F P
0 g
s
.70039 .75882 m .6571 .79253 L .66253 .87438 L p .13 0 .214 r
F P
0 g
s
.66253 .87438 m .70739 .8402 L .70039 .75882 L p .13 0 .214 r
F P
0 g
s
.65493 .87427 m .70996 .87384 L p .69459 .87485 L .012 .587 .719 r
F P
0 g
s
.70111 .87494 m .70139 .8784 L p .6996 .87492 L .886 .458 .145 r
F P
0 g
s
.69459 .87485 m .70139 .8749 L .70139 .8784 L p .954 .779 .626 r
F P
0 g
s
.70914 .87485 m .70139 .8749 L p .75802 .87427 L .012 .587 .719 r
F P
0 g
s
.70383 .90798 m .66253 .87438 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.74865 .87438 m .70383 .90798 L p .70559 .87438 L .657 .749 .918 r
F P
0 g
s
.70996 .87384 m .65493 .87427 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.65493 .87427 m .64101 .87438 L p .68548 .93444 L .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63806 1.04464 m .70775 1.04601 L .67151 1.043 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44344 1.15905 m .44461 1.09757 L .44459 1.11724 L F
.63538 1.08458 m .60923 1.09451 L .44497 1.07958 L .682 .404 .495 r
F
.44497 1.07874 m .44497 1.07958 L .43099 1.07831 L F
.63538 1.08458 m .44497 1.07958 L .44497 1.07874 L F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.44461 1.09757 m .44498 1.07831 L .44479 1.09692 L .732 .598 .026 r
F
.44461 1.09757 m .44479 1.09692 L .44459 1.11724 L F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.37905 1.28726 m .36515 1.31058 L .3511 1.29143 L p .968 .79 .61 r
F P
0 g
s
.53516 1.26808 m .54815 1.28726 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.39587 1.28899 m .53159 1.27227 L .53205 1.27361 L .691 .686 .84 r
F
.53732 1.28899 m .49763 1.28899 L p .53205 1.27361 L F P
0 g
s
.49763 1.28899 m .39587 1.28899 L p .53205 1.27361 L .691 .686 .84 r
F P
0 g
s
.54815 1.28726 m .53516 1.31058 L .53205 1.30604 L p .975 .796 .599 r
F P
0 g
s
.37209 1.3207 m .37224 1.31162 L p .37285 1.31157 L .694 .457 .559 r
F P
0 g
s
.51885 1.2995 m .51733 1.29875 L .53478 1.2972 L .694 .457 .559 r
F
.37209 1.3207 m .53478 1.2972 L .53372 1.30062 L F
.54815 1.28726 m .53205 1.30604 L .53732 1.28899 L .975 .796 .599 r
F
.56574 1.28899 m .6274 1.28899 L p .57513 1.29362 L .694 .457 .559 r
F P
0 g
s
.55907 1.28311 m .56574 1.28899 L .55611 1.28424 L .289 .557 .927 r
F
.62791 1.2604 m .62789 1.26135 L p .55843 1.28255 L .691 .686 .84 r
F P
0 g
s
.55825 1.28238 m .62791 1.2604 L .55843 1.28255 L .691 .686 .84 r
F
.54108 1.29995 m .54815 1.28726 L .56574 1.28899 L p .398 .064 .278 r
F P
0 g
s
.56574 1.28899 m .54815 1.28726 L p .55611 1.28424 L .289 .557 .927 r
F P
0 g
s
.54815 1.28726 m .53516 1.26808 L .54283 1.2688 L p .289 .557 .927 r
F P
0 g
s
.55907 1.28311 m .54815 1.28726 L .54283 1.2688 L .289 .557 .927 r
F
.56574 1.28899 m .53732 1.28899 L p .55843 1.28255 L .691 .686 .84 r
F P
0 g
s
.55843 1.28255 m .62789 1.26135 L .56574 1.28899 L .691 .686 .84 r
F
.53205 1.27361 m .53516 1.26808 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.53516 1.26808 m .53205 1.27361 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.53205 1.27361 m .62791 1.2604 L .53732 1.28899 L .691 .686 .84 r
F
.53159 1.27227 m .53638 1.27168 L .53205 1.27361 L F
.53638 1.27168 m .62791 1.2604 L .53205 1.27361 L F
.54283 1.2688 m .53516 1.26808 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.3932 1.28668 m .62791 1.2604 L .39587 1.28899 L .691 .686 .84 r
F
.39587 1.28899 m .37905 1.28726 L p .38907 1.28311 L .269 .551 .927 r
F P
0 g
s
.3511 1.29143 m .36515 1.26808 L .37905 1.28726 L p .968 .79 .61 r
F P
0 g
s
.37287 1.27873 m .36515 1.26808 L .37225 1.26878 L p .269 .551 .927 r
F P
0 g
s
.36515 1.31058 m .37148 1.29995 L p .37279 1.29936 L .386 .047 .262 r
F P
0 g
s
.39587 1.28899 m .37252 1.3054 L .37279 1.29936 L .386 .047 .262 r
F
.37252 1.3054 m .36515 1.31058 L .37279 1.29936 L F
.37148 1.29995 m .37905 1.28726 L .39587 1.28899 L p F P
0 g
s
.37693 1.30713 m .36515 1.31058 L .39587 1.28899 L .386 .047 .262 r
F
.3511 1.29143 m .36182 1.30604 L p .37203 1.30798 L .261 .548 .926 r
F P
0 g
s
.53516 1.31058 m .54108 1.29995 L p .56574 1.28899 L .398 .064 .278 r
F P
0 g
s
.54718 1.30713 m .53516 1.31058 L .56574 1.28899 L .398 .064 .278 r
F
.37224 1.31162 m .56574 1.28899 L .55958 1.295 L .694 .457 .559 r
F
.39587 1.28899 m .56574 1.28899 L p .37224 1.31162 L F P
0 g
s
.38683 1.31857 m .37285 1.31157 L .51733 1.29875 L .694 .457 .559 r
F
.38683 1.31857 m .51733 1.29875 L .51885 1.2995 L F
.6274 1.28899 m .62791 1.3207 L .53331 1.3207 L p F P
0 g
s
.54283 1.31139 m .53516 1.31058 L p .54718 1.30713 L .398 .064 .278 r
F P
0 g
s
.53205 1.30604 m .53516 1.31058 L .54283 1.31139 L p .281 .554 .927 r
F P
0 g
s
.53331 1.3207 m .37209 1.3207 L p .52364 1.30188 L .694 .457 .559 r
F P
0 g
s
.52364 1.30188 m .55676 1.29776 L .54283 1.31139 L .694 .457 .559 r
F
.52364 1.30188 m .54283 1.31139 L .53331 1.3207 L F
.55676 1.29776 m .6274 1.28899 L .53331 1.3207 L F
.53372 1.30062 m .53478 1.2972 L .6274 1.28899 L F
.599 1.29226 m .58611 1.31592 L .54283 1.31139 L p .398 .064 .278 r
F P
0 g
s
.599 1.29226 m .54283 1.31139 L .54718 1.30713 L .398 .064 .278 r
F
.4277 1.29226 m .41389 1.31592 L .37225 1.31136 L p .386 .047 .262 r
F P
0 g
s
.37225 1.31136 m .36515 1.31058 L p .37238 1.30847 L .386 .047 .262 r
F P
0 g
s
.4277 1.29226 m .37225 1.31136 L .37238 1.30847 L .386 .047 .262 r
F
.36182 1.30604 m .36515 1.31058 L .37225 1.31136 L p .261 .548 .926 r
F P
0 g
s
.37225 1.31136 m .37248 1.31139 L p .37224 1.31126 L .261 .548 .926 r
F P
0 g
s
.37224 1.31126 m .36182 1.30604 L .37225 1.31136 L .261 .548 .926 r
F
.37224 1.31162 m .37224 1.31126 L p .37211 1.3145 L .763 .623 .059 r
F P
0 g
s
.37224 1.31126 m .3726 1.28899 L p .37219 1.31039 L .763 .623 .059 r
F P
0 g
s
.37225 1.26878 m .36515 1.26808 L p .36832 1.27068 L .381 .04 .256 r
F P
0 g
s
.37202 1.27371 m .37224 1.26891 L .36832 1.27068 L .381 .04 .256 r
F
.37224 1.26891 m .37225 1.26878 L .36832 1.27068 L F
.37905 1.28726 m .37287 1.27873 L p .37248 1.2688 L .269 .551 .927 r
F P
0 g
s
.37225 1.26878 m .37248 1.2688 L p .37287 1.27873 L .269 .551 .927 r
F P
0 g
s
.38907 1.28311 m .37905 1.28726 L .37248 1.2688 L .269 .551 .927 r
F
.3726 1.28899 m .37224 1.26891 L p .38945 1.28344 L .691 .686 .84 r
F P
0 g
s
.37224 1.26891 m .37224 1.26859 L p .37248 1.2688 L .691 .686 .84 r
F P
0 g
s
.37224 1.26891 m .37248 1.2688 L .38945 1.28344 L .691 .686 .84 r
F
.37209 1.27225 m .37224 1.26859 L .37209 1.26622 L .763 .623 .059 r
F
.37209 1.30886 m .37223 1.26908 L .37209 1.27225 L F
.37223 1.26908 m .37224 1.26859 L .37209 1.27225 L F
.38945 1.28344 m .37691 1.2668 L .45947 1.2604 L .691 .686 .84 r
F
.37209 1.2604 m .39108 1.2604 L p .37691 1.2668 L F P
0 g
s
.39108 1.2604 m .45947 1.2604 L p .37691 1.2668 L .691 .686 .84 r
F P
0 g
s
.37224 1.26859 m .37209 1.2604 L p .38945 1.28344 L .691 .686 .84 r
F P
0 g
s
.41389 1.27286 m .38907 1.28311 L .37248 1.2688 L .269 .551 .927 r
F
.45947 1.2604 m .62791 1.2604 L p .40359 1.28552 L .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .45947 1.2604 L .40359 1.28552 L .691 .686 .84 r
F
.37224 1.31162 m .3726 1.28899 L .39587 1.28899 L p .694 .457 .559 r
F P
0 g
s
.39587 1.28899 m .4277 1.29226 L p .37693 1.30713 L .386 .047 .262 r
F P
0 g
s
.39587 1.28899 m .3726 1.28899 L p .3932 1.28668 L .691 .686 .84 r
F P
0 g
s
.41389 1.27286 m .4277 1.29226 L .39587 1.28899 L p .269 .551 .927 r
F P
0 g
s
.41389 1.27286 m .39587 1.28899 L .38907 1.28311 L .269 .551 .927 r
F
.39992 1.29654 m .41389 1.27286 L .37248 1.2688 L p .381 .04 .256 r
F P
0 g
s
.37248 1.2688 m .37225 1.26878 L p .37234 1.26887 L .381 .04 .256 r
F P
0 g
s
.39992 1.29654 m .37248 1.2688 L .37234 1.26887 L .381 .04 .256 r
F
.37211 1.30915 m .37224 1.26859 L .37209 1.30886 L .763 .623 .059 r
F
.37203 1.30798 m .36182 1.30604 L .37224 1.31126 L .261 .548 .926 r
F
.37211 1.3145 m .37224 1.26859 L .37209 1.31488 L .763 .623 .059 r
F
.3726 1.28899 m .37224 1.26891 L p .37212 1.30936 L F P
0 g
s
.37212 1.30936 m .37224 1.26891 L .37224 1.26907 L .763 .623 .059 r
F
.37202 1.27371 m .36515 1.26808 L .37112 1.29353 L .381 .04 .256 r
F
.37149 1.29938 m .3511 1.29143 L .37203 1.30798 L .261 .548 .926 r
F
.37209 1.2604 m .37083 1.25133 L p .37179 1.30413 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .37209 1.30886 L .37179 1.30413 L .763 .623 .059 r
F
.37209 1.30886 m .37209 1.2604 L .37179 1.30413 L F
.37219 1.31039 m .3726 1.28899 L .37212 1.30936 L F
.37112 1.29353 m .3511 1.29143 L p .37149 1.29938 L .261 .548 .926 r
F P
0 g
s
.36515 1.26808 m .3511 1.29143 L .37112 1.29353 L p .381 .04 .256 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.41389 1.31592 m .39992 1.29654 L .37112 1.29353 L p .261 .548 .926 r
F P
0 g
s
.41389 1.31592 m .37112 1.29353 L .37149 1.29938 L .261 .548 .926 r
F
.39992 1.29654 m .37225 1.26878 L .37202 1.27371 L .381 .04 .256 r
F
.37248 1.31139 m .41389 1.31592 L p .37203 1.30798 L .261 .548 .926 r
F P
0 g
s
.37203 1.30798 m .37224 1.31126 L .37248 1.31139 L .261 .548 .926 r
F
.37209 1.31488 m .37211 1.30915 L .37209 1.30886 L .763 .623 .059 r
F
.37224 1.31126 m .37219 1.31039 L .37211 1.3145 L F
.37209 1.3207 m .37211 1.3145 L .37209 1.31488 L F
.37224 1.26891 m .37224 1.26859 L p .37224 1.26907 L F P
0 g
s
.37112 1.29353 m .39992 1.29654 L p .37202 1.27371 L .381 .04 .256 r
F P
0 g
s
.41389 1.31592 m .37149 1.29938 L .37203 1.30798 L .261 .548 .926 r
F
.37211 1.3145 m .37219 1.31039 L .37212 1.30936 L .763 .623 .059 r
F
.37209 1.3207 m .37224 1.31162 L p .37211 1.3145 L F P
0 g
s
.37224 1.26859 m .37209 1.2604 L p .37209 1.26622 L .763 .623 .059 r
F P
0 g
s
.54283 1.2688 m .58611 1.27286 L p .55907 1.28311 L .289 .557 .927 r
F P
0 g
s
.58611 1.27286 m .56574 1.28899 L .55907 1.28311 L .289 .557 .927 r
F
.53732 1.28899 m .55825 1.28238 L .55843 1.28255 L .691 .686 .84 r
F
.62789 1.26135 m .6274 1.28899 L .56574 1.28899 L p F P
0 g
s
.55958 1.295 m .56574 1.28899 L .57513 1.29362 L .694 .457 .559 r
F
.56574 1.28899 m .599 1.29226 L p .54718 1.30713 L .398 .064 .278 r
F P
0 g
s
.58611 1.27286 m .599 1.29226 L .56574 1.28899 L p .289 .557 .927 r
F P
0 g
s
.57309 1.29654 m .58611 1.27286 L .54283 1.2688 L p .393 .057 .272 r
F P
0 g
s
.57309 1.29654 m .54283 1.2688 L .53862 1.27068 L .393 .057 .272 r
F
.53205 1.30604 m .52203 1.29143 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.52203 1.29143 m .53205 1.30604 L p .54699 1.30877 L .281 .554 .927 r
F P
0 g
s
.54148 1.29886 m .52203 1.29143 L .54699 1.30877 L .281 .554 .927 r
F
.52203 1.29143 m .53205 1.27361 L p .53732 1.28899 L .975 .796 .599 r
F P
0 g
s
.52203 1.29143 m .57309 1.29654 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.53205 1.27361 m .52203 1.29143 L p .53862 1.27068 L .393 .057 .272 r
F P
0 g
s
.54938 1.2604 m .51457 1.2604 L p .52382 1.25967 L .365 .792 .97 r
F P
0 g
s
.52382 1.25967 m .54487 1.25801 L .548 1.25967 L .365 .792 .97 r
F
.52382 1.25967 m .548 1.25967 L .54938 1.2604 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.44479 1.09692 m .50733 1.09692 L p .51462 1.09771 L F P
0 g
s
.50733 1.09692 m .55521 1.09692 L p .51462 1.09771 L .09 0 0 r
F P
0 g
s
.51462 1.09771 m .48479 1.09778 L .48814 1.09741 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .484 1.09787 L .51462 1.09771 L F
.484 1.09787 m .44453 1.09787 L .48479 1.09778 L F
.484 1.09787 m .48479 1.09778 L .51462 1.09771 L F
.48814 1.09741 m .44453 1.09787 L .44479 1.09692 L F
.48479 1.09778 m .44453 1.09787 L .48814 1.09741 L F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.48543 1.2604 m .37209 1.2604 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .47812 1.25666 L .484 1.25967 L .365 .792 .97 r
F
.39284 1.25967 m .484 1.25967 L .48543 1.2604 L F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.25967 L p .48918 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.37209 1.2604 m .37083 1.25133 L .46771 1.25133 L p .365 .792 .97 r
F P
0 g
s
.46771 1.25133 m .46771 1.09965 L p .47971 1.24056 L .997 .814 .539 r
F P
0 g
s
.47971 1.24056 m .48122 1.25825 L .46771 1.25133 L .997 .814 .539 r
F
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L F
.48028 1.24005 m .484 1.29086 L .47971 1.24056 L F
.48028 1.24005 m .47971 1.24056 L .46771 1.09965 L F
.45621 1.25744 m .46771 1.25133 L .47812 1.25666 L .365 .792 .97 r
F
.37209 1.2604 m .46771 1.25133 L .45621 1.25744 L F
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L F
.53229 1.25133 m .62917 1.25133 L p .52512 1.255 L .365 .792 .97 r
F P
0 g
s
.62917 1.25133 m .62791 1.2604 L .54938 1.2604 L p .365 .792 .97 r
F P
0 g
s
.54487 1.25801 m .62917 1.25133 L .54938 1.2604 L .365 .792 .97 r
F
.52512 1.255 m .53833 1.25454 L .51457 1.2604 L F
.53833 1.25454 m .62917 1.25133 L .54487 1.25801 L F
.53833 1.25454 m .54487 1.25801 L .51457 1.2604 L F
.53229 1.09965 m .53229 1.25133 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.484 1.06663 m .516 1.25967 L .51155 1.25967 L .707 .577 .707 r
F
.516 1.25967 m .516 1.09787 L p .52887 1.25309 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .529 1.24838 L .516 1.09787 L .08 .066 .539 r
F
.58611 1.31592 m .57309 1.29654 L .52203 1.29143 L p .281 .554 .927 r
F P
0 g
s
.529 1.24838 m .53229 1.29439 L .52844 1.24787 L .08 .066 .539 r
F
.529 1.24838 m .52844 1.24787 L .516 1.09787 L F
.51457 1.2604 m .48543 1.2604 L p .49081 1.25967 L .365 .792 .97 r
F P
0 g
s
.49081 1.25967 m .516 1.25967 L .51457 1.2604 L .365 .792 .97 r
F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.47812 1.25666 m .52512 1.255 L .49081 1.25967 L .365 .792 .97 r
F
.484 1.25967 m .49081 1.25967 L .48543 1.2604 L F
.47812 1.25666 m .49081 1.25967 L .484 1.25967 L F
.46771 1.25133 m .53229 1.25133 L p .47812 1.25666 L F P
0 g
s
.47812 1.25666 m .53229 1.25133 L .52512 1.255 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48122 1.25825 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.49081 1.25967 m .52512 1.255 L .516 1.25967 L .365 .792 .97 r
F
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.516 1.25967 m .516 1.29086 L p .51155 1.25967 L F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52887 1.25309 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.53229 1.28236 m .53229 1.25133 L p .52091 1.26192 L .998 .815 .53 r
F P
0 g
s
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.54437 1.26218 m .54036 1.25857 L .52604 1.25715 L F
.52377 1.25926 m .52604 1.25715 L .46771 1.25133 L F
.54437 1.26218 m .52604 1.25715 L .52377 1.25926 L F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.52091 1.26192 m .51629 1.29798 L .53229 1.28236 L .998 .815 .53 r
F
.51866 1.26402 m .51629 1.29798 L .52091 1.26192 L F
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.26622 L p .063 .051 .53 r
F P
0 g
s
.48824 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47713 1.2601 m .48371 1.26622 L .50811 1.26622 L .513 .022 .027 r
F
.47058 1.25401 m .46771 1.29439 L .48371 1.26622 L .063 .051 .53 r
F
.4614 1.25699 m .51486 1.26755 L .52213 1.26079 L .513 .022 .027 r
F
.54451 1.09826 m .47257 1.1002 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .47257 1.1002 L .54451 1.09826 L F
.53229 1.25133 m .46771 1.25133 L p .54036 1.25857 L .513 .022 .027 r
F P
0 g
s
.47257 1.1002 m .46974 1.09988 L .52783 1.09787 L .09 0 0 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48918 1.09787 L .707 .577 .707 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.52783 1.09787 m .46974 1.09988 L .452 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48093 1.10115 L .063 .051 .53 r
F P
0 g
s
.46974 1.09988 m .44371 1.10079 L .452 1.09787 L .09 0 0 r
F
.48371 1.26622 m .48371 1.10147 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.48371 1.09733 m .484 1.09787 L .48371 1.0979 L .997 .814 .539 r
F
.48371 1.09733 m .48371 1.0979 L .47 1.0994 L F
.46771 1.06813 m .48371 1.09733 L .47 1.0994 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L .707 .577 .707 r
F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53616 1.09921 m .50844 1.10147 L .48087 1.10115 L .09 0 0 r
F
.52581 1.10039 m .50844 1.10147 L .53616 1.09921 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.53926 1.09886 m .48087 1.10115 L .47257 1.1002 L .09 0 0 r
F
.55566 1.09853 m .53616 1.09921 L .53926 1.09886 L F
.53616 1.09921 m .48087 1.10115 L .53926 1.09886 L F
.53229 1.25133 m .53229 1.09965 L p .51999 1.24481 L .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .53037 1.09575 L p .516 1.06663 L .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51825 1.09811 L .08 .066 .539 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.50844 1.10147 m .48371 1.10147 L .48087 1.10115 L .09 0 0 r
F
.48371 1.06966 m .48093 1.10115 L .48146 1.10121 L .063 .051 .53 r
F
.48093 1.10115 m .46771 1.25133 L .48146 1.10121 L F
.47257 1.1002 m .47166 1.10147 L .44371 1.10079 L .09 0 0 r
F
.48087 1.10115 m .47166 1.10147 L .47257 1.1002 L F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .44352 1.10147 L .09 0 0 r
F
.47166 1.10147 m .44352 1.10147 L .44371 1.10079 L F
.51629 1.26622 m .51629 1.10147 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .55648 1.10147 L .50844 1.10147 L .09 0 0 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .52581 1.10039 L .53616 1.09921 L .09 0 0 r
F
.50844 1.10147 m .49246 1.10246 L .48371 1.10147 L F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.55676 1.10246 m .49246 1.10246 L p .50844 1.10147 L .09 0 0 r
F P
0 g
s
.55648 1.10147 m .55676 1.10246 L .50844 1.10147 L .09 0 0 r
F
.48146 1.10121 m .47058 1.25401 L .48371 1.10147 L .063 .051 .53 r
F
.49246 1.10246 m .44324 1.10246 L p .48087 1.10115 L .09 0 0 r
F P
0 g
s
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.47257 1.1002 m .44371 1.10079 L .46974 1.09988 L .09 0 0 r
F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48093 1.10115 L .063 .051 .53 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L .732 .598 .026 r
F
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.44964 1.26755 m .48514 1.26755 L p .48214 1.26622 L .513 .022 .027 r
F P
0 g
s
.4614 1.25699 m .45112 1.26622 L .48214 1.26622 L .513 .022 .027 r
F
.45112 1.26622 m .44964 1.26755 L .48214 1.26622 L F
.48514 1.26755 m .51486 1.26755 L p .50811 1.26622 L F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .50811 1.26622 L .513 .022 .027 r
F
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.4614 1.25699 m .48514 1.26755 L .47713 1.2601 L .513 .022 .027 r
F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .52213 1.26079 L .513 .022 .027 r
F P
0 g
s
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.51904 1.25855 m .51866 1.26402 L .52091 1.26192 L F
.53229 1.25133 m .51904 1.25855 L .52091 1.26192 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L .513 .022 .027 r
F
.54437 1.26218 m .63045 1.26755 L .54036 1.25857 L F
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p F P
0 g
s
.54036 1.25857 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.37083 1.25133 m .36955 1.26755 L .44964 1.26755 L p F P
0 g
s
.37083 1.25133 m .44964 1.26755 L .4614 1.25699 L .513 .022 .027 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.51999 1.24481 m .51904 1.25855 L .53229 1.25133 L .998 .815 .53 r
F
.53229 1.28979 m .53229 1.28236 L p .52319 1.29124 L F P
0 g
s
.52319 1.29124 m .51629 1.29798 L .53229 1.28979 L .998 .815 .53 r
F
.51629 1.29798 m .53229 1.29439 L .53229 1.28979 L p F P
0 g
s
.58611 1.31592 m .54148 1.29886 L .54699 1.30877 L .281 .554 .927 r
F
.54283 1.31139 m .58611 1.31592 L p .53205 1.30604 L F P
0 g
s
.37209 1.3207 m .37285 1.31157 L .38683 1.31857 L .694 .457 .559 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.41813 .23425 m .39789 .22675 L .359 .22434 L p .289 .763 .934 r
F P
0 g
s
.41813 .23425 m .39789 .22675 L .39789 .39897 L p .996 .813 .545 r
F P
0 g
s
.34544 .17708 m .35483 .17276 L .34271 .17655 L p 0 0 0 r
F P
0 g
s
.34271 .17655 m .33334 .18085 L .34544 .17708 L p 0 0 0 r
F P
0 g
s
.61378 .17708 m .62254 .17276 L .60903 .17655 L p 0 0 0 r
F P
0 g
s
.60903 .17655 m .60028 .18085 L .61378 .17708 L p 0 0 0 r
F P
0 g
s
.60611 .18391 m .61378 .17708 L .60028 .18085 L p 0 0 0 r
F P
0 g
s
.60028 .18085 m .59263 .18765 L .60611 .18391 L p 0 0 0 r
F P
0 g
s
.33723 .18391 m .34544 .17708 L .33334 .18085 L p 0 0 0 r
F P
0 g
s
.33334 .18085 m .32515 .18765 L .33723 .18391 L p 0 0 0 r
F P
0 g
s
.5999 .19297 m .60611 .18391 L .59263 .18765 L p .087 0 .079 r
F P
0 g
s
.59263 .18765 m .58643 .19667 L .5999 .19297 L p .087 0 .079 r
F P
0 g
s
.33058 .19297 m .33723 .18391 L .32515 .18765 L p .021 0 .013 r
F P
0 g
s
.32515 .18765 m .31852 .19667 L .33058 .19297 L p .021 0 .013 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.359 .39718 m .39789 .39897 L .39789 .22675 L p .797 .651 .7 r
F P
0 g
s
.39789 .22675 m .359 .22434 L .359 .39718 L p .797 .651 .7 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59544 .20386 m .5999 .19297 L .58643 .19667 L p .157 0 .296 r
F P
0 g
s
.58643 .19667 m .58197 .20751 L .59544 .20386 L p .157 0 .296 r
F P
0 g
s
.32579 .20386 m .33058 .19297 L .31852 .19667 L p .096 0 .244 r
F P
0 g
s
.31852 .19667 m .31374 .20751 L .32579 .20386 L p .096 0 .244 r
F P
0 g
s
.31233 .2458 m .31623 .25856 L .32829 .25518 L p .254 .347 .766 r
F P
0 g
s
.58065 .2458 m .58429 .25856 L .59776 .25518 L p .294 .37 .771 r
F P
0 g
s
.59292 .2161 m .59544 .20386 L .58197 .20751 L p .208 .068 .46 r
F P
0 g
s
.58197 .20751 m .57946 .21968 L .59292 .2161 L p .208 .068 .46 r
F P
0 g
s
.3231 .2161 m .32579 .20386 L .31374 .20751 L p .152 .014 .425 r
F P
0 g
s
.31374 .20751 m .31105 .21968 L .3231 .2161 L p .152 .014 .425 r
F P
0 g
s
.32829 .25518 m .32437 .24235 L .31233 .2458 L p .254 .347 .766 r
F P
0 g
s
.31057 .23264 m .31233 .2458 L .32437 .24235 L p .228 .251 .676 r
F P
0 g
s
.59776 .25518 m .59411 .24235 L .58065 .2458 L p .294 .37 .771 r
F P
0 g
s
.57901 .23264 m .58065 .2458 L .59411 .24235 L p .273 .282 .687 r
F P
0 g
s
.59247 .22912 m .59292 .2161 L .57946 .21968 L p .245 .183 .586 r
F P
0 g
s
.57946 .21968 m .57901 .23264 L .59247 .22912 L p .245 .183 .586 r
F P
0 g
s
.32262 .22912 m .3231 .2161 L .31105 .21968 L p .195 .141 .565 r
F P
0 g
s
.31105 .21968 m .31057 .23264 L .32262 .22912 L p .195 .141 .565 r
F P
0 g
s
.74033 .79253 m .70039 .75882 L .70739 .8402 L p .882 .449 .124 r
F P
0 g
s
.59411 .24235 m .59247 .22912 L .57901 .23264 L p .273 .282 .687 r
F P
0 g
s
.32437 .24235 m .32262 .22912 L .31057 .23264 L p .228 .251 .676 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.36341 .3687 m .36341 .18607 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.39982 .36517 m .38947 .36617 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.38947 .36617 m .36341 .3687 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.38991 .14037 m .39929 .18443 L .40198 .18093 L .919 .751 .656 r
F
.40148 .19474 m .40184 .18489 L p .39929 .18443 L F P
0 g
s
.40184 .18489 m .40198 .18093 L p .39929 .18443 L .919 .751 .656 r
F P
0 g
s
.36341 .18607 m .38947 .18267 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.39868 .20771 m .40148 .19474 L .41483 .19077 L p .141 .002 .418 r
F P
0 g
s
.39868 .20771 m .40148 .19474 L p .39929 .18443 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .39556 .18376 L .39929 .18443 L .919 .751 .656 r
F
.39556 .18376 m .39868 .20771 L .39929 .18443 L F
.32203 .18336 m .36341 .18607 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.36341 .18607 m .38947 .18267 L p .38947 .22515 L .481 .393 .679 r
F P
0 g
s
.37356 .236 m .38947 .22515 L .38947 .31427 L .481 .393 .679 r
F
.36341 .18607 m .38947 .22515 L .37356 .236 L F
.38947 .22515 m .39368 .21931 L .39942 .21766 L p .018 0 .01 r
F P
0 g
s
.39942 .21766 m .40123 .21713 L p .39982 .2181 L .018 0 .01 r
F P
0 g
s
.38947 .22515 m .39942 .21766 L .39982 .2181 L .018 0 .01 r
F
.36795 .24126 m .37799 .23646 L p .38477 .18182 L .919 .751 .656 r
F P
0 g
s
.38947 .14388 m .38123 .18119 L .38477 .18182 L .919 .751 .656 r
F
.38123 .18119 m .36795 .24126 L .38477 .18182 L F
.38947 .14237 m .38103 .18115 L .38947 .14388 L F
.38103 .18115 m .36795 .24126 L .38123 .18119 L F
.38103 .18115 m .38123 .18119 L .38947 .14388 L F
.29905 .17465 m .32203 .18336 L p .36311 .17794 L .289 .763 .934 r
F P
0 g
s
.4135 .16276 m .41534 .17689 L .40198 .18093 L p .219 .244 .674 r
F P
0 g
s
.40198 .18093 m .40016 .16688 L .4135 .16276 L p .219 .244 .674 r
F P
0 g
s
.40942 .14896 m .4135 .16276 L .40016 .16688 L p .247 .343 .766 r
F P
0 g
s
.40016 .16688 m .39608 .15317 L .40942 .14896 L p .247 .343 .766 r
F P
0 g
s
.40323 .13608 m .40942 .14896 L .39608 .15317 L p .271 .434 .841 r
F P
0 g
s
.40323 .13608 m .4028 .14813 L .40473 .17897 L .921 .752 .656 r
F
.40323 .13608 m .40473 .17897 L .40528 .17907 L F
.39982 .36517 m .39982 .2181 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.40219 .22068 m .4028 .23082 L .39982 .2181 L 0 0 .313 r
F
.4028 .23082 m .41044 .358 L .4028 .25729 L F
.4028 .23082 m .4028 .25729 L .39982 .2181 L F
.40148 .19474 m .40198 .18093 L .41534 .17689 L p .184 .132 .56 r
F P
0 g
s
.41534 .17689 m .41483 .19077 L .40148 .19474 L p .184 .132 .56 r
F P
0 g
s
.41483 .19077 m .41202 .20382 L .39868 .20771 L p .141 .002 .418 r
F P
0 g
s
.39368 .21931 m .39868 .20771 L .41202 .20382 L p .086 0 .237 r
F P
0 g
s
.38947 .31427 m .39667 .22175 L .39982 .36517 L .481 .393 .679 r
F
.41202 .20382 m .41021 .20803 L p .39368 .21931 L .086 0 .237 r
F P
0 g
s
.40123 .21713 m .39368 .21931 L p .41021 .20803 L .086 0 .237 r
F P
0 g
s
.39368 .21931 m .39868 .20771 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.39982 .18132 m .39982 .21856 L p .39667 .22175 L .481 .393 .679 r
F P
0 g
s
.39982 .21856 m .39982 .36517 L p .39667 .22175 L .481 .393 .679 r
F P
0 g
s
.41021 .20803 m .40701 .21547 L .40123 .21713 L p .086 0 .237 r
F P
0 g
s
.40528 .17907 m .40473 .17897 L .40701 .21547 L .921 .752 .656 r
F
.40105 .21944 m .40064 .21899 L .40701 .21547 L .018 0 .01 r
F
.38669 .22903 m .39368 .21931 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.38947 .18267 m .39982 .18132 L p .38947 .31427 L .481 .393 .679 r
F P
0 g
s
.40123 .21713 m .40701 .21547 L p .38947 .22515 L .018 0 .01 r
F P
0 g
s
.41044 .2297 m .41044 .358 L p .40219 .22068 L 0 0 .313 r
F P
0 g
s
.40701 .21547 m .4 .22524 L .38669 .22903 L p .018 0 .01 r
F P
0 g
s
.4028 .22135 m .40701 .21547 L p .40473 .17897 L .921 .752 .656 r
F P
0 g
s
.4028 .14813 m .4028 .17862 L .40473 .17897 L .921 .752 .656 r
F
.4028 .17862 m .4028 .22135 L .40473 .17897 L F
.40198 .18093 m .40016 .16688 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.37799 .23646 m .38669 .22903 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36311 .17794 m .32203 .18336 L .38006 .18098 L .289 .763 .934 r
F
.32203 .18336 m .36341 .18607 L .36341 .3687 L p .802 .655 .7 r
F P
0 g
s
.35699 .2432 m .36795 .24126 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.39982 .18132 m .4028 .17862 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.39336 .17691 m .38006 .18098 L .4028 .17862 L .289 .763 .934 r
F
.41202 .20382 m .41483 .19077 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40701 .21547 m .41202 .20382 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.39982 .18132 m .41044 .17169 L .41044 .2297 L p 0 0 .313 r
F P
0 g
s
.39982 .18132 m .41044 .2297 L .40219 .22068 L 0 0 .313 r
F
.38669 .22903 m .40022 .21922 L .40019 .22002 L .018 0 .01 r
F
.38669 .22903 m .38947 .22515 L p .40022 .21922 L F P
0 g
s
.40093 .19972 m .40219 .22068 L .40024 .21856 L 0 0 .313 r
F
.40093 .19972 m .40024 .21856 L .39982 .2181 L F
.39982 .2181 m .39982 .18132 L p .40093 .19972 L F P
0 g
s
.34558 .24219 m .35699 .2432 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36341 .3687 m .32203 .36668 L .32203 .18336 L p .802 .655 .7 r
F P
0 g
s
.33421 .23823 m .34558 .24219 L p .3728 .17968 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .36803 .17882 L .3728 .17968 L .919 .751 .656 r
F
.36803 .17882 m .33421 .23823 L .3728 .17968 L F
.4028 .14813 m .39875 .17789 L .4017 .17842 L .921 .752 .656 r
F
.38947 .18267 m .39982 .18132 L p .38006 .18098 L .289 .763 .934 r
F P
0 g
s
.40016 .16688 m .39608 .15317 L .38991 .14037 L p .919 .751 .656 r
F P
0 g
s
.37799 .23646 m .38669 .22903 L .4 .22524 L p 0 0 0 r
F P
0 g
s
.4 .22524 m .39129 .2327 L .37799 .23646 L p 0 0 0 r
F P
0 g
s
.4028 .13962 m .39129 .2327 L .4028 .14813 L .921 .752 .656 r
F
.40019 .22002 m .40022 .21922 L .40064 .21899 L .018 0 .01 r
F
.40019 .22002 m .40064 .21899 L .40105 .21944 L F
.4 .22524 m .4028 .22135 L p .4028 .17862 L .921 .752 .656 r
F P
0 g
s
.4028 .14813 m .4017 .17842 L .4028 .17862 L .921 .752 .656 r
F
.4017 .17842 m .4 .22524 L .4028 .17862 L F
.30574 .16764 m .29905 .17465 L p .33889 .17359 L .289 .763 .934 r
F P
0 g
s
.33889 .17359 m .29905 .17465 L .36311 .17794 L .289 .763 .934 r
F
.32203 .36668 m .29905 .3602 L .29905 .17465 L p .997 .814 .54 r
F P
0 g
s
.29905 .17465 m .32203 .18336 L .32203 .36668 L p .997 .814 .54 r
F P
0 g
s
.38991 .14037 m .30574 .19348 L .30574 .21046 L .919 .751 .656 r
F
.29905 .17465 m .29905 .3602 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.38991 .14037 m .30574 .17871 L .30574 .19348 L .919 .751 .656 r
F
.30574 .16764 m .29905 .17465 L p .30478 .21406 L 0 0 .278 r
F P
0 g
s
.30574 .21146 m .30478 .21406 L .30574 .22063 L 0 0 .278 r
F
.30574 .16764 m .30478 .21406 L .30574 .21146 L F
.3136 .22221 m .32339 .23148 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30529 .21083 m .3136 .22221 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.3136 .22221 m .32674 .21832 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.30574 .21146 m .3136 .22221 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.29262 .16938 m .29454 .18381 L p .30574 .17871 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .30574 .16546 L .30574 .17871 L .919 .751 .656 r
F
.30574 .16546 m .29262 .16938 L .30574 .17871 L F
.32339 .23148 m .33421 .23823 L p .38991 .14037 L F P
0 g
s
.36795 .24126 m .37799 .23646 L .39129 .2327 L p 0 0 0 r
F P
0 g
s
.39129 .2327 m .38123 .23752 L .36795 .24126 L p 0 0 0 r
F P
0 g
s
.38123 .23752 m .39129 .2327 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3704 .17275 m .30574 .16764 L .33889 .17359 L .289 .763 .934 r
F
.40323 .13608 m .39038 .17637 L .39434 .17709 L .921 .752 .656 r
F
.39336 .17691 m .36311 .17794 L .38006 .18098 L .289 .763 .934 r
F
.38388 .1752 m .36311 .17794 L .39336 .17691 L F
.39608 .15317 m .38991 .14037 L .40323 .13608 L p .271 .434 .841 r
F P
0 g
s
.3588 .23843 m .37024 .23947 L p .39038 .17637 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .38608 .17559 L .39038 .17637 L .921 .752 .656 r
F
.38608 .17559 m .3588 .23843 L .39038 .17637 L F
.38388 .1752 m .33889 .17359 L .36311 .17794 L .289 .763 .934 r
F
.3704 .17275 m .33889 .17359 L .38388 .1752 L F
.34741 .23444 m .3588 .23843 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.33656 .22764 m .34741 .23444 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.35205 .16943 m .30574 .16764 L .3704 .17275 L .289 .763 .934 r
F
.32674 .21832 m .33656 .22764 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .31886 .20648 L .32674 .21832 L .921 .752 .656 r
F
.31886 .20749 m .32674 .21832 L p .31886 .20648 L F P
0 g
s
.30841 .16484 m .30827 .16774 L p .35205 .16943 L .289 .763 .934 r
F P
0 g
s
.30841 .16484 m .30574 .16764 L p .30574 .21146 L 0 0 .278 r
F P
0 g
s
.32674 .21832 m .31886 .20749 L p .30604 .21065 L .262 .509 .902 r
F P
0 g
s
.30589 .21105 m .32674 .21832 L .30604 .21065 L .262 .509 .902 r
F
.30841 .16484 m .30574 .21146 L .30605 .2106 L 0 0 .278 r
F
.30605 .2106 m .31763 .2071 L p .30834 .20222 L .242 .421 .839 r
F P
0 g
s
.30834 .20222 m .31763 .2071 L .31145 .20366 L .242 .421 .839 r
F
.31763 .2071 m .30605 .2106 L p .31886 .20749 L .262 .509 .902 r
F P
0 g
s
.30604 .21065 m .31886 .20749 L .30605 .2106 L .262 .509 .902 r
F
.30841 .35291 m .30841 .20417 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.31886 .16342 m .30841 .16484 L p .33746 .16679 L .289 .763 .934 r
F P
0 g
s
.33746 .16679 m .30841 .16484 L .35205 .16943 L .289 .763 .934 r
F
.31886 .16342 m .30841 .16484 L p .31145 .20365 L .472 .385 .677 r
F P
0 g
s
.3118 .20385 m .31145 .20365 L .31156 .20517 L .472 .385 .677 r
F
.31886 .16342 m .31145 .20365 L .3118 .20385 L F
.31886 .16342 m .31156 .20517 L .31886 .20749 L F
.30841 .16484 m .30841 .20197 L p .31145 .20365 L F P
0 g
s
.30841 .20197 m .31841 .20686 L .31053 .19422 L .242 .421 .839 r
F
.30834 .20222 m .31145 .20366 L .30841 .20197 L F
.31145 .20366 m .31841 .20686 L .30841 .20197 L F
.31841 .20686 m .31194 .19379 L .31053 .19422 L p F P
0 g
s
.30841 .20197 m .30841 .16484 L p .30626 .20986 L 0 0 .278 r
F P
0 g
s
.30841 .16484 m .30605 .2106 L .30626 .20986 L 0 0 .278 r
F
.30574 .19348 m .29883 .19784 L .30574 .21046 L .919 .751 .656 r
F
.31053 .19422 m .29883 .19784 L p .30834 .20222 L .242 .421 .839 r
F P
0 g
s
.30841 .20417 m .30841 .20197 L p .30625 .21008 L 0 0 .278 r
F P
0 g
s
.30626 .20986 m .30625 .21008 L .30841 .20197 L 0 0 .278 r
F
.30625 .21008 m .30574 .22063 L .30841 .20417 L F
.30605 .2106 m .30529 .21083 L p .30604 .21065 L .262 .509 .902 r
F P
0 g
s
.3136 .22221 m .32339 .23148 L .33656 .22764 L p .276 .591 .947 r
F P
0 g
s
.33656 .22764 m .32674 .21832 L .3136 .22221 L p .276 .591 .947 r
F P
0 g
s
.31886 .20749 m .31156 .20517 L .31886 .29856 L .472 .385 .677 r
F
.31763 .2071 m .31841 .20686 L p .31145 .20366 L .242 .421 .839 r
F P
0 g
s
.31156 .20517 m .31145 .20365 L .30841 .20417 L .472 .385 .677 r
F
.30841 .20197 m .30841 .20417 L p .31145 .20365 L F P
0 g
s
.30626 .20986 m .30605 .2106 L .30625 .21008 L 0 0 .278 r
F
.29883 .19784 m .30529 .21083 L p .30574 .21046 L .919 .751 .656 r
F P
0 g
s
.29883 .19784 m .30529 .21083 L .30605 .2106 L p .242 .421 .839 r
F P
0 g
s
.29883 .19784 m .30605 .2106 L .30834 .20222 L .242 .421 .839 r
F
.30625 .21008 m .30574 .21146 L .30574 .22063 L 0 0 .278 r
F
.30529 .21083 m .30589 .21105 L .30604 .21065 L .262 .509 .902 r
F
.31886 .20749 m .31841 .20686 L .31763 .2071 L p F P
0 g
s
.31886 .29856 m .31156 .20517 L .30841 .35291 L .472 .385 .677 r
F
.30841 .20417 m .30841 .35291 L p .31156 .20517 L F P
0 g
s
.40323 .13608 m .31886 .18941 L .31886 .20648 L .921 .752 .656 r
F
.38991 .14037 m .38947 .14237 L .38947 .14388 L .919 .751 .656 r
F
.30764 .17967 m .31194 .19379 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.39521 .12468 m .40323 .13608 L .38991 .14037 L p .29 .519 .902 r
F P
0 g
s
.38991 .14037 m .3819 .12904 L .39521 .12468 L p .29 .519 .902 r
F P
0 g
s
.29314 .1552 m .29262 .16938 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.2961 .14192 m .29314 .1552 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30135 .13014 m .2961 .14192 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.30864 .12039 m .30135 .13014 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.31764 .11309 m .30864 .12039 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.32793 .10855 m .31764 .11309 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.33905 .10696 m .32793 .10855 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.3505 .10836 m .33905 .10696 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.36177 .11267 m .3505 .10836 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.37239 .11967 m .36177 .11267 L p .38991 .14037 L .919 .751 .656 r
F P
0 g
s
.38991 .14037 m .3819 .12904 L .37239 .11967 L p .919 .751 .656 r
F P
0 g
s
.3057 .16515 m .30764 .17967 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.34554 .1598 m .3444 .16573 L p .41044 .17169 L .289 .763 .934 r
F P
0 g
s
.41044 .17169 m .31886 .16342 L .33746 .16679 L .289 .763 .934 r
F
.41044 .17169 m .33746 .16679 L .35205 .16943 L F
.32339 .23148 m .33421 .23823 L .34741 .23444 L p .283 .665 .971 r
F P
0 g
s
.34741 .23444 m .33656 .22764 L .32339 .23148 L p .283 .665 .971 r
F P
0 g
s
.34554 .1598 m .31886 .16342 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.31194 .19379 m .31841 .20686 L p .31886 .20648 L .921 .752 .656 r
F P
0 g
s
.31886 .18941 m .31194 .19379 L .31886 .20648 L .921 .752 .656 r
F
.31841 .20686 m .31886 .20749 L p .31886 .20648 L F P
0 g
s
.33421 .23823 m .34558 .24219 L .3588 .23843 L p .279 .726 .96 r
F P
0 g
s
.3588 .23843 m .34741 .23444 L .33421 .23823 L p .279 .726 .96 r
F P
0 g
s
.34554 .34916 m .34554 .1598 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.30841 .35291 m .31886 .35185 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.31886 .35185 m .34554 .34916 L p .31886 .29856 L .472 .385 .677 r
F P
0 g
s
.41044 .17169 m .35205 .16943 L .3704 .17275 L .289 .763 .934 r
F
.37024 .23947 m .38123 .23752 L p .39434 .17709 L .921 .752 .656 r
F P
0 g
s
.39038 .17637 m .37024 .23947 L .39434 .17709 L .921 .752 .656 r
F
.30529 .21083 m .30574 .21146 L p .30589 .21105 L .262 .509 .902 r
F P
0 g
s
.29454 .18381 m .29883 .19784 L p .30574 .19348 L .919 .751 .656 r
F P
0 g
s
.30574 .17871 m .29454 .18381 L .30574 .19348 L .919 .751 .656 r
F
.29905 .3602 m .30574 .35499 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.30574 .35499 m .30841 .35291 L p .30574 .22063 L 0 0 .278 r
F P
0 g
s
.41044 .17169 m .3704 .17275 L .38388 .1752 L .289 .763 .934 r
F
.39129 .2327 m .4 .22524 L p .4017 .17842 L .921 .752 .656 r
F P
0 g
s
.39875 .17789 m .39129 .2327 L .4017 .17842 L .921 .752 .656 r
F
.4028 .17862 m .41044 .17169 L p .39336 .17691 L .289 .763 .934 r
F P
0 g
s
.40323 .13608 m .4028 .13962 L .4028 .14813 L .921 .752 .656 r
F
.41044 .17169 m .38388 .1752 L .39336 .17691 L .289 .763 .934 r
F
.41044 .358 m .4028 .36316 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.4028 .36316 m .39982 .36517 L p .4028 .25729 L 0 0 .313 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.36341 .3687 m .39982 .36517 L .41044 .358 L p .224 .73 .894 r
F P
0 g
s
.32203 .36668 m .36341 .3687 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.29905 .3602 m .32203 .36668 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.38818 .35131 m .41044 .358 L .41044 .17169 L p .999 .815 .525 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.30841 .35291 m .29905 .3602 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.34554 .34916 m .30841 .35291 L p .41044 .358 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.41044 .17169 m .38818 .1627 L .34554 .1598 L p .289 .763 .934 r
F P
0 g
s
.41044 .17169 m .38818 .1627 L .38818 .35131 L p .999 .815 .525 r
F P
0 g
s
.35699 .2432 m .36795 .24126 L .38123 .23752 L p .214 .737 .754 r
F P
0 g
s
.38123 .23752 m .37024 .23947 L .35699 .2432 L p .214 .737 .754 r
F P
0 g
s
.34554 .34916 m .38818 .35131 L .38818 .1627 L p .805 .657 .699 r
F P
0 g
s
.34558 .24219 m .35699 .2432 L .37024 .23947 L p .258 .757 .896 r
F P
0 g
s
.37024 .23947 m .3588 .23843 L .34558 .24219 L p .258 .757 .896 r
F P
0 g
s
.38818 .1627 m .34554 .1598 L .34554 .34916 L p .805 .657 .699 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41044 .358 m .38818 .35131 L .34554 .34916 L p .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64898 .3687 m .60869 .36668 L .60869 .18336 L p .804 .657 .699 r
F P
0 g
s
.60869 .36668 m .58919 .3602 L .58919 .17465 L p 1 .816 .501 r
F P
0 g
s
.58919 .17465 m .60869 .18336 L .60869 .36668 L p 1 .816 .501 r
F P
0 g
s
.70128 .16276 m .70298 .17689 L .68802 .18093 L p .264 .276 .685 r
F P
0 g
s
.68802 .18093 m .68632 .16688 L .70128 .16276 L p .264 .276 .685 r
F P
0 g
s
.68802 .18093 m .68632 .16688 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.58919 .17465 m .60869 .18336 L p .65193 .17794 L .289 .763 .934 r
F P
0 g
s
.67681 .14037 m .68552 .18443 L .68802 .18093 L .929 .759 .649 r
F
.68495 .20771 m .68756 .19474 L p .68552 .18443 L F P
0 g
s
.67681 .14037 m .68205 .18376 L .68552 .18443 L .929 .759 .649 r
F
.68205 .18376 m .68495 .20771 L .68552 .18443 L F
.68031 .21931 m .68495 .20771 L p .68205 .18376 L F P
0 g
s
.67681 .14037 m .6787 .18311 L .68205 .18376 L .929 .759 .649 r
F
.6787 .18311 m .68031 .21931 L .68205 .18376 L F
.60869 .18336 m .64898 .18607 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.64898 .18607 m .67641 .18267 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.67681 .14037 m .67641 .15235 L .68031 .21931 L .929 .759 .649 r
F
.64898 .18607 m .67641 .18267 L p .67641 .22515 L .493 .402 .681 r
F P
0 g
s
.65966 .236 m .67641 .22515 L .67641 .31427 L .493 .402 .681 r
F
.64898 .18607 m .67641 .22515 L .65966 .236 L F
.67641 .22515 m .68031 .21931 L .68674 .21766 L p .084 0 .077 r
F P
0 g
s
.68674 .21766 m .68878 .21713 L p .68729 .2181 L .084 0 .077 r
F P
0 g
s
.67641 .22515 m .68674 .21766 L .68729 .2181 L .084 0 .077 r
F
.68729 .36517 m .68729 .2181 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.69052 .22068 m .69135 .23082 L .68729 .2181 L 0 0 .395 r
F
.69135 .23082 m .70176 .358 L .69135 .25729 L F
.69135 .23082 m .69135 .25729 L .68729 .2181 L F
.67382 .22903 m .67641 .22515 L p .67641 .15235 L .929 .759 .649 r
F P
0 g
s
.67641 .22515 m .68031 .21931 L p .67641 .15235 L .929 .759 .649 r
F P
0 g
s
.66575 .23646 m .67382 .22903 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.64898 .3687 m .64898 .18607 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.65643 .24126 m .66575 .23646 L p .67641 .14388 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .67641 .14237 L .67641 .14388 L .929 .759 .649 r
F
.67641 .14237 m .65643 .24126 L .67641 .14388 L F
.68729 .36517 m .67641 .36617 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.67641 .36617 m .64898 .3687 L p .67641 .31427 L .493 .402 .681 r
F P
0 g
s
.65193 .17794 m .60869 .18336 L .66767 .18098 L .289 .763 .934 r
F
.60869 .18336 m .64898 .18607 L .64898 .3687 L p .804 .657 .699 r
F P
0 g
s
.64626 .2432 m .65643 .24126 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.63567 .24219 m .64626 .2432 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.62511 .23823 m .63567 .24219 L p .66093 .17968 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .6565 .17882 L .66093 .17968 L .929 .759 .649 r
F
.6565 .17882 m .62511 .23823 L .66093 .17968 L F
.69749 .14896 m .70128 .16276 L .68632 .16688 L p .288 .366 .77 r
F P
0 g
s
.68632 .16688 m .68254 .15317 L .69749 .14896 L p .288 .366 .77 r
F P
0 g
s
.69175 .13608 m .69749 .14896 L .68254 .15317 L p .306 .45 .841 r
F P
0 g
s
.69175 .13608 m .69135 .14813 L .69314 .17897 L .931 .76 .648 r
F
.69175 .13608 m .69314 .17897 L .69365 .17907 L F
.69135 .21794 m .69135 .21748 L .69526 .21547 L .084 0 .077 r
F
.67641 .31427 m .68411 .22016 L .68729 .36517 L .493 .402 .681 r
F
.68756 .19474 m .68789 .18489 L p .68552 .18443 L .929 .759 .649 r
F P
0 g
s
.68789 .18489 m .68802 .18093 L p .68552 .18443 L .929 .759 .649 r
F P
0 g
s
.68495 .20771 m .68756 .19474 L .70251 .19077 L p .198 .058 .454 r
F P
0 g
s
.70251 .19077 m .6999 .20382 L .68495 .20771 L p .198 .058 .454 r
F P
0 g
s
.68495 .20771 m .6999 .20382 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68031 .21931 m .68327 .21191 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68327 .21191 m .68495 .20771 L p .68534 .21533 L .15 0 .289 r
F P
0 g
s
.68756 .19474 m .68802 .18093 L .70298 .17689 L p .236 .175 .582 r
F P
0 g
s
.70298 .17689 m .70251 .19077 L .68756 .19474 L p .236 .175 .582 r
F P
0 g
s
.6999 .20382 m .69822 .20803 L p .68031 .21931 L .15 0 .289 r
F P
0 g
s
.69822 .20803 m .69526 .21547 L .68878 .21713 L p .15 0 .289 r
F P
0 g
s
.68878 .21713 m .68031 .21931 L p .69822 .20803 L .15 0 .289 r
F P
0 g
s
.67641 .18267 m .68729 .18132 L p .68398 .22175 L .493 .402 .681 r
F P
0 g
s
.67641 .22905 m .68398 .22175 L .67641 .31427 L .493 .402 .681 r
F
.67641 .18267 m .68398 .22175 L .67641 .22905 L F
.69365 .17907 m .69314 .17897 L .69526 .21547 L .931 .76 .648 r
F
.68878 .21713 m .69526 .21547 L p .68841 .21899 L .084 0 .077 r
F P
0 g
s
.68729 .2181 m .68729 .36517 L p .68411 .22016 L .493 .402 .681 r
F P
0 g
s
.67641 .22515 m .68729 .2181 L .68841 .21899 L .084 0 .077 r
F
.68729 .2181 m .68878 .21713 L .68841 .21899 L F
.69052 .22068 m .70176 .2425 L .69082 .2244 L 0 0 .395 r
F
.68729 .18132 m .69135 .17862 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.69135 .14813 m .69135 .17862 L .69314 .17897 L .931 .76 .648 r
F
.6826 .17691 m .66767 .18098 L .69135 .17862 L .289 .763 .934 r
F
.67382 .22903 m .69135 .21748 L .69135 .21794 L .084 0 .077 r
F
.67382 .22903 m .67641 .22515 L p .69135 .21748 L F P
0 g
s
.69803 .2267 m .70176 .2425 L .69052 .22068 L 0 0 .395 r
F
.69526 .21547 m .68876 .22524 L .67382 .22903 L p .084 0 .077 r
F P
0 g
s
.68729 .18132 m .69135 .19846 L .69052 .22068 L 0 0 .395 r
F
.69135 .19846 m .69135 .22135 L .69052 .22068 L F
.69135 .22135 m .69526 .21547 L p .69314 .17897 L .931 .76 .648 r
F P
0 g
s
.69135 .17862 m .69135 .22135 L .69314 .17897 L .931 .76 .648 r
F
.70298 .17689 m .70128 .16276 L p .69175 .13608 L F P
0 g
s
.70251 .19077 m .70298 .17689 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.6999 .20382 m .70251 .19077 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69526 .21547 m .6999 .20382 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.68729 .18132 m .70176 .17169 L .70176 .2425 L p 0 0 .395 r
F P
0 g
s
.68938 .20676 m .69052 .22068 L .68895 .21942 L 0 0 .395 r
F
.68938 .20676 m .68895 .21942 L .68729 .2181 L F
.68729 .2181 m .68729 .18132 L p .68938 .20676 L F P
0 g
s
.68876 .22524 m .69135 .22135 L p .69135 .14813 L .931 .76 .648 r
F P
0 g
s
.68729 .18132 m .68729 .2181 L p .68411 .22016 L .493 .402 .681 r
F P
0 g
s
.67641 .18267 m .68729 .18132 L p .66767 .18098 L .289 .763 .934 r
F P
0 g
s
.66575 .23646 m .67382 .22903 L .68876 .22524 L p 0 0 0 r
F P
0 g
s
.68876 .22524 m .68067 .2327 L .66575 .23646 L p 0 0 0 r
F P
0 g
s
.68067 .2327 m .68876 .22524 L p .69033 .17842 L .931 .76 .648 r
F P
0 g
s
.69135 .14813 m .68759 .17789 L .69033 .17842 L .931 .76 .648 r
F
.68759 .17789 m .68067 .2327 L .69033 .17842 L F
.62945 .17359 m .58919 .17465 L .65193 .17794 L .289 .763 .934 r
F
.61507 .23148 m .62511 .23823 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60598 .22221 m .61507 .23148 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .59868 .21046 L .60598 .22221 L .929 .759 .649 r
F
.59868 .21146 m .60598 .22221 L p .59868 .21046 L F P
0 g
s
.69135 .13962 m .68067 .2327 L .69135 .14813 L .931 .76 .648 r
F
.59868 .16764 m .58919 .17465 L p .62945 .17359 L .289 .763 .934 r
F P
0 g
s
.58919 .17465 m .58919 .3602 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.59868 .16764 m .58919 .17465 L p .59733 .21406 L 0 0 .367 r
F P
0 g
s
.59868 .21146 m .59733 .21406 L .59868 .22063 L 0 0 .367 r
F
.59868 .16764 m .59733 .21406 L .59868 .21146 L F
.60598 .22221 m .6208 .21832 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.59868 .21146 m .60598 .22221 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.67681 .14037 m .59868 .19348 L .59868 .21046 L .929 .759 .649 r
F
.58829 .18381 m .59227 .19784 L p .67681 .14037 L F P
0 g
s
.5865 .16938 m .58829 .18381 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.68632 .16688 m .68254 .15317 L .67681 .14037 L p .929 .759 .649 r
F P
0 g
s
.65643 .24126 m .66575 .23646 L .68067 .2327 L p 0 0 0 r
F P
0 g
s
.68067 .2327 m .67134 .23752 L .65643 .24126 L p 0 0 0 r
F P
0 g
s
.67134 .23752 m .68067 .2327 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.66115 .23947 m .67134 .23752 L p .6835 .17709 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67983 .17637 L .6835 .17709 L .931 .76 .648 r
F
.6826 .17691 m .65193 .17794 L .66767 .18098 L .289 .763 .934 r
F
.6738 .1752 m .65193 .17794 L .6826 .17691 L F
.67983 .17637 m .66115 .23947 L .6835 .17709 L .931 .76 .648 r
F
.66129 .17275 m .59868 .16764 L .62945 .17359 L .289 .763 .934 r
F
.65054 .23843 m .66115 .23947 L p .67983 .17637 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67584 .17559 L .67983 .17637 L .931 .76 .648 r
F
.67584 .17559 m .65054 .23843 L .67983 .17637 L F
.60248 .16484 m .60228 .16778 L p .64428 .16943 L .289 .763 .934 r
F P
0 g
s
.6738 .1752 m .62945 .17359 L .65193 .17794 L .289 .763 .934 r
F
.66129 .17275 m .62945 .17359 L .6738 .1752 L F
.63997 .23444 m .65054 .23843 L p .67584 .17559 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .67141 .17473 L .67584 .17559 L .931 .76 .648 r
F
.67141 .17473 m .63997 .23444 L .67584 .17559 L F
.68254 .15317 m .67681 .14037 L .69175 .13608 L p .306 .45 .841 r
F P
0 g
s
.62991 .22764 m .63997 .23444 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.64428 .16943 m .59868 .16764 L .66129 .17275 L .289 .763 .934 r
F
.6208 .21832 m .62991 .22764 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .61349 .20648 L .6208 .21832 L .931 .76 .648 r
F
.61349 .20749 m .6208 .21832 L p .61349 .20648 L F P
0 g
s
.60598 .22221 m .61507 .23148 L .62991 .22764 L p .303 .599 .949 r
F P
0 g
s
.62991 .22764 m .6208 .21832 L .60598 .22221 L p .303 .599 .949 r
F P
0 g
s
.60248 .16484 m .59868 .16764 L p .59868 .21146 L 0 0 .367 r
F P
0 g
s
.6208 .21832 m .61349 .20749 L p .5991 .21065 L .295 .521 .902 r
F P
0 g
s
.5989 .21105 m .6208 .21832 L .5991 .21065 L .295 .521 .902 r
F
.60248 .16484 m .59868 .21146 L .59913 .2106 L 0 0 .367 r
F
.59913 .2106 m .61219 .2071 L p .60238 .20222 L .282 .439 .841 r
F P
0 g
s
.60238 .20222 m .61219 .2071 L .60568 .20366 L .282 .439 .841 r
F
.61219 .2071 m .59913 .2106 L p .61349 .20749 L .295 .521 .902 r
F P
0 g
s
.5991 .21065 m .61349 .20749 L .59913 .2106 L .295 .521 .902 r
F
.60248 .35291 m .60248 .20417 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.61349 .16342 m .60248 .16484 L p .63075 .16679 L .289 .763 .934 r
F P
0 g
s
.63075 .16679 m .60248 .16484 L .64428 .16943 L .289 .763 .934 r
F
.61349 .16342 m .60248 .16484 L p .60567 .20365 L .484 .395 .68 r
F P
0 g
s
.60604 .20385 m .60567 .20365 L .6058 .20517 L .484 .395 .68 r
F
.61349 .16342 m .60567 .20365 L .60604 .20385 L F
.60248 .20197 m .60248 .16484 L p .59942 .20986 L 0 0 .367 r
F P
0 g
s
.60248 .16484 m .59913 .2106 L .59942 .20986 L 0 0 .367 r
F
.59868 .19348 m .59227 .19784 L .59868 .21046 L .929 .759 .649 r
F
.59227 .19784 m .60238 .20222 L .60248 .20197 L .282 .439 .841 r
F
.60248 .16484 m .60248 .20197 L p .60567 .20365 L .484 .395 .68 r
F P
0 g
s
.60548 .19422 m .59385 .19741 L p .60248 .20197 L .282 .439 .841 r
F P
0 g
s
.59385 .19741 m .59227 .19784 L p .60248 .20197 L .282 .439 .841 r
F P
0 g
s
.61349 .16342 m .60604 .20385 L .61349 .20749 L .484 .395 .68 r
F
.60604 .20385 m .6058 .20517 L .61219 .2071 L F
.60604 .20385 m .61219 .2071 L .61349 .20749 L F
.60248 .20197 m .61307 .20686 L .60548 .19422 L .282 .439 .841 r
F
.60238 .20222 m .60568 .20366 L .60248 .20197 L F
.60568 .20366 m .61307 .20686 L .60248 .20197 L F
.61307 .20686 m .60707 .19379 L .60548 .19422 L p F P
0 g
s
.60248 .20417 m .60248 .20197 L p .5994 .21008 L 0 0 .367 r
F P
0 g
s
.59942 .20986 m .5994 .21008 L .60248 .20197 L 0 0 .367 r
F
.5994 .21008 m .59868 .22063 L .60248 .20417 L F
.59913 .2106 m .59826 .21083 L p .5991 .21065 L .295 .521 .902 r
F P
0 g
s
.61349 .20749 m .6058 .20517 L .61349 .29856 L .484 .395 .68 r
F
.61219 .2071 m .61307 .20686 L p .60568 .20366 L .282 .439 .841 r
F P
0 g
s
.6058 .20517 m .60567 .20365 L .60248 .20417 L .484 .395 .68 r
F
.60248 .20197 m .60248 .20417 L p .60567 .20365 L F P
0 g
s
.59942 .20986 m .59913 .2106 L .5994 .21008 L 0 0 .367 r
F
.59227 .19784 m .59826 .21083 L p .59868 .21046 L .929 .759 .649 r
F P
0 g
s
.59227 .19784 m .59826 .21083 L .59913 .2106 L p .282 .439 .841 r
F P
0 g
s
.59227 .19784 m .59913 .2106 L .60238 .20222 L .282 .439 .841 r
F
.5994 .21008 m .59868 .21146 L .59868 .22063 L 0 0 .367 r
F
.59826 .21083 m .59868 .21146 L p .59868 .21046 L .929 .759 .649 r
F P
0 g
s
.59826 .21083 m .5989 .21105 L .5991 .21065 L .295 .521 .902 r
F
.61349 .20749 m .61307 .20686 L .61219 .2071 L p F P
0 g
s
.61349 .29856 m .6058 .20517 L .60248 .35291 L .484 .395 .68 r
F
.60248 .20417 m .60248 .35291 L p .6058 .20517 L F P
0 g
s
.69175 .13608 m .61349 .18941 L .61349 .20648 L .931 .76 .648 r
F
.60308 .17967 m .60707 .19379 L p .69175 .13608 L F P
0 g
s
.60129 .16515 m .60308 .17967 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.64161 .1598 m .64037 .16594 L p .70176 .17169 L .289 .763 .934 r
F P
0 g
s
.70176 .17169 m .61349 .16342 L .63075 .16679 L .289 .763 .934 r
F
.70176 .17169 m .63075 .16679 L .64428 .16943 L F
.62511 .23823 m .63567 .24219 L .65054 .23843 L p .289 .729 .965 r
F P
0 g
s
.65054 .23843 m .63997 .23444 L .62511 .23823 L p .289 .729 .965 r
F P
0 g
s
.61507 .23148 m .62511 .23823 L .63997 .23444 L p .303 .671 .974 r
F P
0 g
s
.63997 .23444 m .62991 .22764 L .61507 .23148 L p .303 .671 .974 r
F P
0 g
s
.64161 .1598 m .61349 .16342 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.60707 .19379 m .61307 .20686 L p .61349 .20648 L .931 .76 .648 r
F P
0 g
s
.61349 .18941 m .60707 .19379 L .61349 .20648 L .931 .76 .648 r
F
.61307 .20686 m .61349 .20749 L p .61349 .20648 L F P
0 g
s
.63567 .24219 m .64626 .2432 L .66115 .23947 L p .253 .754 .893 r
F P
0 g
s
.66115 .23947 m .65054 .23843 L .63567 .24219 L p .253 .754 .893 r
F P
0 g
s
.64161 .34916 m .64161 .1598 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.60248 .35291 m .61349 .35185 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.61349 .35185 m .64161 .34916 L p .61349 .29856 L .484 .395 .68 r
F P
0 g
s
.70176 .17169 m .64428 .16943 L .66129 .17275 L .289 .763 .934 r
F
.59826 .21083 m .59868 .21146 L p .5989 .21105 L .295 .521 .902 r
F P
0 g
s
.58919 .3602 m .59868 .35499 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.59868 .35499 m .60248 .35291 L p .59868 .22063 L 0 0 .367 r
F P
0 g
s
.70176 .17169 m .66129 .17275 L .6738 .1752 L .289 .763 .934 r
F
.69135 .17862 m .70176 .17169 L p .6826 .17691 L F P
0 g
s
.69135 .19846 m .69803 .2267 L .69135 .22135 L 0 0 .395 r
F
.70176 .2425 m .70176 .358 L p .69082 .2244 L F P
0 g
s
.70176 .17169 m .6738 .1752 L .6826 .17691 L .289 .763 .934 r
F
.69175 .13608 m .69135 .13962 L .69135 .14813 L .931 .76 .648 r
F
.70176 .358 m .69135 .36316 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.69135 .36316 m .68729 .36517 L p .69135 .25729 L 0 0 .395 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.60869 .36668 m .64898 .3687 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.58919 .3602 m .60869 .36668 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64898 .3687 m .68729 .36517 L .70176 .358 L p .224 .73 .894 r
F P
0 g
s
.60248 .35291 m .58919 .3602 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64161 .34916 m .60248 .35291 L p .70176 .358 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64626 .2432 m .65643 .24126 L .67134 .23752 L p .188 .717 .729 r
F P
0 g
s
.67134 .23752 m .66115 .23947 L .64626 .2432 L p .188 .717 .729 r
F P
0 g
s
.70176 .17169 m .6831 .1627 L .64161 .1598 L p .289 .763 .934 r
F P
0 g
s
.64161 .34916 m .6831 .35131 L .6831 .1627 L p .807 .659 .699 r
F P
0 g
s
.6831 .1627 m .64161 .1598 L .64161 .34916 L p .807 .659 .699 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70176 .358 m .6831 .35131 L .64161 .34916 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6831 .35131 m .70176 .358 L .70176 .17169 L p .999 .816 .481 r
F P
0 g
s
.70176 .17169 m .6831 .1627 L .6831 .35131 L p .999 .816 .481 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.39992 1.29654 m .41389 1.27286 L .4277 1.29226 L p .971 .793 .605 r
F P
0 g
s
.4277 1.29226 m .41389 1.31592 L .39992 1.29654 L p .971 .793 .605 r
F P
0 g
s
.57309 1.29654 m .58611 1.27286 L .599 1.29226 L p .978 .799 .593 r
F P
0 g
s
.599 1.29226 m .58611 1.31592 L .57309 1.29654 L p .978 .799 .593 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.68431 .12468 m .69175 .13608 L .67681 .14037 L p .321 .53 .901 r
F P
0 g
s
.67681 .14037 m .66938 .12904 L .68431 .12468 L p .321 .53 .901 r
F P
0 g
s
.58699 .1552 m .5865 .16938 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.58974 .14192 m .58699 .1552 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.59461 .13014 m .58974 .14192 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60138 .12039 m .59461 .13014 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.60973 .11309 m .60138 .12039 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.61928 .10855 m .60973 .11309 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.6296 .10696 m .61928 .10855 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.64023 .10836 m .6296 .10696 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.65069 .11267 m .64023 .10836 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.66055 .11967 m .65069 .11267 L p .67681 .14037 L .929 .759 .649 r
F P
0 g
s
.67681 .14037 m .66938 .12904 L .66055 .11967 L p .929 .759 .649 r
F P
0 g
s
.38568 .11525 m .39521 .12468 L .3819 .12904 L p .306 .6 .949 r
F P
0 g
s
.3819 .12904 m .37239 .11967 L .38568 .11525 L p .306 .6 .949 r
F P
0 g
s
.67547 .11525 m .68431 .12468 L .66938 .12904 L p .331 .607 .949 r
F P
0 g
s
.66938 .12904 m .66055 .11967 L .67547 .11525 L p .331 .607 .949 r
F P
0 g
s
.41534 .17689 m .4135 .16276 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.41483 .19077 m .41534 .17689 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.4135 .16276 m .40942 .14896 L .40323 .13608 L p .921 .752 .656 r
F P
0 g
s
.70128 .16276 m .69749 .14896 L .69175 .13608 L p .931 .76 .648 r
F P
0 g
s
.66559 .10819 m .67547 .11525 L .66055 .11967 L p .335 .68 .978 r
F P
0 g
s
.66055 .11967 m .65069 .11267 L .66559 .10819 L p .335 .68 .978 r
F P
0 g
s
.37503 .10819 m .38568 .11525 L .37239 .11967 L p .316 .675 .976 r
F P
0 g
s
.37239 .11967 m .36177 .11267 L .37503 .10819 L p .316 .675 .976 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.30623 .15089 m .3057 .16515 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3092 .13754 m .30623 .15089 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.31446 .1257 m .3092 .13754 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.32177 .1159 m .31446 .1257 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.33079 .10857 m .32177 .1159 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.3505 .10836 m .33905 .10696 L .35225 .10243 L p .305 .781 .926 r
F P
0 g
s
.34111 .10402 m .35225 .10243 L .33905 .10696 L p .27 .776 .804 r
F P
0 g
s
.33905 .10696 m .32793 .10855 L .34111 .10402 L p .27 .776 .804 r
F P
0 g
s
.34111 .10402 m .33079 .10857 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.36373 .10385 m .37503 .10819 L .36177 .11267 L p .318 .739 .975 r
F P
0 g
s
.36177 .11267 m .3505 .10836 L .36373 .10385 L p .318 .739 .975 r
F P
0 g
s
.35225 .10243 m .36373 .10385 L .3505 .10836 L p .305 .781 .926 r
F P
0 g
s
.35225 .10243 m .34111 .10402 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.36373 .10385 m .35225 .10243 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.37503 .10819 m .36373 .10385 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.38568 .11525 m .37503 .10819 L p .40323 .13608 L .921 .752 .656 r
F P
0 g
s
.40323 .13608 m .39521 .12468 L .38568 .11525 L p .921 .752 .656 r
F P
0 g
s
.60178 .15089 m .60129 .16515 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.60453 .13754 m .60178 .15089 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.60941 .1257 m .60453 .13754 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.61619 .1159 m .60941 .1257 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.62456 .10857 m .61619 .1159 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65069 .11267 m .64023 .10836 L .65511 .10385 L p .327 .742 .978 r
F P
0 g
s
.64446 .10243 m .65511 .10385 L .64023 .10836 L p .301 .779 .923 r
F P
0 g
s
.64023 .10836 m .6296 .10696 L .64446 .10243 L p .301 .779 .923 r
F P
0 g
s
.63413 .10402 m .64446 .10243 L .6296 .10696 L p .245 .759 .782 r
F P
0 g
s
.6296 .10696 m .61928 .10855 L .63413 .10402 L p .245 .759 .782 r
F P
0 g
s
.63413 .10402 m .62456 .10857 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65511 .10385 m .66559 .10819 L .65069 .11267 L p .327 .742 .978 r
F P
0 g
s
.64446 .10243 m .63413 .10402 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.65511 .10385 m .64446 .10243 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.66559 .10819 m .65511 .10385 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.67547 .11525 m .66559 .10819 L p .69175 .13608 L .931 .76 .648 r
F P
0 g
s
.69175 .13608 m .68431 .12468 L .67547 .11525 L p .931 .76 .648 r
F P
0 g
s
.33079 .10857 m .34111 .10402 L .32793 .10855 L p 0 0 0 r
F P
0 g
s
.32793 .10855 m .31764 .11309 L .33079 .10857 L p 0 0 0 r
F P
0 g
s
.62456 .10857 m .63413 .10402 L .61928 .10855 L p 0 0 0 r
F P
0 g
s
.61928 .10855 m .60973 .11309 L .62456 .10857 L p 0 0 0 r
F P
0 g
s
.32177 .1159 m .33079 .10857 L .31764 .11309 L p 0 0 0 r
F P
0 g
s
.31764 .11309 m .30864 .12039 L .32177 .1159 L p 0 0 0 r
F P
0 g
s
.61619 .1159 m .62456 .10857 L .60973 .11309 L p 0 0 0 r
F P
0 g
s
.60973 .11309 m .60138 .12039 L .61619 .1159 L p 0 0 0 r
F P
0 g
s
.31446 .1257 m .32177 .1159 L .30864 .12039 L p 0 0 0 r
F P
0 g
s
.30864 .12039 m .30135 .13014 L .31446 .1257 L p 0 0 0 r
F P
0 g
s
.60941 .1257 m .61619 .1159 L .60138 .12039 L p .035 0 .027 r
F P
0 g
s
.60138 .12039 m .59461 .13014 L .60941 .1257 L p .035 0 .027 r
F P
0 g
s
.3092 .13754 m .31446 .1257 L .30135 .13014 L p .039 0 .197 r
F P
0 g
s
.30135 .13014 m .2961 .14192 L .3092 .13754 L p .039 0 .197 r
F P
0 g
s
.60453 .13754 m .60941 .1257 L .59461 .13014 L p .109 0 .256 r
F P
0 g
s
.59461 .13014 m .58974 .14192 L .60453 .13754 L p .109 0 .256 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.29454 .18381 m .29883 .19784 L .31194 .19379 L p .218 .326 .761 r
F P
0 g
s
.58829 .18381 m .59227 .19784 L .60707 .19379 L p .263 .352 .768 r
F P
0 g
s
.30623 .15089 m .3092 .13754 L .2961 .14192 L p .101 0 .392 r
F P
0 g
s
.2961 .14192 m .29314 .1552 L .30623 .15089 L p .101 0 .392 r
F P
0 g
s
.60178 .15089 m .60453 .13754 L .58974 .14192 L p .164 .025 .433 r
F P
0 g
s
.58974 .14192 m .58699 .1552 L .60178 .15089 L p .164 .025 .433 r
F P
0 g
s
.31194 .19379 m .30764 .17967 L .29454 .18381 L p .218 .326 .761 r
F P
0 g
s
.29262 .16938 m .29454 .18381 L .30764 .17967 L p .187 .221 .665 r
F P
0 g
s
.60707 .19379 m .60308 .17967 L .58829 .18381 L p .263 .352 .768 r
F P
0 g
s
.5865 .16938 m .58829 .18381 L .60308 .17967 L p .238 .257 .679 r
F P
0 g
s
.3057 .16515 m .30623 .15089 L .29314 .1552 L p .149 .102 .545 r
F P
0 g
s
.29314 .1552 m .29262 .16938 L .3057 .16515 L p .149 .102 .545 r
F P
0 g
s
.60129 .16515 m .60178 .15089 L .58699 .1552 L p .206 .15 .57 r
F P
0 g
s
.58699 .1552 m .5865 .16938 L .60129 .16515 L p .206 .15 .57 r
F P
0 g
s
.30764 .17967 m .3057 .16515 L .29262 .16938 L p .187 .221 .665 r
F P
0 g
s
.60308 .17967 m .60129 .16515 L .5865 .16938 L p .238 .257 .679 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool700000;@0oooo1`00003P0?oo
o`00f@3oool5000000L0jl2W1@00002Z0?ooo`D000001`3^`ZD500000=/0oooo003F0?ooo`<00000
4@3[`:L400000:<0oooo1000000@0>k2Y@<00000f03oool00=<0oooo1000000G0>_0Y`800000WP3o
ool5000001D0k/:U0P00003F0?ooo`00d@3oool4000001/0jl2W0P00002J0?ooo`D000006@3^`ZD2
00000=@0oooo003?0?ooo`@000007`3[`:L00`000000oooo0?ooo`2E0?ooo`D000007@3^`ZD00`00
0000oooo0?ooo`3A0?ooo`00c@3oool400000280jl2W00<000000?ooo`3oool0TP3oool6000001l0
k/:U00<000000?ooo`3oool0d03oool00</0oooo1@00000T0>_0Y`800000T03oool600000280k/:U
0P00003@0?ooo`00b@3oool5000002P0jl2W00<000000?ooo`3oool0R`3oool7000002D0k/:U00<0
00000?ooo`3oool0c@3oool00<P0oooo1@00000Z0>_0Y`030000003oool0oooo08T0oooo1`00000W
0>k2Y@030000003oool0oooo0<`0oooo00360?ooo`L00000:`3[`:L00`000000oooo0?ooo`260?oo
o`D000000`0800H00`000000k/:U0>k2Y@0V0>k2Y@030000003oool0oooo0</0oooo00350?ooo`L0
0000;@3[`:L00`000000oooo0?ooo`240?ooo`8000001P0800H00`000000k/:U0>k2Y@0W0>k2Y@03
0000003oool0oooo0</0oooo00340?ooo`P00000;P3[`:L00`000000oooo0?ooo`220?ooo`030000
000800H0200600D0200600<000000>k2Y@3^`ZD0:@3^`ZD00`000000oooo0?ooo`3:0?ooo`00a03o
ool700000300jl2W00<000000?ooo`3oool0P@3oool00`000000200600P01P0400P01P030000003^
`ZD0k/:U02/0k/:U00<000000?ooo`3oool0b@3oool00<<0oooo2000000a0>_0Y`030000003oool0
oooo07l0oooo00<0000000P01P0800H01@0800H00`000000k/:U0>k2Y@0/0>k2Y@030000003oool0
oooo0<P0oooo00320?ooo`P00000<`3[`:L00`000000oooo0?ooo`1n0?ooo`030000000800H02006
00<020060P00000`0>k2Y@030000003oool0oooo0<L0oooo00310?ooo`P00000=@3[`:L00`000000
oooo0?ooo`1l0?ooo`040000000800H0200600P01P<0000000<06`110000003^`ZD0;`3^`ZD00`00
0000oooo0?ooo`370?ooo`00`@3oool4000000<02@0b00<000000>_0Y`3[`:L0=03[`:L00`000000
oooo0?ooo`1k0?ooo`@000000`0K04400`000000k/:U0>k2Y@0`0>k2Y@030000003oool0oooo0<H0
oooo00300?ooo`8000001@0903800`000000jl2W0>_0Y`0e0>_0Y`030000003oool0oooo07X0oooo
0P00000601/0@@030000003^`ZD0k/:U0340k/:U00<000000?ooo`3oool0a@3oool00<00oooo00<0
000000T0<P090380100903800`000000jl2W0>_0Y`0f0>_0Y`030000003oool0oooo07T0oooo00<0
000001/0@@0K0440100K04400`000000k/:U0>k2Y@0c0>k2Y@030000003oool0oooo0<@0oooo002o
0?ooo`030000000903802@0b00@02@0b00<000000>_0Y`3[`:L0>03[`:L00`000000oooo0?ooo`1g
0?ooo`030000000K04406`1100D06`1100<000000>k2Y@3^`ZD0<`3^`ZD00`000000oooo0?ooo`34
0?ooo`00_`3oool00`0000002@0b00T0<P0400T0<P030000003[`:L0jl2W03T0jl2W00<000000?oo
o`3oool0MP3oool00`0000006`1101/0@@0401/0@@030000003^`ZD0k/:U03D0k/:U00<000000?oo
o`3oool0``3oool00;h0oooo00<0000000T0<P0903800`090382000003X0jl2W00<000000>_0Y`00
0000M`3oool00`0000006`1101/0@@0401/0@@800000=03^`ZD2000000030>k2Y@000000oooo0<@0
oooo002n0?ooo`040000000903802@0b00T0<P80000000<06@1T0000003[`:L0?03[`:L00`000000
oooo0?ooo`1d0?ooo`040000000K04406`1101/0@@<0000000<0:@I^0000003^`ZD0<03^`ZD20000
00D0k/:U00<000000?ooo`3oool0`P3oool00;d0oooo00<0000000T0<P0000000P00000301T0I003
0000003[`:L0jl2W03/0jl2W00<000000?ooo`3oool0L`3oool00`0000006`1100000002000000@0
:@I^00<000000>k2Y@3^`ZD0;03^`ZD2000000P0k/:U00<000000?ooo`3oool0`P3oool00;d0oooo
0P00000501T0I0030000003[`:L0jl2W03d0jl2W00<000000?ooo`3oool0LP3oool2000000L0:@I^
00<000000>k2Y@3^`ZD0=`3^`ZD00`000000oooo0?ooo`310?ooo`00_@3oool00`0000006@1T01T0
I00401T0I0030000003[`:L0jl2W03d0jl2W00<000000?ooo`3oool0LP3oool00`000000:@I^02T6
KP0602T6KP030000003^`ZD0k/:U03L0k/:U00<000000?ooo`3oool0`@3oool00;d0oooo00<00000
01T0I00I06@0100I06@00`000000jl2W0>_0Y`0n0>_0Y`030000003oool0oooo0740oooo00<00000
02T6KP0Y1Vh01@0Y1Vh00`000000k/:U0>k2Y@0i0>k2Y@030000003oool0oooo0<00oooo002l0?oo
o`030000000I06@06@1T00D06@1T00<000000>_0Y`3[`:L0>03[`:L00`15KmL0jl2W0>_0Y`030>_0
Y`030000003oool0oooo0700oooo00<0000002T6KP0Y1Vh01P0Y1Vh00`000000k/:U0>k2Y@0i0>k2
Y@030000003oool0oooo0<00oooo002l0?ooo`030000000I06@06@1T00@06@1T00<000000>_0Y`3[
`:L0@03[`:L00`000000oooo0?ooo`1_0?ooo`030000000Y1Vh0:@I^00H0:@I^00<000000>k2Y@3^
`ZD0>P3^`ZD00`000000oooo0?ooo`2o0?ooo`00_03oool00`0000006@1T01T0I00401T0I0030000
003[`:L0jl2W0400jl2W00<000000?ooo`3oool0K`3oool00`000000:@I^02T6KP0602T6KP030000
003^`ZD0k/:U03D0k/:U00<0CW?G0>k2Y@3^`ZD00P3^`ZD00`000000oooo0?ooo`2o0?ooo`00_03o
ool00`0000006@1T01T0I00301T0I0800000@P3[`:L00`000000oooo0?ooo`1_0?ooo`030000000Y
1Vh0:@I^00D0:@I^0P00000g0>k2Y@030000003^`ZD0k/:U0080k/:U00<000000?ooo`3oool0_`3o
ool00;/0oooo00<0000001T0I00I06@00P0I06@20000000302HJR`000000jl2W0440jl2W00<00000
0?ooo`3oool0KP3oool00`000000:@I^02T6KP0302T6KP<0000000<0=2JA0000003^`ZD0=P3^`ZD0
0`19GLD0k/:U0>k2Y@020>k2Y@030000003oool0oooo0;l0oooo002k0?ooo`030000000I06@00000
008000000`0V6X/00`000000jl2W0>_0Y`110>_0Y`030000003oool0oooo06d0oooo00<0000002T6
KP0000000`00000403@VT@030000003^`ZD0k/:U03/0k/:U00<000000?ooo`3oool0_P3oool00;/0
oooo0P00000602HJR`030000003[`:L0jl2W0440jl2W00<000000?ooo`3oool0K@3oool2000000P0
=2JA00<000000>k2Y@3^`ZD0>`3^`ZD00`000000oooo0?ooo`2n0?ooo`00^`3oool00`0000009QZ;
02HJR`0502HJR`030000003[`:L0jl2W0440jl2W00<000000?ooo`3oool0K@3oool00`000000=2JA
03@VT@0703@VT@030000003^`ZD0k/:U03/0k/:U00<000000?ooo`3oool0_P3oool00;/0oooo00<0
000002HJR`0V6X/01@0V6X/00`000000jl2W0>_0Y`110>_0Y`030000003oool0oooo06d0oooo00<0
000003@VT@0d9Y401P0d9Y400`000000k/:U0>k2Y@0l0>k2Y@030000003oool0oooo0;h0oooo002k
0?ooo`030000000V6X/09QZ;00D09QZ;00<000000>_0Y`3[`:L04`3[`:LB000001D0jl2W00<0?eO4
0>_0Y`3[`:L01@3[`:L00`000000oooo0?ooo`1/0?ooo`030000000d9Y40=2JA00H0=2JA00<00000
0>k2Y@3^`ZD04`3^`ZDB00000140k/:U00<0BEg50>k2Y@3^`ZD0103^`ZD00`000000oooo0?ooo`2m
0?ooo`00^`3oool00`0000009QZ;02HJR`0502HJR`030000003[`:L0jl2W00/0jl2W2000000407QR
[@030000003>Z;80cZRb00/0cZRb3`0000060>_0Y`0303mGa03[`:L0jl2W00D0jl2W00<000000?oo
o`3oool0K03oool00`000000=2JA03@VT@0603@VT@030000003^`ZD0k/:U00X0k/:U2@00000407]U
[P030000003>Z;80cZRb00/0cZRb3P0000030>k2Y@0304UMa@3^`ZD0k/:U00@0k/:U00<000000?oo
o`3oool0_@3oool00;/0oooo00<0000002HJR`0V6X/01@0V6X/00`000000jl2W0>_0Y`060>_0Y`D0
0000301hHZd00`000000cZRb0<jX/P0H0<jX/P040000003od8H00000000000`0jl2W00<000000?oo
o`3oool0K03oool00`000000=2JA03@VT@0603@VT@030000003^`ZD0k/:U00D0k/:U1@00000=07]U
[P030000003>Z;80cZRb01P0cZRb0`0000000`19GLD0k/:U0>k2Y@050>k2Y@030000003oool0oooo
0;d0oooo002k0?ooo`030000000V6X/09QZ;00@09QZ;0P0000080>_0Ya40N6:]00<000000<jX/P3>
Z;80603>Z;8010000000om260?o@QP3od8H200000080jl2W00<000000>_0Y`3[`:L01@3[`:L00`00
0000oooo0?ooo`1/0?ooo`030000000d9Y40=2JA00D0=2JA0P0000070>k2YA80NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`02000000H0k/:U00<000000?ooo`3oool0_@3oool00;/0
oooo00<0000002HJR`0V6X/00P0V6X/20000000302lhZP000000jl2W00L0jl2W4@1hHZd00`000000
cZRb0<jX/P0H0<jX/P030000003od8H0om2600<0om260`0000070>_0Y`030000003oool0oooo06`0
oooo00<0000003@VT@0d9Y400P0d9Y430000000303a1[@000000k/:U00H0k/:U4P1kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k0080om1k0P0000040>k2Y@030000003oool0oooo0;d0
oooo002k0?ooo`030000000V6X/00000008000000`0_>:X00`000000jl2W0>_0Y`060>_0Ya40N6:]
00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP060?o@QP8000001@3[`:L00`000000oooo
0?ooo`1/0?ooo`030000000d9Y40000000800000100l@Jd00`000000k/:U0>k2Y@050>k2YA80NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`040?o@N`8000000P3^`ZD00`000000oooo
0?ooo`2m0?ooo`00^`3oool2000000H0;cRZ00<000000>_0Y`3[`:L01P3[`:LA07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H0203od8H2000000@0jl2W00<000000?ooo`3oool0J`3o
ool2000000L0?46]00<000000>k2Y@3^`ZD01@3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/01P3od7/2000000030>k2Y@000000oooo0;d0oooo002k0?ooo`030000000_>:X0
;cRZ00D0;cRZ00<000000>_0Y`3[`:L01P3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02P3od8H200000080jl2W00<000000?ooo`3oool0J`3oool00`000000?46]03a1[@06
03a1[@030000003^`ZD0k/:U00D0k/:U4P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0
om1k00P0om1k0P00002n0?ooo`00^`3oool00`000000;cRZ02lhZP0602lhZP030000003[`:L0jl2W
00D0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000K@3oool00`000000?46]03a1[@0703a1[@030000003^`ZD0k/:U00@0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;/0oooo00<0000002lhZP0_>:X01P0_>:X00`000000jl2W0>_0Y`050>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006d0oooo00<00000
03a1[@0l@Jd01`0l@Jd00`000000k/:U0>k2Y@040>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;80
0`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002k0?ooo`030000000_>:X0;cRZ
00H0;cRZ00<000000>_0Y`3[`:L01@3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H010000000jl2W0>_0Y`00001]0?ooo`030000000l@Jd0?46]00L0?46]00<00000
0>k2Y@3^`ZD0103^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000;cRZ02lhZP0502lhZP030000003[`:L0jl2W
00D0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000KP3oool00`000000?46]03a1[@0603a1[@030000003^`ZD0k/:U00@0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;`0oooo00<0000002lhZP0_>:X0100_>:X2000000L0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600@000000>_0Y`3[`:L00000KP3oool00`000000?46]03a1[@05
03a1[@8000001P3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000;cRZ02lhZP0202lhZP80000000<0=e?20000
003[`:L01P3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H01000
0000jl2W0>_0Y`00001^0?ooo`030000000l@Jd0?46]0080?46]0`0000000`13F/@000000>k2Y@05
0>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0
oooo0;`0oooo002l0?ooo`030000000_>:X0000000800000100gDl800`000000jl2W0>_0Y`040>_0
Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W
000006h0oooo00<0000003a1[@0000000P00000504=Ja0030000003^`ZD0k/:U00<0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;`0oooo0P00000703MC`P030000003[`:L0jl2W00@0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600@000000>_0Y`3[`:L00000KP3oool2000000P0@e[400<00000
0>k2Y@3^`ZD00`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_03oool00`000000=e?203MC`P0603MC`P030000003[`:L0jl2W
00@0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000KP3oool00`000000@e[404=Ja00704=Ja0030000003^`ZD0k/:U00<0k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;d0oooo00<0000003MC`P0gDl801P0gDl800`000000jl2W0>_0Y`030>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006l0oooo00<00000
04=Ja013F/@01`13F/@00`000000k/:U0>k2Y@020>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;80
0`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002m0?ooo`030000000gDl80=e?2
00H0=e?200<000000>_0Y`3[`:L00`3[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H010000000jl2W0>_0Y`00001_0?ooo`0300000013F/@0@e[400L0@e[400<00000
0>k2Y@3^`ZD00P3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_@3oool00`000000=e?203MC`P0603MC`P030000003[`:L0jl2W
00<0jl2W4@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>_0
Y`3[`:L00000K`3oool00`000000@e[404=Ja00704=Ja0030000003^`ZD0k/:U0080k/:U4P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;h0oooo00<0000003MC`P0gDl801P0gDl800`000000jl2W0>_0Y`020>_0Ya40N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0jl2W000006l0oooo0P000009
04=Ja0040000003^`ZD0k/:U0>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@
N`090?o@N`030000003oool0oooo0;`0oooo002n0?ooo`030000000gDl80=e?200D0=e?20P000004
0>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP040000003[`:L0
jl2W000006h0oooo0`00000804=Ja08000000`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000=e?203MC`P03
03MC`P@00000103[`:LA07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H0
0`000000jl2W0000001_0?ooo`<000001@13F/@5000000<0k/:U4P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0000003MC
`P0000000`00000303e[eP040000003[`:L0jl2W0>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003[`:L0000006h0oooo0`0000000`0005d0000004=Ja005
000000<0B73G0`3^`ZDB07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool2000000L0?F_F00@000000>_0Y`3[`:L0jl2W4@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000>_0Y`000000KP3oool0
10000000:01;0000000005d3000000L0B73G00<000000>k2Y@3^`ZD04P1kIJh00`000000cZRb0<jX
/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
03e[eP0mJmH01`0mJmH00`000000jl2W0>_0Y`0A07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02`3od8H00`000000jl2W0000001]0?ooo`060000000X04/0:01;0000000005d00000
2P18L=L20>k2YA80NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000mJmH0?F_F00<0?F_F00D0000003e[eP0mJmH0?F_F
000000020>_0Ya40N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP800000
KP3oool010000000:01;02P0B`0000020000G@D0B73G00<0000004Q`e`18L=L00P18L=L00`000000
k/:U07]U[P0A07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000
oooo0?ooo`2l0?ooo`00_`3oool2000000@0?F_F00<0000003e[eP0mJmH00P0mJmH00`000000jl2W
07QR[@0@07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H2000006d0oooo
00D0000002P0B`0X04/0:01;000000020000G@0300000018L=L0B73G0080B73G00<0000004Q`e`18
L=L00`18L=L00`3^`ZD0NfF^07]U[P0@07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3o
d7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`000000001703e[eP0303e[eP030000
001hHZd0?F_F0080?F_F00<000000>_0Y`1hHZd0401hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om260`00001/0?ooo`050000000X04/0:01;02P0B`0000000P0005d00`000000
B73G04Q`e`0204Q`e`030000001kIJh0B73G00<0B73G00<0000007]U[P1kIJh0401kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo
00<000000000A`0000000`0mJmH010000000N6:]07QR[@1hHZd203e[eP030000001hHZd0N6:]00l0
N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP<00000J`3oool00`000000
:01;02P0B`03000000<0001M00D0000004Q`e`18L=L0B73G0000000307]U[P<0B73G00<0k/:U07]U
[P1kIJh03`1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00P0mJmH00`0004L0000007QR[@0407QR[@80
0000401hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>RmZ@3X
_JT00000JP3oool300000080=A5e00D000000000G@0005d0001M0000000204Q`e`030000G@000000
NfF^00@0NfF^0P00000A07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool01`00000000170000A`000000?F_F0000A`0000005`1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000>RmZ@3X_JT00000
JP3oool00`000000=A5e03DAM@0203DAM@030000000005d0001M0080001M00@0000004Q`e`0005d0
0000601kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3o
ool0_03oool00;l0oooo00L000000000A`0004L000170000000004L0000001L0N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP050000003X_JT0j;fY0>RmZ@000000J03oool0
0`000000=A5e03DAM@0303DAM@030000000005d0001M0080001M00@0000004^5iP0005d00000601k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00L000000000A`0004L000170000000004L0000001L0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP050000003X_JT0j;fY0>RmZ@000000J03oool00`000000
=A5e03DAM@0303DAM@030000000005d0001M00<0001M00<000000000G@000000601kIJh00`000000
cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo
00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb
00<000000?o@QP3od8H02`3od8H01@000000j;fY0>RmZ@3X_JT0000006P0oooo00<0000003DAM@0e
4GD00`0e4GD00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>
Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000
000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om2600<000000>RmZ@3X_JT00P3X_JT00`000000oooo0?ooo`1U0?ooo`030000
000e4GD0=A5e00<0=A5e00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000
003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>
Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY0080j;fY00<000000?ooo`3oool0I03o
ool00`000000=A5e03DAM@0403DAM@030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80
cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000j;fY0>RmZ@020>RmZ@030000003oool0
oooo06@0oooo00<0000003DAM@0e4GD01@0000070000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000>RmZ@3X_JT00`3X_JT00`000000oooo0?ooo`1S0?oo
o`<00000100n;YH00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`03
0000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P03
0000003od8H0om2600/0om2600<000000>RmZ@3X_JT00`3X_JT00`000000oooo0?ooo`1S0?ooo`03
0000000n;YH0?RjF00@0?RjF00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY00@0j;fY00<000000?ooo`3oool0
HP3oool00`000000?RjF03h^UP0403h^UP030000000005d0001M00D0001M00<0000007]U[P1kIJh0
5P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0
_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000j;fY0>RmZ@040>RmZ@030000003o
ool0oooo0680oooo00<0000003h^UP0n;YH0100n;YH00`000000001M0000G@050000G@030000001k
IJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003o
ool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000>RmZ@3X_JT0103X_JT0
0`000000oooo0?ooo`1R0?ooo`030000000n;YH0?RjF00@0?RjF00<000000000G@0005d01@0005d0
0`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]
01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003X_JT0j;fY
00@0j;fY00<000000?ooo`3oool0HP3oool00`000000?RjF03h^UP0403h^UP030000000005d0001M
00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k
00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000
N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000
j;fY0>RmZ@040>RmZ@030000003oool0oooo0680oooo00<0000003h^UP0n;YH0100n;YH00`000000
001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000
om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<00017
00<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om26
0P0000050>RmZ@030000003oool0oooo0680oooo00<0000003h^UP0n;YH01@0000070000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000?k@R`0000000000
103X_JT00`000000oooo0?ooo`1Q0?ooo`<000001015B:l00`000000001M0000G@050000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600@000000?k@R`3nd8/0o]2;
0P0000020>RmZ@030000003oool0oooo0640oooo00<0000004E8[`15B:l01015B:l00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001S0?ooo`0300000015B:l0ADR_00@0ADR_
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@000000>RmZ@3X_JT00000H`3oool00`000000ADR_
04E8[`0404E8[`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`040000003X_JT0j;fY000006<0oooo
00<0000004E8[`15B:l01015B:l00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/010000000j;fY0>Rm
Z@00001T0?ooo`0300000015B:l0ADR_00<0ADR_00<000000000G@0005d01@0005d00`000000NfF^
07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo
0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<0
00000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@0
00000>RmZ@3X_JT00000I03oool00`000000ADR_04E8[`0304E8[`030000000005d0001M00D0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`040000003X_JT0j;fY000006@0oooo00<0000004E8[`15B:l00P15B:l2000000L0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`040000003X_JT0j;fY000006@0oooo00<0000004E8[`0000000P0000000`1;G/D00000
0000G@060000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001T0?ooo`800000101;G/D00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/010000000j;fY0>RmZ@00001T0?ooo`030000001;G/D0Bek500<0Bek5
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00@000000>RmZ@3X_JT00000I03oool00`000000Bek5
04]Na@0304]Na@030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`040000003X_JT0j;fY000006D0oooo
00<0000004]Na@1;G/D00P1;G/D00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/010000000j;fY0>Rm
Z@00001U0?ooo`030000001;G/D0Bek50080Bek500<000000000G@0005d01@0005d00`000000NfF^
07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo
0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<0
00000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<0
00000>RmZ@000000IP3oool00`000000Bek504]Na@0204]Na@030000000005d0001M00D0001M00<0
000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<0
00000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E
07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`02
0?k@R`030000003X_JT0000006H0oooo00<0000004]Na@1;G/D00P1;G/D00`000000001M0000G@05
0000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`09
0?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR
[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@
R`3nd8/00P3nd8/00`000000j;fY0000001V0?ooo`8000000P1;G/D2000000L0001M00<0000007]U
[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`03
0000003X_JT0000006H0oooo100000000`1?LmL000000000G@060000G@030000001kIJh0NfF^01H0
NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0
oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb
0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo
00<000000000H`1?LmL00P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^
00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo
002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX
/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo00<0
00000000H`0000000P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<0
00000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o
0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H
0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/2000006L0oooo00<00000
0000H`0006<00P1?LmL00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?oo
o`060000000006<0001S0000001?LmL000001`0005d00`000000NfF^07]U[P0F07]U[P030000003>
Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool0
0`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool0
1P000000001S0000H`0006<0Cg?G000000L0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00@0
00000000H`0006<0001S0P0000070000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80
603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`0300000000
04L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003o
d8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`0300000000
06<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>
Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool0
0`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;80
0`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool0
0`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh0
0`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool0
0;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb
01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo
06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^
01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo
0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000
cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000
oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000
NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000
oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]
00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;
00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M
00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k
00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR
[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@
R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000
G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@
N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<00000
07QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<00000
0?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<00000
0000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<00000
0?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000
A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@
QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000
H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX
/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`00
04L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3o
d8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`00
06<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>
Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000
000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000
003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000
000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000
003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>
Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3o
ool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1k
IJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80
cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0
oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0
NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0
oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`00
0000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`00
0000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`00
0000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`00
0000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0
N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080
o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0
001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0
om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]
07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;
0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M
0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k
0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0
000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<0
00000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<0
00000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<0
00000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`03
0000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;
0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`02
0000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000
A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000
H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX
/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`03
0000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P03
0000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`03
0000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0
IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh0
5P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0
_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>
Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003o
ool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000001k
IJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003o
ool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd0
0`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/0
0`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d0
0`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/0
0`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]
01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;
0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M
00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k
00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000
N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000
o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000
001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000
om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<00017
00<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om26
00<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S
00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb
00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000
A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@
QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000
H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX
/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
0000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<00000
0?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<00000
0000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<00000
0<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?oo
o`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX
/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?oo
o`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U
[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?oo
o`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>
Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3o
ool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1k
IJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3o
ool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000
003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000
003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@030000
001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000
003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1h
HZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3n
d8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@00
05d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3o
d7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0
N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0
o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0
001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0
om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`00
0000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`00
0000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`00
0000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`00
0000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0
001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0
om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080
001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0
cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`0000000017
0000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om26
0?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?ooo`3oool0IP3oool00`000000001S
0000H`020000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb
0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<0
00000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<0
00000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`030000003oool0oooo06H0oooo00<0
00000000H`0006<00P0006<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<0
00000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o
0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H
0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`1V
0?ooo`030000000006<0001S0080001S00<000000000G@0005d01@0005d00`000000NfF^07]U[P0F
07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l
0?ooo`00_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX
/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003nd8/0o]2;0080o]2;00<000000?oo
o`3oool0IP3oool00`000000001S0000H`020000H`030000000005d0001M00D0001M00<0000007]U
[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb01P0cZRb00<000000?o@QP3od8H02`3od8H00`000000o]2;0?k@R`020?k@R`03
0000003oool0oooo06H0oooo00<000000000H`0006<00P0006<00`000000001M0000G@050000G@03
0000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>Z;800`000000om1k0?o@N`090?o@N`03
0000003oool0oooo0;`0oooo002o0?ooo`030000000004L0001700<0001700<0000007QR[@1hHZd0
5@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0om2600/0om2600<000000?k@R`3nd8/0
0P3nd8/00`000000oooo0?ooo`1V0?ooo`030000000006<0001S0080001S00<000000000G@0005d0
1@0005d00`000000NfF^07]U[P0F07]U[P030000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/0
2@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3oool00`00000000170000A`030000A`030000001h
HZd0N6:]01D0N6:]00<000000<jX/P3>Z;80603>Z;800`000000om260?o@QP0;0?o@QP030000003n
d8/0o]2;0080o]2;00<000000?ooo`3oool0503oooll000001H0oooo00<000000000H`0006<00P00
06<00`000000001M0000G@050000G@030000001kIJh0NfF^01H0NfF^00<000000<jX/P3>Z;80603>
Z;800`000000om1k0?o@N`090?o@N`030000003oool0oooo0;`0oooo002o0?ooo`030000000004L0
001700<0001700<0000007QR[@1hHZd05@1hHZd00`000000cZRb0<jX/P0H0<jX/P030000003od8H0
om2600/0om2600<000000?k@R`3nd8/00P3nd8/00`000000oooo0?ooo`0D000000T0WX6c00<00000
0;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@000000P3oool00`000000001S0000H`02
0000H`030000000005d0001M00D0001M00<0000007]U[P1kIJh05P1kIJh00`000000cZRb0<jX/P0H
0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<000000000
A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@030000003>Z;80cZRb01P0cZRb00<000000?o@
QP3od8H00P3od8HA000001d0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`0K0<RT
/a4000005`1kIJh00`000000cZRb0<jX/P0H0<jX/P030000003od7/0om1k00T0om1k00<000000?oo
o`3oool0_03oool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0E07QR[@03
0000003>Z;80cZRb0140cZRb3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02d
Tk@09P2dTk@00`000000b:Bc0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000;07]U[P03
0000003>Z;80cZRb01P0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00
_`3oool00`00000000170000A`030000A`030000001hHZd0N6:]01D0N6:]00<000000<jX/P3>Z;80
1@3>Z;8<00000180Q6b_00<0000009j1/`2NPK<04P2NPK=@000001@0b:Bc00<000000=^b[`3K/Zl0
403K/Zl<000001X0cZRb00<000000?o@N`3od7/02@3od7/00`000000oooo0?ooo`2l0?ooo`00_`3o
ool00`00000000170000A`030000A`030000001hHZd0N6:]01<0N6:]2P00000H08A/[a/00000D00h
^^@E000001h0fk:_2P00000@0<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03o
ool00;l0oooo00<000000000A`0004L00`0004L00`000000N6:]07QR[@0;07QR[@P000000`1SD:L0
0`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@000000>c0Y`3/`:L0k<2W2000
00080<jX/P030000003od7/0om1k00T0om1k00<000000?ooo`3oool0_03oool00;l0oooo00<00000
0000A`0004L00`0004L00`000000N6:]07QR[@0307QR[@P000002`1SD:L00`000000Q6b_08A/[`04
08A/[``00000WP0h^^@<000000H0fk:_00<000000>c0Y`3/`:L02@3/`:L9000000/0om1k00<00000
0?ooo`3oool0_03oool00;l0oooo00@000000000A`0004L000172000000@06=@Y`X00000]P0h^^@7
000001<0k<2W200000040?o@N`030000003oool0oooo0;`0oooo002m0?ooo`H00000401SD:L80000
0<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0He2W00T0
He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?ooo`D00000
1`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<V03jc9P0
1@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D00000[`3o
ool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo002U0?oo
o`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool200000003
0000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`000000080
0000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rji1h0>;[T
100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0001l00<0
000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0om1l0P00
002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000V`3oool0
09P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F0?ooo`80
0000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3000000H0001l
0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`0004/00000
100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool00940oooo
0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000003`a4/0
0P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540>;[T0P00
00050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[TE@0h^^@2
000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h^^@0>;[T
0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=0?ooo`04
0000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?ooo`2;0?oo
o`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000S@3oool0
08d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2000008`0
oooo002<0?ooo`8000005@0h^^@203Vji9X0>;[T00<0000003Rji00h^^@03@0h^^@00`3F[k40>;[T
03Rji02P03Rji0800000S03oool008`0oooo0P00000[03Rji0@0>K[TJ@0h^^@2000000<0001a2`0h
^^@908ab/@030000003F[k40eZna00L0eZna200h^^@00`3F[k40>;[T03Rji02N03Rji0800000S03o
ool008`0oooo00<0000003Rji00h^^@0?`0h^^@603Vji5P0>;[T00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0>;[T0P00002<0?ooo`00S03oool00`00
0000>;[T03Rji02K03Rji080001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma09d0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h
^^@0V00h^^@50000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@030?k?LIX0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h^^@0
U@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T09D0>;[T00<000000?ooo`3oool0
RP3oool008d0oooo00<0000003Rji00h^^@0<@0h^^@=03Vji5H0>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>K[T03Vji02D03Rji0030000003oool0oooo08/0oooo002>0?ooo`800000IP0h^^@I
03Vji1D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00=03Rji100>K[TM@0h^^@2
000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji00]03Rji0`0>K[TF00h^^@00`000000oooo0?ooo`2>0?ooo`00T@3oool00`000000
>;[T03Rji02@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@09P0h^^@00`0i^^@0
>;[T03Rji00T03Rji0P0>K[T>`0h^^@00`000000oooo0?ooo`2?0?ooo`00TP3oool200000900>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rji0@0>K[T7@0h^^@200000980oooo
002D0?ooo`030000000h^^@0>;[T08d0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i02=03Rji0030000003oool0oooo0980oooo002F0?ooo`800000S00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T08X0>;[T0P00002F0?ooo`00V03oool2000008X0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji02803Rji0800000V03oool009X0oooo0`00002703Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h^^@3000009X0oooo002M0?ooo`800000
Q@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08<0>;[T0P00002M0?ooo`00W`3o
ool2000008<0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02103Rji0800000W`3o
ool00:40oooo1000001o03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0O@0h^^@4
00000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T
07P0>;[T1@00002U0?ooo`00ZP3oool5000007D0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00000R03Rji0800000C00h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T06h0>;[T1@00002_0?ooo`00]03oool5000006/0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji01Y03Rji0D00000]03oool00;T0oooo1@00001V
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0I00h^^@500000;T0oooo002n0?oo
o`D00000H@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05l0>;[T1@00002n0?oo
o`00``3oool5000005`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01J03Rji0D0
0000``3oool00<P0oooo1@00001G03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
E@0h^^@500000<P0oooo003=0?ooo`L00000D00h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T04h0>;[T1`00003=0?ooo`00e03oool:000004H0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji01403Rji0X00000e03oool00=h0oooo2P00000l03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0>P0h^^@:00000=h0oooo003X0?ooo`d00000;`0h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T02d0>;[T3@00003X0?ooo`00m@3oool@000001l0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00M03Rji1000000m@3oool00?l0oooo1P3o
oolI000000H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00403Rji1T00000o`3o
ool60?ooo`00o`3ooolO0?ooo`L000001`0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg4700000?l0oooo7`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00<<0oooo0`00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool2
00000140oooo00<0000007YIX01jFJ001@00001I0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00[@3oool30000000307]^^P000000000000l0oooo00<0000007YI
X01jFJ001P1jFJ03000005H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Y0?ooo`@000001@1kK[X00`000000oooo0?ooo`0=0?ooo`030000001jFJ00NUVP00P0
NUVP00<000000?ooo`3oool0E03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:L0oooo0P00000907]^^P8000003P3oool00`000000NUVP07YIX00707YIX0800000
EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:L0oooo00<0
000007]^^P1kK[X0201kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02000005H0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0
Nfjj00L0Nfjj0P00000=0?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0oooo00<0000007]^
^P1kK[X0201kK[X00`30N@00oooo0?ooo`0;0?ooo`030000001jFJ00NUVP00P0NUVP00<000000?oo
o`3oool0E@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0
oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`0;0?ooo`030000001jFJ00NUVP00L0
NUVP0P00001G0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
Z03oool00`000000Nfjj07]^^P0807]^^P800000303oool00`000000NUVP07YIX00707YIX0800000
E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0
000007]^^P1kK[X01`1kK[X2000000/0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?oo
o`1F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool0
0`000000Nfjj07]^^P0807]^^P030<1i003oool0oooo00T0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YI
X01jFJ001`1jFJ02000005P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02@3oool00`000000
NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:X0oooo00<0000007]^^P1kK[X01`1kK[X00`30N@0000000?ooo`080?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X01`1kK[X2000000T0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1G0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000
oooo00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000
003oool01`3oool00`000000NUVP07YIX00707YIX0800000F@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X01`1kK[X2000000L0
oooo00<0000007YIX01jFJ001`1jFJ000`3M_[X000000?ooo`1I0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^^P800000
1`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05P0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0
`7T00000003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X0
0`30N@0000000?ooo`050?ooo`030000001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^
^P8000001@3oool00`000000NUVP07YIX00807YIX0800000FP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0
oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1I0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000
103oool00`000000NUVP07YIX00707YIX0800000F`3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:`0oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0
000007YIX01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00
NUVP00P0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002]0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0
NUVP0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[@3oool2000000T0Nfjj00D0`7T00000003oool0oooo0000000907YIX0800000G03oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X0
1`1kK[X2000000030?ooo`000000NUVP00T0NUVP0P00001L0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P@00000201j
FJ000`3M_[X000000000001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00[P3oool00`000000Nfjj07]^^P0807]^^P<000002@1jFJ02000005d0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`8000002@1kK[X30000
00T0NUVP0P00001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[`3oool00`000000Nfjj07]^^P0707]^^P800000201jFJ00103M_[X0NUVP0<S7AP00001M0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000
Nfjj07]^^P0707]^^P8000002@1jFJ02000005h0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ00
1`1jFJ02000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002_0?ooo`8000002@1kK[X00`000000NUVP07YIX00707YIX0800000GP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo00<0000007]^^P1kK[X01`1kK[X0
0`000000NUVP07YIX00707YIX0030<S7AP000000oooo05d0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YI
X01jFJ001@1jFJ02000005l0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002`0?ooo`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00000907]^^P030000
001jFJ00NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00/@3oool00`000000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00D0NUVP00<0
b<M60000003oool0GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;40oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00307YIX0<00000G`3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^
^P060000001jFJ00NUVP07YIX03M_[X0NUVP0P00001P0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/@3oool2000000T0Nfjj00<0000007YIX01jFJ000`1jFJ02
00000600oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?oo
o`030000001kK[X0Nfjj00L0Nfjj00<0000007YIX01jFJ000`1jFJ000`38adH000000?ooo`1O0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`000000
Nfjj07]^^P0807]^^P040000001jFJ00gKjj07YIX0<00000H03oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00;80oooo0P00000907]^^P040000001jFJ00NUVP07YI
X0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80
oooo0P00000907]^^P040000001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo00<0000007]^^P1kK[X01`1kK[X01P000000
gKjj07YIX01jFJ00b<M600000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002c0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX00000000P00001Q0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool2000000T0
Nfjj00@0000007YIX00000000000HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00;<0oooo0P00000907]^^P040000001jFJ00000000000680oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002d0?ooo`030000001kK[X0Nfjj00L0
Nfjj00@0000007YIX038adH00000HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00;@0oooo00<0000007]^^P1kK[X0201kK[X300000680oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooob<00000D`3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05@0oooo00<000000?ooo`3oool0b`3oool00:00oooo3P00
000<04PkWP030000003aa:<0lLBS00`0lLBS3`00001<0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0DP3oool20000000306<GE@000000oooo01L0oooo0P00002b0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0540oooo00D0000006<GE@1S5eD0HaME0000
000E0?ooo`<0000000<0?P0H0000003oool0/@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`1?0?ooo`8000001@1S5eD00`000000oooo0?ooo`0>0?ooo`@000000`0n01P2
00000;80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0CP3oool00`00
0000HaME06<GE@0506<GE@030000003oool0oooo00`0oooo0P00000703h060800000/P3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1<0?ooo`8000002@1S5eD00`000000
oooo0?ooo`0;0?ooo`030000000n01P0?P0H00H0?P0H0P00002b0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo04/0oooo00<0000006<GE@1S5eD02@1S5eD00`000000oooo
0?ooo`0:0?ooo`030000000n01P0?P0H00H0?P0H0P00002c0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo04/0oooo00<0000006<GE@1S5eD02P1S5eD00`000000oooo0?oo
o`090?ooo`030000000n01P0?P0H00H0?P0H0P00002c0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo04`0oooo00<0000006<GE@1S5eD02@1S5eD00`000000oooo0?ooo`09
0?ooo`030000000n01P0?P0H00D0?P0H0`00002c0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo04`0oooo00<0000006<GE@1S5eD02P1S5eD00`000000oooo0?ooo`070?oo
o`030000000n01P0?P0H00H0?P0H00<000000=c9B`000000/`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1=0?ooo`030000001S5eD0HaME00T0HaME00<000000?ooo`3o
ool01`3oool00`000000?P0H03h0600603h060030000003LbD/000000;<0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0C@3oool00`000000HaME06<GE@0:06<GE@030000
003oool0oooo00H0oooo00<0000003h0600n01P01@0n01P010000000g<U;0=c9B`00002c0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04h0oooo00<0000006<GE@1S5eD0
2@1S5eD00`000000oooo0?ooo`050?ooo`030000000n01P0?P0H00H0?P0H00<000000=c9B`000000
]03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1>0?ooo`030000001S
5eD0HaME00X0HaME00<000000?ooo`3oool0103oool00`000000?P0H03h0600603h060030000003L
bD/000000;@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0C`3oool0
0`000000HaME06<GE@0906<GE@030000003oool0oooo00<0oooo00<0000003h0600n01P01P0n01P0
10000000g<U;0=c9B`00002d0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo04l0oooo00<0000006<GE@1S5eD02P1S5eD00`000000oooo0?ooo`020?ooo`8000001`0n01P0
0`000000g<U;0000002e0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0500oooo00<0000006<GE@1S5eD02@1S5eD00`000000oooo0?ooo`020?ooo`<000001@0n01P20000
00030=c9B`000000oooo0;@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0D03oool00`000000HaME06<GE@0:06<GE@080000003oool000000000000Q03H000000>5b7`00
000403h060040000003LbD/0g<U;00000;D0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0D@3oool00`000000HaME06<GE@0906<GE@8000000`0Q03H00`000000hG8O0>5b
7`0200000080?P0H00<000000=c9B`000000]P3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`1A0?ooo`030000001S5eD0HaME00T0HaME00<000000240=P0Q03H00P0Q03H0
0`000000hG8O0>5b7`020>5b7`<0000000<0g<U;0000003oool0]@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000001S5eD0HaME00H0HaME0P0000050240
=P030000003QLQl0hG8O00<0hG8O00@000000=c9B`3LbD/00000]P3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000001S5eD0HaME00D0HaME00<000000240
=P0Q03H01@0Q03H00`000000hG8O0>5b7`040>5b7`800000]`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1C0?ooo`030000001S5eD0HaME00<0HaME00<000000240=P0Q
03H01`0Q03H00`000000hG8O0>5b7`040>5b7`030000003oool0oooo0;D0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0D`3oool010000000HaME06<GE@1S5eD2000000X0
8@0f00<000000>5b7`3QLQl01@3QLQl200000;D0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0E03oool00`000000HaME0000000<0240=P030000003QLQl0hG8O00L0hG8O
00<000000?ooo`3oool0/P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo04L0oooo?P00001C0?ooo`8000003@0Q03H00`000000hG8O0>5b
7`080>5b7`030000003oool0oooo0;40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`/000002@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om2600L0om262`0000170?ooo`8000003P0Q03H00`000000hG8O0>5b7`09
0>5b7`030000003oool0oooo0;00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@09`2dTk@2000001<0om2600<000000?ooo`3oool0A03oool00`0000008@0f0240=P0>0240
=P030000003QLQl0hG8O00X0hG8O00<000000?ooo`3oool0[`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0@`3oool00`0000008@0f0240=P0?0240=P030000003QLQl0hG8O00/0hG8O0P00002_0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`110?ooo`8000004P0Q03H00`000000hG8O0>5b7`0=0>5b7`030000
003oool0oooo0:`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0400oooo00<000000240=P0Q03H04P0Q
03H00`000000hG8O0>5b7`0>0>5b7`030000003oool0oooo0:/0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo03l0oooo00<000000240=P0Q03H04`0Q03H00`000000hG8O0>5b7`0?0>5b7`030000003oool0
oooo0:X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03d0oooo0P00000F0240=P030000003QLQl0hG8O
0100hG8O00<000000?ooo`3oool0Z@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?03oool00`000000
8@0f0240=P0F0240=P030000003QLQl0hG8O0140hG8O0P00002Y0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0k0?ooo`030000000Q03H08@0f01L08@0f00<000000>5b7`3QLQl04`3QLQl00`000000oooo
0?ooo`2V0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0i0?ooo`8000006`0Q03H00`000000hG8O0>5b
7`0C0>5b7`030000003oool0oooo0:D0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<00000
0240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b
7`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q
03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000
003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q
03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0
oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`00
0000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03P0
oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo03P0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O
0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<0
00000240=P0Q03H06P0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06P0Q03H00`000000hG8O0>5b7`0E
0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240
=P0Q03H06P0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0D0>5b7`03
0000003oool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H0
6`0Q03H00`000000hG8O0>5b7`0D0>5b7`030000003oool0oooo0:<0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003o
ool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H0
0`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo
0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000
hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo
00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b
7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<00000
0240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b
7`030000003oool0oooo0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q
03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:80oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0F0>5b7`030000
003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H06`0Q
03H00`000000hG8O0>5b7`0F0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo03T0oooo00<000000240=P0Q03H0700Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0
oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03T0oooo00<000000240=P0Q03H0700Q03H00`00
0000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0
oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O
0>5b7`0E0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<0
00000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E0>5b7`030000003oool0oooo0:40oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H06`0Q03H00`000000hG8O0>5b7`0E
0>5b7`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240
=P0Q03H06`0Q03H00`000000hG8O0>5b7`0F0>5b7`030000003oool0oooo0:00oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03X0oooo00<000000240=P0Q03H06P0Q03H00`000000Z;o[0000000G0>5b7`03
0000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H0
600Q03H2000000<0Z;o[0P00000E0>5b7`030000003oool0oooo0:00oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03X0oooo00<000000240=P0Q03H05`0Q03H00`000000Z;o[0:Roj`050:Roj`030000003Q
LQl0hG8O0180hG8O00<000000?ooo`3oool0X03oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>P3oool0
0`0000008@0f0240=P0F0240=P030000002X_n/0Z;o[00L0Z;o[00<000000>5b7`3QLQl04@3QLQl0
0`000000oooo0?ooo`2P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0j0?ooo`030000000Q03H08@0f
01@08@0f0P00000;0:Roj`030000003QLQl0hG8O0100hG8O00<000000?ooo`3oool0X03oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>P3oool00`0000008@0f0240=P0C0240=P8000003@2X_n/00`000000
hG8O0>5b7`0?0>5b7`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo
00<000000240=P0Q03H04P0Q03H00`000000Z;o[0:Roj`0>0:Roj`8000003`3QLQl00`000000oooo
0?ooo`2P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0j0?ooo`030000000Q03H08@0f01008@0f0P00
000C0:Roj`030000003QLQl0hG8O00`0hG8O00<000000?ooo`3oool0X03oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>P3oool00`0000008@0f0240=P0?0240=P8000005@2X_n/00`000000hG8O0>5b7`0<
0>5b7`030000003oool0oooo09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240
=P0Q03H03P0Q03H00`000000Z;o[0:Roj`0F0:Roj`030000003QLQl0hG8O00/0hG8O00<000000?oo
o`3oool0W`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>P3oool00`0000008@0f0240=P0<0240=P80
00006P2X_n/2000000/0hG8O00<000000?ooo`3oool0W`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>P3oool00`0000008@0f0240=P0;0240=P8000007@2X_n/00`000000hG8O0>5b7`080>5b7`030000
003oool0oooo09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03X0oooo00<000000240=P0Q03H02P0Q
03H2000001l0Z;o[00<000000>5b7`3QLQl01`3QLQl00`000000oooo0?ooo`2O0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0k0?ooo`030000000Q03H08@0f00L08@0f0P00000R0:Roj`030000003QLQl0
hG8O00H0hG8O00<000000?ooo`3oool0W`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
00008@0f0240=P060240=P800000902X_n/2000000H0hG8O00<000000?ooo`3oool0W`3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`0000008@0f0240=P050240=P8000009`2X_n/00`000000
hG8O0>5b7`030>5b7`030000003oool0oooo09l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03/0oooo
00<000000240=P0Q03H00`0Q03H3000002T0Z;o[00<000000>5b7`3QLQl00P3QLQl00`000000oooo
0?ooo`2O0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000Q03H08@0f00808@0f0P00
000/0:Roj`030000003QLQl0hG8O0080hG8O00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool0100000008@0f0240=P0Q03H2000002h0Z;o[00D000000>5b7`3QLQl0hG8O
0000002P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000Q03H0000000800000<02X
_n/2000000030>5b7`000000oooo09l0oooo002P0?ooo`0300000018>ih0B3^N00@0B3^N:0000008
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool3000000/0Z;o[90000005
0:Roj`800000X03oool009<0oooo5000000B04LjWP030000003aaJ<0lLFS01<0lLFS5`00000`0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo6`00000A05E5X`030000003eb9h0mLRN0100mLRN5000002C0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS0200EDFS00<0m<NP05E5X`1E
AJ<01P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<07P1EAJ<00`3daj00EDFS05E5X`0805E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0L05E5X`03
0?C7X01EAJ<0EDFS00X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01X0EDFS00<0m<NP05E5X`1EAJ<0301EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<06@1EAJ<00`3daj00EDFS05E5
X`0=05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0H05E5X`030?C7X01EAJ<0EDFS00h0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01H0
EDFS00<0m<NP05E5X`1EAJ<0401EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0_000001<03@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QRl000000P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75Xc4000000`0=2hH>000000<03@^600<000000;BC]02dTk@0:02dTk@D
0?o@QPT000002005000Q000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eT
N`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000:`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC
]0040000003od8H0om260?o@QT00[FAk0P00000F05E5X`030?C7X01EAJ<0EDFS0180EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@01000
0000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<20000
0400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000[05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/200d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000D05E5X`030?C7X01EAJ<0EDFS01@0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d02T0]9>d00<00000
0?o@QP2]I7/0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eT
N`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]I7/0@@2]I7/2000002/0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d02T0]9>d00<000000:eTN`2]
I7/0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;
QP000000]9>d02T0]9>d00<000000:eTN`2]I7/0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS0P0000130:eTN`030000002dTk@0]9>d02P0]9>d00<000000:eTN`2]I7/0@@2]
I7/200000180EDFS00<0m<NP05E5X`1EAJ<05P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2
000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`800000:`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02dTk@0:02dTkA40:eTN`80
0000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/200000100EDFS00<0m<NP05E5X`1EAJ<0601E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000h0EDFS00<0
m<NP05E5X`1EAJ<06P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/@2]I7/2000002/0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0G@2]I7/00`2^]]l0[FAk0:eTN`1B0:eTN`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk06@0[FAk00<0[[KO0:eTN`2]I7/0B`2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0K`2]I7/00`2^]]l0[FAk
0:eTN`100:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]I7/0[FAk07H0[FAk00<0[[KO0:eTN`2]I7/0>@2]I7/00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1m0:eTN`03
0:jfg`2]I7/0[FAk0380[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0Q02]I7/00`2^]]l0[FAk0:eTN`0[0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk
08/0[FAk00<0[[KO0:eTN`2]I7/0902]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eT
N`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ>f000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]
^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40
[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0C0?75XaL00000]02]^>4K00000140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS01<0lLFS5P2^
IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01@0[VEl5@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^IG`D
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0B0?75XaL0[VEl00<000000:fhh@2]^>40/P2]^>400`00
0000[VEl0:iUO00E0:iUO1@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^IG`00`000000
[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
4@3aaJ<H0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05P2^IG`C05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0@0?75XaT0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iU
O00G0:iUO180EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fhh@2`
0:fhh@8000006P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75Xa/0[VEl00<000000:fh
h@2]^>40/02]^>42000001X0[VEl4@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03P3aaJ<E0:iUO003
0?75X`2^IG`0[VEl00@0[VEl00<000000:fhh@2]^>40/02]^>42000001/0[VEl401EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<03P3aaJ<L0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000K0:iUO100EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00d0lLFS7@2^IG`00`000000[KSQ0:fhh@2`0:fhh@800000702^
IG`?05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0<0?75Xah0[VEl00<000000:fhh@2]^>40/02]^>42
000001`0[VEl3`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0702^IG`>05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0;0?75Xal0
[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M0:iUO0d0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00/0lLFS7`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0[VEl
3@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02P3aaJ<P0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`07P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75Xb40[VEl00<00000
0:fhh@2]^>40/02]^>400`000000[VEl0:iUO00N0:iUO0`0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01l0[VEl2`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0203aaJ<R0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^
IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]^>40
/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00L0lLFS8`2^
IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240[VEl2@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08@2^IG`9
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>400`00
0000[VEl0:iUO0050:iUO00305E5X`2^IG`0[VEl01X0[VEl201EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<01@3aaJ<U0:iUO0030000002]^>40[KSQ0380[KSQ00<0^iT60:fhh@2]^>40AP2]^>400`000000
[KSQ0:fhh@0b0:fhh@030000002^IG`0[VEl02<0[VEl1`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
1@3aaJ=J0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl
0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00@0lLFS?`2^IG`00`2]^>40[VEl0:iU
O00I0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iU
O00=0:iUO00305E5X`2^IG`0[VEl01@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ=>
0:iUO0030:fhh@2^IG`0[VEl00/0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b
0:iUO0030000002^IG`0[VEl02@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ=50:iU
O0030:fhh@2^IG`0[VEl01@0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iUO003
0;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00E0:iUO003
05E5X`2^IG`0[VEl00h0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=;0:iUO0030:fh
h@2^IG`0[VEl00l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000
002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00@000000?75X`3aaJ<0lLFSGP2^IG`00`2kV@H0[KSQ
0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09`2^IG`305E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`1H0:iUO0030:fhh@2^IG`0[VEl00@0[VEl00<0^iT60:fhh@2]^>40AP2]
^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<00000
0:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`00
0000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0EDFS0000003eb9h07P3eb9h70000
09<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ04H0
[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN0180
mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iUO02^IG`0G`2^IG`00`2kV@H00000
00000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`000000mLRN0?G8WP040?G8WPd00000
YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006000000000000I`00
002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fh
hP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fh
hP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00
^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003o
ool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`00
0000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0
oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fh
hP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<0
00000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?oo
o`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000
002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3o
ool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]
^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]
^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool0
0;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`00
00H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0
[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000
oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<0
00000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fh
hP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h
0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]
^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP03
0000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3o
ool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0
oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000
[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0
[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo
002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<00000
0?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]
^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3o
ool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`0=0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`000000oooo0?ooo`2i0?ooo`00^`3o
oomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
0`0@3HL01@3od8T040f7010=Q`0@3HL0000001@0]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7008040f700<0om29010=
Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@
3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T0
1@0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`040000000@3HL040f7
0?o@R@H040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f70?o@R@07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003]0?ooocl0000000<040f70000000@3HL01P0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om27?`00003]0?ooo`00k@3oool00`000000P`D608<5
1P0l08<51P03010=Q`231@H040f700H040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`060?o@Qcl0P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H0?@231@H8
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01@3od8M008<51P030000003oool0
oooo0>/0oooo003]0?ooo`03000000231@H0P`D603h0P`D61`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700@0om27@@231@H00`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000
P`D608<51P0o08<51PH040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`030?o@Qd80
P`D600<000000?ooo`3oool0j`3oool00>`0oooo00<0000008<51P231@H0?@231@H0100@3HL0P`D6
08<51P231@H5010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00P3od8M308<51P03
0000003oool0oooo0>/0oooo003/0?ooo`03000000231@H0P`D60480P`D6100@3HL00`000000]9>d
0;BC]00B0;BC]0040000003od8L0om270?o@QdD0P`D600<000000?ooo`3oool0jP3oool00>`0oooo
00<0000008<51P231@H0=0231@H00`2`[mL0P`D608<51P0808<51P03010=Q`231@H0P`D60080P`D6
0P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2704H0P`D600<000000?ooo`3oool0
jP3oool00>`0oooo00<0000008<51P231@H0<`231@H00`2`[mL0P`D608<51P0;08<51P06010=Q`23
1@H0P`D608<51P0@3HL00000502dTk@00`000000P`D608<51P1608<51P030000003oool0oooo0>X0
oooo003/0?ooo`03000000231@H0P`D60380P`D600<0/:oG08<51P231@H03P231@H2010=Q`0308<5
1P000000]9>d01<0]9>d00<0000008<51P231@H0AP231@H00`000000oooo0?ooo`3Z0?ooo`00k03o
oonX00000>`0oooo003Y0?ooo`@00000YP2aLhh00`000000oooo0?ooo`3Z0?ooo`00j03oool01@00
0000H@Y1064:@@1Q2T4000000:H0/G>>00<000000?ooo`3oool0jP3oool00>P0oooo00D00000064:
@@1Q2T40H@Y10000002V0;5cSP030000003oool0oooo0>X0oooo003W0?ooo`030000001Q2T40H@Y1
0080H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00i`3oool00`000000
H@Y1064:@@02064:@@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>H0oooo
00<00000064:@@1Q2T400`1Q2T400`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo
003U0?ooo`030000001Q2T40H@Y100@0H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?oo
o`3Z0?ooo`00i@3oool00`000000H@Y1064:@@04064:@@030000002aLhh0/G>>0:@0/G>>00<00000
0?ooo`3oool0jP3oool00>@0oooo00<00000064:@@1Q2T401@1Q2T400`000000/G>>0;5cSP2T0;5c
SP030000003oool0oooo0>X0oooo003T0?ooo`030000001Q2T40H@Y100D0H@Y100<000000;5cSP2a
Lhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00h`3oool00`000000H@Y1064:@@06064:@@030000
002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>80oooo00<00000064:@@1Q2T401`1Q
2T400`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003R0?ooo`030000001Q2T40
H@Y100L0H@Y100<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00h@3oool00`00
0000H@Y1064:@@08064:@@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>40
oooo00<00000064:@@1Q2T40201Q2T400`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0
oooo003P0?ooo`L000001@1Q2T400`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo
003Q0?ooo`0300000012S>d0@Xc]00<0@Xc]1P00002V0;5cSP030000003oool0oooo0>X0oooo003Q
0?ooo`8000002@12S>d00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003R0?oo
o`0300000012S>d0@Xc]00L0@Xc]00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?oo
o`00h`3oool00`000000@Xc]04:<k@0604:<k@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3o
ool0jP3oool00>@0oooo00<0000004:<k@12S>d01@12S>fX00000>`0oooo003T0?ooo`8000001P12
S>d00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003U0?ooo`0300000012S>d0
@Xc]00@0@Xc]00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00iP3oool00`00
0000@Xc]04:<k@0304:<k@030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>L0
oooo00<0000004:<k@12S>d00P12S>d00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0
oooo003W0?ooo`8000000`12S>d00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo
003X0?ooo`0500000012S>d0@Xc]04:<k@000000YP2`/=L00`000000oooo0?ooo`3Z0?ooo`00j@3o
ool400000:H0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L0
0`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo
0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`
e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?oo
o`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000
002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`
/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0
oooo0>X0oooo003/0?ooojP00000k03oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000
oooo0?ooo`3Z0?ooo`00k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo
003]0?ooo`030000001Fb?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3oool00>d0oooo00<00000
05K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?ooo`00k@3ooonV00000>d0oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.67497 .40982 m .64206 .41337 L .64206 .24609 L p .455 .372 .673 r
F P
0 g
s
.64206 .24609 m .67497 .24132 L .67497 .40982 L p .455 .372 .673 r
F P
0 g
s
.64206 .41337 m .60403 .41234 L .60403 .24471 L p .762 .622 .705 r
F P
0 g
s
.60403 .24471 m .64206 .24609 L .64206 .41337 L p .762 .622 .705 r
F P
0 g
s
.67497 .40982 m .67497 .24132 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.6838 .40365 m .68128 .40541 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.68128 .40541 m .67497 .40982 L p .68128 .35732 L 0 0 .305 r
F P
0 g
s
.68795 .26519 m .69297 .25307 L p .68128 .23784 L .627 .512 .703 r
F P
0 g
s
.64206 .24609 m .67497 .24132 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.63385 .17608 m .67018 .23593 L .67947 .23548 L .627 .512 .703 r
F
.65153 .23683 m .64206 .24609 L .6706 .23591 L .289 .763 .934 r
F
.68128 .27508 m .68795 .26519 L p .68128 .25421 L .627 .512 .703 r
F P
0 g
s
.68128 .25421 m .68795 .26519 L .68128 .23784 L .627 .512 .703 r
F
.67497 .24132 m .68128 .23539 L p .68128 .27508 L 0 0 .305 r
F P
0 g
s
.67749 .28759 m .68128 .27508 L .68128 .35732 L 0 0 .305 r
F
.67497 .24132 m .68128 .27508 L .67749 .28759 L F
.68128 .27508 m .68795 .26519 L .68724 .26433 L p .839 .983 .698 r
F P
0 g
s
.68724 .26433 m .68527 .26192 L p .6838 .26677 L .839 .983 .698 r
F P
0 g
s
.68128 .27508 m .68724 .26433 L .6838 .26677 L .839 .983 .698 r
F
.68128 .35732 m .68302 .27163 L .6838 .40365 L 0 0 .305 r
F
.69297 .25307 m .69545 .24026 L p .68128 .2255 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .67947 .23548 L .68128 .2255 L .627 .512 .703 r
F
.67947 .23548 m .68128 .23539 L .68128 .2255 L F
.68128 .23784 m .69297 .25307 L .68128 .2255 L F
.63385 .17608 m .66201 .23632 L .67018 .23593 L F
.69545 .24026 m .69525 .22733 L p .63385 .17608 L F P
0 g
s
.68961 .24884 m .6921 .23595 L p .68698 .23061 L .627 .512 .703 r
F P
0 g
s
.58855 .23114 m .57468 .24054 L .58106 .24023 L .627 .512 .703 r
F
.58855 .23987 m .60403 .24471 L p .62465 .23813 L .289 .763 .934 r
F P
0 g
s
.57479 .24786 m .57759 .26023 L p .58855 .24384 L .627 .512 .703 r
F P
0 g
s
.58855 .23987 m .60403 .24471 L p .59069 .28168 L .985 .804 .58 r
F P
0 g
s
.58855 .27908 m .59069 .28168 L .58855 .28763 L .985 .804 .58 r
F
.58855 .23987 m .59069 .28168 L .58855 .27908 L F
.58288 .27163 m .58855 .27908 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.58855 .23114 m .57479 .24786 L .58855 .24384 L .627 .512 .703 r
F
.57759 .26023 m .58288 .27163 L p .63385 .17608 L F P
0 g
s
.60403 .24471 m .60403 .41234 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.60403 .24471 m .64206 .24609 L p .65153 .23683 L .289 .763 .934 r
F P
0 g
s
.62465 .23813 m .60403 .24471 L .65153 .23683 L .289 .763 .934 r
F
.58288 .27163 m .59043 .28155 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58238 .23794 m .58855 .23987 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.58238 .40731 m .58238 .27287 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.57759 .26023 m .58023 .26593 L p .58012 .26886 L .765 .382 0 r
F P
0 g
s
.58023 .26593 m .58288 .27163 L .58159 .27034 L p .765 .382 0 r
F P
0 g
s
.58159 .27034 m .58012 .26886 L p .58023 .26593 L .765 .382 0 r
F P
0 g
s
.58238 .27287 m .58238 .27159 L p .58794 .28277 L .985 .804 .58 r
F P
0 g
s
.58288 .27163 m .58414 .27373 L .58238 .27159 L .613 .149 0 r
F
.58012 .26886 m .58159 .27034 L p .58238 .27159 L F P
0 g
s
.58159 .27034 m .58288 .27163 L p .58238 .27159 L .613 .149 0 r
F P
0 g
s
.58238 .27159 m .58238 .23794 L p .5873 .27756 L .985 .804 .58 r
F P
0 g
s
.63385 .17608 m .58855 .23114 L .58855 .24384 L .627 .512 .703 r
F
.59043 .28155 m .59993 .28958 L p .63385 .17608 L F P
0 g
s
.59993 .28958 m .61096 .29535 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.61096 .29535 m .62304 .29861 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.62304 .29861 m .63566 .29921 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.67124 .28531 m .6806 .2761 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.66031 .29242 m .67124 .28531 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.64827 .29712 m .66031 .29242 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63566 .29921 m .64827 .29712 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58238 .23794 m .58855 .23987 L p .62082 .23383 L .289 .763 .934 r
F P
0 g
s
.60478 .23461 m .58238 .23794 L .62082 .23383 L .289 .763 .934 r
F
.5873 .27756 m .58794 .28277 L .58238 .27159 L .985 .804 .58 r
F
.59043 .28155 m .58643 .27755 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.58855 .27908 m .59043 .28155 L p .58414 .27373 L .613 .149 0 r
F P
0 g
s
.64121 .23284 m .58855 .23987 L .62465 .23813 L .289 .763 .934 r
F
.62082 .23383 m .58855 .23987 L .64121 .23284 L F
.58643 .27755 m .59599 .28562 L p .61132 .23429 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .58855 .22117 L .58855 .23114 L .627 .512 .703 r
F
.57703 .22234 m .5746 .23505 L p .63385 .17608 L F P
0 g
s
.58197 .2103 m .57703 .22234 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.58922 .19943 m .58197 .2103 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.59846 .19022 m .58922 .19943 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.6093 .18307 m .59846 .19022 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .62127 .17828 L .6093 .18307 L p .627 .512 .703 r
F P
0 g
s
.63385 .17608 m .62127 .17828 L .61746 .17359 L p .405 .837 .952 r
F P
0 g
s
.61746 .17359 m .63012 .17137 L .63385 .17608 L p .405 .837 .952 r
F P
0 g
s
.63012 .17137 m .60408 .23464 L .61132 .23429 L .627 .512 .703 r
F
.5746 .23505 m .57468 .24054 L p .58855 .23114 L F P
0 g
s
.58855 .22117 m .5746 .23505 L .58855 .23114 L .627 .512 .703 r
F
.63012 .17137 m .58454 .22681 L .58729 .23546 L F
.58454 .22681 m .57701 .23596 L .58454 .23559 L F
.58454 .22681 m .58454 .23559 L .58729 .23546 L F
.58238 .23794 m .58238 .27159 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.58902 .23538 m .58872 .237 L p .60478 .23461 L .289 .763 .934 r
F P
0 g
s
.58454 .23559 m .58238 .23794 L p .58454 .23762 L .289 .763 .934 r
F P
0 g
s
.58454 .23559 m .58238 .23794 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.58238 .27159 m .58238 .27287 L p .58255 .27188 L 0 0 .269 r
F P
0 g
s
.58414 .27373 m .58643 .27755 L .58401 .27421 L .613 .149 0 r
F
.58238 .27159 m .58401 .27421 L .58012 .26886 L F
.58414 .27373 m .58401 .27421 L .58238 .27159 L F
.58794 .28277 m .58855 .28763 L .58238 .27287 L .985 .804 .58 r
F
.58788 .28041 m .58238 .27287 L .58749 .2894 L 0 0 .269 r
F
.59618 .23503 m .58454 .24584 L .58454 .25686 L .627 .512 .703 r
F
.63012 .17137 m .58729 .23546 L .59618 .23503 L F
.58729 .23546 m .58454 .23959 L .59618 .23503 L F
.57479 .24786 m .57759 .26023 L .57351 .25609 L p .87 .585 .06 r
F P
0 g
s
.58454 .23959 m .57351 .25609 L .58454 .24584 L .627 .512 .703 r
F
.58454 .23959 m .58454 .24584 L .59618 .23503 L F
.63012 .17137 m .58454 .25686 L .58643 .27755 L F
.58255 .27188 m .58238 .27287 L .58454 .27583 L 0 0 .269 r
F
.58255 .27188 m .58454 .27583 L .58454 .27506 L F
.57883 .26756 m .58012 .26886 L p .58454 .27494 L .613 .149 0 r
F P
0 g
s
.58454 .27494 m .58643 .27755 L .57883 .26756 L .613 .149 0 r
F
.58454 .26073 m .58255 .27188 L .58454 .27506 L 0 0 .269 r
F
.58454 .26073 m .58238 .27159 L .58255 .27188 L F
.58454 .25981 m .58238 .27159 L .58454 .26073 L F
.58012 .26886 m .57883 .26756 L p .57859 .26613 L .765 .382 0 r
F P
0 g
s
.57759 .26023 m .58012 .26886 L .57859 .26613 L .765 .382 0 r
F
.57883 .26756 m .58454 .27506 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .27506 m .58643 .27755 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .27506 m .58454 .27583 L .58788 .28041 L 0 0 .269 r
F
.59599 .28562 m .60708 .29142 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.60708 .29142 m .61925 .2947 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.65637 .2321 m .62465 .23813 L .65153 .23683 L .289 .763 .934 r
F
.64121 .23284 m .62465 .23813 L .65637 .2321 L F
.61925 .2947 m .63195 .2953 L p .63103 .23333 L .627 .512 .703 r
F P
0 g
s
.63012 .17137 m .62463 .23364 L .63103 .23333 L .627 .512 .703 r
F
.62463 .23364 m .61925 .2947 L .63103 .23333 L F
.68302 .27163 m .6838 .23303 L .6838 .40365 L 0 0 .305 r
F
.68128 .23539 m .6838 .23303 L p .68128 .35732 L F P
0 g
s
.6806 .2761 m .68128 .27508 L p .67018 .23593 L .627 .512 .703 r
F P
0 g
s
.67018 .23593 m .68128 .27508 L .68128 .25421 L .627 .512 .703 r
F
.66201 .23632 m .6806 .2761 L .67018 .23593 L F
.67497 .24132 m .68128 .23539 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.67947 .23548 m .68128 .25421 L .68128 .23784 L .627 .512 .703 r
F
.67018 .23593 m .68128 .25421 L .67947 .23548 L F
.6838 .26677 m .6838 .23303 L p .67904 .27016 L .989 .807 .569 r
F P
0 g
s
.6671 .23158 m .65153 .23683 L .6706 .23591 L .289 .763 .934 r
F
.65637 .2321 m .65153 .23683 L .6671 .23158 L F
.63012 .17137 m .65845 .232 L .66668 .2316 L .627 .512 .703 r
F
.65845 .232 m .67716 .27203 L .66668 .2316 L F
.6838 .23303 m .67785 .23106 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.68128 .23539 m .6838 .23303 L p .6706 .23591 L .289 .763 .934 r
F P
0 g
s
.67947 .23548 m .68128 .23784 L .68128 .23539 L .627 .512 .703 r
F
.67124 .28531 m .6806 .2761 L .67716 .27203 L p .756 .993 .8 r
F P
0 g
s
.6838 .23303 m .67785 .23106 L p .67785 .27101 L .989 .807 .569 r
F P
0 g
s
.67716 .27203 m .6806 .2761 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.67785 .27101 m .67716 .27203 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.67904 .27016 m .67785 .27101 L .67785 .27946 L .989 .807 .569 r
F
.6838 .23303 m .67785 .27101 L .67904 .27016 L F
.68456 .26105 m .67785 .27101 L p .68288 .26743 L .839 .983 .698 r
F P
0 g
s
.6671 .23158 m .6706 .23591 L .67785 .23106 L .289 .763 .934 r
F
.68456 .26105 m .68961 .24884 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.66775 .2813 m .67716 .27203 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .65637 .2321 L .6671 .23158 L .289 .763 .934 r
F
.66775 .2813 m .65674 .28846 L .66031 .29242 L p .649 .969 .874 r
F P
0 g
s
.66031 .29242 m .67124 .28531 L .66775 .2813 L p .649 .969 .874 r
F P
0 g
s
.67716 .27203 m .66775 .2813 L .67124 .28531 L p .756 .993 .8 r
F P
0 g
s
.65674 .28846 m .66775 .2813 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .6626 .39843 L p .67785 .27946 L .989 .807 .569 r
F P
0 g
s
.67716 .27203 m .67785 .27101 L p .66668 .2316 L .627 .512 .703 r
F P
0 g
s
.66668 .2316 m .67785 .27101 L .67785 .25 L .627 .512 .703 r
F
.64649 .17657 m .63385 .17608 L .63012 .17137 L p .236 .716 .934 r
F P
0 g
s
.65864 .17973 m .64649 .17657 L .63385 .17608 L p .627 .512 .703 r
F P
0 g
s
.66977 .18544 m .65864 .17973 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.67937 .19344 m .66977 .18544 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.68703 .20339 m .67937 .19344 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.69241 .21486 m .68703 .20339 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.69525 .22733 m .69241 .21486 L p .63385 .17608 L .627 .512 .703 r
F P
0 g
s
.63012 .17137 m .67602 .23115 L .68698 .23061 L .627 .512 .703 r
F
.67602 .23115 m .68961 .24884 L .68698 .23061 L F
.67785 .23106 m .6626 .22601 L p .6671 .23158 L .289 .763 .934 r
F P
0 g
s
.67785 .23106 m .6626 .22601 L p .67785 .27946 L .989 .807 .569 r
F P
0 g
s
.67785 .27101 m .68456 .26105 L p .67785 .25 L .627 .512 .703 r
F P
0 g
s
.64463 .29319 m .65674 .28846 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6626 .22601 m .64121 .23284 L .65637 .2321 L .289 .763 .934 r
F
.63195 .2953 m .64463 .29319 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.59008 .22957 m .58902 .23538 L p .6626 .22601 L .289 .763 .934 r
F P
0 g
s
.6626 .22601 m .58902 .23538 L .60478 .23461 L .289 .763 .934 r
F
.60408 .23464 m .58643 .27755 L .61132 .23429 L .627 .512 .703 r
F
.59599 .28562 m .58643 .27755 L .59043 .28155 L p 0 .093 .572 r
F P
0 g
s
.59008 .22957 m .58454 .26073 L .58788 .28041 L 0 0 .269 r
F
.58454 .26073 m .58454 .27506 L .58788 .28041 L F
.59008 .22957 m .58454 .25981 L .58454 .26073 L F
.57883 .26756 m .57351 .25609 L .57759 .26023 L p .765 .382 0 r
F P
0 g
s
.57351 .25609 m .57883 .26756 L p .58454 .25686 L .627 .512 .703 r
F P
0 g
s
.58454 .24584 m .57351 .25609 L .58454 .25686 L .627 .512 .703 r
F
.57468 .24054 m .57479 .24786 L p .58106 .24023 L F P
0 g
s
.5746 .23505 m .57479 .24786 L .57069 .24364 L p .927 .748 .265 r
F P
0 g
s
.57351 .25609 m .57069 .24364 L .57479 .24786 L p .87 .585 .06 r
F P
0 g
s
.57069 .24364 m .57351 .25609 L p .58729 .23546 L .627 .512 .703 r
F P
0 g
s
.57701 .23596 m .57069 .24364 L .58729 .23546 L .627 .512 .703 r
F
.59008 .22957 m .58454 .23559 L p .58454 .25981 L 0 0 .269 r
F P
0 g
s
.6626 .22601 m .62082 .23383 L .64121 .23284 L .289 .763 .934 r
F
.6626 .22601 m .60478 .23461 L .62082 .23383 L F
.58238 .27287 m .58238 .40731 L p .58749 .2894 L 0 0 .269 r
F P
0 g
s
.60403 .41234 m .58855 .40874 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.58855 .40874 m .58238 .40731 L p .58855 .28763 L .985 .804 .58 r
F P
0 g
s
.6626 .39843 m .6838 .40365 L .6838 .26677 L p .989 .807 .569 r
F P
0 g
s
.6806 .2761 m .68128 .27508 L p .68456 .26105 L .839 .983 .698 r
F P
0 g
s
.68527 .26192 m .68456 .26105 L p .68128 .27508 L .839 .983 .698 r
F P
0 g
s
.67904 .27016 m .6626 .39843 L .6838 .26677 L .989 .807 .569 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64206 .41337 m .67497 .40982 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.60403 .41234 m .64206 .41337 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.67497 .40982 m .6838 .40365 L .6626 .39843 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.58238 .40731 m .59008 .40107 L .59008 .22957 L p 0 0 .269 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58238 .40731 m .60403 .41234 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.4115 .40982 m .3805 .41337 L .3805 .24609 L p .439 .358 .669 r
F P
0 g
s
.3805 .41337 m .34192 .41234 L .34192 .24471 L p .761 .621 .705 r
F P
0 g
s
.34192 .24471 m .3805 .24609 L .3805 .41337 L p .761 .621 .705 r
F P
0 g
s
.63566 .29921 m .64827 .29712 L .64463 .29319 L p .365 .821 .93 r
F P
0 g
s
.65674 .28846 m .64463 .29319 L .64827 .29712 L p .518 .912 .918 r
F P
0 g
s
.64827 .29712 m .66031 .29242 L .65674 .28846 L p .518 .912 .918 r
F P
0 g
s
.62344 .39734 m .6626 .39843 L .6626 .22601 L p .763 .623 .705 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6769 .93127 m .66235 .92198 L .67668 .91427 L closepath p .783 .577 .623 r
F P
0 g
s
.68266 .91 m .70188 .89629 L p .69105 .91145 L 0 0 .35 r
F P
0 g
s
.70188 .89629 m .67668 .91427 L p .68658 .90477 L .407 .835 .68 r
F P
0 g
s
.69446 .90034 m .70188 .89629 L .68658 .90477 L .407 .835 .68 r
F
.697 .89891 m .70188 .89629 L p .68691 .90446 L F P
0 g
s
.70188 .89629 m .70189 .89663 L p .6769 .93127 L 0 0 .35 r
F P
0 g
s
.68289 .9271 m .6769 .93127 L p .70189 .89663 L 0 0 .35 r
F P
0 g
s
.68693 .90527 m .697 .89891 L p .69937 .90066 L .678 .976 .889 r
F P
0 g
s
.69507 .90756 m .69937 .90066 L .71704 .91374 L .678 .976 .889 r
F
.68693 .90527 m .69937 .90066 L .69507 .90756 L F
.697 .89891 m .70188 .89629 L .70189 .89663 L p .785 .577 .62 r
F P
0 g
s
.70227 .89601 m .70254 .89632 L p .697 .89891 L .678 .976 .889 r
F P
0 g
s
.70254 .89632 m .71704 .91374 L p .697 .89891 L .678 .976 .889 r
F P
0 g
s
.71704 .91374 m .7023 .92303 L .68693 .90527 L p .678 .976 .889 r
F P
0 g
s
.69249 .9117 m .7023 .92303 L p .7023 .91346 L 0 .34 .752 r
F P
0 g
s
.7023 .9134 m .70213 .91337 L .7023 .91346 L 0 .34 .752 r
F
.70213 .91337 m .69249 .9117 L .7023 .91346 L F
.70189 .89663 m .70214 .91371 L .68289 .9271 L p 0 0 .35 r
F P
0 g
s
.70199 .91329 m .69717 .91031 L .69824 .90248 L .785 .577 .62 r
F
.69717 .91031 m .69708 .90434 L .69824 .90248 L F
.69717 .91053 m .68693 .90527 L .697 .89891 L p .614 .44 .623 r
F P
0 g
s
.68691 .90446 m .69446 .90034 L .68658 .90477 L .407 .835 .68 r
F
.6769 .93127 m .67668 .91427 L .68266 .91 L p 0 0 .35 r
F P
0 g
s
.69105 .91145 m .6769 .93127 L .68266 .91 L 0 0 .35 r
F
.67668 .91427 m .66235 .92198 L .68645 .90472 L p .407 .835 .68 r
F P
0 g
s
.68691 .90446 m .67668 .91427 L .68645 .90472 L .407 .835 .68 r
F
.66668 .894 m .6965 .86458 L p .69717 .91053 L .703 .511 .626 r
F P
0 g
s
.68645 .90472 m .68722 .90416 L p .68691 .90446 L .407 .835 .68 r
F P
0 g
s
.65581 .90472 m .66668 .894 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.66235 .92198 m .6769 .93127 L .70214 .91371 L p .132 .507 .91 r
F P
0 g
s
.68722 .90416 m .697 .89891 L p .68733 .90423 L .407 .835 .68 r
F P
0 g
s
.68722 .90416 m .68733 .90423 L p .68691 .90446 L .407 .835 .68 r
F P
0 g
s
.69717 .91053 m .68722 .90416 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.68693 .90527 m .69249 .9117 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.69717 .91053 m .68693 .90527 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.7023 .91331 m .70193 .91325 L .7023 .9134 L 0 .34 .752 r
F
.70193 .91325 m .69249 .9117 L .70213 .91337 L F
.70199 .91329 m .697 .89891 L .70213 .91337 L .785 .577 .62 r
F
.70193 .91325 m .70213 .91337 L .7023 .9134 L 0 .34 .752 r
F
.70189 .89663 m .70213 .91337 L p .697 .89891 L .785 .577 .62 r
F P
0 g
s
.70213 .91337 m .70214 .91371 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.70192 .91311 m .69249 .9117 L .7023 .91331 L 0 .34 .752 r
F
.70214 .91371 m .69717 .91053 L p .66235 .92198 L .132 .507 .91 r
F P
0 g
s
.69717 .91053 m .68722 .90416 L .68645 .90472 L p .132 .507 .91 r
F P
0 g
s
.68645 .90472 m .66235 .92198 L p .69717 .91053 L .132 .507 .91 r
F P
0 g
s
.69442 .90861 m .68722 .90416 L .69705 .90266 L .785 .577 .62 r
F
.69708 .90434 m .69705 .90266 L .69824 .90248 L F
.69442 .90861 m .69705 .90266 L .69708 .90434 L F
.68722 .90416 m .697 .89891 L p .69824 .90248 L F P
0 g
s
.70214 .91371 m .69717 .91053 L p .70199 .91329 L .785 .577 .62 r
F P
0 g
s
.71731 .93075 m .7023 .92303 L .71704 .91374 L closepath p .616 .444 .625 r
F P
0 g
s
.7023 .92303 m .71731 .93075 L .70253 .91344 L p 0 .34 .752 r
F P
0 g
s
.69717 .91053 m .6965 .86458 L .70201 .87824 L .703 .511 .626 r
F
.71731 .93075 m .71704 .91374 L .70227 .89601 L p .908 .711 .21 r
F P
0 g
s
.70228 .89627 m .71731 .93075 L .70227 .89601 L .908 .711 .21 r
F
.69717 .91053 m .70201 .87824 L .70253 .91344 L .703 .511 .626 r
F
.697 .89891 m .70204 .89573 L .70227 .89601 L p .678 .976 .889 r
F P
0 g
s
.70204 .89573 m .7023 .91316 L .70253 .91344 L p .908 .711 .21 r
F P
0 g
s
.70253 .91344 m .71731 .93075 L p .70228 .89627 L .908 .711 .21 r
F P
0 g
s
.70204 .89573 m .70253 .91344 L .70228 .89627 L .908 .711 .21 r
F
.7023 .91331 m .7023 .92303 L .70253 .91344 L 0 .34 .752 r
F
.69767 .94509 m .69717 .91053 L .70253 .91344 L .703 .511 .626 r
F
.72002 .92292 m .70293 .93987 L p .70253 .91344 L F P
0 g
s
.70293 .93987 m .69767 .94509 L p .70253 .91344 L .703 .511 .626 r
F P
0 g
s
.70253 .91344 m .70201 .87824 L .72002 .92292 L .703 .511 .626 r
F
.70227 .89601 m .70204 .89573 L p .70228 .89627 L .908 .711 .21 r
F P
0 g
s
.70253 .91344 m .7023 .91316 L p .7023 .91331 L 0 .34 .752 r
F P
0 g
s
.6965 .86458 m .73836 .90472 L .72002 .92292 L p .703 .511 .626 r
F P
0 g
s
.7023 .91316 m .70192 .91311 L .7023 .91331 L 0 .34 .752 r
F
.69767 .94509 m .66694 .91545 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.66694 .91545 m .65581 .90472 L p .6765 .91019 L .703 .511 .626 r
F P
0 g
s
.69767 .94509 m .66668 .894 L .69717 .91053 L .703 .511 .626 r
F
.7023 .91316 m .69717 .91053 L p .70192 .91311 L 0 .34 .752 r
F P
0 g
s
.7023 .91316 m .69717 .91053 L p .697 .89891 L .614 .44 .623 r
F P
0 g
s
.69717 .91031 m .69442 .90861 L .69708 .90434 L .785 .577 .62 r
F
.697 .89891 m .70204 .89573 L .70204 .89607 L p .614 .44 .623 r
F P
0 g
s
.70204 .89607 m .7023 .91316 L p .697 .89891 L .614 .44 .623 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.3805 .24609 m .4115 .24132 L .4115 .40982 L p .439 .358 .669 r
F P
0 g
s
.31082 .23505 m .3109 .24054 L p .32449 .23114 L .626 .511 .703 r
F P
0 g
s
.3109 .24054 m .311 .24786 L p .31716 .24023 L .626 .511 .703 r
F P
0 g
s
.32449 .23114 m .3109 .24054 L .31716 .24023 L .626 .511 .703 r
F
.32449 .23987 m .34192 .24471 L p .3599 .23813 L .289 .763 .934 r
F P
0 g
s
.311 .24786 m .31375 .26023 L p .32449 .24384 L .626 .511 .703 r
F P
0 g
s
.32449 .23987 m .34192 .24471 L p .32691 .28168 L .974 .795 .601 r
F P
0 g
s
.32449 .27908 m .32691 .28168 L .32449 .28763 L .974 .795 .601 r
F
.32449 .23987 m .32691 .28168 L .32449 .27908 L F
.31893 .27163 m .32449 .27908 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.32449 .23114 m .311 .24786 L .32449 .24384 L .626 .511 .703 r
F
.31375 .26023 m .31893 .27163 L p .36892 .17608 L F P
0 g
s
.31893 .27163 m .32634 .28155 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.31755 .23794 m .32449 .23987 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.31755 .40731 m .31755 .27287 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.31375 .26023 m .31634 .26593 L p .31502 .26886 L .841 .454 0 r
F P
0 g
s
.31634 .26593 m .31893 .27163 L .31711 .27034 L p .841 .454 0 r
F P
0 g
s
.31711 .27034 m .31502 .26886 L p .31634 .26593 L .841 .454 0 r
F P
0 g
s
.31755 .27287 m .31755 .27159 L p .32382 .28277 L .974 .795 .601 r
F P
0 g
s
.31893 .27163 m .31954 .27373 L .31755 .27159 L .698 .226 0 r
F
.31502 .26886 m .31711 .27034 L p .31755 .27159 L F P
0 g
s
.31711 .27034 m .31893 .27163 L p .31755 .27159 L .698 .226 0 r
F P
0 g
s
.31755 .27159 m .31755 .23794 L p .32309 .27756 L .974 .795 .601 r
F P
0 g
s
.36892 .17608 m .32449 .23114 L .32449 .24384 L .626 .511 .703 r
F
.34192 .24471 m .34192 .41234 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.34192 .24471 m .3805 .24609 L p .38626 .23683 L .289 .763 .934 r
F P
0 g
s
.3599 .23813 m .34192 .24471 L .38626 .23683 L .289 .763 .934 r
F
.32634 .28155 m .33565 .28958 L p .3506 .23859 L .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .34355 .23893 L .3506 .23859 L .626 .511 .703 r
F
.34355 .23893 m .32634 .28155 L .3506 .23859 L F
.34647 .29535 m .35833 .29861 L p .36892 .17608 L F P
0 g
s
.35833 .29861 m .3707 .29921 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3805 .24609 m .4115 .24132 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.38626 .23683 m .3805 .24609 L .40496 .23591 L .289 .763 .934 r
F
.4115 .40982 m .4115 .24132 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41701 .40365 m .41544 .40541 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41544 .40541 m .4115 .40982 L p .41544 .35732 L 0 0 .202 r
F P
0 g
s
.41544 .27508 m .42198 .26519 L p .41544 .25421 L .626 .511 .703 r
F P
0 g
s
.41544 .23784 m .42691 .25307 L .41947 .23519 L .626 .511 .703 r
F
.41544 .23539 m .41947 .23519 L .41544 .2255 L F
.41544 .23784 m .41947 .23519 L .41544 .23539 L F
.4115 .24132 m .41544 .23539 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.4115 .24132 m .41544 .23539 L p .41544 .27508 L 0 0 .202 r
F P
0 g
s
.41307 .28759 m .41544 .27508 L .41544 .35732 L 0 0 .202 r
F
.4115 .24132 m .41544 .27508 L .41307 .28759 L F
.41544 .27508 m .42198 .26519 L .42091 .26433 L p .872 .991 .74 r
F P
0 g
s
.42091 .26433 m .41793 .26192 L p .41701 .26677 L .872 .991 .74 r
F P
0 g
s
.41544 .27508 m .42091 .26433 L .41701 .26677 L .872 .991 .74 r
F
.41544 .35732 m .41655 .26929 L .41701 .40365 L 0 0 .202 r
F
.42198 .26519 m .42691 .25307 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42181 .24884 m .4186 .25675 L p .42198 .26519 L .929 .953 .625 r
F P
0 g
s
.41655 .26929 m .41701 .23303 L .41701 .26906 L 0 0 .202 r
F
.41544 .23539 m .41701 .23303 L p .41544 .35732 L F P
0 g
s
.41477 .2761 m .41544 .27508 L p .40455 .23593 L .626 .511 .703 r
F P
0 g
s
.40455 .23593 m .41544 .27508 L .41544 .25421 L .626 .511 .703 r
F
.39654 .23632 m .41477 .2761 L .40455 .23593 L F
.40559 .28531 m .41477 .2761 L p .36892 .17608 L F P
0 g
s
.41701 .26677 m .41701 .23303 L p .41162 .27016 L .979 .799 .592 r
F P
0 g
s
.4186 .25675 m .41685 .26105 L .41793 .26192 L p .929 .953 .625 r
F P
0 g
s
.41793 .26192 m .42198 .26519 L p .4186 .25675 L .929 .953 .625 r
F P
0 g
s
.41656 .27254 m .41701 .26906 L .41701 .40365 L 0 0 .202 r
F
.41655 .26929 m .41701 .26906 L .41656 .27254 L F
.393 .39843 m .41701 .40365 L .41701 .26677 L p .979 .799 .592 r
F P
0 g
s
.41477 .2761 m .41544 .27508 L p .41685 .26105 L .872 .991 .74 r
F P
0 g
s
.41793 .26192 m .41685 .26105 L p .41544 .27508 L .872 .991 .74 r
F P
0 g
s
.40559 .28531 m .41477 .2761 L .40959 .27203 L p .788 .999 .829 r
F P
0 g
s
.40959 .27203 m .41477 .2761 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41496 .2372 m .41544 .23784 L .41544 .23623 L .626 .511 .703 r
F
.41496 .2372 m .41544 .23623 L .41544 .2255 L F
.36892 .17608 m .41496 .2372 L .41544 .2255 L F
.39487 .29242 m .40559 .28531 L p .36892 .17608 L F P
0 g
s
.41701 .23303 m .41027 .24673 L .41162 .27016 L .979 .799 .592 r
F
.36892 .17608 m .39654 .23632 L .40455 .23593 L .626 .511 .703 r
F
.36892 .17608 m .32449 .22117 L .32449 .23114 L F
.3132 .22234 m .31082 .23505 L p .36892 .17608 L F P
0 g
s
.31805 .2103 m .3132 .22234 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.32516 .19943 m .31805 .2103 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.33422 .19022 m .32516 .19943 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.34485 .18307 m .33422 .19022 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.33565 .28958 m .34647 .29535 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .35659 .17828 L .34485 .18307 L p .626 .511 .703 r
F P
0 g
s
.36892 .17608 m .35659 .17828 L .35106 .17359 L p .414 .84 .957 r
F P
0 g
s
.35106 .17359 m .36347 .17137 L .36892 .17608 L p .414 .84 .957 r
F P
0 g
s
.38306 .29712 m .39487 .29242 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3707 .29921 m .38306 .29712 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.36347 .17137 m .40848 .23115 L .41027 .2211 L .625 .51 .703 r
F
.41701 .23303 m .41027 .23106 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.39973 .23158 m .40496 .23591 L .41027 .23106 L .289 .763 .934 r
F
.40848 .23115 m .41027 .23352 L .41027 .23106 L .625 .51 .703 r
F
.40848 .23115 m .41027 .23106 L .41027 .2211 L F
.41544 .23539 m .41701 .23303 L p .40496 .23591 L .289 .763 .934 r
F P
0 g
s
.40848 .23115 m .41027 .25 L .41027 .23352 L .625 .51 .703 r
F
.36347 .17137 m .39932 .2316 L .40848 .23115 L F
.39973 .23158 m .38626 .23683 L .40496 .23591 L .289 .763 .934 r
F
.38921 .2321 m .38626 .23683 L .39973 .23158 L F
.39932 .2316 m .41027 .25 L .40848 .23115 L .625 .51 .703 r
F
.41027 .24673 m .41027 .27101 L .41162 .27016 L .979 .799 .592 r
F
.38921 .2321 m .3599 .23813 L .38626 .23683 L .289 .763 .934 r
F
.36347 .17137 m .39125 .232 L .39193 .23197 L .625 .51 .703 r
F
.31755 .23794 m .32449 .23987 L p .35435 .23383 L .289 .763 .934 r
F P
0 g
s
.36347 .17137 m .39193 .23197 L .39932 .2316 L .625 .51 .703 r
F
.33862 .23461 m .31755 .23794 L .35435 .23383 L .289 .763 .934 r
F
.32309 .27756 m .32382 .28277 L .31755 .27159 L .974 .795 .601 r
F
.32634 .28155 m .32063 .27755 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.32449 .27908 m .32634 .28155 L p .31954 .27373 L .698 .226 0 r
F P
0 g
s
.37435 .23284 m .32449 .23987 L .3599 .23813 L .289 .763 .934 r
F
.35435 .23383 m .32449 .23987 L .37435 .23284 L F
.33 .28562 m .32063 .27755 L .32634 .28155 L p .506 0 0 r
F P
0 g
s
.32634 .28155 m .33565 .28958 L .33 .28562 L p .506 0 0 r
F P
0 g
s
.32063 .27755 m .33 .28562 L p .34504 .23429 L .625 .51 .703 r
F P
0 g
s
.36347 .17137 m .33794 .23464 L .34504 .23429 L .625 .51 .703 r
F
.32449 .22117 m .31082 .23505 L .32449 .23114 L .626 .511 .703 r
F
.36347 .17137 m .31877 .22681 L .32148 .23546 L .625 .51 .703 r
F
.31877 .22681 m .31139 .23596 L .31877 .23559 L F
.31877 .22681 m .31877 .23559 L .32148 .23546 L F
.31755 .23794 m .31755 .27159 L p .31877 .25981 L 0 0 .16 r
F P
0 g
s
.31877 .23559 m .31755 .23794 L p .33862 .23461 L .289 .763 .934 r
F P
0 g
s
.31877 .23559 m .31755 .23794 L p .31877 .25981 L 0 0 .16 r
F P
0 g
s
.31502 .26886 m .31318 .26756 L p .31329 .26613 L .841 .454 0 r
F P
0 g
s
.31375 .26023 m .31502 .26886 L .31329 .26613 L .841 .454 0 r
F
.311 .24786 m .31375 .26023 L .30796 .25609 L p .93 .641 .168 r
F P
0 g
s
.31318 .26756 m .30796 .25609 L .31375 .26023 L p .841 .454 0 r
F P
0 g
s
.30796 .25609 m .31318 .26756 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.36347 .17137 m .31877 .23959 L .31877 .25686 L .625 .51 .703 r
F
.31877 .23959 m .30796 .25609 L .31877 .25686 L F
.31755 .27159 m .31755 .27287 L p .31765 .27188 L 0 0 .16 r
F P
0 g
s
.31954 .27373 m .32063 .27755 L .31847 .27421 L .698 .226 0 r
F
.31755 .27159 m .31847 .27421 L .31502 .26886 L F
.31954 .27373 m .31847 .27421 L .31755 .27159 L F
.36347 .17137 m .31877 .25686 L .32063 .27755 L .625 .51 .703 r
F
.31877 .27583 m .31755 .27287 L .31877 .27985 L 0 0 .16 r
F
.32382 .28277 m .32449 .28763 L .31755 .27287 L .974 .795 .601 r
F
.31765 .27188 m .31755 .27287 L .32066 .28041 L 0 0 .16 r
F
.31755 .27287 m .31755 .40731 L p .32044 .2894 L F P
0 g
s
.32063 .27755 m .31318 .26756 L .31502 .26886 L p .698 .226 0 r
F P
0 g
s
.31877 .27506 m .32063 .27755 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.33 .28562 m .34088 .29142 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.34088 .29142 m .35281 .2947 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.37435 .23284 m .3599 .23813 L .38921 .2321 L .289 .763 .934 r
F
.35281 .2947 m .36526 .2953 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.40037 .2813 m .40959 .27203 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.38958 .28846 m .40037 .2813 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.3777 .29319 m .38958 .28846 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.36526 .2953 m .3777 .29319 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.32191 .22957 m .32177 .23521 L p .393 .22601 L .289 .763 .934 r
F P
0 g
s
.32191 .22957 m .31877 .23559 L p .32133 .23526 L .289 .763 .934 r
F P
0 g
s
.393 .22601 m .31877 .23559 L .33862 .23461 L .289 .763 .934 r
F
.31082 .23505 m .311 .24786 L .3052 .24364 L p .97 .785 .355 r
F P
0 g
s
.30796 .25609 m .3052 .24364 L .311 .24786 L p .93 .641 .168 r
F P
0 g
s
.3052 .24364 m .30796 .25609 L p .31877 .23959 L .625 .51 .703 r
F P
0 g
s
.32148 .23546 m .31877 .23682 L .31877 .23959 L .625 .51 .703 r
F
.31877 .23682 m .3052 .24364 L .31877 .23959 L F
.31139 .23596 m .3052 .24364 L .32148 .23546 L F
.33794 .23464 m .32063 .27755 L .34504 .23429 L F
.32191 .22957 m .31877 .26073 L .32066 .28041 L 0 0 .16 r
F
.31877 .26073 m .31765 .27188 L .31877 .27506 L F
.31877 .26073 m .31877 .27506 L .32066 .28041 L F
.31877 .26073 m .31755 .27159 L .31765 .27188 L F
.31877 .25981 m .31755 .27159 L .31877 .26073 L F
.31318 .26756 m .31877 .27506 L p .31877 .25686 L .625 .51 .703 r
F P
0 g
s
.32066 .28041 m .31877 .27583 L .32044 .2894 L 0 0 .16 r
F
.31877 .27583 m .31877 .27985 L .32044 .2894 L F
.32191 .22957 m .31877 .25981 L .31877 .26073 L F
.32191 .22957 m .31877 .23559 L p .31877 .25981 L F P
0 g
s
.393 .22601 m .35435 .23383 L .37435 .23284 L .289 .763 .934 r
F
.393 .22601 m .33862 .23461 L .35435 .23383 L F
.39932 .2316 m .41027 .27101 L .41027 .25 L .625 .51 .703 r
F
.39193 .23197 m .41027 .27101 L .39932 .2316 L F
.393 .22601 m .37435 .23284 L .38921 .2321 L .289 .763 .934 r
F
.40959 .27203 m .41027 .27101 L p .39193 .23197 L .625 .51 .703 r
F P
0 g
s
.39125 .232 m .40959 .27203 L .39193 .23197 L .625 .51 .703 r
F
.41027 .27101 m .41685 .26105 L p .41027 .25 L F P
0 g
s
.38306 .29712 m .39487 .29242 L .38958 .28846 L p .541 .919 .931 r
F P
0 g
s
.40037 .2813 m .38958 .28846 L .39487 .29242 L p .678 .976 .894 r
F P
0 g
s
.39487 .29242 m .40559 .28531 L .40037 .2813 L p .678 .976 .894 r
F P
0 g
s
.40959 .27203 m .40037 .2813 L .40559 .28531 L p .788 .999 .829 r
F P
0 g
s
.393 .28185 m .393 .39843 L p .41027 .27946 L .979 .799 .592 r
F P
0 g
s
.41027 .27101 m .40959 .27203 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41162 .27016 m .41027 .27101 L .41027 .27946 L .979 .799 .592 r
F
.41027 .27101 m .393 .28185 L .41027 .27946 L F
.393 .22601 m .38921 .2321 L .39973 .23158 L .289 .763 .934 r
F
.393 .22601 m .393 .28185 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41701 .23303 m .41027 .23106 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41027 .23106 m .393 .22601 L p .39973 .23158 L .289 .763 .934 r
F P
0 g
s
.41027 .23106 m .393 .22601 L p .41027 .24673 L .979 .799 .592 r
F P
0 g
s
.41685 .26105 m .42181 .24884 L p .41027 .23352 L .625 .51 .703 r
F P
0 g
s
.41027 .25 m .41685 .26105 L .41027 .23352 L .625 .51 .703 r
F
.42691 .25307 m .42933 .24026 L p .41544 .2255 L .626 .511 .703 r
F P
0 g
s
.42181 .24884 m .42425 .23595 L p .41027 .2211 L .625 .51 .703 r
F P
0 g
s
.41027 .23352 m .42181 .24884 L .41027 .2211 L .625 .51 .703 r
F
.41027 .24673 m .393 .28185 L .41027 .27101 L .979 .799 .592 r
F
.41685 .26105 m .41027 .27101 L p .41597 .26743 L .872 .991 .74 r
F P
0 g
s
.41162 .27016 m .393 .39843 L .41701 .26677 L .979 .799 .592 r
F
.34192 .41234 m .32449 .40874 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.32449 .40874 m .31755 .40731 L p .32449 .28763 L .974 .795 .601 r
F P
0 g
s
.59993 .28958 m .61096 .29535 L .60708 .29142 L p 0 .323 .729 r
F P
0 g
s
.61925 .2947 m .60708 .29142 L .61096 .29535 L p 0 .526 .841 r
F P
0 g
s
.61096 .29535 m .62304 .29861 L .61925 .2947 L p 0 .526 .841 r
F P
0 g
s
.63195 .2953 m .61925 .2947 L .62304 .29861 L p .188 .693 .906 r
F P
0 g
s
.62304 .29861 m .63566 .29921 L .63195 .2953 L p .188 .693 .906 r
F P
0 g
s
.6626 .22601 m .62344 .22455 L .59008 .22957 L p .289 .763 .934 r
F P
0 g
s
.59008 .40107 m .62344 .39734 L .62344 .22455 L p .445 .364 .67 r
F P
0 g
s
.59043 .28155 m .59993 .28958 L .59599 .28562 L p 0 .093 .572 r
F P
0 g
s
.60708 .29142 m .59599 .28562 L .59993 .28958 L p 0 .323 .729 r
F P
0 g
s
.62344 .22455 m .59008 .22957 L .59008 .40107 L p .445 .364 .67 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3805 .41337 m .4115 .40982 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.34192 .41234 m .3805 .41337 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.59008 .40107 m .58238 .40731 L p .6626 .39843 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.31755 .40731 m .34192 .41234 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.4115 .40982 m .41701 .40365 L .393 .39843 L p .224 .73 .894 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31755 .40731 m .32191 .40107 L .32191 .22957 L p 0 0 .16 r
F P
0 g
s
.33565 .28958 m .34647 .29535 L .34088 .29142 L p 0 .278 .676 r
F P
0 g
s
.35281 .2947 m .34088 .29142 L .34647 .29535 L p 0 .504 .815 r
F P
0 g
s
.34647 .29535 m .35833 .29861 L .35281 .2947 L p 0 .504 .815 r
F P
0 g
s
.36526 .2953 m .35281 .2947 L .35833 .29861 L p .178 .688 .9 r
F P
0 g
s
.393 .22601 m .35326 .22455 L .32191 .22957 L p .289 .763 .934 r
F P
0 g
s
.32191 .40107 m .35326 .39734 L .35326 .22455 L p .428 .35 .666 r
F P
0 g
s
.34088 .29142 m .33 .28562 L .33565 .28958 L p 0 .278 .676 r
F P
0 g
s
.35326 .22455 m .32191 .22957 L .32191 .40107 L p .428 .35 .666 r
F P
0 g
s
.64463 .29319 m .63195 .2953 L .63566 .29921 L p .365 .821 .93 r
F P
0 g
s
.6626 .22601 m .62344 .22455 L .62344 .39734 L p .763 .623 .705 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32191 .40107 m .31755 .40731 L p .393 .39843 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.57069 .24364 m .5705 .23074 L .5746 .23505 L p .927 .748 .265 r
F P
0 g
s
.57703 .22234 m .5746 .23505 L .5705 .23074 L p .939 .868 .446 r
F P
0 g
s
.3052 .24364 m .30501 .23074 L .31082 .23505 L p .97 .785 .355 r
F P
0 g
s
.3132 .22234 m .31082 .23505 L .30501 .23074 L p .972 .888 .516 r
F P
0 g
s
.5705 .23074 m .57295 .21796 L .57703 .22234 L p .939 .868 .446 r
F P
0 g
s
.58197 .2103 m .57703 .22234 L .57295 .21796 L p .914 .947 .599 r
F P
0 g
s
.30501 .23074 m .30741 .21796 L .3132 .22234 L p .972 .888 .516 r
F P
0 g
s
.31805 .2103 m .3132 .22234 L .30741 .21796 L p .941 .955 .649 r
F P
0 g
s
.57295 .21796 m .57792 .20583 L .58197 .2103 L p .914 .947 .599 r
F P
0 g
s
.58922 .19943 m .58197 .2103 L .57792 .20583 L p .859 .989 .724 r
F P
0 g
s
.30741 .21796 m .31229 .20583 L .31805 .2103 L p .941 .955 .649 r
F P
0 g
s
.32516 .19943 m .31805 .2103 L .31229 .20583 L p .885 .991 .758 r
F P
0 g
s
.57792 .20583 m .58522 .19489 L .58922 .19943 L p .859 .989 .724 r
F P
0 g
s
.59846 .19022 m .58922 .19943 L .58522 .19489 L p .779 .998 .821 r
F P
0 g
s
.31229 .20583 m .31944 .19489 L .32516 .19943 L p .885 .991 .758 r
F P
0 g
s
.33422 .19022 m .32516 .19943 L .31944 .19489 L p .804 .999 .844 r
F P
0 g
s
.58522 .19489 m .59452 .18562 L .59846 .19022 L p .779 .998 .821 r
F P
0 g
s
.6093 .18307 m .59846 .19022 L .59452 .18562 L p .676 .975 .893 r
F P
0 g
s
.31944 .19489 m .32856 .18562 L .33422 .19022 L p .804 .999 .844 r
F P
0 g
s
.34485 .18307 m .33422 .19022 L .32856 .18562 L p .701 .978 .908 r
F P
0 g
s
.59452 .18562 m .60542 .17841 L .6093 .18307 L p .676 .975 .893 r
F P
0 g
s
.62127 .17828 m .6093 .18307 L .60542 .17841 L p .551 .922 .937 r
F P
0 g
s
.32856 .18562 m .33925 .17841 L .34485 .18307 L p .701 .978 .908 r
F P
0 g
s
.35659 .17828 m .34485 .18307 L .33925 .17841 L p .571 .927 .947 r
F P
0 g
s
.60542 .17841 m .61746 .17359 L .62127 .17828 L p .551 .922 .937 r
F P
0 g
s
.33925 .17841 m .35106 .17359 L .35659 .17828 L p .571 .927 .947 r
F P
0 g
s
.35833 .29861 m .3707 .29921 L .36526 .2953 L p .178 .688 .9 r
F P
0 g
s
.38132 .17657 m .36892 .17608 L .36347 .17137 L p .227 .712 .929 r
F P
0 g
s
.39324 .17973 m .38132 .17657 L .36892 .17608 L p .626 .511 .703 r
F P
0 g
s
.40415 .18544 m .39324 .17973 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.41357 .19344 m .40415 .18544 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42108 .20339 m .41357 .19344 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42635 .21486 m .42108 .20339 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42914 .22733 m .42635 .21486 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.42933 .24026 m .42914 .22733 L p .36892 .17608 L .626 .511 .703 r
F P
0 g
s
.3777 .29319 m .36526 .2953 L .3707 .29921 L p .375 .825 .936 r
F P
0 g
s
.3707 .29921 m .38306 .29712 L .3777 .29319 L p .375 .825 .936 r
F P
0 g
s
.63012 .17137 m .64284 .17186 L .64649 .17657 L p .236 .716 .934 r
F P
0 g
s
.65864 .17973 m .64649 .17657 L .64284 .17186 L p .047 .559 .876 r
F P
0 g
s
.36347 .17137 m .37594 .17186 L .38132 .17657 L p .227 .712 .929 r
F P
0 g
s
.39324 .17973 m .38132 .17657 L .37594 .17186 L p .013 .539 .855 r
F P
0 g
s
.38958 .28846 m .3777 .29319 L .38306 .29712 L p .541 .919 .931 r
F P
0 g
s
.64284 .17186 m .65507 .17504 L .65864 .17973 L p .047 .559 .876 r
F P
0 g
s
.66977 .18544 m .65864 .17973 L .65507 .17504 L p 0 .365 .774 r
F P
0 g
s
.37594 .17186 m .38793 .17504 L .39324 .17973 L p .013 .539 .855 r
F P
0 g
s
.40415 .18544 m .39324 .17973 L .38793 .17504 L p 0 .322 .728 r
F P
0 g
s
.6965 .86458 m .70139 .84608 L p .72461 .87504 L 0 .225 .738 r
F P
0 g
s
.70139 .84608 m .70496 .83261 L p .71623 .85695 L 0 .225 .738 r
F P
0 g
s
.71623 .85695 m .72461 .87504 L .70139 .84608 L 0 .225 .738 r
F
.73836 .90472 m .70788 .87549 L p .72461 .87504 L F P
0 g
s
.70788 .87549 m .6965 .86458 L p .72461 .87504 L 0 .225 .738 r
F P
0 g
s
.77017 .87438 m .77017 .89646 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.74034 .87461 m .75114 .87453 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.75114 .87453 m .77017 .87438 L p .74693 .87944 L .347 .283 .642 r
F P
0 g
s
.77017 .87438 m .74034 .87461 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.75401 .87424 m .77017 .87438 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.74865 .87438 m .73196 .89091 L p .70496 .83261 L 0 .225 .738 r
F P
0 g
s
.73315 .89348 m .74865 .87438 L .73836 .90472 L p 0 .225 .738 r
F P
0 g
s
.70139 .8749 m .74034 .87461 L p .74177 .88546 L .347 .283 .642 r
F P
0 g
s
.71437 .91745 m .70139 .8749 L .74177 .88546 L .347 .283 .642 r
F
.69767 .94509 m .73836 .90472 L .7403 .89899 L p .644 .92 .631 r
F P
0 g
s
.7403 .89899 m .74693 .87944 L p .71744 .91874 L .644 .92 .631 r
F P
0 g
s
.71744 .91874 m .69767 .94509 L .7403 .89899 L .644 .92 .631 r
F
.6965 .86458 m .68544 .87549 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.67009 .8722 m .6965 .86458 L .66141 .87944 L .665 .934 .653 r
F
.70496 .83261 m .74865 .87438 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.6672 .87461 m .64101 .87438 L .65952 .87424 L p .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .65772 .87453 L p .65328 .88622 L .954 .779 .626 r
F P
0 g
s
.65772 .87453 m .6672 .87461 L p .66141 .87944 L .954 .779 .626 r
F P
0 g
s
.65328 .88622 m .65772 .87453 L .66141 .87944 L .954 .779 .626 r
F
.66483 .87659 m .66253 .87438 L p .67009 .8722 L .665 .934 .653 r
F P
0 g
s
.65581 .90472 m .66141 .87944 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.68544 .87549 m .65581 .90472 L p .67224 .87485 L .665 .934 .653 r
F P
0 g
s
.66141 .87944 m .65581 .90472 L p .68562 .91163 L 0 .207 .723 r
F P
0 g
s
.68562 .91163 m .65581 .90472 L .70139 .93261 L 0 .207 .723 r
F
.70139 .93261 m .65328 .88622 L .66453 .88358 L .954 .779 .626 r
F
.70139 .8749 m .70139 .93261 L p .66453 .88358 L F P
0 g
s
.65581 .90472 m .69767 .94509 L .70139 .93261 L p 0 .207 .723 r
F P
0 g
s
.70139 .93261 m .69767 .94509 L p .73473 .89368 L .644 .92 .631 r
F P
0 g
s
.73473 .89368 m .69767 .94509 L .74693 .87944 L .644 .92 .631 r
F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.70139 .93261 m .70623 .91641 L p .68562 .91163 L 0 .207 .723 r
F P
0 g
s
.6672 .87461 m .70139 .8749 L p .65328 .88622 L .954 .779 .626 r
F P
0 g
s
.70623 .91641 m .66253 .87438 L .66141 .87944 L p 0 .207 .723 r
F P
0 g
s
.70623 .91641 m .66141 .87944 L .68562 .91163 L 0 .207 .723 r
F
.66253 .87438 m .70496 .83261 L .6965 .86458 L p .665 .934 .653 r
F P
0 g
s
.66253 .87438 m .70496 .83261 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70139 .8749 m .6672 .87461 L p .67977 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .67977 .87438 L .70559 .87438 L .012 .587 .719 r
F
.65952 .87424 m .70996 .87384 L p .6672 .87461 L F P
0 g
s
.70996 .87384 m .75401 .87424 L p .70139 .8749 L .012 .587 .719 r
F P
0 g
s
.74034 .87461 m .70139 .8749 L p .75401 .87424 L .012 .587 .719 r
F P
0 g
s
.70623 .91641 m .66253 .87438 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70559 .87438 m .67977 .87438 L .70996 .87384 L .012 .587 .719 r
F
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.55483 1.09633 m .55502 1.07831 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44517 1.09633 L .36524 1.09633 L p .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.63508 1.08393 m .6913 1.07831 L .70139 1.09633 L .678 .717 .878 r
F
.60506 1.07831 m .63522 1.07831 L .63508 1.08393 L F
.63522 1.07831 m .6913 1.07831 L .63508 1.08393 L F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L .678 .717 .878 r
F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L 0 0 .063 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.5554 1.043 m .63614 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.63614 1.043 m .70347 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.60506 1.07831 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63614 1.043 m .63772 1.04435 L .67151 1.043 L .066 0 0 r
F
.63772 1.04435 m .63806 1.04464 L .64101 1.04449 L F
.63772 1.04435 m .64101 1.04449 L .67151 1.043 L F
.70139 1.09633 m .64101 1.04449 L .64101 .98856 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04449 L p .954 .779 .626 r
F P
0 g
s
.70139 .93261 m .70139 1.04154 L p .66533 .96377 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .66533 .96377 L .70139 1.04154 L .954 .779 .626 r
F
.66533 .96377 m .64101 .87438 L .70139 .93261 L F
.74127 .88169 m .74034 .87461 L .74498 .87801 L .347 .283 .642 r
F
.74127 .88169 m .74498 .87801 L .77017 .89646 L F
.77017 .89646 m .77017 1.10042 L p .74127 .88169 L F P
0 g
s
.74865 .87438 m .70623 .91641 L p .70559 .87438 L .703 .508 .622 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 1.04449 L p .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63806 1.04464 m .70775 1.04601 L .67151 1.043 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44344 1.15905 m .44461 1.09757 L .44459 1.11724 L F
.63538 1.08458 m .60923 1.09451 L .44497 1.07958 L .682 .404 .495 r
F
.44497 1.07874 m .44497 1.07958 L .43099 1.07831 L F
.63538 1.08458 m .44497 1.07958 L .44497 1.07874 L F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.44461 1.09757 m .44498 1.07831 L .44479 1.09692 L .732 .598 .026 r
F
.44461 1.09757 m .44479 1.09692 L .44459 1.11724 L F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.50802 1.25704 m .54018 1.25552 L .52667 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .54517 1.25817 L F
.54018 1.25552 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.51938 1.25967 m .51947 1.25865 L .52667 1.25967 L .365 .792 .97 r
F
.452 1.25967 m .51947 1.25865 L .51938 1.25967 L F
.452 1.25967 m .50802 1.25704 L .51947 1.25865 L F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L .365 .792 .97 r
F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.52783 1.09787 m .46974 1.09988 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.58611 1.27286 m .58077 1.29174 L .53867 1.29296 L p .685 .85 .962 r
F P
0 g
s
.53867 1.29296 m .52722 1.29329 L p .53642 1.2901 L .685 .85 .962 r
F P
0 g
s
.58611 1.27286 m .53867 1.29296 L .53642 1.2901 L .685 .85 .962 r
F
.58611 1.27286 m .52722 1.29329 L .52902 1.29028 L F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.52325 1.31785 m .51832 1.29355 L .52722 1.29329 L p .706 .339 .351 r
F P
0 g
s
.52722 1.29329 m .58077 1.29174 L p .53613 1.31201 L .706 .339 .351 r
F P
0 g
s
.53613 1.31201 m .52325 1.31785 L .52722 1.29329 L .706 .339 .351 r
F
.516 1.25967 m .52978 1.28903 L .52722 1.29329 L .08 .066 .539 r
F
.52722 1.29329 m .516 1.29086 L .516 1.26975 L p F P
0 g
s
.516 1.26975 m .516 1.25967 L p .52722 1.29329 L .08 .066 .539 r
F P
0 g
s
.53229 1.26089 m .53229 1.28484 L p .52954 1.25517 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.28484 L .53168 1.28585 L .08 .066 .539 r
F
.53869 1.27417 m .58611 1.27286 L p .52902 1.29028 L .685 .85 .962 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.53229 1.28484 m .53229 1.26089 L p .52429 1.27465 L .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .53229 1.26089 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.26089 L .52954 1.25517 L .08 .066 .539 r
F
.53229 1.26089 m .53229 1.25133 L p .52444 1.27421 L .998 .815 .53 r
F P
0 g
s
.52444 1.27421 m .52429 1.27465 L .53229 1.26089 L .998 .815 .53 r
F
.51832 1.29355 m .52325 1.31785 L .5235 1.31691 L p 0 0 .3 r
F P
0 g
s
.5235 1.31691 m .52826 1.29894 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.51832 1.29355 m .5235 1.31691 L .5235 1.29636 L 0 0 .3 r
F
.53229 1.29439 m .51629 1.29798 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.516 1.29086 m .52722 1.29329 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.52722 1.29329 m .53229 1.29439 L p .51611 1.29361 L .174 0 0 r
F P
0 g
s
.52902 1.29028 m .51832 1.29355 L .53869 1.27417 L .685 .85 .962 r
F
.53229 1.29439 m .52722 1.29329 L p .52978 1.28903 L .08 .066 .539 r
F P
0 g
s
.53168 1.28585 m .53229 1.28484 L .53229 1.29439 L .08 .066 .539 r
F
.52722 1.29329 m .51832 1.29355 L p .52902 1.29028 L .685 .85 .962 r
F P
0 g
s
.53229 1.29439 m .53229 1.28484 L p .5235 1.29206 L .998 .815 .53 r
F P
0 g
s
.5235 1.29636 m .53229 1.29439 L p .5235 1.29206 L .998 .815 .53 r
F P
0 g
s
.51832 1.29355 m .52325 1.2746 L .52423 1.27457 L p .685 .85 .962 r
F P
0 g
s
.53023 1.28222 m .51832 1.29355 L .52423 1.27457 L .685 .85 .962 r
F
.52325 1.2746 m .51832 1.29355 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.52423 1.27457 m .52325 1.2746 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.52423 1.27457 m .5235 1.27695 L .52429 1.27465 L .998 .815 .53 r
F
.52325 1.2746 m .5235 1.27581 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.5235 1.27364 m .5235 1.27581 L .52423 1.27457 L .998 .815 .53 r
F
.5235 1.27581 m .5235 1.27695 L .52423 1.27457 L F
.51875 1.26758 m .52429 1.27465 L .53229 1.25133 L F
.52423 1.27457 m .53869 1.27417 L p .53023 1.28222 L .685 .85 .962 r
F P
0 g
s
.5235 1.27581 m .52325 1.2746 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.52429 1.27465 m .51629 1.29798 L .53229 1.28484 L .998 .815 .53 r
F
.58077 1.29174 m .58611 1.31592 L .52325 1.31785 L p .706 .339 .351 r
F P
0 g
s
.58077 1.29174 m .58611 1.31592 L .59152 1.29708 L p 0 0 .322 r
F P
0 g
s
.52826 1.29894 m .59152 1.29708 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.5235 1.27581 m .52826 1.29894 L p .52406 1.27486 L .705 .336 .346 r
F P
0 g
s
.52826 1.29894 m .5235 1.27581 L p .5235 1.29636 L 0 0 .3 r
F P
0 g
s
.51875 1.26758 m .51629 1.29798 L .5235 1.27695 L .998 .815 .53 r
F
.51875 1.26758 m .5235 1.27695 L .5235 1.27364 L F
.51629 1.29798 m .5235 1.29636 L p .5235 1.29206 L F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51875 1.26758 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.46974 1.09988 m .46771 1.09965 L .484 1.09787 L .09 0 0 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L .063 .051 .53 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L .09 0 0 r
F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.35023 1.31785 m .34646 1.29355 L .37134 1.29284 L p .707 .342 .354 r
F P
0 g
s
.37173 1.30072 m .37194 1.27693 L .37151 1.28848 L .763 .623 .059 r
F
.37209 1.3207 m .37209 1.30812 L .37173 1.30072 L F
.37209 1.30812 m .37209 1.2604 L .37173 1.30072 L F
.37074 1.30885 m .35023 1.31785 L .37134 1.29284 L .707 .342 .354 r
F
.37134 1.29284 m .34646 1.29355 L p .37101 1.28602 L .686 .848 .961 r
F P
0 g
s
.37042 1.31724 m .35023 1.31785 L p .37074 1.30885 L .707 .342 .354 r
F P
0 g
s
.37209 1.2604 m .37119 1.25391 L p .37151 1.28848 L .763 .623 .059 r
F P
0 g
s
.37119 1.25391 m .37083 1.25133 L p .37098 1.25943 L .763 .623 .059 r
F P
0 g
s
.37151 1.28848 m .37119 1.25391 L .37098 1.25943 L .763 .623 .059 r
F
.37194 1.27693 m .37209 1.2604 L .37151 1.28848 L F
.34646 1.29355 m .35023 1.2746 L .37042 1.27405 L p .686 .848 .961 r
F P
0 g
s
.37101 1.28602 m .34646 1.29355 L .37042 1.27405 L .686 .848 .961 r
F
.37042 1.27405 m .35023 1.2746 L p .37015 1.28119 L .706 .339 .35 r
F P
0 g
s
.35023 1.2746 m .35405 1.29894 L .36949 1.29849 L p .706 .339 .35 r
F P
0 g
s
.37209 1.3207 m .37173 1.30072 L .37026 1.27833 L .763 .623 .059 r
F
.37209 1.3207 m .37026 1.27833 L .37017 1.28057 L F
.37083 1.25133 m .36989 1.26323 L p .37173 1.30072 L F P
0 g
s
.36989 1.26323 m .36955 1.26755 L p .37173 1.30072 L .763 .623 .059 r
F P
0 g
s
.37042 1.27405 m .41389 1.27286 L p .37101 1.28602 L .686 .848 .961 r
F P
0 g
s
.37015 1.28119 m .35023 1.2746 L .36949 1.29849 L .706 .339 .35 r
F
.36955 1.26755 m .36915 1.29168 L p .37066 1.31103 L .763 .623 .059 r
F P
0 g
s
.36973 1.30339 m .35405 1.29894 L .37042 1.31724 L .685 .851 .962 r
F
.37066 1.31103 m .36915 1.29168 L .36984 1.30551 L .763 .623 .059 r
F
.37209 1.3207 m .37108 1.29966 L .37066 1.31103 L F
.37108 1.29966 m .36955 1.26755 L .37066 1.31103 L F
.41067 1.29729 m .4007 1.29758 L p .40971 1.29174 L .707 .342 .354 r
F P
0 g
s
.37209 1.3207 m .36984 1.30551 L .3708 1.32493 L .763 .623 .059 r
F
.38807 1.30578 m .41389 1.31592 L .37042 1.31724 L p .707 .342 .354 r
F P
0 g
s
.40971 1.29174 m .37042 1.31724 L .37074 1.30885 L .707 .342 .354 r
F
.37134 1.29284 m .40971 1.29174 L p .37074 1.30885 L F P
0 g
s
.40971 1.29174 m .41389 1.31592 L .41812 1.29708 L p 0 0 .263 r
F P
0 g
s
.41389 1.31592 m .41812 1.29708 L .36949 1.29849 L p .685 .851 .962 r
F P
0 g
s
.36949 1.29849 m .35405 1.29894 L p .36973 1.30339 L .685 .851 .962 r
F P
0 g
s
.41389 1.31592 m .36949 1.29849 L .36973 1.30339 L .685 .851 .962 r
F
.35405 1.29894 m .35023 1.31785 L .37042 1.31724 L p F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .3708 1.32493 L .763 .623 .059 r
F P
0 g
s
.36984 1.30551 m .36901 1.29994 L .3708 1.32493 L .763 .623 .059 r
F
.36915 1.29168 m .36901 1.29994 L p .36984 1.30551 L F P
0 g
s
.37042 1.31724 m .41389 1.31592 L p .36973 1.30339 L .685 .851 .962 r
F P
0 g
s
.41389 1.27286 m .40971 1.29174 L .37134 1.29284 L p .686 .848 .961 r
F P
0 g
s
.41389 1.27286 m .37134 1.29284 L .37101 1.28602 L .686 .848 .961 r
F
.36949 1.29849 m .41812 1.29708 L p .37015 1.28119 L .706 .339 .35 r
F P
0 g
s
.37017 1.28057 m .37026 1.27833 L .36955 1.26755 L .763 .623 .059 r
F
.41812 1.29708 m .41389 1.27286 L .40971 1.29174 L p 0 0 .263 r
F P
0 g
s
.41812 1.29708 m .41389 1.27286 L .37042 1.27405 L p .706 .339 .35 r
F P
0 g
s
.41812 1.29708 m .37042 1.27405 L .37015 1.28119 L .706 .339 .35 r
F
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.53869 1.27417 m .52423 1.27457 L p .54185 1.28072 L .705 .336 .346 r
F P
0 g
s
.54185 1.28072 m .52423 1.27457 L .52406 1.27486 L .705 .336 .346 r
F
.59152 1.29708 m .58611 1.27286 L .58077 1.29174 L p 0 0 .322 r
F P
0 g
s
.59152 1.29708 m .58611 1.27286 L .53869 1.27417 L p .705 .336 .346 r
F P
0 g
s
.59152 1.29708 m .53869 1.27417 L .54185 1.28072 L .705 .336 .346 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L .513 .022 .027 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46974 1.09988 m .46368 1.10009 L .46771 1.09965 L F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L .732 .598 .026 r
F
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.74865 .87438 m .70623 .91641 L .70139 .93261 L p .644 .92 .631 r
F P
0 g
s
.74865 .87438 m .70139 .93261 L .73473 .89368 L .644 .92 .631 r
F
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.74693 .87944 m .74865 .87438 L p .73473 .89368 L .644 .92 .631 r
F P
0 g
s
.77017 1.10042 m .71437 .91745 L .74177 .88546 L .347 .283 .642 r
F
.5705 .23074 m .57069 .24364 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.57295 .21796 m .5705 .23074 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.30501 .23074 m .3052 .24364 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.30741 .21796 m .30501 .23074 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.57792 .20583 m .57295 .21796 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.31229 .20583 m .30741 .21796 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.65507 .17504 m .66626 .18078 L .66977 .18544 L p 0 .365 .774 r
F P
0 g
s
.67937 .19344 m .66977 .18544 L .66626 .18078 L p 0 .14 .626 r
F P
0 g
s
.38793 .17504 m .39891 .18078 L .40415 .18544 L p 0 .322 .728 r
F P
0 g
s
.41357 .19344 m .40415 .18544 L .39891 .18078 L p 0 .074 .549 r
F P
0 g
s
.58522 .19489 m .57792 .20583 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.31944 .19489 m .31229 .20583 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.59452 .18562 m .58522 .19489 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.32856 .18562 m .31944 .19489 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.66626 .18078 m .67593 .18883 L .67937 .19344 L p 0 .14 .626 r
F P
0 g
s
.68703 .20339 m .67937 .19344 L .67593 .18883 L p 0 0 .437 r
F P
0 g
s
.39891 .18078 m .40839 .18883 L .41357 .19344 L p 0 .074 .549 r
F P
0 g
s
.42108 .20339 m .41357 .19344 L .40839 .18883 L p .649 .181 0 r
F P
0 g
s
.67593 .18883 m .68364 .19885 L .68703 .20339 L p 0 0 .437 r
F P
0 g
s
.69241 .21486 m .68703 .20339 L .68364 .19885 L p .715 .338 0 r
F P
0 g
s
.40839 .18883 m .41595 .19885 L .42108 .20339 L p .649 .181 0 r
F P
0 g
s
.42635 .21486 m .42108 .20339 L .41595 .19885 L p .804 .418 0 r
F P
0 g
s
.60542 .17841 m .59452 .18562 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.33925 .17841 m .32856 .18562 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.68961 .24884 m .68456 .26105 L .68795 .26519 L p .893 .937 .567 r
F P
0 g
s
.68795 .26519 m .69297 .25307 L .68961 .24884 L p .893 .937 .567 r
F P
0 g
s
.42198 .26519 m .42691 .25307 L .42181 .24884 L p .929 .953 .625 r
F P
0 g
s
.68364 .19885 m .68905 .21038 L .69241 .21486 L p .715 .338 0 r
F P
0 g
s
.69525 .22733 m .69241 .21486 L .68905 .21038 L p .831 .55 .003 r
F P
0 g
s
.41595 .19885 m .42125 .21038 L .42635 .21486 L p .804 .418 0 r
F P
0 g
s
.42914 .22733 m .42635 .21486 L .42125 .21038 L p .904 .616 .117 r
F P
0 g
s
.6921 .23595 m .68961 .24884 L .69297 .25307 L p .915 .852 .406 r
F P
0 g
s
.69297 .25307 m .69545 .24026 L .6921 .23595 L p .915 .852 .406 r
F P
0 g
s
.42425 .23595 m .42181 .24884 L .42691 .25307 L p .958 .881 .484 r
F P
0 g
s
.42691 .25307 m .42933 .24026 L .42425 .23595 L p .958 .881 .484 r
F P
0 g
s
.68905 .21038 m .69191 .22294 L .69525 .22733 L p .831 .55 .003 r
F P
0 g
s
.69545 .24026 m .69525 .22733 L .69191 .22294 L p .896 .723 .216 r
F P
0 g
s
.42125 .21038 m .42406 .22294 L .42914 .22733 L p .904 .616 .117 r
F P
0 g
s
.42933 .24026 m .42914 .22733 L .42406 .22294 L p .953 .77 .315 r
F P
0 g
s
.69191 .22294 m .6921 .23595 L .69545 .24026 L p .896 .723 .216 r
F P
0 g
s
.42406 .22294 m .42425 .23595 L .42933 .24026 L p .953 .77 .315 r
F P
0 g
s
.63012 .17137 m .61746 .17359 L .60542 .17841 L p .627 .512 .703 r
F P
0 g
s
.36347 .17137 m .35106 .17359 L .33925 .17841 L p .625 .51 .703 r
F P
0 g
s
.65507 .17504 m .64284 .17186 L .63012 .17137 L p .627 .512 .703 r
F P
0 g
s
.66626 .18078 m .65507 .17504 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.67593 .18883 m .66626 .18078 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.68364 .19885 m .67593 .18883 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.68905 .21038 m .68364 .19885 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.69191 .22294 m .68905 .21038 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.6921 .23595 m .69191 .22294 L p .63012 .17137 L .627 .512 .703 r
F P
0 g
s
.38793 .17504 m .37594 .17186 L .36347 .17137 L p .625 .51 .703 r
F P
0 g
s
.39891 .18078 m .38793 .17504 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.40839 .18883 m .39891 .18078 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.41595 .19885 m .40839 .18883 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42125 .21038 m .41595 .19885 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42406 .22294 m .42125 .21038 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.42425 .23595 m .42406 .22294 L p .36347 .17137 L .625 .51 .703 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.35326 .39734 m .393 .39843 L .393 .22601 L p .763 .623 .705 r
F P
0 g
s
.393 .22601 m .35326 .22455 L .35326 .39734 L p .763 .623 .705 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6626 .39843 m .62344 .39734 L .59008 .40107 L p .224 .73 .894 r
F P
0 g
s
.393 .39843 m .35326 .39734 L .32191 .40107 L p .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.40328 .36429 m .36948 .36852 L .36948 .18583 L p .413 .337 .662 r
F P
0 g
s
.36948 .36852 m .32732 .3673 L .32732 .18419 L p .766 .625 .704 r
F P
0 g
s
.32732 .18419 m .36948 .18583 L .36948 .36852 L p .766 .625 .704 r
F P
0 g
s
.29322 .1732 m .29331 .17921 L p .30815 .16886 L .618 .504 .702 r
F P
0 g
s
.29331 .17921 m .29342 .18721 L p .30014 .17884 L .618 .504 .702 r
F P
0 g
s
.30815 .16886 m .29331 .17921 L .30014 .17884 L .618 .504 .702 r
F
.30815 .17841 m .32732 .18419 L p .34682 .17632 L .289 .763 .934 r
F P
0 g
s
.29342 .18721 m .29642 .20072 L p .30815 .18274 L .618 .504 .702 r
F P
0 g
s
.30815 .17841 m .32732 .18419 L p .31081 .22418 L .982 .801 .586 r
F P
0 g
s
.30815 .22127 m .31081 .22418 L .30815 .23062 L .982 .801 .586 r
F
.30815 .17841 m .31081 .22418 L .30815 .22127 L F
.30208 .21315 m .30815 .22127 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.30815 .16886 m .29342 .18721 L .30815 .18274 L .618 .504 .702 r
F
.29642 .20072 m .30208 .21315 L p .35667 .10843 L F P
0 g
s
.30208 .21315 m .31017 .22396 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.30051 .1761 m .30815 .17841 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30051 .36128 m .30051 .21429 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.29642 .20072 m .29925 .20693 L p .29772 .20984 L .826 .439 0 r
F P
0 g
s
.29925 .20693 m .30208 .21315 L .30005 .21161 L p .826 .439 0 r
F P
0 g
s
.30005 .21161 m .29772 .20984 L p .29925 .20693 L .826 .439 0 r
F P
0 g
s
.30051 .21429 m .30051 .2129 L p .30741 .22529 L .982 .801 .586 r
F P
0 g
s
.30208 .21315 m .3027 .21529 L .30051 .2129 L .68 .209 0 r
F
.29772 .20984 m .30005 .21161 L p .30051 .2129 L F P
0 g
s
.30005 .21161 m .30208 .21315 L p .30051 .2129 L .68 .209 0 r
F P
0 g
s
.30051 .2129 m .30051 .1761 L p .3066 .21957 L .982 .801 .586 r
F P
0 g
s
.35667 .10843 m .30815 .16886 L .30815 .18274 L .618 .504 .702 r
F
.32732 .18419 m .32732 .3673 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.32732 .18419 m .36948 .18583 L p .37562 .17477 L .289 .763 .934 r
F P
0 g
s
.34682 .17632 m .32732 .18419 L .37562 .17477 L .289 .763 .934 r
F
.31017 .22396 m .32034 .23269 L p .33666 .17687 L .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .32896 .17729 L .33666 .17687 L .618 .504 .702 r
F
.32896 .17729 m .31017 .22396 L .33666 .17687 L F
.33215 .23895 m .3451 .24246 L p .35667 .10843 L F P
0 g
s
.3451 .24246 m .35862 .24306 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.36948 .18583 m .40328 .18013 L .40328 .36429 L p .413 .337 .662 r
F P
0 g
s
.36948 .18583 m .40328 .18013 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.37562 .17477 m .36948 .18583 L .39606 .17367 L .289 .763 .934 r
F
.40328 .36429 m .40328 .18013 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.4092 .35691 m .40751 .35902 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.40751 .35902 m .40328 .36429 L p .40751 .30642 L 0 0 .183 r
F P
0 g
s
.40751 .21647 m .41465 .20562 L p .40751 .19364 L .618 .504 .702 r
F P
0 g
s
.40751 .17573 m .42004 .19233 L .41192 .17282 L .618 .504 .702 r
F
.40751 .17305 m .41192 .17282 L .40751 .16223 L F
.40751 .17573 m .41192 .17282 L .40751 .17305 L F
.40328 .18013 m .40751 .17305 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.40328 .18013 m .40751 .17305 L p .40751 .21647 L 0 0 .183 r
F P
0 g
s
.40496 .23048 m .40751 .21647 L .40751 .30642 L 0 0 .183 r
F
.40328 .18013 m .40751 .21647 L .40496 .23048 L F
.40751 .21647 m .41465 .20562 L .41347 .20458 L p .865 .99 .731 r
F P
0 g
s
.41347 .20458 m .41019 .2017 L p .4092 .20715 L .865 .99 .731 r
F P
0 g
s
.40751 .21647 m .41347 .20458 L .4092 .20715 L .865 .99 .731 r
F
.40751 .30642 m .40871 .20982 L .4092 .35691 L 0 0 .183 r
F
.41465 .20562 m .42004 .19233 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41442 .18727 m .4109 .19594 L p .41465 .20562 L .923 .951 .614 r
F P
0 g
s
.40871 .20982 m .4092 .17022 L .4092 .20965 L 0 0 .183 r
F
.40751 .17305 m .4092 .17022 L p .40751 .30642 L F P
0 g
s
.40677 .21758 m .40751 .21647 L p .39561 .17369 L .618 .504 .702 r
F P
0 g
s
.39561 .17369 m .40751 .21647 L .40751 .19364 L .618 .504 .702 r
F
.38685 .17417 m .40677 .21758 L .39561 .17369 L F
.39675 .2277 m .40677 .21758 L p .35667 .10843 L F P
0 g
s
.4092 .20715 m .4092 .17022 L p .40328 .2107 L .986 .805 .576 r
F P
0 g
s
.4109 .19594 m .40899 .20066 L .41019 .2017 L p .923 .951 .614 r
F P
0 g
s
.41019 .2017 m .41465 .20562 L p .4109 .19594 L .923 .951 .614 r
F P
0 g
s
.40872 .2135 m .4092 .20965 L .4092 .35691 L 0 0 .183 r
F
.40871 .20982 m .4092 .20965 L .40872 .2135 L F
.40677 .21758 m .40751 .21647 L p .40899 .20066 L .865 .99 .731 r
F P
0 g
s
.41019 .2017 m .40899 .20066 L p .40751 .21647 L .865 .99 .731 r
F P
0 g
s
.38281 .35065 m .4092 .35691 L .4092 .20715 L p .986 .805 .576 r
F P
0 g
s
.39675 .2277 m .40677 .21758 L .40105 .21271 L p .781 .998 .823 r
F P
0 g
s
.40105 .21271 m .40677 .21758 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40687 .17488 m .40751 .17573 L .40751 .1736 L .618 .504 .702 r
F
.40687 .17488 m .40751 .1736 L .40751 .16223 L F
.35667 .10843 m .40687 .17488 L .40751 .16223 L F
.38502 .23552 m .39675 .2277 L p .35667 .10843 L F P
0 g
s
.4092 .17022 m .40179 .18502 L .40328 .2107 L .986 .805 .576 r
F
.35667 .10843 m .38685 .17417 L .39561 .17369 L .618 .504 .702 r
F
.35667 .10843 m .30815 .15796 L .30815 .16886 L F
.29582 .1593 m .29322 .1732 L p .35667 .10843 L F P
0 g
s
.30112 .14611 m .29582 .1593 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.30888 .1342 m .30112 .14611 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.31877 .12408 m .30888 .1342 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.33038 .1162 m .31877 .12408 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.32034 .23269 m .33215 .23895 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .3432 .11091 L .33038 .1162 L p .618 .504 .702 r
F P
0 g
s
.35667 .10843 m .3432 .11091 L .33706 .1053 L p .412 .839 .956 r
F P
0 g
s
.33706 .1053 m .35062 .1028 L .35667 .10843 L p .412 .839 .956 r
F P
0 g
s
.37213 .24071 m .38502 .23552 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35862 .24306 m .37213 .24071 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35062 .1028 m .39984 .16797 L .40179 .15696 L .617 .504 .702 r
F
.4092 .17022 m .40179 .16786 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.39027 .16849 m .39606 .17367 L .40179 .16786 L .289 .763 .934 r
F
.39984 .16797 m .40179 .17056 L .40179 .16786 L .617 .504 .702 r
F
.39984 .16797 m .40179 .16786 L .40179 .15696 L F
.40751 .17305 m .4092 .17022 L p .39606 .17367 L .289 .763 .934 r
F P
0 g
s
.39984 .16797 m .40179 .18859 L .40179 .17056 L .617 .504 .702 r
F
.35062 .1028 m .38982 .16851 L .39984 .16797 L F
.39027 .16849 m .37562 .17477 L .39606 .17367 L .289 .763 .934 r
F
.37876 .16911 m .37562 .17477 L .39027 .16849 L F
.38982 .16851 m .40179 .18859 L .39984 .16797 L .617 .504 .702 r
F
.40179 .18502 m .40179 .21159 L .40328 .2107 L .986 .805 .576 r
F
.37876 .16911 m .34682 .17632 L .37562 .17477 L .289 .763 .934 r
F
.35062 .1028 m .38099 .16899 L .38174 .16895 L .617 .504 .702 r
F
.30051 .1761 m .30815 .17841 L p .34066 .17118 L .289 .763 .934 r
F P
0 g
s
.35062 .1028 m .38174 .16895 L .38982 .16851 L .617 .504 .702 r
F
.32346 .17212 m .30051 .1761 L .34066 .17118 L .289 .763 .934 r
F
.3066 .21957 m .30741 .22529 L .30051 .2129 L .982 .801 .586 r
F
.31017 .22396 m .30381 .21917 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.30815 .22127 m .31017 .22396 L p .3027 .21529 L .68 .209 0 r
F P
0 g
s
.36251 .17 m .30815 .17841 L .34682 .17632 L .289 .763 .934 r
F
.34066 .17118 m .30815 .17841 L .36251 .17 L F
.31404 .22796 m .30381 .21917 L .31017 .22396 L p .488 0 0 r
F P
0 g
s
.31017 .22396 m .32034 .23269 L .31404 .22796 L p .488 0 0 r
F P
0 g
s
.30381 .21917 m .31404 .22796 L p .33048 .17174 L .617 .504 .702 r
F P
0 g
s
.35062 .1028 m .32272 .17216 L .33048 .17174 L .617 .504 .702 r
F
.30815 .15796 m .29322 .1732 L .30815 .16886 L .618 .504 .702 r
F
.35062 .1028 m .30178 .16368 L .30473 .17313 L .617 .504 .702 r
F
.30178 .16368 m .29372 .17373 L .30178 .17329 L F
.30178 .16368 m .30178 .17329 L .30473 .17313 L F
.30051 .1761 m .30051 .2129 L p .30178 .19978 L 0 0 .14 r
F P
0 g
s
.30178 .17329 m .30051 .1761 L p .32346 .17212 L .289 .763 .934 r
F P
0 g
s
.30178 .17329 m .30051 .1761 L p .30178 .19978 L 0 0 .14 r
F P
0 g
s
.29772 .20984 m .29567 .20828 L p .29582 .2068 L .826 .439 0 r
F P
0 g
s
.29642 .20072 m .29772 .20984 L .29582 .2068 L .826 .439 0 r
F
.29342 .18721 m .29642 .20072 L .28997 .19576 L p .919 .63 .144 r
F P
0 g
s
.29567 .20828 m .28997 .19576 L .29642 .20072 L p .826 .439 0 r
F P
0 g
s
.28997 .19576 m .29567 .20828 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.35062 .1028 m .30178 .17766 L .30178 .19655 L .617 .504 .702 r
F
.30178 .17766 m .28997 .19576 L .30178 .19655 L F
.30051 .2129 m .30051 .21429 L p .30061 .21319 L 0 0 .14 r
F P
0 g
s
.3027 .21529 m .30381 .21917 L .30147 .21558 L .68 .209 0 r
F
.30051 .2129 m .30147 .21558 L .29772 .20984 L F
.3027 .21529 m .30147 .21558 L .30051 .2129 L F
.35062 .1028 m .30178 .19655 L .30381 .21917 L .617 .504 .702 r
F
.30178 .2173 m .30051 .21429 L .30178 .2217 L 0 0 .14 r
F
.30741 .22529 m .30815 .23062 L .30051 .21429 L .982 .801 .586 r
F
.30061 .21319 m .30051 .21429 L .30374 .22197 L 0 0 .14 r
F
.30051 .21429 m .30051 .36128 L p .30352 .23184 L F P
0 g
s
.30381 .21917 m .29567 .20828 L .29772 .20984 L p .68 .209 0 r
F P
0 g
s
.30178 .21646 m .30381 .21917 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.31404 .22796 m .32594 .23425 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.32594 .23425 m .33897 .23778 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.36251 .17 m .34682 .17632 L .37876 .16911 L .289 .763 .934 r
F
.33897 .23778 m .35258 .23838 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.39096 .2229 m .40105 .21271 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.37916 .23078 m .39096 .2229 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.36618 .23602 m .37916 .23078 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.35258 .23838 m .36618 .23602 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.30504 .16608 m .30489 .17285 L p .38281 .16181 L .289 .763 .934 r
F P
0 g
s
.30504 .16608 m .30178 .17329 L p .3044 .17292 L .289 .763 .934 r
F P
0 g
s
.38281 .16181 m .30178 .17329 L .32346 .17212 L .289 .763 .934 r
F
.29322 .1732 m .29342 .18721 L .28695 .18216 L p .963 .778 .337 r
F P
0 g
s
.28997 .19576 m .28695 .18216 L .29342 .18721 L p .919 .63 .144 r
F P
0 g
s
.28695 .18216 m .28997 .19576 L p .30178 .17766 L .617 .504 .702 r
F P
0 g
s
.30473 .17313 m .30178 .17463 L .30178 .17766 L .617 .504 .702 r
F
.30178 .17463 m .28695 .18216 L .30178 .17766 L F
.29372 .17373 m .28695 .18216 L .30473 .17313 L F
.32272 .17216 m .30381 .21917 L .33048 .17174 L F
.30504 .16608 m .30178 .20079 L .30374 .22197 L 0 0 .14 r
F
.30178 .20079 m .30061 .21319 L .30178 .21646 L F
.30178 .20079 m .30178 .21646 L .30374 .22197 L F
.30178 .20079 m .30051 .2129 L .30061 .21319 L F
.30178 .19978 m .30051 .2129 L .30178 .20079 L F
.29567 .20828 m .30178 .21646 L p .30178 .19655 L .617 .504 .702 r
F P
0 g
s
.30374 .22197 m .30178 .2173 L .30352 .23184 L 0 0 .14 r
F
.30178 .2173 m .30178 .2217 L .30352 .23184 L F
.30504 .16608 m .30178 .19978 L .30178 .20079 L F
.30504 .16608 m .30178 .17329 L p .30178 .19978 L F P
0 g
s
.38281 .16181 m .34066 .17118 L .36251 .17 L .289 .763 .934 r
F
.38281 .16181 m .32346 .17212 L .34066 .17118 L F
.38982 .16851 m .40179 .21159 L .40179 .18859 L .617 .504 .702 r
F
.38174 .16895 m .40179 .21159 L .38982 .16851 L F
.38281 .16181 m .36251 .17 L .37876 .16911 L .289 .763 .934 r
F
.40105 .21271 m .40179 .21159 L p .38174 .16895 L .617 .504 .702 r
F P
0 g
s
.38099 .16899 m .40105 .21271 L .38174 .16895 L .617 .504 .702 r
F
.40179 .21159 m .40899 .20066 L p .40179 .18859 L F P
0 g
s
.37213 .24071 m .38502 .23552 L .37916 .23078 L p .536 .918 .928 r
F P
0 g
s
.39096 .2229 m .37916 .23078 L .38502 .23552 L p .672 .975 .89 r
F P
0 g
s
.38502 .23552 m .39675 .2277 L .39096 .2229 L p .672 .975 .89 r
F P
0 g
s
.40105 .21271 m .39096 .2229 L .39675 .2277 L p .781 .998 .823 r
F P
0 g
s
.38281 .22297 m .38281 .35065 L p .40179 .22084 L .986 .805 .576 r
F P
0 g
s
.40179 .21159 m .40105 .21271 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40328 .2107 m .40179 .21159 L .40179 .22084 L .986 .805 .576 r
F
.40179 .21159 m .38281 .22297 L .40179 .22084 L F
.38281 .16181 m .37876 .16911 L .39027 .16849 L .289 .763 .934 r
F
.38281 .16181 m .38281 .22297 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.4092 .17022 m .40179 .16786 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.40179 .16786 m .38281 .16181 L p .39027 .16849 L .289 .763 .934 r
F P
0 g
s
.40179 .16786 m .38281 .16181 L p .40179 .18502 L .986 .805 .576 r
F P
0 g
s
.40899 .20066 m .41442 .18727 L p .40179 .17056 L .617 .504 .702 r
F P
0 g
s
.40179 .18859 m .40899 .20066 L .40179 .17056 L .617 .504 .702 r
F
.42004 .19233 m .42269 .1783 L p .40751 .16223 L .618 .504 .702 r
F P
0 g
s
.41442 .18727 m .41708 .17314 L p .40179 .15696 L .617 .504 .702 r
F P
0 g
s
.40179 .17056 m .41442 .18727 L .40179 .15696 L .617 .504 .702 r
F
.40179 .18502 m .38281 .22297 L .40179 .21159 L .986 .805 .576 r
F
.40899 .20066 m .40179 .21159 L p .40805 .20784 L .865 .99 .731 r
F P
0 g
s
.40328 .2107 m .38281 .35065 L .4092 .20715 L .986 .805 .576 r
F
.32732 .3673 m .30815 .363 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30815 .363 m .30051 .36128 L p .30815 .23062 L .982 .801 .586 r
F P
0 g
s
.30051 .36128 m .30504 .35382 L .30504 .16608 L p 0 0 .14 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.36948 .36852 m .40328 .36429 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.32732 .3673 m .36948 .36852 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.30051 .36128 m .32732 .3673 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.32034 .23269 m .33215 .23895 L .32594 .23425 L p 0 .288 .689 r
F P
0 g
s
.33897 .23778 m .32594 .23425 L .33215 .23895 L p 0 .509 .821 r
F P
0 g
s
.33215 .23895 m .3451 .24246 L .33897 .23778 L p 0 .509 .821 r
F P
0 g
s
.35258 .23838 m .33897 .23778 L .3451 .24246 L p .181 .689 .902 r
F P
0 g
s
.38281 .16181 m .33925 .16006 L .30504 .16608 L p .289 .763 .934 r
F P
0 g
s
.30504 .35382 m .33925 .34935 L .33925 .16006 L p .4 .326 .658 r
F P
0 g
s
.32594 .23425 m .31404 .22796 L .32034 .23269 L p 0 .288 .689 r
F P
0 g
s
.33925 .16006 m .30504 .16608 L .30504 .35382 L p .4 .326 .658 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.40328 .36429 m .4092 .35691 L .38281 .35065 L p .224 .73 .894 r
F P
0 g
s
.30504 .35382 m .30051 .36128 L p .38281 .35065 L .224 .73 .894 r
F P
0 g
s
.38281 .35065 m .33925 .34935 L .30504 .35382 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.36618 .23602 m .35258 .23838 L .35862 .24306 L p .373 .824 .935 r
F P
0 g
s
.35862 .24306 m .37213 .24071 L .36618 .23602 L p .373 .824 .935 r
F P
0 g
s
.37916 .23078 m .36618 .23602 L .37213 .24071 L p .536 .918 .928 r
F P
0 g
s
.33925 .34935 m .38281 .35065 L .38281 .16181 L p .767 .627 .704 r
F P
0 g
s
.3451 .24246 m .35862 .24306 L .35258 .23838 L p .181 .689 .902 r
F P
0 g
s
.38281 .16181 m .33925 .16006 L .33925 .34935 L p .767 .627 .704 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65515 .36852 m .61364 .3673 L .61364 .18419 L p .766 .626 .704 r
F P
0 g
s
.58154 .1732 m .58163 .17921 L p .59679 .16886 L .62 .506 .702 r
F P
0 g
s
.58163 .17921 m .58174 .18721 L p .58861 .17884 L .62 .506 .702 r
F P
0 g
s
.59679 .16886 m .58163 .17921 L .58861 .17884 L .62 .506 .702 r
F
.59679 .17841 m .61364 .18419 L p .63629 .17632 L .289 .763 .934 r
F P
0 g
s
.58174 .18721 m .5848 .20072 L p .59679 .18274 L .62 .506 .702 r
F P
0 g
s
.59679 .17841 m .61364 .18419 L p .59913 .22418 L .991 .809 .561 r
F P
0 g
s
.59679 .22127 m .59913 .22418 L .59679 .23062 L .991 .809 .561 r
F
.59679 .17841 m .59913 .22418 L .59679 .22127 L F
.59059 .21315 m .59679 .22127 L p .59199 .21529 L .591 .131 0 r
F P
0 g
s
.59679 .16886 m .58174 .18721 L .59679 .18274 L .62 .506 .702 r
F
.5848 .20072 m .59059 .21315 L p .64636 .10843 L F P
0 g
s
.61364 .18419 m .61364 .3673 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.61364 .18419 m .65515 .18583 L .65515 .36852 L p .766 .626 .704 r
F P
0 g
s
.61364 .18419 m .65515 .18583 L p .66571 .17477 L .289 .763 .934 r
F P
0 g
s
.63629 .17632 m .61364 .18419 L .66571 .17477 L .289 .763 .934 r
F
.59059 .21315 m .59885 .22396 L p .61804 .17729 L .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .60945 .17774 L .61804 .17729 L .62 .506 .702 r
F
.60945 .17774 m .59059 .21315 L .61804 .17729 L F
.6213 .23895 m .63453 .24246 L p .64636 .10843 L F P
0 g
s
.63453 .24246 m .64834 .24306 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.65515 .18583 m .69122 .18013 L .69122 .36429 L p .432 .353 .667 r
F P
0 g
s
.65515 .18583 m .69122 .18013 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.66571 .17477 m .65515 .18583 L .68659 .17367 L .289 .763 .934 r
F
.69122 .36429 m .69122 .18013 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.70111 .35691 m .69829 .35902 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.69829 .35902 m .69122 .36429 L p .69829 .30642 L 0 0 .288 r
F P
0 g
s
.69829 .21647 m .70559 .20562 L p .69829 .19364 L .62 .506 .702 r
F P
0 g
s
.69829 .17573 m .71109 .19233 L .70279 .17282 L .62 .506 .702 r
F
.69829 .17305 m .70279 .17282 L .69829 .16223 L F
.69829 .17573 m .70279 .17282 L .69829 .17305 L F
.69122 .18013 m .69829 .17305 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.69122 .18013 m .69829 .17305 L p .69829 .21647 L 0 0 .288 r
F P
0 g
s
.69404 .23048 m .69829 .21647 L .69829 .30642 L 0 0 .288 r
F
.69122 .18013 m .69829 .21647 L .69404 .23048 L F
.69829 .21647 m .70559 .20562 L .70484 .20458 L p .829 .979 .687 r
F P
0 g
s
.70484 .20458 m .70276 .2017 L p .70111 .20715 L .829 .979 .687 r
F P
0 g
s
.69829 .21647 m .70484 .20458 L .70111 .20715 L .829 .979 .687 r
F
.69829 .30642 m .70023 .21263 L .70111 .35691 L 0 0 .288 r
F
.70559 .20562 m .71109 .19233 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70023 .21263 m .70111 .17022 L .70111 .35691 L 0 0 .288 r
F
.69829 .17305 m .70111 .17022 L p .69829 .30642 L F P
0 g
s
.69122 .36429 m .65515 .36852 L .65515 .18583 L p .432 .353 .667 r
F P
0 g
s
.67808 .35065 m .70111 .35691 L .70111 .20715 L p .995 .812 .548 r
F P
0 g
s
.69753 .21758 m .69829 .21647 L p .68613 .17369 L .62 .506 .702 r
F P
0 g
s
.68613 .17369 m .69829 .21647 L .69829 .19364 L .62 .506 .702 r
F
.70111 .20715 m .70111 .17022 L p .69594 .2107 L .995 .812 .548 r
F P
0 g
s
.69753 .21758 m .69829 .21647 L p .702 .20066 L .829 .979 .687 r
F P
0 g
s
.70276 .2017 m .702 .20066 L p .69829 .21647 L .829 .979 .687 r
F P
0 g
s
.67718 .17417 m .69753 .21758 L .68613 .17369 L .62 .506 .702 r
F
.68729 .2277 m .69753 .21758 L p .64636 .10843 L F P
0 g
s
.68729 .2277 m .69753 .21758 L .69389 .21271 L p .748 .99 .792 r
F P
0 g
s
.69389 .21271 m .69753 .21758 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.67532 .23552 m .68729 .2277 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70111 .17022 m .69465 .18502 L .69594 .2107 L .995 .812 .548 r
F
.69465 .18502 m .69465 .21159 L .69594 .2107 L F
.69465 .17102 m .69829 .17573 L .69829 .16919 L .62 .506 .702 r
F
.69465 .17102 m .69829 .16919 L .69829 .16223 L F
.64636 .10843 m .69465 .17102 L .69829 .16223 L F
.70111 .17022 m .69465 .16786 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.64636 .10843 m .67718 .17417 L .68613 .17369 L .62 .506 .702 r
F
.64636 .10843 m .59679 .16886 L .59679 .18274 L F
.64636 .10843 m .59679 .15796 L .59679 .16886 L F
.5842 .1593 m .58154 .1732 L p .64636 .10843 L F P
0 g
s
.5896 .14611 m .5842 .1593 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.59753 .1342 m .5896 .14611 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.60764 .12408 m .59753 .1342 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.59885 .22396 m .60924 .23269 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.6195 .1162 m .60764 .12408 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.60924 .23269 m .6213 .23895 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .63259 .11091 L .6195 .1162 L p .62 .506 .702 r
F P
0 g
s
.64636 .10843 m .63259 .11091 L .62851 .1053 L p .402 .836 .951 r
F P
0 g
s
.66019 .1089 m .64636 .10843 L .64237 .1028 L p .238 .717 .935 r
F P
0 g
s
.62851 .1053 m .64237 .1028 L .64636 .10843 L p .402 .836 .951 r
F P
0 g
s
.6735 .11229 m .66019 .1089 L .64636 .10843 L p .62 .506 .702 r
F P
0 g
s
.68568 .11847 m .6735 .11229 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.6962 .12718 m .68568 .11847 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.70459 .13802 m .6962 .12718 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.71047 .15053 m .70459 .13802 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.71359 .16416 m .71047 .15053 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.7138 .1783 m .71359 .16416 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.66214 .24071 m .67532 .23552 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64834 .24306 m .66214 .24071 L p .64636 .10843 L .62 .506 .702 r
F P
0 g
s
.64237 .1028 m .68241 .16851 L .69265 .16797 L .619 .505 .702 r
F
.68287 .16849 m .68659 .17367 L .69465 .16786 L .289 .763 .934 r
F
.64237 .1028 m .69465 .17056 L .69465 .15696 L .619 .505 .702 r
F
.68287 .16849 m .66571 .17477 L .68659 .17367 L .289 .763 .934 r
F
.64237 .1028 m .6734 .16899 L .67416 .16895 L .619 .505 .702 r
F
.67111 .16911 m .66571 .17477 L .68287 .16849 L .289 .763 .934 r
F
.68241 .16851 m .69465 .21159 L .69465 .18859 L .619 .505 .702 r
F
.64237 .1028 m .67416 .16895 L .68241 .16851 L F
.67416 .16895 m .69465 .21159 L .68241 .16851 L F
.67111 .16911 m .63629 .17632 L .66571 .17477 L .289 .763 .934 r
F
.65452 .17 m .63629 .17632 L .67111 .16911 L F
.68358 .2229 m .69389 .21271 L p .6734 .16899 L .619 .505 .702 r
F P
0 g
s
.64237 .1028 m .66523 .16943 L .6734 .16899 L .619 .505 .702 r
F
.66523 .16943 m .68358 .2229 L .6734 .16899 L F
.59007 .1761 m .59679 .17841 L p .63218 .17118 L .289 .763 .934 r
F P
0 g
s
.61462 .17212 m .59007 .1761 L .63218 .17118 L .289 .763 .934 r
F
.59548 .21996 m .59679 .22106 L .59679 .23062 L .991 .809 .561 r
F
.59007 .1761 m .59679 .22106 L .59548 .21996 L F
.59007 .1761 m .59679 .17841 L p .59679 .22106 L F P
0 g
s
.59007 .36128 m .59007 .21429 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.5848 .20072 m .5877 .20693 L p .58761 .20984 L .744 .363 0 r
F P
0 g
s
.5877 .20693 m .59059 .21315 L .5892 .21161 L p .744 .363 0 r
F P
0 g
s
.5892 .21161 m .58761 .20984 L p .5877 .20693 L .744 .363 0 r
F P
0 g
s
.59007 .21429 m .59007 .2129 L p .59613 .22529 L .991 .809 .561 r
F P
0 g
s
.59059 .21315 m .59199 .21529 L .59007 .2129 L .591 .131 0 r
F
.58761 .20984 m .5892 .21161 L p .59007 .2129 L F P
0 g
s
.5892 .21161 m .59059 .21315 L p .59007 .2129 L .591 .131 0 r
F P
0 g
s
.59007 .2129 m .59007 .1761 L p .59543 .21957 L .991 .809 .561 r
F P
0 g
s
.59679 .15796 m .58154 .1732 L .59679 .16886 L .62 .506 .702 r
F
.64237 .1028 m .61386 .17216 L .62178 .17174 L .619 .505 .702 r
F
.59246 .17329 m .59007 .1761 L p .61462 .17212 L .289 .763 .934 r
F P
0 g
s
.59007 .1761 m .59007 .2129 L p .59246 .19978 L 0 0 .252 r
F P
0 g
s
.59246 .17329 m .59007 .1761 L p .59246 .19978 L 0 0 .252 r
F P
0 g
s
.58154 .1732 m .58174 .18721 L .57731 .18216 L p .913 .737 .242 r
F P
0 g
s
.58039 .19576 m .57731 .18216 L .58174 .18721 L p .853 .569 .034 r
F P
0 g
s
.58174 .18721 m .5848 .20072 L .58039 .19576 L p .853 .569 .034 r
F P
0 g
s
.57731 .18216 m .58039 .19576 L p .59246 .17766 L .619 .505 .702 r
F P
0 g
s
.64237 .1028 m .59246 .16368 L .59246 .17766 L .619 .505 .702 r
F
.59246 .16368 m .57731 .18216 L .59246 .17766 L F
.58761 .20984 m .58622 .20828 L p .58594 .2068 L .744 .363 0 r
F P
0 g
s
.5848 .20072 m .58761 .20984 L .58594 .2068 L .744 .363 0 r
F
.58622 .20828 m .58039 .19576 L .5848 .20072 L p F P
0 g
s
.58039 .19576 m .58622 .20828 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.65452 .17 m .59679 .17841 L .63629 .17632 L .289 .763 .934 r
F
.63218 .17118 m .59679 .17841 L .65452 .17 L F
.61714 .23425 m .63046 .23778 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.63046 .23778 m .64437 .23838 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67152 .23078 m .68358 .2229 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.65826 .23602 m .67152 .23078 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.64437 .23838 m .65826 .23602 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67808 .16181 m .63218 .17118 L .65452 .17 L .289 .763 .934 r
F
.6052 .17262 m .59246 .17766 L .59246 .19655 L .619 .505 .702 r
F
.64237 .1028 m .59548 .17313 L .6052 .17262 L F
.59548 .17313 m .59246 .17766 L .6052 .17262 L F
.59246 .17766 m .58039 .19576 L .59246 .19655 L F
.59543 .21957 m .59613 .22529 L .59007 .2129 L .991 .809 .561 r
F
.59007 .2129 m .59007 .21429 L p .59027 .21319 L 0 0 .252 r
F P
0 g
s
.59199 .21529 m .59454 .21917 L .59188 .21558 L .591 .131 0 r
F
.59007 .2129 m .59188 .21558 L .58761 .20984 L F
.59199 .21529 m .59188 .21558 L .59007 .2129 L F
.59613 .22529 m .59679 .23062 L .59007 .21429 L .991 .809 .561 r
F
.59617 .22197 m .59007 .21429 L .59573 .23184 L 0 0 .252 r
F
.59447 .21842 m .59454 .21917 L p .59199 .21529 L .591 .131 0 r
F P
0 g
s
.59472 .21873 m .59885 .22396 L .59454 .21917 L .591 .131 0 r
F
.59679 .22127 m .59885 .22396 L p .59199 .21529 L F P
0 g
s
.64237 .1028 m .59246 .19655 L .59454 .21917 L .619 .505 .702 r
F
.59027 .21319 m .59007 .21429 L .59617 .22197 L 0 0 .252 r
F
.59454 .21917 m .58622 .20828 L .58761 .20984 L p .591 .131 0 r
F P
0 g
s
.59246 .20079 m .59027 .21319 L .59246 .21646 L 0 0 .252 r
F
.59246 .20079 m .59007 .2129 L .59027 .21319 L F
.59246 .19978 m .59007 .2129 L .59246 .20079 L F
.58622 .20828 m .59246 .21646 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.59246 .21646 m .59454 .21917 L p .59246 .19655 L .619 .505 .702 r
F P
0 g
s
.60499 .22796 m .61714 .23425 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.67808 .16181 m .59246 .17329 L .61462 .17212 L .289 .763 .934 r
F
.59454 .21917 m .60499 .22796 L p .62178 .17174 L .619 .505 .702 r
F P
0 g
s
.61386 .17216 m .59454 .21917 L .62178 .17174 L .619 .505 .702 r
F
.60499 .22796 m .59454 .21917 L .59885 .22396 L p 0 .108 .589 r
F P
0 g
s
.59861 .16608 m .59246 .20079 L .59617 .22197 L 0 0 .252 r
F
.59246 .20079 m .59246 .21646 L .59617 .22197 L F
.59861 .16608 m .59833 .17251 L p .67808 .16181 L .289 .763 .934 r
F P
0 g
s
.59861 .16608 m .59246 .17329 L p .59745 .17262 L .289 .763 .934 r
F P
0 g
s
.59861 .16608 m .59246 .19978 L .59246 .20079 L 0 0 .252 r
F
.59861 .16608 m .59246 .17329 L p .59246 .19978 L F P
0 g
s
.59007 .21429 m .59007 .36128 L p .59573 .23184 L 0 0 .252 r
F P
0 g
s
.67808 .16181 m .61462 .17212 L .63218 .17118 L .289 .763 .934 r
F
.67808 .16181 m .65452 .17 L .67111 .16911 L F
.67808 .16181 m .67111 .16911 L .68287 .16849 L F
.69389 .21271 m .69465 .21159 L p .67416 .16895 L .619 .505 .702 r
F P
0 g
s
.6734 .16899 m .69389 .21271 L .67416 .16895 L .619 .505 .702 r
F
.69465 .21159 m .702 .20066 L p .69465 .18859 L F P
0 g
s
.68358 .2229 m .67152 .23078 L .67532 .23552 L p .642 .967 .868 r
F P
0 g
s
.67532 .23552 m .68729 .2277 L .68358 .2229 L p .642 .967 .868 r
F P
0 g
s
.69389 .21271 m .68358 .2229 L .68729 .2277 L p .748 .99 .792 r
F P
0 g
s
.67808 .22297 m .67808 .35065 L p .69465 .22084 L .995 .812 .548 r
F P
0 g
s
.69465 .21159 m .69389 .21271 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.69594 .2107 m .69465 .21159 L .69465 .22084 L .995 .812 .548 r
F
.69465 .21159 m .67808 .22297 L .69465 .22084 L F
.69465 .16786 m .67808 .16181 L p .68287 .16849 L .289 .763 .934 r
F P
0 g
s
.69829 .17305 m .70111 .17022 L p .68659 .17367 L .289 .763 .934 r
F P
0 g
s
.69265 .16797 m .69465 .18859 L .69465 .17056 L .619 .505 .702 r
F
.68241 .16851 m .69465 .18859 L .69265 .16797 L F
.70111 .17022 m .69465 .16786 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.702 .20066 m .70754 .18727 L p .69465 .17056 L .619 .505 .702 r
F P
0 g
s
.69465 .18859 m .702 .20066 L .69465 .17056 L .619 .505 .702 r
F
.67808 .16181 m .67808 .22297 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.69465 .16786 m .67808 .16181 L p .69465 .18502 L .995 .812 .548 r
F P
0 g
s
.69465 .18502 m .67808 .22297 L .69465 .21159 L .995 .812 .548 r
F
.71109 .19233 m .7138 .1783 L p .69829 .16223 L .62 .506 .702 r
F P
0 g
s
.70754 .18727 m .71027 .17314 L p .69465 .15696 L .619 .505 .702 r
F P
0 g
s
.69465 .17056 m .70754 .18727 L .69465 .15696 L .619 .505 .702 r
F
.702 .20066 m .69465 .21159 L p .70011 .20784 L .829 .979 .687 r
F P
0 g
s
.69594 .2107 m .67808 .35065 L .70111 .20715 L .995 .812 .548 r
F
.61364 .3673 m .59679 .363 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.59679 .363 m .59007 .36128 L p .59679 .23062 L .991 .809 .561 r
F P
0 g
s
.59007 .36128 m .59861 .35382 L .59861 .16608 L p 0 0 .252 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61364 .3673 m .65515 .36852 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.59007 .36128 m .61364 .3673 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60924 .23269 m .6213 .23895 L .61714 .23425 L p 0 .333 .74 r
F P
0 g
s
.63046 .23778 m .61714 .23425 L .6213 .23895 L p 0 .531 .846 r
F P
0 g
s
.6213 .23895 m .63453 .24246 L .63046 .23778 L p 0 .531 .846 r
F P
0 g
s
.64437 .23838 m .63046 .23778 L .63453 .24246 L p .19 .694 .908 r
F P
0 g
s
.63453 .24246 m .64834 .24306 L .64437 .23838 L p .19 .694 .908 r
F P
0 g
s
.67808 .16181 m .63522 .16006 L .59861 .16608 L p .289 .763 .934 r
F P
0 g
s
.59861 .35382 m .63522 .34935 L .63522 .16006 L p .42 .343 .664 r
F P
0 g
s
.59885 .22396 m .60924 .23269 L .60499 .22796 L p 0 .108 .589 r
F P
0 g
s
.61714 .23425 m .60499 .22796 L .60924 .23269 L p 0 .333 .74 r
F P
0 g
s
.63522 .16006 m .59861 .16608 L .59861 .35382 L p .42 .343 .664 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59861 .35382 m .59007 .36128 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64834 .24306 m .66214 .24071 L .65826 .23602 L p .362 .82 .929 r
F P
0 g
s
.67152 .23078 m .65826 .23602 L .66214 .24071 L p .513 .91 .914 r
F P
0 g
s
.66214 .24071 m .67532 .23552 L .67152 .23078 L p .513 .91 .914 r
F P
0 g
s
.63522 .34935 m .67808 .35065 L .67808 .16181 L p .768 .627 .704 r
F P
0 g
s
.65826 .23602 m .64437 .23838 L .64834 .24306 L p .362 .82 .929 r
F P
0 g
s
.67808 .16181 m .63522 .16006 L .63522 .34935 L p .768 .627 .704 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.65515 .36852 m .69122 .36429 L p .67808 .35065 L .224 .73 .894 r
F P
0 g
s
.67808 .35065 m .63522 .34935 L .59861 .35382 L p .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.69122 .36429 m .70111 .35691 L .67808 .35065 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.35405 1.29894 m .35023 1.2746 L .34646 1.29355 L p 0 0 .238 r
F P
0 g
s
.34646 1.29355 m .35023 1.31785 L .35405 1.29894 L p 0 0 .238 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.52826 1.29894 m .52325 1.31785 L .58611 1.31592 L p .683 .852 .964 r
F P
0 g
s
.58611 1.31592 m .59152 1.29708 L .52826 1.29894 L p .683 .852 .964 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.28695 .18216 m .28675 .16806 L .29322 .1732 L p .963 .778 .337 r
F P
0 g
s
.29582 .1593 m .29322 .1732 L .28675 .16806 L p .966 .885 .501 r
F P
0 g
s
.57731 .18216 m .57711 .16806 L .58154 .1732 L p .913 .737 .242 r
F P
0 g
s
.5842 .1593 m .58154 .1732 L .57711 .16806 L p .928 .861 .428 r
F P
0 g
s
.28675 .16806 m .28937 .15406 L .29582 .1593 L p .966 .885 .501 r
F P
0 g
s
.30112 .14611 m .29582 .1593 L .28937 .15406 L p .937 .954 .639 r
F P
0 g
s
.57711 .16806 m .57978 .15406 L .5842 .1593 L p .928 .861 .428 r
F P
0 g
s
.5896 .14611 m .5842 .1593 L .57978 .15406 L p .906 .944 .586 r
F P
0 g
s
.28937 .15406 m .2947 .14077 L .30112 .14611 L p .937 .954 .639 r
F P
0 g
s
.30888 .1342 m .30112 .14611 L .2947 .14077 L p .88 .991 .751 r
F P
0 g
s
.57978 .15406 m .58523 .14077 L .5896 .14611 L p .906 .944 .586 r
F P
0 g
s
.59753 .1342 m .5896 .14611 L .58523 .14077 L p .852 .987 .714 r
F P
0 g
s
.2947 .14077 m .30251 .12877 L .30888 .1342 L p .88 .991 .751 r
F P
0 g
s
.31877 .12408 m .30888 .1342 L .30251 .12877 L p .799 .999 .84 r
F P
0 g
s
.58523 .14077 m .59321 .12877 L .59753 .1342 L p .852 .987 .714 r
F P
0 g
s
.60764 .12408 m .59753 .1342 L .59321 .12877 L p .772 .997 .815 r
F P
0 g
s
.30251 .12877 m .31247 .11858 L .31877 .12408 L p .799 .999 .84 r
F P
0 g
s
.33038 .1162 m .31877 .12408 L .31247 .11858 L p .695 .978 .905 r
F P
0 g
s
.59321 .12877 m .60339 .11858 L .60764 .12408 L p .772 .997 .815 r
F P
0 g
s
.6195 .1162 m .60764 .12408 L .60339 .11858 L p .67 .974 .888 r
F P
0 g
s
.31247 .11858 m .32415 .11064 L .33038 .1162 L p .695 .978 .905 r
F P
0 g
s
.3432 .11091 m .33038 .1162 L .32415 .11064 L p .567 .926 .945 r
F P
0 g
s
.60339 .11858 m .61532 .11064 L .6195 .1162 L p .67 .974 .888 r
F P
0 g
s
.63259 .11091 m .6195 .1162 L .61532 .11064 L p .547 .921 .934 r
F P
0 g
s
.32415 .11064 m .33706 .1053 L .3432 .11091 L p .567 .926 .945 r
F P
0 g
s
.61532 .11064 m .62851 .1053 L .63259 .11091 L p .547 .921 .934 r
F P
0 g
s
.37022 .1089 m .35667 .10843 L .35062 .1028 L p .229 .713 .93 r
F P
0 g
s
.38324 .11229 m .37022 .1089 L .35667 .10843 L p .618 .504 .702 r
F P
0 g
s
.39516 .11847 m .38324 .11229 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.40546 .12718 m .39516 .11847 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41367 .13802 m .40546 .12718 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.41944 .15053 m .41367 .13802 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.42249 .16416 m .41944 .15053 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.42269 .1783 m .42249 .16416 L p .35667 .10843 L .618 .504 .702 r
F P
0 g
s
.35062 .1028 m .36426 .10327 L .37022 .1089 L p .229 .713 .93 r
F P
0 g
s
.38324 .11229 m .37022 .1089 L .36426 .10327 L p .021 .544 .86 r
F P
0 g
s
.64237 .1028 m .6563 .10327 L .66019 .1089 L p .238 .717 .935 r
F P
0 g
s
.6735 .11229 m .66019 .1089 L .6563 .10327 L p .055 .563 .881 r
F P
0 g
s
.36426 .10327 m .37737 .10668 L .38324 .11229 L p .021 .544 .86 r
F P
0 g
s
.39516 .11847 m .38324 .11229 L .37737 .10668 L p 0 .332 .739 r
F P
0 g
s
.6563 .10327 m .66969 .10668 L .6735 .11229 L p .055 .563 .881 r
F P
0 g
s
.68568 .11847 m .6735 .11229 L .66969 .10668 L p 0 .374 .784 r
F P
0 g
s
.28675 .16806 m .28695 .18216 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.28937 .15406 m .28675 .16806 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.57711 .16806 m .57731 .18216 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.57978 .15406 m .57711 .16806 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.2947 .14077 m .28937 .15406 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.58523 .14077 m .57978 .15406 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.37737 .10668 m .38937 .1129 L .39516 .11847 L p 0 .332 .739 r
F P
0 g
s
.40546 .12718 m .39516 .11847 L .38937 .1129 L p 0 .089 .568 r
F P
0 g
s
.66969 .10668 m .68195 .1129 L .68568 .11847 L p 0 .374 .784 r
F P
0 g
s
.6962 .12718 m .68568 .11847 L .68195 .1129 L p 0 .155 .642 r
F P
0 g
s
.30251 .12877 m .2947 .14077 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.59321 .12877 m .58523 .14077 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.31247 .11858 m .30251 .12877 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.60339 .11858 m .59321 .12877 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.38937 .1129 m .39974 .12166 L .40546 .12718 L p 0 .089 .568 r
F P
0 g
s
.41367 .13802 m .40546 .12718 L .39974 .12166 L p .629 .164 0 r
F P
0 g
s
.68195 .1129 m .69255 .12166 L .6962 .12718 L p 0 .155 .642 r
F P
0 g
s
.70459 .13802 m .6962 .12718 L .69255 .12166 L p 0 0 .459 r
F P
0 g
s
.39974 .12166 m .408 .13258 L .41367 .13802 L p .629 .164 0 r
F P
0 g
s
.41944 .15053 m .41367 .13802 L .408 .13258 L p .786 .401 0 r
F P
0 g
s
.69255 .12166 m .70099 .13258 L .70459 .13802 L p 0 0 .459 r
F P
0 g
s
.71047 .15053 m .70459 .13802 L .70099 .13258 L p .692 .318 0 r
F P
0 g
s
.32415 .11064 m .31247 .11858 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.61532 .11064 m .60339 .11858 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.41465 .20562 m .42004 .19233 L .41442 .18727 L p .923 .951 .614 r
F P
0 g
s
.70754 .18727 m .702 .20066 L .70559 .20562 L p .882 .931 .551 r
F P
0 g
s
.70559 .20562 m .71109 .19233 L .70754 .18727 L p .882 .931 .551 r
F P
0 g
s
.408 .13258 m .4138 .14518 L .41944 .15053 L p .786 .401 0 r
F P
0 g
s
.42249 .16416 m .41944 .15053 L .4138 .14518 L p .89 .603 .092 r
F P
0 g
s
.70099 .13258 m .70692 .14518 L .71047 .15053 L p .692 .318 0 r
F P
0 g
s
.71359 .16416 m .71047 .15053 L .70692 .14518 L p .81 .532 0 r
F P
0 g
s
.41708 .17314 m .41442 .18727 L .42004 .19233 L p .951 .876 .468 r
F P
0 g
s
.42004 .19233 m .42269 .1783 L .41708 .17314 L p .951 .876 .468 r
F P
0 g
s
.71027 .17314 m .70754 .18727 L .71109 .19233 L p .901 .842 .385 r
F P
0 g
s
.71109 .19233 m .7138 .1783 L .71027 .17314 L p .901 .842 .385 r
F P
0 g
s
.4138 .14518 m .41688 .1589 L .42249 .16416 L p .89 .603 .092 r
F P
0 g
s
.42269 .1783 m .42249 .16416 L .41688 .1589 L p .942 .761 .294 r
F P
0 g
s
.70692 .14518 m .71006 .1589 L .71359 .16416 L p .81 .532 0 r
F P
0 g
s
.7138 .1783 m .71359 .16416 L .71006 .1589 L p .879 .709 .191 r
F P
0 g
s
.41688 .1589 m .41708 .17314 L .42269 .1783 L p .942 .761 .294 r
F P
0 g
s
.71006 .1589 m .71027 .17314 L .7138 .1783 L p .879 .709 .191 r
F P
0 g
s
.35062 .1028 m .33706 .1053 L .32415 .11064 L p .617 .504 .702 r
F P
0 g
s
.64237 .1028 m .62851 .1053 L .61532 .11064 L p .619 .505 .702 r
F P
0 g
s
.37737 .10668 m .36426 .10327 L .35062 .1028 L p .617 .504 .702 r
F P
0 g
s
.38937 .1129 m .37737 .10668 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.39974 .12166 m .38937 .1129 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.408 .13258 m .39974 .12166 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.4138 .14518 m .408 .13258 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.41688 .1589 m .4138 .14518 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.41708 .17314 m .41688 .1589 L p .35062 .1028 L .617 .504 .702 r
F P
0 g
s
.66969 .10668 m .6563 .10327 L .64237 .1028 L p .619 .505 .702 r
F P
0 g
s
.68195 .1129 m .66969 .10668 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.69255 .12166 m .68195 .1129 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70099 .13258 m .69255 .12166 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70692 .14518 m .70099 .13258 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.71006 .1589 m .70692 .14518 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.71027 .17314 m .71006 .1589 L p .64237 .1028 L .619 .505 .702 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool=00000:h0oooo3000003K0?oo
o`00fP3oool4000000d0WH6c0P00002X0?ooo`@00000302NPK<300000=P0oooo003F0?ooo`@00000
4`2MPK<300000:40oooo1000000C09j1/`<00000e@3oool00=@0oooo0P00000K09f1/`800000V`3o
ool3000001/0WX6c0P00003B0?ooo`00d@3oool3000001l0WH6c0P00002F0?ooo`<00000802NPK<2
00000=00oooo003?0?ooo`8000002`2MPK<00`000000WH6c09f1/`0F09f1/`<00000T@3oool20000
02D0WX6c0`00003=0?ooo`00c@3oool2000002X0WH6c00<000000?ooo`3oool0R`3oool2000002/0
WX6c00<000000?ooo`3oool0b@3oool00<`0oooo00<0000009f1/`2MPK<0:`2MPK<00`000000oooo
0?ooo`290?ooo`030000002NPK<0WX6c02`0WX6c00<000000?ooo`3oool0b03oool00<X0oooo0P00
000_09f1/`030000003oool0oooo08L0oooo00<0000009j1/`2NPK<0;P2NPK<00`000000oooo0?oo
o`370?ooo`00b03oool200000380WH6c00<000000?ooo`3oool0Q03oool200000380WX6c0P000037
0?ooo`00a`3oool00`000000WH6c09f1/`0>09f1/`0309j1/`2MPK<0WH6c0280WH6c00<000000?oo
o`3oool0PP3oool00`000000WX6c09j1/`0d09j1/`030000003oool0oooo0<@0oooo00360?ooo`03
0000002MPK<0WH6c03D0WH6c00<000000?ooo`3oool0P03oool00`000000WX6c09j1/`0f09j1/`03
0000003oool0oooo0<<0oooo00350?ooo`030000002MPK<0WH6c03L0WH6c00<000000?ooo`3oool0
OP3oool00`000000WX6c09j1/`0h09j1/`030000003oool0oooo0<80oooo00340?ooo`030000002M
PK<0WH6c03T0WH6c00<000000?ooo`3oool0O03oool00`000000WX6c09j1/`0E09j1/`030?ooo`2N
PK<0WX6c0280WX6c00<000000?ooo`3oool0`@3oool00<@0oooo00<0000009f1/`2MPK<0>P2MPK<0
0`000000oooo0?ooo`1j0?ooo`030000002NPK<0WX6c03/0WX6c00<000000?ooo`3oool0`@3oool0
0<<0oooo00<0000009f1/`2MPK<03P2MPK<00`2NPK<0WH6c09f1/`0[09f1/`030000003oool0oooo
07P0oooo00<0000009j1/`2NPK<0?@2NPK<00`000000oooo0?ooo`300?ooo`00`P3oool00`000000
WH6c09f1/`0m09f1/`800000N03oool00`000000WX6c09j1/`0o09j1/`030000003oool0oooo0;l0
oooo00310?ooo`030000002MPK<0WH6c03l0WH6c0P00001f0?ooo`030000002NPK<0WX6c0440WX6c
00<000000?ooo`3oool0_P3oool00<00oooo00<0000009f1/`2MPK<0@@2MPK<00`000000oooo0?oo
o`1c0?ooo`030000002NPK<0WX6c0480WX6c00<000000?ooo`3oool0_P3oool00<00oooo00<00000
09f1/`2MPK<0@P2MPK<00`000000oooo0?ooo`1b0?ooo`030000002NPK<0WX6c01P0WX6c00<0oooo
09j1/`2NPK<0:02NPK<00`000000oooo0?ooo`2m0?ooo`00_`3oool00`000000WH6c09f1/`0>09f1
/`0309j1/`2MPK<0WH6c0380WH6c0P00001b0?ooo`030000002NPK<0WX6c04@0WX6c00<000000?oo
o`3oool0_@3oool00;h0oooo00<0000009f1/`2MPK<0A@2MPK<200000700oooo00<0000009j1/`2N
PK<0AP2NPK<00`000000oooo0?ooo`2l0?ooo`00_@3oool00`000000WH6c09f1/`1609f1/`800000
K`3oool00`000000WX6c09j1/`1709j1/`030000003oool0oooo0;`0oooo002m0?ooo`030000002M
PK<0WH6c04H0WH6c00<000000<UV00000000KP3oool00`000000WX6c09j1/`1809j1/`030000003o
ool0oooo0;/0oooo002l0?ooo`030000002MPK<0WH6c04P0WH6c0P00001]0?ooo`030000002NPK<0
WX6c04T0WX6c00<000000?ooo`3oool0^`3oool00;`0oooo00<0000009f1/`2MPK<03@2MPK<00`2N
PK<0WH6c09f1/`0h09f1/`0300000039IP00000006`0oooo00<0000009j1/`2NPK<0BP2NPK<00`00
0000oooo0?ooo`2j0?ooo`00^`3oool00`000000WH6c09f1/`1:09f1/`0300000039IP00oooo06X0
oooo00<0000009j1/`2NPK<0B`2NPK<00`000000oooo0?ooo`2j0?ooo`00^`3oool00`000000WH6c
09f1/`1:09f1/`0300000039IP00000006X0oooo00<0000009j1/`2NPK<0C02NPK<00`000000oooo
0?ooo`2i0?ooo`00^`3oool00`000000WH6c09f1/`1:09f1/`80000000<0bFH00?ooo`3oool0J03o
ool00`000000WX6c09j1/`1<09j1/`030000003oool0oooo0;T0oooo002j0?ooo`030000002MPK<0
WH6c04/0WH6c00@000000>>J5`0000000000J03oool00`000000WX6c09j1/`1=09j1/`800000^P3o
ool00;X0oooo00<0000009f1/`2MPK<02`2MPK<00`2NPK<0WH6c09f1/`0n09f1/`030000003SVQL0
000006P0oooo00<0000009j1/`2NPK<0CP2NPK<00`000000oooo0?ooo`2h0?ooo`00^P3oool00`00
0000WH6c09f1/`1<09f1/`040000003SVQL0hiXG000006L0oooo00<0000009j1/`2NPK<0CP2NPK<2
00000;T0oooo002i0?ooo`030000002MPK<0WH6c04d0WH6c00@000000>>J5`3SVQL00000IP3oool0
0`000000WX6c09j1/`1?09j1/`800000^@3oool00;T0oooo00<0000009f1/`2MPK<0C@2MPK<01000
0000hiXG0>>J5`00001V0?ooo`030000002NPK<0WX6c04l0WX6c0P00002i0?ooo`00^@3oool00`00
0000WH6c09f1/`1>09f1/`040000003SVQL0hiXG000006D0oooo00<0000009j1/`2NPK<0D02NPK<2
00000;P0oooo002i0?ooo`030000002MPK<0WH6c00P0WH6c00<0WX6c09f1/`2MPK<0@`2MPK<01000
0000hiXG0>>J5`00001U0?ooo`030000002NPK<0WX6c0500WX6c0P00002h0?ooo`00^03oool00`00
0000WH6c09f1/`1?09f1/`040000003SVQL0hiXG000006@0oooo00<0000009j1/`2NPK<06`2NPK<0
0`3oool0WX6c09j1/`0c09j1/`800000^03oool00;P0oooo00<0000009f1/`2MPK<0702MPK<@0000
02<0WH6c0P0000000`3SVQL000000?ooo`1S0?ooo`030000002NPK<0WX6c01l0WX6c4000000R09j1
/`800000^03oool00;P0oooo00<0000009f1/`2MPK<05P2MPK<600000080IU>X00<000000<BP]034
X;@02`34X;@?000001@0WH6c00<000000?72B`0000000P00001S0?ooo`030000002NPK<0WX6c01T0
WX6c1P00000206]GZ@0300000034X;@0a:2d00/0a:2d3`00000C09j1/`<00000]`3oool00;P0oooo
00<0000009f1/`2MPK<04@2MPK<5000000P0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0000000200000140WH6c00D000000?72B`3a`T/0lL9;0000001S0?ooo`030000002NPK<0WX6c01<0
WX6c1P00000806]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S00000000P00000@09j1/`03
0000003Q]C0000000;L0oooo002g0?ooo`030000002MPK<0WH6c00`0WH6c1P00000=06ICZ0030000
0034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<00P3lcY<4000000d0WH6c00D000000?72B`3a`T/0
lL9;0000001R0?ooo`030000002NPK<0WX6c00h0WX6c1P00000>06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`00P3nch`2000000h0WX6c00<000000>6e<0000000]`3oool00;L0oooo
00<0000009f1/`2MPK<02@2MPK<3000001<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`060?c>T`<000002P2MPK<01@000000lL9;0?72B`3a`T/000000680oooo00<0000009j1/`2N
PK<02`2NPK<3000001@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0040?k?S0<0
00002`2NPK<00`000000hKD`0000002g0?ooo`00]`3oool00`000000WH6c09f1/`0809f1/`800000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00T0o<jC00<0000009f1/`2MPK<0
1`2MPK<01@000000lL9;0?72B`3a`T/000000680oooo00<0000009j1/`2NPK<02P2NPK<2000001H0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0070?k?S0030000002NPK<0WX6c00P0
WX6c00<000000>6e<0000000]`3oool00;L0oooo00<0000009f1/`2MPK<0202MPK<2000001D0IU>X
00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0
lL9;0000001R0?ooo`030000002NPK<0WX6c00T0WX6c00<000000000@00000005P1[EjT00`000000
a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<2P2NPK<00`000000hKD`0000002g0?ooo`00
]`3oool00`000000WH6c09f1/`0709f1/`030000000002<0000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0lL9;0000001R0?ooo`03
0000002NPK<0WX6c00P0WX6c00@000000000@000040000005P1[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00P0o/n<2P2NPK<00`000000hKD`0000002g0?ooo`00]`3oool00`000000
WH6c09f1/`0709f1/`030000000002<0000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0:0?c>T`T0WH6c00D000000?72B`3a`T/0lL9;0000001R0?ooo`030000002NPK<0WX6c
00L0WX6c00D000000000@000040000100000000F06]GZ@0300000034X;@0a:2d01P0a:2d00<00000
0?k?S03nch`0203nch`:09j1/`030000003Q]C0000000;L0oooo002g0?ooo`030000002MPK<0WH6c
00L0WH6c0P0002<00`000000IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<02P3lcY<909f1/`8000000P3a`T/00`000000oooo0?ooo`1P0?ooo`030000002NPK<0WX6c
00L0WX6c100004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0203nch`:09j1/`<00000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`03
0000001VDjP0IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0
WH6c00<000000??PM`0000000P00001R0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`:09j1/`<0
0000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`030000001VDjP0IU>X01<0IU>X
00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`T0WH6c00D000000??PM`3ch7L0
ln1g0000001R0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000JeNY06]GZ@0D06]GZ@03
00000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`909j1/`040000003Vef80i]MR0000
0;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06ICZ00C06ICZ003
00000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<909f1/`050000003ch7L0ln1g0??P
M`000000HP3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`00
0000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<2@2NPK<010000000i]MR0>KGHP00002g
0?ooo`00]`3oool00`000000WH6c09f1/`0709f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC202MPK<00`000000ln1g0??PM`020??P
M`030000003oool0oooo0600oooo00<0000009j1/`2NPK<01`2NPK<40000@0030000001[EjT0JeNY
01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0T0WX6c00@000000>KG
HP3Vef800000]`3oool00;L0oooo00<0000009f1/`2MPK<01`2MPK<200008`030000001VDjP0IU>X
01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`P0WH6c00D000000??P
M`3ch7L0ln1g0000001S0?ooo`030000002NPK<0WX6c00L0WX6c100004000`000000JeNY06]GZ@0D
06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`909j1/`040000003Vef80
i]MR00000;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06ICZ00C
06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<809f1/`050000003ch7L0
ln1g0??PM`000000H`3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0501[
EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<01@000000i]MR0>KG
HP3Vef8000000;L0oooo002g0?ooo`030000002MPK<0WH6c00L0WH6c0P0002<00`000000IU>X06IC
Z00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<809f1/`050000003c
h7L0ln1g0??PM`000000H`3oool00`000000WX6c09j1/`0709j1/`@0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<010000000i]MR
0>KGHP00002h0?ooo`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP0
4`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC202MPK<01@000000ln1g
0??PM`3ch7L0000006@0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0P0WX6c00@000000>KGHP3V
ef800000^03oool00;P0oooo00<0000009f1/`2MPK<01P2MPK<200008`030000001VDjP0IU>X01<0
IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`P0WH6c00@0k?>M0000003c
h7L00000I@3oool00`000000WX6c09j1/`0609j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`00
0000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00P0o/n<202NPK<0103QkXd000000>KGHP00002h
0?ooo`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1`2MPK<00`000000k?>M0>ccW@020000
06D0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00<000000>7^S@3QkXd00P00002h0?oo
o`00^03oool00`000000WH6c09f1/`0609f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1`2MPK<01@000000k?>M0>ccW@3/lid00000
06D0oooo00<0000009j1/`2NPK<01P2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00D000000>7^S@3QkXd0hNj=0000002h
0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`00
0000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1P2MPK<00`000000k?>M0>ccW@020>cc
W@030000003oool0oooo06@0oooo00<0000009j1/`2NPK<01@2NPK<40000@0030000001[EjT0JeNY
01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0L0WX6c00D000000>7^
S@3QkXd0hNj=0000002h0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<0000006IC
Z01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1P2MPK<01@00
0000k?>M0>ccW@3/lid0000006L0oooo00<0000009j1/`2NPK<01@2NPK<30000@00309j1/`000000
JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0H0WX6c00D00000
0>7^S@3QkXd0hNj=0000002i0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<00000
06ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1@2MPK<0
0`000000k?>M0>ccW@020>ccW@030000003oool0oooo06D0oooo202NPK<30000@00309j1/`000000
JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0H0WX6c00D00000
0>7^S@3QkXd0hNj=0000002i0?ooo`00^@3oool00`000000WH6c09f1/`0509f1/`80000S00<00000
06ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00X0o<jC1@2MPK<0
0`000000k?>M0>ccW@020>ccW@030000003oool0oooo06D0oooo00<0000009j1/`2NPK<01@2NPK<3
0000@00309j1/`000000JeNY01D0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S008
0?k?S0H0WX6c00@000000>7^S@3QkXd00000^P3oool00;X0oooo00<0000009f1/`2MPK<0102MPK<2
00008`030000001VDjP0IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:
0?c>T`@0WH6c00<000000>ccW@3/lid00P3/lid2000006P0oooo00<0000009j1/`2NPK<0102NPK<4
0000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S008
0?k?S0D0WX6c00D000000>7^S@3QkXd0hNj=0000002j0?ooo`00^P3oool00`000000WH6c09f1/`04
09f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0
o<jC00X0o<jC102MPK<2000000<0k?>M0`00001V0?ooo`8000001P2NPK<40000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0D0WX6c00@00000
0>7^S@3QkXd00000^`3oool00;/0oooo00<0000009f1/`2MPK<00`2MPK<200008`030000001VDjP0
IU>X01<0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`<0WH6c00@00000
0=gm^`3MoK/000000P3/lid2000000030<e[00000000oooo06<0oooo00@000000:23/`2PPk<00000
1@2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<
0?k?S0080?k?S0@0WX6c00D000000=Cj[`000000hNj=0000002k0?ooo`00^`3oool00`000000WH6c
09f1/`0309f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00X0o<jC0`2MPK<010000000gOfk0=gm^`3MoK/20000000409n2/`000000cF/00000
06@0oooo00@000000:23/`2PPk<000001@2NPK<40000@0030000001[EjT0JeNY01@0JeNY00<00000
0<BP]034X;@06034X;@00`000000o/n<0?k?S0080?k?S0@0WX6c00@000000=Cj[`0000000000_03o
ool00;`0oooo00<0000009f1/`2MPK<00P2MPK<200008`030000001VDjP0IU>X01<0IU>X00<00000
0<BP]034X;@06034X;@00`000000o<jC0?c>T`0:0?c>T`80WH6c00<000000=gm^`3MoK/00`3MoK/0
1P000000Wh:c09n2/`000000cF/000000680oooo00<000000:23/`2PPk<00P2PPk<00`000000WX6c
09j1/`0209j1/`@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00P0o/n<0`2NPK<01@000000e?Z_0=Cj[`3DnZl000000;`0oooo002l0?ooo`030000
002MPK<0WH6c0080WH6c0P0002<00`000000IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<02P3lcY<209f1/`030000003MoK/000000080gOfk00L0000009n2/`2OP[<0
Wh:c0000003=J`0000000680oooo00<000000:23/`2PPk<00P2PPk<00`000000WX6c09j1/`0209j1
/`@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<
00P0o/n<0P2NPK<01@000000e?Z_0000003DnZl000000;d0oooo002m0?ooo`040000002MPK<0WH6c
09f1/`80000S00<0000006ICZ01VDjP04`1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0
o<jC00X0o<jC00D0WH6c0000003MoK/0o<jC000000020=gm^`030000002OP[<0Wh:c0080Wh:c0P00
001Q0?ooo`030000002PPk<0X8>c00@0X8>c00@0000009j1/`2NPK<0WX6c100004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01`2NPK<00000
0=Cj[`3nch`000000=Cj[`000000_@3oool00;h0oooo00<0000009f1/`2MPK<00P0002<00`000000
IU>X06ICZ00C06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<02P3lcY<01`2MPK<0
o<jC0?c>T`3lcY<000000=gm^`0000001@2OP[<00`000000cF/00000001P0?ooo`030000002PPk<0
X8>c00D0X8>c00<0000009j1/`2NPK<0100004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0203nch`0102NPK<0o/n<0?k?S03nch`200000;h0oooo002n
0?ooo`80000000@0WH6c00008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003l
cY<0o<jC00X0o<jC00@000000?c>T`3lcY<0o<jC0P00000609n2/`<00000G`3oool00`000000X8>c
0:23/`060:23/`80000000<0WX6c0000@00004000P0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01@000000o/n<0?k?S03nch`000000;l0
oooo002o0?ooo`050000002MPK<0000S00008`0000005@1VDjP00`000000a:2d0<BP]00H0<BP]003
0000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01@2OP[<010000000iidM00000000001N0?oo
o`030000002PPk<0X8>c00L0X8>c00<0000009j1/`0004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`030000003WWAd0000005h0oooo00<000000:23
/`2PPk<01`2PPk<2000000@0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo0P0000000`0002<0
000006ICZ00D06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03@3lcY<2000000P0
Wh:c00<000000>NM7@000000G@3oool00`000000X8>c0:23/`080:23/`03000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01P2OP[<00`000000
iidM0000001M0?ooo`030000002PPk<0X8>c00P0X8>c00<000000000@00000000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`040000003WWAd0iidM0000
05`0oooo00<000000:23/`2PPk<0202PPk<01000000000100000@00000020000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0
oooo0;d0oooo00300?ooo`040000000002<0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@0
0`000000o<jC0?c>T`0>0?c>T`030000002PP[<0Wh:c00L0Wh:c00<000000>NM7@000000G03oool0
0`000000X8>c0:23/`080:23/`0700000000040000100000@000000000100000000F06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0203nch`01@0004T0o/n<0?k?S03nch`000000;l0
oooo00300?ooo`040000003kcIH0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000002OP[<0X8:c00L0Wh:c00<000000>NM7@000000G03oool00`000000
X8>c0:23/`080:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
10000000Wh:c09n2/`2PP[<609n2/`80000000<0iidM0?ooo`3oool0F@3oool00`000000X8>c0:23
/`090:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S
0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<01@000000
Wh:c09n2/`2OP[<0X8:c00D0Wh:c00@000000??5D00000000000FP3oool00`000000X8>c0:23/`09
0:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0a:2d01P0a:2d
00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S0?_=
UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c
09n2/`0209n2/`030?ooo`2OP[<0Wh:c0080Wh:c00@000000??5D03caE000000FP3oool00`000000
X8>c0:23/`090:23/`0700000000040000100000@03mchl000100000000F06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S0?_=UP00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
0`000000Wh:c09n2/`0309n2/`050?ooo`2OP[<0Wh:c09n2/`0000000P3caE000`000000oooo0?oo
o`1H0?ooo`030000002PPk<0X8>c00T0X8>c00L000000000@000040000100?g?S`000400000001H0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0
oooo00300?ooo`040000000002<0nlfF000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00@0oooo09n2/`2OP[<000000P3caE000`00
0000oooo0?ooo`1H0?ooo`030000002PPk<0X8>c00P0X8>c0P0000030000@0030?g?S`0004000000
01H0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo
0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`00
0000o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00D0Wh:c00<0oooo09n2/`0000000P3caE000`00
0000oooo0?ooo`1H0?ooo`030000002PPk<0X8>c00L0X8>c00<000000000A00000001@0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050?ooo`000000llE@
0??5D0000000FP3oool00`000000X8>c0:23/`070:23/`030000000004@0000000D0001000<00000
06]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<00000
0?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H
0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<01`2OP[<010000000llE@0??5D000
001J0?ooo`030000002PPk<0X8>c00H0X8>c00@000000000A00004@000001@0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0709n2/`80000000<0llE@0000003oool0
F@3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`030000003ehG/0mN5k00800000
FP3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY
06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo
0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d
00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k0?GQN`00
0000FP3oool00`000000X8>c0:23/`060:23/`<0001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k0?GQ
N`000000FP3oool00`000000X8>c0:23/`050:23/`@0001400<000000000@00004000`0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`0609n2/`050000003ehG/0mN5k
0?GQN`000000FP3oool00`000000X8>c0:23/`040:23/`030000002PPk<000140080001400<00000
0000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<00000
0?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E
06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000Wh:c09n2/`05
09n2/`030000003ehG/0mN5k0080mN5k00<000000?ooo`3oool0F03oool00`000000X8>c0:23/`06
0:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<0
0`000000Wh:c09n2/`0509n2/`050000003ehG/0mN5k0?GQN`000000F`3oool00`000000X8>c0:23
/`060:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034
X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool0
10000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3l
cY<00`000000Wh:c09n2/`0509n2/`050000003ehG/0mN5k0?GQN`000000G03oool00`000000X8>c
0:23/`050:23/`<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03o
ool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<0
3P3lcY<00`000000Wh:c09n2/`0509n2/`8000000P3ehG/00`000000oooo0?ooo`1J0?ooo`030000
002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00<000000>gcW`3]lil00`00001L0?ooo`030000
002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000002OP[<0Wh:c00@0Wh:c00<000000>gcW`3]lil00P3]lil00`000000oooo
0?ooo`1J0?ooo`030000002PPk<0X8>c00D0X8>c0`0004@00`00000000100000@0030000@0030000
001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000
003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0>0?c>T`030000002OP[<0Wh:c00<0Wh:c0P0000040>gcW`030000
003oool0oooo05/0oooo00<000000:23/`2PPk<0102PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<00`2OP[<00`000000kO>O
0>gcW`020>gcW`030000003oool0oooo05`0oooo00<000000:23/`2PPk<0102PPk<30000A0030000
00000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<00000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<0
0`2OP[<00`000000kO>O0>gcW`020>gcW`030000003oool0oooo05`0oooo00<000000:23/`2PPk<0
102PPk<30000A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d
0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0
000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC
00<0000009n2/`2OP[<00P2OP[<00`000000kO>O0>gcW`020>gcW`030000003oool0oooo05h0oooo
00<000000:23/`2PPk<00`2PPk<30000A003000000000400001000<0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0
_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00h0o<jC00<0000009n2/`2OP[<00P2OP[<00`000000kO>O0>gcW`020>gcW`030000
003oool0oooo05h0oooo00<000000:23/`2PPk<00`2PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00L0000009n2/`2OP[<0Wh:c0000003OoKd00000
00<0kO>O00<000000?ooo`3oool0G`3oool00`000000X8>c0:23/`020:23/`<0001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<01@000000Wh:c09n2/`2OP[<0
00000080gofm0`00001R0?ooo`030000002PPk<0X8>c0080X8>c0`0004@00`00000000100000@003
0000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<
0?k?S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<00000
0<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`040000002OP[<0Wh:c000000D0gofm00<0
00000?ooo`3oool0H@3oool010000000X8>c0:23/`2PPk<30000A003000000000400001000<00010
00<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<
00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d
0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00@0000009n2/`2OP[<00000103OoKd00`000000
oooo0?ooo`1R0?ooo`040000002PPk<0X8>c0:23/`<0001400<000000000@00004000`0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<020000000Wh:c0000003OoKd0n/bG0000003OoKd00000
IP3oool00`000000X8>c0:23/`030000A003000000000400001000<0001000<0000006]GZ@1[EjT0
501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0
_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000
003lcY<0o<jC00h0o<jC00<0000009n2/`3jc9L00P3jc9L2000006P0oooo00<000000:23/`0004@0
0P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@0
6034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`0400000000
02<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`800000
0`3jc9L2000006P0oooo00<000000:23/`0004@00P0004@00`00000000100000@0030000@0030000
001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000
003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@0
6034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0
I`3oool2000000<0001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@030000
0034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03o
ool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<0
3P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000A00004@0
0P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@0
6034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`0400000000
02<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`040000
003jc9L0n/bG0?[<U`800000J@3oool00`00000000140000A0020000A003000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000
oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000bOoD0?[<U`020?[<U`030000003oool0oooo06L0
oooo00<000000000A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0
JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0
oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000
o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`000000
00140000A0020000A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000
a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo
00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0
o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080
001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0
a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S
00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000
n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`000000
00100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000
o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0
IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080
n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0
001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0
o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000
a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000
oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000@00004000`0004000`000000
JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000
oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0
a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0
oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY00<00000
0<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?oo
o`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>
0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P00000000140000A03l
cI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000
003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<00000
5@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L0
0P3jc9L00`000000oooo0?ooo`1W0?ooo`060000000004@000140?c=U00004@000001@0004000`00
0000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`00
0000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d
01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo
06L0oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY00<0
00000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo0030
0?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>
T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P00000000140000
A03lcI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]003
0000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<0
00005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3j
c9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`060000000004@000140?c=U00004@000001@000400
0`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`0
0`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0
a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0
oooo06L0oooo00H000000000A00004@0o<fD0000A00000050000@0030000001[EjT0JeNY01@0JeNY
00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo
00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC
0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool01P0000000014
0000A03lcI@00014000000D0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@000140080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A00004@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool0I`3oool00`00000000140000A0020000A003000000000400001000<0001000<0000006]G
Z@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP]0030000003nch`0o/n<00`0o/n<00<000000?oo
o`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP00`000000a:2d0<BP]00H0<BP
]0030000003lcY<0o<jC00h0o<jC00<000000?[<U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?oo
o`030000000004@000140080001400<000000000@00004000`0004000`000000JeNY06]GZ@0D06]G
Z@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?oo
o`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0a:2d01P0a:2d00<000000?c>
T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<U`030000003oool0oooo06L0oooo00<000000000
A00004@00P0004@00`00000000100000@0030000@0030000001[EjT0JeNY01@0JeNY00<000000<BP
]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0oooo0;d0oooo00300?ooo`04
0000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>
T`030000003jc9L0n/bG0080n/bG00<000000?ooo`3oool0I`3oool00`00000000140000A0020000
A003000000000400001000<0001000<0000006]GZ@1[EjT0501[EjT00`000000a:2d0<BP]00H0<BP
]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`00
02<000005@1VDjP00`000000a:2d0<BP]00H0<BP]0030000003lcY<0o<jC00h0o<jC00<000000?[<
U`3jc9L00P3jc9L00`000000oooo0?ooo`1W0?ooo`030000000004@0o<fD0080001400<000000000
@00004000`0004000`000000JeNY06]GZ@0D06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?
S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06IC
Z00300000034X;@0a:2d01P0a:2d00<000000?c>T`3lcY<03P3lcY<00`000000n/bG0?[<U`020?[<
U`030000003oool0oooo06L0oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00<000000?oo
o`3oool05@3oooll000001H0oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000
@0030000001[EjT0JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?
S0030000003oool0oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP
]034X;@06034X;@00`000000o<jC0?c>T`0>0?c>T`030000003jc9L0n/bG0080n/bG00@000000?oo
o`3oool0oooo5000000909j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D
00000080oooo00<000000000A03lcI@00P0004@00`00000000100000@0030000@0030000001[EjT0
JeNY01@0JeNY00<000000<BP]034X;@06034X;@00`000000o/n<0?k?S00<0?k?S0030000003oool0
oooo0;d0oooo00300?ooo`040000000002<0000S000001D0IU>X00<000000<BP]034X;@06034X;@0
0`000000o<jC0?c>T`060?c>Ta4000007@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0
b:Bc01/0b:Bc4@00000C06]GZ@0300000034X;@0a:2d01P0a:2d00<000000?k?S03nch`0303nch`0
0`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000E06ICZ00300000034X;@0
a:2d01D0a:2d3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02dTk@09P2dTk@0
0`000000b:Bc0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000706]GZ@0300000034X;@0
a:2d01P0a:2d00<000000?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool01000
0000000S00008`00000E06ICZ00300000034X;@0a:2d00T0a:2d3000000B08A/[`030000002NPK<0
WX6c0180WX6cD000000D0<RT/`030000003K/Zl0fk:_0100fk:_3000000F0<BP]0030000003nch`0
o/n<00`0o/n<00<000000?ooo`3oool0_@3oool00<00oooo00@0000000008`0002<000005@1VDjP0
0`000000a:2d00000009000001P0Q6b_6`00001@03Rji1D000007P3K/Zl:000000`0a:2d00<00000
0?k?S03nch`0303nch`00`000000oooo0?ooo`2m0?ooo`00`03oool010000000000S00008`00000?
06ICZ0P000000`1SD:L00`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@00000
0>c0Y`3/`:L0k<2W200000040<BP]0030000003nch`0o/n<00`0o/n<00<000000?ooo`3oool0_@3o
ool00<00oooo00@0000000008`0002<000001`1VDjP8000000/0He2W00<0000008A/[`24K:l01024
K:l<000009h0>;[T300000060=^b[`030000003/`:L0k<2W00T0k<2W2000000;0?k?S0030000003o
ool0oooo0;d0oooo00300?ooo`030000000002<0000S00P00000401SD:L:00000;H0>;[T1`00000C
0>c0Y`P000000`3nch`00`000000oooo0?ooo`2m0?ooo`00_@3oool600000100He2W2000003:03Rj
i0P00000403/`:L600000;d0oooo002h0?ooo`D000000P0f;9P00`000000He2W06=@Y`0906=@Y`P0
0000fP0h^^@8000000/0k<2W00<000000?[<V03jc9P01@00002h0?ooo`00/`3oool5000000L0=RbH
00<0000006=@Y`1SD:L00P1SD:L700000>X0>;[T200000030>c0Y`030000003jc9P0n/bH00D0n/bH
1000002d0?ooo`00[P3oool5000000X0=RbH1P00003j03Rji0@000002`3jc9P500000:l0oooo002Y
0?ooo`D000002`0f;9P400000?l0>;[T1P0h^^@4000000/0n/bH1@00002Z0?ooo`00Y@3oool40000
00`0=RbH1000003o03Rji0h0>;[T1000000<0?[<V0@00000YP3oool00:<0oooo0P0000000`0007`0
000003H/V00903H/V0@00000o`0h^^@F03Rji0@000002P3jc9P00`000000om1l0000000200000:<0
oooo002P0?ooo`<000000`0007`00`000000=RbH03H/V00403H/V0@00000o`0h^^@N03Rji0@00000
1P3jc9P00`000000om1l0?o@O0020?o@O0<00000X03oool009d0oooo0`0000060000O0030000000f
;9P0=RbH00@00000o`0h^^@V03Rji0@000000P3jc9P00`000000om1l0?o@O0050?o@O0800000WP3o
ool009/0oooo0P0000080000O0@00000o`0h^^@^03Rji0<000002@3od7`3000009/0oooo002H0?oo
o`<00000200007`200000?l0>;[T=P0h^^@3000000P0om1l0`00002H0?ooo`00UP3oool2000000P0
001l0`00003o03Rji3/0>;[T0`0000080?o@O0800000UP3oool009@0oooo0`0000060000O0<00000
o`0h^^A103Rji08000001`3od7`3000009@0oooo002C0?ooo`040000000004/0001;000000@0001l
0P00003o03Rji4H0>;[T0`0000040?o@O0040000003`a4/0l<A;000009<0oooo002A0?ooo`800000
0`0004/00`000000001l0000000200000?l0>;[TB`0h^^@3000000030?o@O0000000l<A;0080l<A;
0P00002A0?ooo`00T03oool00`000000001;0000B`030000B`800000o`0h^^AA03Rji08000001@3`
a4/00`000000oooo0?ooo`2>0?ooo`00SP3oool2000000@0001;0P00003o03Rji5D0>;[T0P000004
0?34B`800000SP3oool008d0oooo00<000000000B`0004/00`0004/00`000000>;[T03Rji03o03Rj
i5L0>;[T00<000000?34B`3`a4/00`3`a4/00`000000oooo0?ooo`2;0?ooo`00S@3oool010000000
001;0000B`0004/200000?l0>;[TF`0h^^@2000000<0l<A;00<000000?ooo`3oool0R`3oool008d0
oooo00@000000000B`0004/00000o`0h^^AO03Rji0040000003`a4/0l<A;000008d0oooo002=0?oo
o`<00000o`0h^^AQ03Rji0<00000S@3oool008`0oooo0P00003o03Rji6D0>;[T0P00002<0?ooo`00
S03oool2000001d0>;[T100i^^B@03Rji0030000000h^^@0>;[T0;00>;[T0P00002<0?ooo`00S03o
ool2000003/0>;[T1`0i^^AV03Rji0T0S7:a00<000000=J_/@3F[k403@3F[k6S03Rji0800000S03o
ool008`0oooo00<0000003Rji00h^^@0E`0h^^@<03Vji3X0>;[T00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0>;[T0P00002<0?ooo`00S03oool00`00
0000>;[T03Rji01e03Rji0l0>K[T5`0h^^@20000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T09D0>;[T00<000000?oo
o`3oool0RP3oool008`0oooo00<0000003Rji00h^^@0TP0h^^@303Vji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00<0
o/ma400h^^@703Vji8<0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h^^@0
U@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T01h0>;[T200i^^A_03Rji0030000
003oool0oooo08X0oooo002=0?ooo`030000000h^^@0>;[T09@0>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>;[T03Rji00`03Rji0T0>K[TF`0h^^@00`000000oooo0?ooo`2;0?ooo`00SP3oool2
000009@0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00=03Rji100>K[T9P0h^^@7
03Vji4P0>;[T0P00002>0?ooo`00T03oool00`000000>;[T03Rji02A03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0;@0h^^@<03Vji1d0>;[T1@0i^^@f03Rji0030000003oool0oooo
08h0oooo002A0?ooo`030000000h^^@0>;[T0900>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji01=03Rji0P0>K[T4`0h^^@403Vji2@0>;[T00<000000?ooo`3oool0S`3oool00980oooo
0P00002@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0K@0h^^@403Vji0X0>;[T
0P0i^^@A03Rji0800000TP3oool009@0oooo00<0000003Rji00h^^@0S@0h^^@00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?
L@060?k?L@030000000h^^@0>;[T08d0>;[T00<000000?ooo`3oool0TP3oool009H0oooo0P00002<
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@
0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0RP0h^^@2000009H0oooo002H0?oo
o`800000RP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0>;[T0200>;[T00<0000003Rj
i00h^^@0I@0h^^@2000009P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@03
0000000h^^@0>;[T08D0>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000>;[T03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@00000O`0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00Y@3oool50000
07X0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000Y@3oool00:X0
oooo1@00001H03Rji0030000000h^^@0>;[T01X0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00000T03Rji0<00000B@0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T04/0>;[T00<0000003Rji00h^^@0800h^^@500000:l0oooo
002d0?ooo`D00000J`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06T0>;[T1@00
002d0?ooo`00^@3oool5000006H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01T
03Rji0D00000^@3oool00;h0oooo1@00001Q03Rji003000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rj
i00h^^@0G`0h^^@500000;h0oooo00330?ooo`D00000G00h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k400`2=Lk40eZna000000070?k?L@03
0000000h^^@0>;[T05X0>;[T1@0000330?ooo`00b03oool5000005L0>;[T00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00l0eZna00<0SG>a0=J_/@000000
1`3ncg400`000000>;[T03Rji01E03Rji0D00000b03oool00<d0oooo1`00001@03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0?0=J_/@0308ec/@3F
[k40000000L0o/ma00<0000003Rji00h^^@0CP0h^^@700000<d0oooo003D0?ooo`X00000AP0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04@0>;[T2P00003D0?ooo`00gP3oool:0000
03`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00j03Rji0X00000gP3oool00>P0
oooo3@00000_03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0;@0h^^@=00000>P0
oooo003e0?oooa0000007`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T01d0>;[T
4000003e0?ooo`00o`3oool60?oooaT000001P0h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o0?oooal0oooo1`0000070000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@L00000o`3ooolO
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0>
0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0>
0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0>
0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@0508ec/@3F[k40eZna0=J_/@000000
1`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0eZna00D0SG>a0=J_/@3F[k40eZna
000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403@3F[k401@2=Lk40eZna0=J_
/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0<0=J_/@0308ec/@3F[k40eZna0080eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00`0eZna00<0SG>a0=J_/@3F[k400P3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40303F[k400`2=
Lk40eZna0=J_/@020=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0;0=J_/@0308ec/@3F[k40eZna00<0
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00/0eZna
00<0SG>a0=J_/@3F[k400`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k402P3F[k400`2=Lk40eZna0=J_
/@040=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0:
0=J_/@0308ec/@3F[k40eZna00@0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna00X0eZna00<0SG>a0=J_/@3F[k40103F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k402@3F[k400`2=Lk40eZna0=J_/@050=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@090=J_/@0308ec/@3F[k40eZna00D0eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00P0eZna00<0SG>a0=J_/@3F[k401P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k40203F[k400`2=Lk40eZna0=J_/@060=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@070=J_/@0308ec/@3F[k40eZna00L0eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna00L0eZna00<0SG>a0=J_/@3F[k401`3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k401P3F[k400`2=Lk40eZna0=J_/@080=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@060=J_/@0308ec/@3F[k40eZna00P0eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna00D0eZna00<0SG>a0=J_/@3F[k402@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40103F[k400`2=
Lk40eZna0=J_/@0:0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00``3oool3000005h0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000004@3o
ool00`000000NUVP07YIX005000005T0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj0000000000003`3oool00`000000NUVP07YIX006
07YIX0<00000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0000007YIX01jFJ00201jFJ000`00
0000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool00`000000Nfjj
07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YIX0800000EP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k400`3F[k400`2=Lk40eZna
0=J_/@0;0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03o
ool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000NUVP07YIX00807YIX0030000003o
ool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X
0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool02`3oool00`000000NUVP07YIX008
07YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool00`00
0000NUVP07YIX00707YIX0800000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YIX01j
FJ001`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001jFJ00NUVP00P0NUVP
00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00oooo0?ooo`090?ooo`030000001j
FJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`09
0?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo
00T0oooo00<0000007YIX01jFJ001`1jFJ02000005P0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0`7T00000003o
ool0203oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj
0P0000090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0201k
K[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P08
07]^^P030<1i00000000oooo00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj
00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00L0NUVP00<0gKjj0000003oool0F@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k400P3F[k400`2=
Lk40eZna0=J_/@0<0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool00`000000NUVP07YIX00807YIX003
0000003oool0oooo05P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01@3oool00`000000NUVP
07YIX00707YIX0800000FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`050?ooo`030000001j
FJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P8000001@3oool00`000000NUVP07YIX008
07YIX0800000FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0oooo00<0000007YIX01jFJ00201jFJ000`00
0000oooo0?ooo`1I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool00`000000NUVP07YIX00707YIX080
0000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo
0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YIX01jFJ001`1jFJ02000005/0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000001k
K[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0NUVP0P00001K0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool00`000000Nfjj07]^^P07
07]^^P8000000`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000001kK[X0Nfjj
00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP0P00001L0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool2000000T0Nfjj00D0`7T00000003o
ool0oooo0000000907YIX0800000G03oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X2000000030?ooo`000000NUVP00T0
NUVP0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[P3oool00`000000Nfjj07]^^P0707]^^P@00000201jFJ000`3M_[X000000000001M0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^
^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002^0?ooo`8000002@1kK[X3000000T0NUVP0P00001M0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0707]^
^P800000201jFJ00103M_[X0NUVP0<S7AP00001M0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0707]^^P8000002@1jFJ020000
05h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`03
0000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001`1jFJ02000005h0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`8000002@1kK[X00`000000NUVP
07YIX00707YIX0800000GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00;00oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00707YIX0030<S7AP00
0000oooo05d0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`
0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X00`00
0000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/@3oool00`000000Nfjj
07]^^P0707]^^P030000001jFJ00NUVP00D0NUVP00<0b<M60000003oool0GP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo00<0000007]^^P1kK[X0201k
K[X00`000000NUVP07YIX00307YIX0<00000G`3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00@000000=J_/@3F[k40SG>a403F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P060000001jFJ00NUVP07YIX03M_[X0
NUVP0P00001P0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
/@3oool2000000T0Nfjj00<0000007YIX01jFJ000`1jFJ0200000600oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0
000007YIX01jFJ000`1jFJ000`38adH000000?ooo`1O0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`000000Nfjj07]^^P0807]^^P040000001jFJ00
gKjj07YIX0<00000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;80oooo0P00000907]^^P040000001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo0P00000907]^^P040000001jFJ00
NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;<0oooo00<0000007]^^P1kK[X01`1kK[X01P000000gKjj07YIX01jFJ00b<M600000640oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`030000001k
K[X0Nfjj00P0Nfjj00<0000007YIX00000000P00001Q0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000HP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo0P000009
07]^^P040000001jFJ00000000000680oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002d0?ooo`030000001kK[X0Nfjj00L0Nfjj00@0000007YIX038adH00000HP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;@0oooo00<00000
07]^^P1kK[X0201kK[X300000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo002^0?ooob<00000D`3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:00oooo3P00000<04PkWP030000003aa:<0lLBS00`0lLBS3`00001<0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000o`3ooolR0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool;000000T03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP070?o@QP/0
0000o`3ooolG0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo
5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o
0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`2j0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`1F0?ooo`<00000^`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0E@3oool01@000000/h:O0;>2W`2c
PYl000000;X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo05@0oooo00<000000;>2W`2cPYl00`2cPYl0
0`000000oooo0?ooo`2g0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1C0?ooo`030000002cPYl0/h:O
00D0/h:O00<000000?ooo`3oool0]P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0DP3oool00`000000
/h:O0;>2W`070;>2W`030000003oool0oooo0;D0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0540oooo
00<000000;>2W`2cPYl02@2cPYl00`000000oooo0?ooo`2d0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`1@0?ooo`030000002cPYl0/h:O00/0/h:O00<000000?ooo`3oool0/`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0C`3oool00`000000/h:O0;>2W`0=0;>2W`030000003oool0oooo0;80oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo04h0oooo00<000000;>2W`2cPYl03`2cPYl00`000000oooo0?ooo`2a0?oo
o`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3o
ool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`1=0?ooo`030000002cPYl0/h:O0140/h:O00<000000?ooo`3o
ool0/03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0C03oool00`000000/h:O0;>2W`0C0;>2W`030000
003oool0oooo0:l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04/0oooo00<000000;>2W`2cPYl05@2c
PYl00`000000oooo0?ooo`2^0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1:0?ooo`030000002cPYl0
/h:O01L0/h:O00<000000?ooo`3oool0[@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0B03oool20000
01/0/h:O0P00002]0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`170?ooo`030000002cPYl0/h:O01d0
/h:O00<000000?ooo`3oool0ZP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0AP3oool00`000000/h:O
0;>2W`0O0;>2W`030000003oool0oooo0:T0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04D0oooo00<0
00000;>2W`2cPYl08@2cPYl00`000000oooo0?ooo`2X0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`14
0?ooo`030000002cPYl0/h:O02<0/h:O00<000000?ooo`3oool0Y`3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0@`3oool00`000000/h:O0;>2W`0U0;>2W`030000003oool0oooo0:H0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo0480oooo00<000000;>2W`2cPYl09`2cPYl00`000000oooo0?ooo`2U0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`110?ooo`030000002cPYl0/h:O02T0/h:O00<000000?ooo`3oool0
Y03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0@03oool00`000000/h:O0;>2W`0[0;>2W`030000003o
ool0oooo0:<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03l0oooo00<000000;>2W`2cPYl0;@2cPYl0
0`000000oooo0?ooo`2R0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000002cPYl0/h:O
02l0/h:O00<000000?ooo`3oool0X@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?@3oool00`000000
/h:O0;>2W`0a0;>2W`030000003oool0oooo0:00oooo002P0?ooo`0300000018>ih0B3^N00@0B3^N
:00000080?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?03oool00`000000/h:O
0;>2W`060;>2WbP000001@2cPYl00`000000oooo0?ooo`2O0?ooo`00T`3ooolD00000180AcZN00<0
00000?75X`3aaJ<04`3aaJ<G00000300oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3ooolG000001D0EDFS00<0
00000?G8WP3eb9h0403eb9hD000009<0oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0_000001<03@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QRl000000P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75Xc@000004@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om262@00000800D002400000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002d
Tk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2000002/0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@
QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@@2]I7/200d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H0@@2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000110:eT
N`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000:`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000
@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000003o
d8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/0
0`0=2hH000000;BC]00Y0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000002]I7/0[FAk
0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000
]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00
000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X
0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/20000
02/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b
0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;40[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk
05d0[FAk00<0[[KO0:eTN`2]I7/0DP2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1T0:eTN`030:jfg`2]I7/0[FAk04/0[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk06l0[FAk00<0[[KO0:eTN`2]I7/0@02]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1f0:eTN`030:jf
g`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/00`2^]]l0[FAk0:eTN`0b0:eTN`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk08@0
[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b
0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eT
N`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS]P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40
/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]
^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<G00000;@0[KSQ6`00000A05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0[VEl00<000000:fhh@2]^>40/P2]^>400`000000
[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ
0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04P3a
aJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^IG`D05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F
0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^IG`00`000000[KSQ0:fhh@2b0:fh
h@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0403aaJ<I0:iUO003
0000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05`2^IG`B05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0?0?75Xa/0[VEl00<000000:fhh@2]^>40/02]^>42000001X0[VEl4@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000J0:iUO140EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS00h0lLFS5@2^IG`00`3aaJ<0[VEl0:iUO0040:iUO0030000002]^>40
[KSQ0;00[KSQ0P00000K0:iUO100EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00h0lLFS702^IG`00`00
0000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0=0?75Xad0
[VEl00<000000:fhh@2]^>40/02]^>42000001`0[VEl3`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
303aaJ<N0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000L0:iUO0l0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01`0[VEl3P1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<O0:iUO0030000002]^>40[KSQ0;00[KSQ00<00000
0:iUO02^IG`07@2^IG`=05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0;0?75Xal0[VEl00<000000:fh
h@2]^>40/02]^>400`000000[VEl0:iUO00M0:iUO0d0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00X0
lLFS802^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01h0[VEl301EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`0
7P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75Xb40[VEl00<000000:fhh@2]^>40/02]
^>400`000000[VEl0:iUO00O0:iUO0/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00P0lLFS8P2^IG`0
0`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0200[VEl2P1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0203aaJ<R0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`0802^IG`:05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`070?75Xb<0[VEl00<000000:fhh@2]^>40/02]^>400`000000
[VEl0:iUO00Q0:iUO0T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00H0lLFS902^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl0240[VEl2@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3a
aJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`01@2^IG`00`1EAJ<0[VEl0:iU
O00J0:iUO0P0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00D0lLFS9@2^IG`00`000000[KSQ0:fhh@0b
0:fhh@030;^I1P2]^>40[KSQ04H0[KSQ00<000000:fhh@2]^>40<P2]^>400`000000[VEl0:iUO00S
0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00D0lLFSFP2^IG`00`2kV@H0[KSQ0:fhh@160:fh
h@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`040?75Xcl0[VEl00<0[KSQ0:iUO02^IG`06@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@03
0000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS00<0lLFSCP2^IG`00`2]^>40[VEl0:iUO00;0:iUO0030;^I
1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00T0:iUO0H0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00<0lLFSA@2^IG`00`2]^>40[VEl0:iUO00D0:iUO0030;^I1P2]
^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0
[VEl0380[VEl00<000000:iUO02^IG`05@2^IG`00`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS0080lLFSB`2^IG`00`2]^>40[VEl0:iUO00?0:iUO0030;^I1P2]^>40[KSQ
04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00V0:iUO0@0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP04
0000003aaJ<0lLFS0?75Xeh0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0F02^IG`00`2]^>40
[VEl0:iUO0040:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000
[VEl0:iUO00W0:iUO0<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS05l0[VEl00<0^iT60:fhh@2]^>40
AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02P0[VEl0P1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`L000007`17>Yh00`000000lLFS0:iU
O01O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iU
O00Y0:iUO00305E5X`000000mLRN01h0mLRN1`00002C0?ooo`00VP3oool<000001<0AcZN00<00000
0?75X`2^IG`0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<00000
0:iUO02^IG`0:@2^IG`00`1EAJ<000000?G8WP0B0?G8WP`00000VP3oool00:H0oooo3@00000604Lj
WP030000002^IG`0[VEl05l0[VEl00<0^iT6000000000000A`00000d0:iUO0030000002^IG`0[VEl
02X0[VEl00<000000?G8WP3eb9h0103eb9h=00000:H0oooo002c0?ooofX000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000000006L00000/`3oool00;T0oooo00<000000:fhhP2]^>80
G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000
003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool0
0`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo
0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR
0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR
00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i
0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?oo
o`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fh
hP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fh
hP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00
^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003o
ool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`00
0000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR
05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0
oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo
00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^`3oool00`000000[KSR0:fh
hP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<0
00000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?oo
o`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000
002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP80
00003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3o
ool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]
^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo0P00001O0:fhhP030000003o
ool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo00`0oooo0P00001O0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR
05d0[KSR00<000000?ooo`3oool03@3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0=0?ooo`030000002]^>80[KSR
05d0[KSR00<000000?ooo`3oool0^@3oool00;/0ooooH@00000?0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00d0
ooooH@00002k0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700<040f700D0om29010=Q`0@3HL040f70000000D
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`02010=Q`030?o@R@0@3HL040f7008040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool01@00000040f7010=Q`0@3HL0om2900D040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00@00000010=Q`0@3HL0om291P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0X0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01P0@3HL00`3od8T000000;BC]00C0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00>d0oooo?`000009010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8Lo00000>d0oooo003]0?ooo`03000000231@H0P`D600@0P`D600<0
GL[h08<51P231@H0=@231@H7010=Q`0308<51P0@3HL0000001@0]9>d00<000000?o@Q`3od8L01P3o
d8Lo08<51P030000003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D600/0P`D600<0GL[h
08<51P231@H0;`231@H8010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01@3od8M0
08<51P030000003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D60180P`D600<0GL[h08<5
1P231@H0:@231@H7010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0103od8M108<5
1P030000003oool0oooo0>/0oooo003/0?ooo`8000006P231@H305g:n2@0P`D60`0@3HL010231@H0
40f7010=Q`00000D0;BC]0030000003od8L0om2700<0om27@P231@H00`000000oooo0?ooo`3[0?oo
o`00k03oool00`000000P`D608<51P0P08<51P<0GL[h7`231@H4010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L00P3od8M308<51P030000003oool0oooo0>/0oooo003/0?ooo`030000
00231@H0P`D602L0P`D60`00000I08<51P<040f700<000000;BC]02dTk@04P2dTk@010000000om27
0?o@Q`3od8M508<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D602d0P`D6
1@2`[mLB08<51P8040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`1608<51P030000
003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D603@0P`D61@2`[mL<08<51P03010=Q`00
0000]9>d01<0]9>d00<000000?o@Q`231@H07@231@H50;2_eb@0P`D600<000000?ooo`3oool0jP3o
ool00>`0oooo00<0000008<51P231@H0>`231@H00`2`[mL00000010=Q`02010=Q`H0P`D600<00000
0;BC]02dTk@04P2dTk@00`000000P`D608<51P0[08<51PT0/:oG4P231@H00`000000oooo0?ooo`3Z
0?ooo`00k03ooonX00000>`0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3o
ool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03o
ool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0
/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>00oooo3@00002V0;5cSP030000003oool0oooo
0>X0oooo003P0?ooo`030000002dEUT0]5II00T0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000
oooo0?ooo`3Z0?ooo`00g`3oool2000000/0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo
0?ooo`3Z0?ooo`00g`3oool2000000/0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?oo
o`3Z0?ooo`00g`3oool00`000000000l0000000:0;AFF@030000002aLhh0/G>>0:@0/G>>00<00000
0?ooo`3oool0jP3oool00=l0oooo00<000000000?00000002P2dEUT00`000000/G>>0;5cSP2T0;5c
SP030000003oool0oooo0>X0oooo003N0?ooo`040000000003`0000l000000X0]5II00<000000;5c
SP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00gP3oool010000000000l0000?000000:0;AF
F@030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00=h0oooo00@000000000?000
03`000002P2dEUT00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003N0?ooo`04
0000000003`0000l000000X0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?oo
o`00g@3oool01@000000000l0000?00003`0000000X0]5II00<000000;5cSP2aLhh0Y02aLhh00`00
0000oooo0?ooo`3Z0?ooo`00g@3oool01@000000000l0000?00003`0000000X0]5II00<000000;5c
SP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00g@3oool00`000000000l0000?0020000?003
0000002dEUT0]5II00L0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00
g@3oool00`000000000l0000?0020000?0030000002dEUT0]5II00L0]5II00<000000;5cSP2aLhh0
Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00g@3oool00`000000000l0000?0020000?0030000002d
EUT0]5II00L0]5II00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00gP3oool0
10000000000l0000?00003`;00000:H0/G>>00<000000?ooo`3oool0jP3oool00=h0oooo00D00000
0000?00003`0000l000000090:oImZP00000k03oool00=h0oooo00D000000000?00003`0000l0000
00090:oImP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00=h0oooo00D00000
0000?00003`0000l000000090:oImP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3o
ool00=h0oooo00@000000000?00003`000002P2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003o
ool0oooo0>X0oooo003N0?ooo`040000000003`0000l000000X0[mWf00<000000;2`e`2`/=L0Y02`
/=L00`000000oooo0?ooo`3Z0?ooo`00g`3oool00`000000000l0000000:0:oImP030000002`/=L0
/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00=l0oooo00<000000000?00000002P2_fOH00`00
0000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003O0?ooo`030000000003`0000000X0
[mWf00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00g`3oool00`000000000l
0000000:0:oImP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00=l0oooo0P00
000;0:oImP030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>00oooo00<00000
0:oImP2_fOH02@2_fOH00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003P0?oo
o`030000002_fOH0[mWf00@0[mWf1P00002V0;2`e`030000003oool0oooo0>X0oooo003P0?ooo`L0
00001@3oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000
002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`
/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0
oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0
oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooojP00000k03oool00>`0oooo00<00000
05K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000E/Se05K8m@2T05K8
m@030000003oool0oooo0>X0oooo003]0?ooo`030000001Fb?D0E/Se0:80E/Se00<000000?ooo`3o
ool0j`3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?ooo`00k@3o
oonV00000>d0oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.67803 .40902 m .6476 .41312 L .6476 .24575 L p .391 .319 .656 r
F P
0 g
s
.6476 .24575 m .67803 .24025 L .67803 .40902 L p .391 .319 .656 r
F P
0 g
s
.59568 .25697 m .59524 .24447 L .61318 .24633 L p .849 .671 .66 r
F P
0 g
s
.61318 .24633 m .61362 .25879 L .59568 .25697 L p .849 .671 .66 r
F P
0 g
s
.61397 .23343 m .61318 .24633 L .59524 .24447 L p .842 .727 .737 r
F P
0 g
s
.59732 .26852 m .59568 .25697 L .61362 .25879 L p .845 .598 .565 r
F P
0 g
s
.61362 .25879 m .61528 .27031 L .59732 .26852 L p .845 .598 .565 r
F P
0 g
s
.6476 .41312 m .60892 .41278 L .60892 .27909 L p .726 .592 .707 r
F P
0 g
s
.60902 .27914 m .6476 .41312 L .60892 .27909 L .726 .592 .707 r
F
.61819 .28552 m .6476 .41312 L .60902 .27914 L F
.61005 .27962 m .60902 .27914 L .60892 .2788 L F
.61819 .28552 m .60902 .27914 L .61005 .27962 L F
.6181 .28041 m .61987 .28418 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.61005 .27962 m .6181 .28041 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.59732 .26852 m .61528 .27031 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.60892 .27909 m .60892 .2788 L p .60902 .27914 L .726 .592 .707 r
F P
0 g
s
.61528 .27031 m .6181 .28041 L .61005 .27962 L p .824 .499 .439 r
F P
0 g
s
.61528 .27031 m .61005 .27962 L .605 .27596 L .824 .499 .439 r
F
.59524 .24447 m .59603 .23154 L .61397 .23343 L p .842 .727 .737 r
F P
0 g
s
.61597 .22065 m .61397 .23343 L .59603 .23154 L p .826 .772 .801 r
F P
0 g
s
.59603 .23154 m .59801 .21872 L .61597 .22065 L p .826 .772 .801 r
F P
0 g
s
.6191 .2085 m .61597 .22065 L .59801 .21872 L p .801 .81 .858 r
F P
0 g
s
.59801 .21872 m .60111 .20654 L .6191 .2085 L p .801 .81 .858 r
F P
0 g
s
.59524 .24447 m .5953 .24626 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.5953 .24626 m .59568 .25697 L p .5969 .24561 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .5953 .24626 L .5969 .24561 L .042 .034 .521 r
F
.61318 .24633 m .61324 .24811 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.61324 .24811 m .61362 .25879 L p .61486 .24746 L .049 .04 .524 r
F P
0 g
s
.6191 .2085 m .61324 .24811 L .61486 .24746 L .049 .04 .524 r
F
.61397 .23343 m .61318 .24633 L p .6191 .2085 L F P
0 g
s
.61362 .25879 m .61528 .27031 L p .61674 .24669 L .049 .04 .524 r
F P
0 g
s
.6191 .2085 m .61486 .24746 L .61674 .24669 L .049 .04 .524 r
F
.61486 .24746 m .61362 .25879 L .61674 .24669 L F
.6476 .24575 m .67803 .24025 L p .65012 .23315 L .289 .763 .934 r
F P
0 g
s
.61528 .27031 m .6181 .28041 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.61987 .24543 m .6476 .24575 L p .63711 .23843 L .289 .763 .934 r
F P
0 g
s
.6181 .28041 m .61987 .28418 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.6476 .24575 m .6476 .30684 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.61987 .24543 m .6476 .24575 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.6476 .30684 m .6476 .41312 L p .61987 .29279 L .726 .592 .707 r
F P
0 g
s
.61819 .28552 m .61987 .28674 L .61987 .29279 L .726 .592 .707 r
F
.61987 .28674 m .6476 .30684 L .61987 .29279 L F
.6191 .2085 m .61987 .28418 L .61987 .22993 L .049 .04 .524 r
F
.60892 .2453 m .61987 .26271 L .61819 .28552 L .726 .592 .707 r
F
.61987 .26271 m .6476 .30684 L .61987 .28674 L F
.61987 .26271 m .61987 .28674 L .61819 .28552 L F
.67803 .24025 m .68252 .23183 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.61987 .21121 m .6264 .24277 L .62854 .2419 L .049 .04 .524 r
F
.61987 .21215 m .63805 .29906 L .61987 .21121 L F
.63214 .2982 m .63805 .29906 L p .61987 .21215 L F P
0 g
s
.61987 .21376 m .63214 .2982 L .61987 .21215 L .049 .04 .524 r
F
.65012 .23315 m .67803 .24025 L .65945 .22936 L .289 .763 .934 r
F
.68252 .40275 m .67803 .40902 L .67803 .24025 L p 0 0 .164 r
F P
0 g
s
.67803 .24025 m .68252 .23183 L .68252 .40275 L p 0 0 .164 r
F P
0 g
s
.68252 .23183 m .66471 .22723 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.6191 .2085 m .66471 .23582 L .66471 .22382 L .049 .04 .524 r
F
.68252 .23183 m .66471 .22723 L p .66471 .26726 L .966 .789 .613 r
F P
0 g
s
.63711 .23843 m .6476 .24575 L .65012 .23315 L .289 .763 .934 r
F
.66117 .2763 m .66551 .2652 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.656 .28558 m .66117 .2763 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66117 .2763 m .66471 .26726 L p .65 .26398 L .764 .849 .915 r
F P
0 g
s
.66117 .2763 m .65 .26398 L .64848 .26458 L .764 .849 .915 r
F
.6191 .2085 m .66471 .24909 L .66471 .23582 L .049 .04 .524 r
F
.66551 .2652 m .66884 .25277 L p .6191 .2085 L F P
0 g
s
.65024 .29264 m .656 .28558 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.64417 .2972 m .65024 .29264 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.62671 .29467 m .63214 .2982 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.62196 .28864 m .62671 .29467 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65761 .22539 m .64634 .22526 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.6191 .2085 m .61987 .21376 L .61987 .21215 L .049 .04 .524 r
F
.6191 .2085 m .61597 .22065 L .61397 .23343 L p F P
0 g
s
.60111 .20654 m .63786 .22875 L .64634 .22526 L .042 .034 .521 r
F
.64634 .22184 m .64634 .22526 L .65089 .22338 L F
.60111 .20654 m .64634 .22526 L .64634 .22184 L F
.63805 .29906 m .64417 .2972 L p .62854 .2419 L .049 .04 .524 r
F P
0 g
s
.6264 .24277 m .63805 .29906 L .62854 .2419 L .049 .04 .524 r
F
.61987 .28418 m .62196 .28864 L p .61987 .22993 L F P
0 g
s
.60892 .2453 m .61987 .24543 L p .61987 .26271 L .726 .592 .707 r
F P
0 g
s
.60892 .2453 m .61987 .24543 L p .61894 .23653 L .289 .763 .934 r
F P
0 g
s
.60111 .20654 m .6238 .23453 L .6296 .23214 L .042 .034 .521 r
F
.64112 .2274 m .65945 .22936 L .64634 .22526 L .289 .763 .934 r
F
.66196 .26484 m .65071 .2637 L p .66471 .26726 L .764 .849 .915 r
F P
0 g
s
.64112 .2274 m .65012 .23315 L .65945 .22936 L .289 .763 .934 r
F
.60111 .20654 m .6296 .23214 L .63786 .22875 L .042 .034 .521 r
F
.61773 .22491 m .63594 .22954 L .64112 .2274 L .289 .763 .934 r
F
.63594 .22954 m .65012 .23315 L .64112 .2274 L F
.65761 .22539 m .64634 .26541 L .64854 .26455 L .726 .593 .707 r
F
.61773 .22491 m .63711 .23843 L .65012 .23315 L .289 .763 .934 r
F
.65761 .22539 m .64634 .22526 L p .64634 .26541 L .726 .593 .707 r
F P
0 g
s
.65044 .25087 m .65256 .23763 L p .64634 .23387 L .042 .034 .521 r
F P
0 g
s
.63786 .22875 m .64634 .24366 L .64634 .23387 L .042 .034 .521 r
F
.64634 .24366 m .65044 .25087 L .64634 .23387 L F
.62866 .23253 m .61987 .24543 L .63711 .23843 L .289 .763 .934 r
F
.61894 .23653 m .61987 .24543 L .62866 .23253 L F
.64283 .27448 m .64714 .26334 L p .6238 .23453 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .61941 .23634 L .6238 .23453 L .042 .034 .521 r
F
.61941 .23634 m .64283 .27448 L .6238 .23453 L F
.61136 .23965 m .60892 .2453 L .61894 .23653 L .289 .763 .934 r
F
.6377 .28379 m .64283 .27448 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61894 .23653 L .62866 .23253 L .289 .763 .934 r
F
.6296 .23214 m .65044 .25087 L .63786 .22875 L .042 .034 .521 r
F
.64874 .2637 m .64854 .26455 L .65 .26398 L .726 .593 .707 r
F
.64874 .2637 m .65071 .2637 L .65267 .26251 L F
.65761 .22539 m .65761 .25949 L p .65969 .26204 L .966 .789 .613 r
F P
0 g
s
.65071 .2637 m .66196 .26484 L p .65761 .25949 L .803 .818 .863 r
F P
0 g
s
.66471 .26726 m .65071 .2637 L .65 .26398 L .764 .849 .915 r
F
.66471 .22723 m .65761 .22539 L p .65945 .22936 L .289 .763 .934 r
F P
0 g
s
.656 .28558 m .66117 .2763 L .64283 .27448 L p .705 .871 .96 r
F P
0 g
s
.64283 .27448 m .66117 .2763 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.64714 .26334 m .64634 .26541 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.64634 .26541 m .64283 .27448 L p .64848 .26458 L .764 .849 .915 r
F P
0 g
s
.63214 .2982 m .63805 .29906 L .6199 .29733 L p .106 0 0 r
F P
0 g
s
.62671 .29467 m .63214 .2982 L .61405 .29647 L p .434 0 0 r
F P
0 g
s
.6199 .29733 m .61405 .29647 L .63214 .2982 L p .106 0 0 r
F P
0 g
s
.62597 .29545 m .6199 .29733 L .63805 .29906 L p .226 .729 .901 r
F P
0 g
s
.63805 .29906 m .64417 .2972 L .62597 .29545 L p .226 .729 .901 r
F P
0 g
s
.632 .29088 m .62597 .29545 L .64417 .2972 L p .465 .842 .987 r
F P
0 g
s
.64417 .2972 m .65024 .29264 L .632 .29088 L p .465 .842 .987 r
F P
0 g
s
.6377 .28379 m .632 .29088 L .65024 .29264 L p .613 .875 .991 r
F P
0 g
s
.65024 .29264 m .656 .28558 L .6377 .28379 L p .613 .875 .991 r
F P
0 g
s
.64283 .27448 m .6377 .28379 L .656 .28558 L p .705 .871 .96 r
F P
0 g
s
.64634 .27408 m .64223 .26701 L .61773 .3976 L .726 .593 .707 r
F
.632 .29088 m .6377 .28379 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60187 .24356 m .60892 .2453 L p .61136 .23965 L .289 .763 .934 r
F P
0 g
s
.60187 .28242 m .60012 .27864 L .6082 .27943 L p .77 .356 .265 r
F P
0 g
s
.605 .27596 m .60892 .2788 L .60012 .27864 L .824 .499 .439 r
F
.6082 .27943 m .60012 .27864 L p .60892 .2788 L F P
0 g
s
.60012 .27864 m .59797 .27086 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.59797 .27086 m .59732 .26852 L p .605 .27596 L .824 .499 .439 r
F P
0 g
s
.60012 .27864 m .60187 .28242 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60187 .28499 m .6082 .27943 L .60187 .36399 L .96 .784 .62 r
F
.60187 .36399 m .6082 .27943 L .60892 .41278 L F
.60892 .27909 m .60892 .41278 L p .6082 .27943 L F P
0 g
s
.60111 .20654 m .60187 .28242 L .60187 .22802 L .042 .034 .521 r
F
.59568 .25697 m .59732 .26852 L p .60111 .20654 L F P
0 g
s
.59732 .26852 m .60012 .27864 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.58382 .23912 m .60187 .26765 L .59173 .29388 L .96 .784 .62 r
F
.60187 .26765 m .60892 .2788 L .60187 .28499 L F
.60187 .26765 m .60187 .28499 L .59173 .29388 L F
.61005 .27962 m .60776 .28234 L .60761 .28045 L .77 .356 .265 r
F
.60776 .28234 m .60394 .2869 L .60761 .28045 L F
.60394 .2869 m .60187 .28242 L p .60761 .28045 L F P
0 g
s
.60892 .2788 m .60892 .27909 L p .6082 .27943 L .96 .784 .62 r
F P
0 g
s
.6082 .27943 m .61005 .27962 L p .60187 .28242 L .77 .356 .265 r
F P
0 g
s
.62196 .28864 m .62671 .29467 L .60865 .29294 L p .655 .143 .015 r
F P
0 g
s
.59603 .23154 m .59524 .24447 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.60892 .2453 m .60892 .2788 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.58382 .23912 m .60187 .24356 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.60187 .24356 m .60892 .2453 L p .60187 .26765 L .96 .784 .62 r
F P
0 g
s
.60892 .26016 m .60892 .2453 L p .611 .25433 L .726 .592 .707 r
F P
0 g
s
.611 .25433 m .61819 .28552 L .60892 .26016 L .726 .592 .707 r
F
.60892 .2788 m .60892 .26016 L p .61819 .28552 L F P
0 g
s
.62196 .28864 m .60394 .2869 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.61987 .28418 m .62196 .28864 L p .6149 .28187 L .77 .356 .265 r
F P
0 g
s
.6149 .28187 m .60394 .2869 L .61005 .27962 L .77 .356 .265 r
F
.60865 .29294 m .60394 .2869 L .62196 .28864 L p .655 .143 .015 r
F P
0 g
s
.61405 .29647 m .60865 .29294 L .62671 .29467 L p .434 0 0 r
F P
0 g
s
.61405 .29647 m .6199 .29733 L p .60187 .2102 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .60187 .2118 L .60187 .2102 L .042 .034 .521 r
F
.60187 .2118 m .61405 .29647 L .60187 .2102 L F
.61005 .27962 m .6082 .27943 L p .60892 .2788 L .824 .499 .439 r
F P
0 g
s
.60865 .29294 m .61405 .29647 L p .60187 .2118 L .042 .034 .521 r
F P
0 g
s
.60111 .20654 m .60187 .21522 L .60187 .2118 L .042 .034 .521 r
F
.60187 .21522 m .60865 .29294 L .60187 .2118 L F
.60187 .28242 m .60394 .2869 L p .60187 .22802 L F P
0 g
s
.59173 .29388 m .60187 .28499 L .60187 .36399 L .96 .784 .62 r
F
.62597 .29545 m .632 .29088 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61136 .23965 L .61894 .23653 L .289 .763 .934 r
F
.6199 .29733 m .62597 .29545 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .61773 .27658 L p .64223 .26701 L .726 .593 .707 r
F P
0 g
s
.61773 .27658 m .61773 .3976 L p .64223 .26701 L .726 .593 .707 r
F P
0 g
s
.66471 .22723 m .65761 .22539 L p .65969 .26204 L .966 .789 .613 r
F P
0 g
s
.66471 .26822 m .65969 .26204 L .66471 .35065 L .966 .789 .613 r
F
.66471 .22723 m .65969 .26204 L .66471 .26822 L F
.65761 .22539 m .64874 .2637 L .65267 .26251 L .726 .593 .707 r
F
.65761 .26101 m .65761 .25949 L p .65267 .26251 L F P
0 g
s
.65761 .25949 m .65761 .22539 L p .65267 .26251 L .726 .593 .707 r
F P
0 g
s
.66551 .2652 m .66884 .25277 L .66865 .25275 L p .803 .818 .863 r
F P
0 g
s
.66865 .25275 m .65062 .25089 L p .65881 .25876 L .803 .818 .863 r
F P
0 g
s
.66551 .2652 m .66865 .25275 L .65881 .25876 L .803 .818 .863 r
F
.65062 .25089 m .65044 .25087 L p .65119 .25159 L F P
0 g
s
.66551 .2652 m .65062 .25089 L .65119 .25159 L .803 .818 .863 r
F
.66551 .2652 m .65876 .25879 L .65761 .25949 L F
.66196 .26484 m .66551 .2652 L p .65761 .25949 L F P
0 g
s
.66471 .35065 m .65969 .26204 L .65761 .39797 L .966 .789 .613 r
F
.65761 .25949 m .65761 .39797 L p .65969 .26204 L F P
0 g
s
.65044 .25087 m .64714 .26334 L .65071 .2637 L p .803 .818 .863 r
F P
0 g
s
.65876 .25879 m .65044 .25087 L .65071 .2637 L .803 .818 .863 r
F
.64874 .2637 m .65 .26398 L .65071 .2637 L .726 .593 .707 r
F
.65267 .26251 m .65071 .2637 L .65761 .26101 L F
.65071 .2637 m .64714 .26334 L p .65 .26398 L .764 .849 .915 r
F P
0 g
s
.64854 .26455 m .64634 .26541 L .64634 .27408 L .726 .593 .707 r
F
.64714 .26334 m .65044 .25087 L p .6296 .23214 L .042 .034 .521 r
F P
0 g
s
.6238 .23453 m .64714 .26334 L .6296 .23214 L .042 .034 .521 r
F
.64634 .22526 m .61773 .22491 L p .64112 .2274 L .289 .763 .934 r
F P
0 g
s
.63786 .22875 m .65256 .23763 L .65089 .22338 L .042 .034 .521 r
F
.64634 .22526 m .61773 .22491 L p .64634 .27408 L .726 .593 .707 r
F P
0 g
s
.65256 .23763 m .6534 .22423 L p .65089 .22338 L .042 .034 .521 r
F P
0 g
s
.61773 .3976 m .65761 .39797 L .65761 .26101 L p .726 .593 .707 r
F P
0 g
s
.64854 .26455 m .61773 .3976 L .65761 .26101 L .726 .593 .707 r
F
.64848 .26458 m .65 .26398 L .64714 .26334 L .764 .849 .915 r
F
.66471 .26726 m .66551 .2652 L .66196 .26484 L p F P
0 g
s
.67575 .277 m .66471 .26726 L .66471 .35065 L .966 .789 .613 r
F
.68252 .23183 m .66471 .26726 L .67575 .277 L F
.66884 .25277 m .67098 .23957 L p .66471 .23582 L .049 .04 .524 r
F P
0 g
s
.66471 .24909 m .66884 .25277 L .66471 .23582 L .049 .04 .524 r
F
.67098 .23957 m .67183 .22621 L p .66929 .22536 L F P
0 g
s
.66471 .22382 m .66587 .22675 L .66929 .22536 L .049 .04 .524 r
F
.66587 .22675 m .67098 .23957 L .66929 .22536 L F
.66471 .23582 m .67098 .23957 L .66471 .22382 L F
.6191 .2085 m .61987 .21215 L .61987 .21121 L F
.60394 .2869 m .60865 .29294 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.58382 .23912 m .60187 .24356 L p .61773 .22491 L .289 .763 .934 r
F P
0 g
s
.61773 .22491 m .60187 .24356 L .61136 .23965 L .289 .763 .934 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.60892 .41278 m .58382 .40818 L .58382 .23912 L p .96 .784 .62 r
F P
0 g
s
.65761 .39797 m .68252 .40275 L .68252 .23183 L p .966 .789 .613 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6476 .41312 m .67803 .40902 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.60892 .41278 m .6476 .41312 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.67803 .40902 m .68252 .40275 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58382 .40818 m .60892 .41278 L p .61773 .3976 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.60111 .20654 m .59801 .21872 L .59603 .23154 L p .042 .034 .521 r
F P
0 g
s
.61773 .22491 m .58712 .23067 L .58382 .23912 L p .289 .763 .934 r
F P
0 g
s
.58382 .40818 m .58712 .40189 L .58712 .23067 L p 0 0 .122 r
F P
0 g
s
.58712 .23067 m .58382 .23912 L .58382 .40818 L p 0 0 .122 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.41413 .40902 m .3859 .41312 L .3859 .24575 L p .366 .299 .648 r
F P
0 g
s
.33412 .25697 m .33375 .24447 L .35244 .24633 L p .844 .668 .663 r
F P
0 g
s
.35244 .24633 m .35281 .25879 L .33412 .25697 L p .844 .668 .663 r
F P
0 g
s
.3531 .23343 m .35244 .24633 L .33375 .24447 L p .838 .722 .736 r
F P
0 g
s
.3355 .26852 m .33412 .25697 L .35281 .25879 L p .841 .598 .572 r
F P
0 g
s
.35281 .25879 m .3542 .27031 L .3355 .26852 L p .841 .598 .572 r
F P
0 g
s
.3859 .41312 m .34704 .41278 L .34704 .27909 L p .726 .592 .707 r
F P
0 g
s
.34714 .27914 m .3859 .41312 L .34704 .27909 L .726 .592 .707 r
F
.35635 .28552 m .3859 .41312 L .34714 .27914 L F
.34817 .27962 m .34714 .27914 L .34704 .2788 L F
.35635 .28552 m .34714 .27914 L .34817 .27962 L F
.35656 .28041 m .35804 .28418 L p .35305 .28187 L .772 .367 .285 r
F P
0 g
s
.34817 .27962 m .35656 .28041 L p .35305 .28187 L .772 .367 .285 r
F P
0 g
s
.3355 .26852 m .3542 .27031 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.34704 .27909 m .34704 .2788 L p .34714 .27914 L .726 .592 .707 r
F P
0 g
s
.3542 .27031 m .35656 .28041 L .34817 .27962 L p .821 .504 .452 r
F P
0 g
s
.3542 .27031 m .34817 .27962 L .3431 .27596 L .821 .504 .452 r
F
.33375 .24447 m .33441 .23154 L .3531 .23343 L p .838 .722 .736 r
F P
0 g
s
.35478 .22065 m .3531 .23343 L .33441 .23154 L p .823 .766 .799 r
F P
0 g
s
.33441 .23154 m .33607 .21872 L .35478 .22065 L p .823 .766 .799 r
F P
0 g
s
.3574 .2085 m .35478 .22065 L .33607 .21872 L p .8 .803 .855 r
F P
0 g
s
.33607 .21872 m .33866 .20654 L .3574 .2085 L p .8 .803 .855 r
F P
0 g
s
.33375 .24447 m .33381 .24626 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33381 .24626 m .33412 .25697 L p .33514 .24561 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33381 .24626 L .33514 .24561 L 0 0 .476 r
F
.33441 .23154 m .33375 .24447 L p .33866 .20654 L F P
0 g
s
.33412 .25697 m .3355 .26852 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33783 .27864 m .33604 .27086 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.33604 .27086 m .3355 .26852 L p .3431 .27596 L .821 .504 .452 r
F P
0 g
s
.3355 .26852 m .33783 .27864 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33929 .24356 m .34704 .2453 L p .34722 .23965 L .289 .763 .934 r
F P
0 g
s
.3431 .27596 m .34704 .2788 L .33783 .27864 L .821 .504 .452 r
F
.34624 .27943 m .33783 .27864 L p .34704 .2788 L F P
0 g
s
.33929 .36399 m .34624 .27943 L .34704 .41278 L .949 .775 .632 r
F
.32816 .29388 m .33929 .28499 L .33929 .36399 L F
.33929 .28499 m .34624 .27943 L .33929 .36399 L F
.34704 .27909 m .34704 .41278 L p .34624 .27943 L F P
0 g
s
.33929 .28242 m .33783 .27864 L .34624 .27943 L p .772 .367 .285 r
F P
0 g
s
.33783 .27864 m .33929 .28242 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33929 .28242 L .33929 .22802 L 0 0 .476 r
F
.31947 .23912 m .33929 .26765 L .32816 .29388 L .949 .775 .632 r
F
.33929 .26765 m .34704 .2788 L .33929 .28499 L F
.33929 .26765 m .33929 .28499 L .32816 .29388 L F
.34428 .28359 m .34408 .28091 L p .34817 .27962 L .772 .367 .285 r
F P
0 g
s
.34103 .2869 m .33929 .28242 L p .34091 .28191 L .772 .367 .285 r
F P
0 g
s
.34624 .27943 m .34817 .27962 L p .33929 .28242 L .772 .367 .285 r
F P
0 g
s
.34704 .2453 m .34704 .2788 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.33929 .24356 m .34704 .2453 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.3859 .30684 m .3859 .41312 L p .35804 .29279 L .726 .592 .707 r
F P
0 g
s
.35635 .28552 m .35804 .28674 L .35804 .29279 L .726 .592 .707 r
F
.35804 .28674 m .3859 .30684 L .35804 .29279 L F
.3859 .24575 m .41413 .24025 L p .38338 .23315 L .289 .763 .934 r
F P
0 g
s
.3574 .2085 m .35696 .24595 L .35771 .24558 L 0 0 .48 r
F
.35656 .28041 m .35804 .28418 L p .35771 .24558 L F P
0 g
s
.35696 .24595 m .35656 .28041 L .35771 .24558 L 0 0 .48 r
F
.3574 .2085 m .35771 .24558 L .35804 .22993 L F
.35771 .24558 m .35804 .28418 L .35804 .24543 L F
.35771 .24558 m .35804 .24543 L .35804 .22993 L F
.35244 .24633 m .35281 .25879 L p .3574 .2085 L F P
0 g
s
.3531 .23343 m .35244 .24633 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.35281 .25879 m .3542 .27031 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3542 .27031 m .35656 .28041 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.34704 .2453 m .35804 .24543 L p .35356 .23653 L .289 .763 .934 r
F P
0 g
s
.35804 .24543 m .3859 .24575 L p .37248 .23843 L .289 .763 .934 r
F P
0 g
s
.33866 .20654 m .35102 .23778 L .35395 .23634 L 0 0 .476 r
F
.3859 .24575 m .3859 .30684 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.34704 .2453 m .35804 .24543 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.35804 .24543 m .3859 .24575 L p .35804 .26271 L .726 .592 .707 r
F P
0 g
s
.34704 .2453 m .35804 .26271 L .35635 .28552 L .726 .592 .707 r
F
.35804 .26271 m .3859 .30684 L .35804 .28674 L F
.35804 .26271 m .35804 .28674 L .35635 .28552 L F
.41413 .24025 m .41526 .23183 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.35804 .21057 m .36539 .24186 L .36743 .24087 L 0 0 .48 r
F
.35804 .21121 m .3784 .2972 L .35804 .21057 L F
.3574 .2085 m .35478 .22065 L .3531 .23343 L p F P
0 g
s
.38338 .23315 m .41413 .24025 L .39119 .22936 L .289 .763 .934 r
F
.3859 .24575 m .41413 .24025 L .41413 .40902 L p .366 .299 .648 r
F P
0 g
s
.41526 .23183 m .3956 .22723 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.3574 .2085 m .3956 .23582 L .3956 .22382 L 0 0 .48 r
F
.41526 .23183 m .3956 .22723 L p .3956 .26726 L .954 .779 .627 r
F P
0 g
s
.37248 .23843 m .3859 .24575 L .38338 .23315 L .289 .763 .934 r
F
.39263 .2763 m .39627 .2652 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3883 .28558 m .39263 .2763 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.38348 .29264 m .3883 .28558 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39263 .2763 m .3956 .26726 L p .38012 .26398 L .765 .843 .911 r
F P
0 g
s
.39263 .2763 m .38012 .26398 L .37859 .26458 L .765 .843 .911 r
F
.3574 .2085 m .3956 .24909 L .3956 .23582 L 0 0 .48 r
F
.39627 .2652 m .39906 .25277 L p .3574 .2085 L F P
0 g
s
.37327 .29906 m .3784 .2972 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.36832 .2982 m .37327 .29906 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.36376 .29467 m .36832 .2982 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.35979 .28864 m .36376 .29467 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.38777 .22539 m .37644 .22526 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.33866 .20654 m .36936 .22875 L .37644 .22526 L 0 0 .476 r
F
.37644 .22184 m .37644 .22526 L .38024 .22338 L F
.33866 .20654 m .37644 .22526 L .37644 .22184 L F
.3784 .2972 m .38348 .29264 L p .36743 .24087 L 0 0 .48 r
F P
0 g
s
.36539 .24186 m .3784 .2972 L .36743 .24087 L 0 0 .48 r
F
.35804 .28418 m .35979 .28864 L p .35849 .2452 L F P
0 g
s
.35804 .22993 m .35804 .24543 L .35849 .2452 L 0 0 .48 r
F
.35804 .24543 m .35804 .28418 L .35849 .2452 L F
.36167 .23253 m .35804 .24543 L .37248 .23843 L .289 .763 .934 r
F
.35356 .23653 m .35804 .24543 L .36167 .23253 L F
.37208 .2274 m .39119 .22936 L .37644 .22526 L F
.39257 .26484 m .38083 .2637 L p .3956 .26726 L .765 .843 .911 r
F P
0 g
s
.37208 .2274 m .38338 .23315 L .39119 .22936 L .289 .763 .934 r
F
.38777 .22539 m .37644 .26541 L .37866 .26455 L .726 .593 .707 r
F
.36775 .22954 m .38338 .23315 L .37208 .2274 L .289 .763 .934 r
F
.33866 .20654 m .35761 .23453 L .36246 .23214 L 0 0 .476 r
F
.33866 .20654 m .36246 .23214 L .36936 .22875 L F
.36775 .22954 m .37248 .23843 L .38338 .23315 L .289 .763 .934 r
F
.33866 .20654 m .35395 .23634 L .35761 .23453 L 0 0 .476 r
F
.3477 .22491 m .36167 .23253 L .36775 .22954 L .289 .763 .934 r
F
.36167 .23253 m .37248 .23843 L .36775 .22954 L F
.38777 .22539 m .37644 .22526 L p .37644 .26541 L .726 .593 .707 r
F P
0 g
s
.37351 .27448 m .37644 .26541 L p .35761 .23453 L 0 0 .476 r
F P
0 g
s
.37644 .26541 m .37711 .26334 L p .37644 .26235 L 0 0 .476 r
F P
0 g
s
.35761 .23453 m .37644 .26541 L .37644 .26235 L 0 0 .476 r
F
.35395 .23634 m .37351 .27448 L .35761 .23453 L F
.37711 .26334 m .37986 .25087 L p .37644 .24719 L F P
0 g
s
.36246 .23214 m .37644 .26192 L .37644 .24719 L 0 0 .476 r
F
.37644 .26192 m .37711 .26334 L .37644 .24719 L F
.35761 .23453 m .37711 .26334 L .36246 .23214 L F
.3477 .22491 m .36775 .22954 L .37208 .2274 L .289 .763 .934 r
F
.37885 .26371 m .37866 .26455 L .38012 .26398 L .726 .593 .707 r
F
.37885 .26371 m .38083 .2637 L .38278 .26252 L F
.38777 .22539 m .38777 .25949 L p .39006 .26204 L .954 .779 .627 r
F P
0 g
s
.38083 .2637 m .39257 .26484 L p .38777 .25949 L .802 .811 .859 r
F P
0 g
s
.3956 .26726 m .38083 .2637 L .38012 .26398 L .765 .843 .911 r
F
.3956 .22723 m .38777 .22539 L p .39119 .22936 L .289 .763 .934 r
F P
0 g
s
.3883 .28558 m .39263 .2763 L .37351 .27448 L p .708 .867 .957 r
F P
0 g
s
.37351 .27448 m .39263 .2763 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.37711 .26334 m .37644 .26541 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.37644 .26541 m .37351 .27448 L p .37859 .26458 L .765 .843 .911 r
F P
0 g
s
.36922 .28379 m .37351 .27448 L p .35395 .23634 L 0 0 .476 r
F P
0 g
s
.34722 .23965 m .34704 .2453 L .35356 .23653 L .289 .763 .934 r
F
.35102 .23778 m .36922 .28379 L .35395 .23634 L 0 0 .476 r
F
.36446 .29088 m .36922 .28379 L p .33866 .20654 L F P
0 g
s
.36376 .29467 m .36832 .2982 L .34946 .29647 L p .451 0 0 r
F P
0 g
s
.35436 .29733 m .34946 .29647 L .36832 .2982 L p .119 0 0 r
F P
0 g
s
.36832 .2982 m .37327 .29906 L .35436 .29733 L p .119 0 0 r
F P
0 g
s
.35943 .29545 m .35436 .29733 L .37327 .29906 L p .224 .728 .901 r
F P
0 g
s
.37327 .29906 m .3784 .2972 L .35943 .29545 L p .224 .728 .901 r
F P
0 g
s
.35979 .28864 m .36376 .29467 L .34496 .29294 L p .665 .162 .042 r
F P
0 g
s
.34946 .29647 m .34496 .29294 L .36376 .29467 L p .451 0 0 r
F P
0 g
s
.36446 .29088 m .35943 .29545 L .3784 .2972 L p .469 .843 .988 r
F P
0 g
s
.3784 .2972 m .38348 .29264 L .36446 .29088 L p .469 .843 .988 r
F P
0 g
s
.36922 .28379 m .36446 .29088 L .38348 .29264 L p .618 .874 .99 r
F P
0 g
s
.38348 .29264 m .3883 .28558 L .36922 .28379 L p .618 .874 .99 r
F P
0 g
s
.37351 .27448 m .36922 .28379 L .3883 .28558 L p .708 .867 .957 r
F P
0 g
s
.37644 .27408 m .37231 .26701 L .3477 .3976 L .726 .593 .707 r
F
.3477 .22491 m .35356 .23653 L .36167 .23253 L .289 .763 .934 r
F
.35979 .28864 m .3578 .28846 L p .35724 .28608 L .772 .367 .285 r
F P
0 g
s
.3578 .28846 m .34103 .2869 L p .35724 .28608 L .772 .367 .285 r
F P
0 g
s
.34704 .2788 m .34704 .2453 L p .3558 .28314 L .726 .592 .707 r
F P
0 g
s
.3558 .28314 m .35635 .28552 L .34817 .27962 L .726 .592 .707 r
F
.3558 .28314 m .34817 .27962 L .34704 .2788 L F
.35305 .28187 m .35724 .28608 L .34103 .2869 L .772 .367 .285 r
F
.35804 .28418 m .35979 .28864 L p .35305 .28187 L F P
0 g
s
.34496 .29294 m .34103 .2869 L .35979 .28864 L p .665 .162 .042 r
F P
0 g
s
.35943 .29545 m .36446 .29088 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3477 .22491 m .34722 .23965 L .35356 .23653 L .289 .763 .934 r
F
.35305 .28187 m .34103 .2869 L .34817 .27962 L .772 .367 .285 r
F
.35436 .29733 m .35943 .29545 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.34704 .2788 m .34704 .27909 L p .34624 .27943 L .949 .775 .632 r
F P
0 g
s
.34817 .27962 m .34624 .27943 L p .34704 .2788 L .821 .504 .452 r
F P
0 g
s
.34946 .29647 m .35436 .29733 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3477 .22491 m .3477 .27658 L p .37231 .26701 L .726 .593 .707 r
F P
0 g
s
.34496 .29294 m .34946 .29647 L p .33929 .2118 L 0 0 .476 r
F P
0 g
s
.3477 .27658 m .3477 .3976 L p .37231 .26701 L .726 .593 .707 r
F P
0 g
s
.3956 .22723 m .38777 .22539 L p .39006 .26204 L .954 .779 .627 r
F P
0 g
s
.3956 .26822 m .39006 .26204 L .3956 .35065 L .954 .779 .627 r
F
.3956 .22723 m .39006 .26204 L .3956 .26822 L F
.38777 .22539 m .37885 .26371 L .38278 .26252 L .726 .593 .707 r
F
.38777 .26101 m .38777 .25949 L p .38278 .26252 L F P
0 g
s
.38777 .25949 m .38777 .22539 L p .38278 .26252 L .726 .593 .707 r
F P
0 g
s
.39627 .2652 m .39906 .25277 L .39886 .25275 L p .802 .811 .859 r
F P
0 g
s
.39886 .25275 m .38006 .25089 L p .38897 .25876 L .802 .811 .859 r
F P
0 g
s
.39627 .2652 m .39886 .25275 L .38897 .25876 L .802 .811 .859 r
F
.38006 .25089 m .37986 .25087 L p .38068 .25159 L F P
0 g
s
.39627 .2652 m .38006 .25089 L .38068 .25159 L .802 .811 .859 r
F
.39627 .2652 m .38893 .25879 L .38777 .25949 L F
.39257 .26484 m .39627 .2652 L p .38777 .25949 L F P
0 g
s
.3956 .35065 m .39006 .26204 L .38777 .39797 L .954 .779 .627 r
F
.38777 .25949 m .38777 .39797 L p .39006 .26204 L F P
0 g
s
.37986 .25087 m .37711 .26334 L .38083 .2637 L p .802 .811 .859 r
F P
0 g
s
.38893 .25879 m .37986 .25087 L .38083 .2637 L .802 .811 .859 r
F
.37885 .26371 m .38012 .26398 L .38083 .2637 L .726 .593 .707 r
F
.38278 .26252 m .38083 .2637 L .38777 .26101 L F
.38083 .2637 m .37711 .26334 L p .38012 .26398 L .765 .843 .911 r
F P
0 g
s
.37866 .26455 m .37644 .26541 L .37644 .27408 L .726 .593 .707 r
F
.37986 .25087 m .38164 .23763 L p .36936 .22875 L 0 0 .476 r
F P
0 g
s
.36246 .23214 m .37986 .25087 L .36936 .22875 L 0 0 .476 r
F
.37644 .22526 m .3477 .22491 L p .37208 .2274 L .289 .763 .934 r
F P
0 g
s
.36936 .22875 m .38164 .23763 L .38024 .22338 L 0 0 .476 r
F
.37644 .22526 m .3477 .22491 L p .37644 .27408 L .726 .593 .707 r
F P
0 g
s
.38164 .23763 m .38234 .22423 L p .38024 .22338 L 0 0 .476 r
F P
0 g
s
.3477 .3976 m .38777 .39797 L .38777 .26101 L p .726 .593 .707 r
F P
0 g
s
.37866 .26455 m .3477 .3976 L .38777 .26101 L .726 .593 .707 r
F
.37859 .26458 m .38012 .26398 L .37711 .26334 L .765 .843 .911 r
F
.3956 .26726 m .39627 .2652 L .39257 .26484 L p F P
0 g
s
.40778 .277 m .3956 .26726 L .3956 .35065 L .954 .779 .627 r
F
.41526 .23183 m .3956 .26726 L .40778 .277 L F
.39906 .25277 m .40085 .23957 L p .3956 .23582 L 0 0 .48 r
F P
0 g
s
.3956 .24909 m .39906 .25277 L .3956 .23582 L 0 0 .48 r
F
.40085 .23957 m .40156 .22621 L p .39944 .22536 L F P
0 g
s
.3956 .22382 m .39657 .22675 L .39944 .22536 L 0 0 .48 r
F
.39657 .22675 m .40085 .23957 L .39944 .22536 L F
.3956 .23582 m .40085 .23957 L .3956 .22382 L F
.3574 .2085 m .35804 .21121 L .35804 .21057 L F
.34103 .2869 m .34496 .29294 L p .33929 .21522 L 0 0 .476 r
F P
0 g
s
.33866 .20654 m .33929 .22802 L .33929 .21522 L 0 0 .476 r
F
.33929 .22802 m .34103 .2869 L .33929 .21522 L F
.33866 .20654 m .33929 .21522 L .33929 .2118 L F
.33929 .21522 m .34496 .29294 L .33929 .2118 L F
.33929 .28242 m .34103 .2869 L p .33929 .22802 L F P
0 g
s
.31947 .23912 m .33929 .24356 L p .33929 .26765 L .949 .775 .632 r
F P
0 g
s
.31947 .23912 m .33929 .24356 L p .3477 .22491 L .289 .763 .934 r
F P
0 g
s
.3477 .22491 m .33929 .24356 L .34722 .23965 L .289 .763 .934 r
F
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61773 .3976 m .58712 .40189 L .58382 .40818 L p .224 .73 .894 r
F P
0 g
s
.68252 .40275 m .65761 .39797 L .61773 .3976 L p .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.34704 .41278 m .31947 .40818 L .31947 .23912 L p .949 .775 .632 r
F P
0 g
s
.41526 .40275 m .41413 .40902 L .41413 .24025 L p 0 0 .042 r
F P
0 g
s
.58712 .40189 m .61773 .3976 L .61773 .22491 L p .378 .309 .652 r
F P
0 g
s
.61773 .22491 m .58712 .23067 L .58712 .40189 L p .378 .309 .652 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3859 .41312 m .41413 .40902 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.34704 .41278 m .3859 .41312 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.31947 .40818 m .34704 .41278 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.33866 .20654 m .33607 .21872 L .33441 .23154 L p 0 0 .476 r
F P
0 g
s
.62323 .19751 m .6191 .2085 L .60111 .20654 L p .765 .84 .909 r
F P
0 g
s
.6282 .18815 m .62323 .19751 L .6191 .2085 L p .049 .04 .524 r
F P
0 g
s
.6338 .18082 m .6282 .18815 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.63979 .17587 m .6338 .18082 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.64593 .17353 m .63979 .17587 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65193 .17395 m .64593 .17353 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.65754 .17712 m .65193 .17395 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.6625 .18295 m .65754 .17712 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66658 .19117 m .6625 .18295 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.66957 .20145 m .66658 .19117 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.67135 .21331 m .66957 .20145 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.67183 .22621 m .67135 .21331 L p .6191 .2085 L .049 .04 .524 r
F P
0 g
s
.36086 .19751 m .3574 .2085 L .33866 .20654 L p .765 .835 .906 r
F P
0 g
s
.36502 .18815 m .36086 .19751 L .3574 .2085 L p 0 0 .48 r
F P
0 g
s
.3697 .18082 m .36502 .18815 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.37473 .17587 m .3697 .18082 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.37986 .17353 m .37473 .17587 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3849 .17395 m .37986 .17353 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.3896 .17712 m .3849 .17395 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39375 .18295 m .3896 .17712 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39716 .19117 m .39375 .18295 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.39967 .20145 m .39716 .19117 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.40117 .21331 m .39967 .20145 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.40156 .22621 m .40117 .21331 L p .3574 .2085 L 0 0 .48 r
F P
0 g
s
.60111 .20654 m .60521 .19551 L .62323 .19751 L p .765 .84 .909 r
F P
0 g
s
.6282 .18815 m .62323 .19751 L .60521 .19551 L p .71 .863 .954 r
F P
0 g
s
.33866 .20654 m .34208 .19551 L .36086 .19751 L p .765 .835 .906 r
F P
0 g
s
.36502 .18815 m .36086 .19751 L .34208 .19551 L p .713 .859 .951 r
F P
0 g
s
.60521 .19551 m .61013 .18611 L .6282 .18815 L p .71 .863 .954 r
F P
0 g
s
.61013 .18611 m .60521 .19551 L .60111 .20654 L p .042 .034 .521 r
F P
0 g
s
.6338 .18082 m .6282 .18815 L .61013 .18611 L p .627 .87 .988 r
F P
0 g
s
.61013 .18611 m .61568 .17875 L .6338 .18082 L p .627 .87 .988 r
F P
0 g
s
.61568 .17875 m .61013 .18611 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.63979 .17587 m .6338 .18082 L .61568 .17875 L p .492 .846 .994 r
F P
0 g
s
.61568 .17875 m .62163 .17378 L .63979 .17587 L p .492 .846 .994 r
F P
0 g
s
.62163 .17378 m .61568 .17875 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64593 .17353 m .63979 .17587 L .62163 .17378 L p .273 .753 .93 r
F P
0 g
s
.62163 .17378 m .62771 .17143 L .64593 .17353 L p .273 .753 .93 r
F P
0 g
s
.62771 .17143 m .62163 .17378 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65193 .17395 m .64593 .17353 L .62771 .17143 L p 0 .536 .731 r
F P
0 g
s
.62771 .17143 m .63367 .17184 L .65193 .17395 L p 0 .536 .731 r
F P
0 g
s
.63367 .17184 m .62771 .17143 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.63923 .17502 m .63367 .17184 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64415 .18085 m .63923 .17502 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.64819 .18909 m .64415 .18085 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65117 .1994 m .64819 .18909 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.65293 .21129 m .65117 .1994 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.6534 .22423 m .65293 .21129 L p .60111 .20654 L .042 .034 .521 r
F P
0 g
s
.34208 .19551 m .34619 .18611 L .36502 .18815 L p .713 .859 .951 r
F P
0 g
s
.34619 .18611 m .34208 .19551 L .33866 .20654 L p 0 0 .476 r
F P
0 g
s
.3697 .18082 m .36502 .18815 L .34619 .18611 L p .631 .868 .987 r
F P
0 g
s
.34619 .18611 m .35083 .17875 L .3697 .18082 L p .631 .868 .987 r
F P
0 g
s
.35083 .17875 m .34619 .18611 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37473 .17587 m .3697 .18082 L .35083 .17875 L p .496 .847 .994 r
F P
0 g
s
.35083 .17875 m .3558 .17378 L .37473 .17587 L p .496 .847 .994 r
F P
0 g
s
.3558 .17378 m .35083 .17875 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37986 .17353 m .37473 .17587 L .3558 .17378 L p .272 .752 .929 r
F P
0 g
s
.3558 .17378 m .36088 .17143 L .37986 .17353 L p .272 .752 .929 r
F P
0 g
s
.36088 .17143 m .3558 .17378 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.3849 .17395 m .37986 .17353 L .36088 .17143 L p 0 .526 .718 r
F P
0 g
s
.36088 .17143 m .36586 .17184 L .3849 .17395 L p 0 .526 .718 r
F P
0 g
s
.36586 .17184 m .36088 .17143 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37051 .17502 m .36586 .17184 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37461 .18085 m .37051 .17502 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.37799 .18909 m .37461 .18085 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38047 .1994 m .37799 .18909 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38195 .21129 m .38047 .1994 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.38234 .22423 m .38195 .21129 L p .33866 .20654 L 0 0 .476 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.41413 .24025 m .41526 .23183 L .41526 .40275 L p 0 0 .042 r
F P
0 g
s
.31947 .40818 m .31939 .40189 L .31939 .23067 L p .71 .58 .003 r
F P
0 g
s
.31939 .23067 m .31947 .23912 L .31947 .40818 L p .71 .58 .003 r
F P
0 g
s
.38777 .39797 m .41526 .40275 L .41526 .23183 L p .954 .779 .627 r
F P
0 g
s
.31939 .40189 m .3477 .3976 L .3477 .22491 L p .351 .287 .644 r
F P
0 g
s
.3477 .22491 m .31939 .23067 L .31947 .23912 L p .289 .763 .934 r
F P
0 g
s
.3477 .22491 m .31939 .23067 L .31939 .40189 L p .351 .287 .644 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41413 .40902 m .41526 .40275 L p .3477 .3976 L .224 .73 .894 r
F P
0 g
s
.3477 .3976 m .31939 .40189 L .31947 .40818 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65754 .17712 m .65193 .17395 L .63367 .17184 L p .389 0 0 r
F P
0 g
s
.3896 .17712 m .3849 .17395 L .36586 .17184 L p .408 0 0 r
F P
0 g
s
.41526 .40275 m .38777 .39797 L .3477 .3976 L p .224 .73 .894 r
F P
0 g
s
.63367 .17184 m .63923 .17502 L .65754 .17712 L p .389 0 0 r
F P
0 g
s
.36586 .17184 m .37051 .17502 L .3896 .17712 L p .408 0 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6625 .18295 m .65754 .17712 L .63923 .17502 L p .635 .107 0 r
F P
0 g
s
.39375 .18295 m .3896 .17712 L .37051 .17502 L p .647 .128 0 r
F P
0 g
s
.684 1.07578 m .66842 1.06807 L .68303 1.06704 L closepath p .64 .136 .035 r
F P
0 g
s
.6886 1.0493 m .70625 .9931 L p .6967 1.02858 L 0 0 .095 r
F P
0 g
s
.70625 .9931 m .68303 1.06704 L p .68811 1.02338 L .855 .879 .855 r
F P
0 g
s
.69103 .99828 m .70029 .99513 L .68811 1.02338 L .855 .879 .855 r
F
.70029 .99513 m .70625 .9931 L .68811 1.02338 L F
.69884 .99457 m .70354 .99364 L .69103 .99828 L F
.70354 .99364 m .70625 .9931 L .704 .99387 L F
.70354 .99364 m .704 .99387 L .69103 .99828 L F
.70136 .99337 m .70625 .9931 L p .69129 .99606 L F P
0 g
s
.70625 .9931 m .70627 .99327 L p .684 1.07578 L 0 0 .095 r
F P
0 g
s
.6896 1.05798 m .684 1.07578 L p .70627 .99327 L 0 0 .095 r
F P
0 g
s
.6914 .99846 m .70136 .99337 L p .70409 1.00173 L .869 .8 .779 r
F P
0 g
s
.70035 1.01626 m .70409 1.00173 L .72475 1.06482 L .869 .8 .779 r
F
.6914 .99846 m .70409 1.00173 L .70035 1.01626 L F
.70136 .99337 m .70625 .9931 L .70627 .99327 L p .628 .114 .004 r
F P
0 g
s
.70661 .99197 m .70693 .99326 L p .70136 .99337 L .869 .8 .779 r
F P
0 g
s
.70693 .99326 m .72475 1.06482 L p .70136 .99337 L .869 .8 .779 r
F P
0 g
s
.70627 .99327 m .70685 .9977 L p .70196 1.0148 L 0 0 .095 r
F P
0 g
s
.72475 1.06482 m .71003 1.07251 L .6914 .99846 L p .869 .8 .779 r
F P
0 g
s
.69809 1.02504 m .71003 1.07251 L p .70864 1.0334 L .438 .526 .85 r
F P
0 g
s
.70183 1.01546 m .69809 1.02504 L .70864 1.0334 L .438 .526 .85 r
F
.70531 .99701 m .70196 1.0148 L .6896 1.05798 L 0 0 .095 r
F
.70627 .99327 m .70196 1.0148 L .70531 .99701 L F
.70786 1.01149 m .70183 1.01546 L .70864 1.0334 L .438 .526 .85 r
F
.70247 1.01384 m .70183 1.01546 L .70786 1.01149 L F
.696 1.03763 m .6896 1.05798 L p .70196 1.0148 L 0 0 .095 r
F P
0 g
s
.70685 .9977 m .70139 1.01778 L .70196 1.0148 L 0 0 .095 r
F
.70139 1.01778 m .696 1.03763 L .70196 1.0148 L F
.684 1.07578 m .68303 1.06704 L .6886 1.0493 L p F P
0 g
s
.6967 1.02858 m .684 1.07578 L .6886 1.0493 L 0 0 .095 r
F
.68303 1.06704 m .66842 1.06807 L .69083 .99618 L p .855 .879 .855 r
F P
0 g
s
.70136 .99337 m .68421 .99452 L .69927 .97691 L .511 .018 .022 r
F
.65947 .99618 m .67017 .991 L p .68421 .99452 L F P
0 g
s
.67017 .991 m .69927 .97691 L p .68421 .99452 L .511 .018 .022 r
F P
0 g
s
.69129 .99606 m .68303 1.06704 L .69083 .99618 L .855 .879 .855 r
F
.706 1.00081 m .70247 1.01384 L .70139 .99365 L .347 .283 .642 r
F
.70139 1.0143 m .70139 .99365 L p .70247 1.01384 L F P
0 g
s
.72593 1.07356 m .71003 1.07251 L .72475 1.06482 L closepath p .398 0 .067 r
F P
0 g
s
.72593 1.07356 m .72475 1.06482 L .70661 .99197 L p .755 .49 0 r
F P
0 g
s
.70663 .9921 m .72593 1.07356 L .70661 .99197 L .755 .49 0 r
F
.7092 1.00578 m .70247 1.01384 L .706 1.00081 L .347 .283 .642 r
F
.70663 .9921 m .70714 .99606 L .72593 1.07356 L .755 .49 0 r
F
.71757 .9848 m .74396 .99618 L p .70687 .99398 L .511 .018 .022 r
F P
0 g
s
.71021 1.01047 m .70247 1.01384 L .7092 1.00578 L .347 .283 .642 r
F
.71021 1.01047 m .72593 1.07356 L p .70714 .99606 L .755 .49 0 r
F P
0 g
s
.70201 1.01852 m .70139 1.01778 L .7032 1.01477 L .347 .283 .642 r
F
.7032 1.01477 m .70139 1.01778 L .70247 1.01384 L F
.71003 1.07251 m .72593 1.07356 L .71021 1.01047 L p .438 .526 .85 r
F P
0 g
s
.70719 .99644 m .71021 1.01047 L .70714 .99606 L .755 .49 0 r
F
.71225 1.00958 m .70139 .99365 L .70271 .99463 L .347 .283 .642 r
F
.72113 1.02351 m .71178 1.00978 L .71225 1.00958 L F
.72099 1.02407 m .71178 1.00978 L .72113 1.02351 L F
.71178 1.00978 m .70139 .99365 L .71225 1.00958 L F
.74396 .99618 m .72562 1.0053 L p .70719 .99644 L .511 .018 .022 r
F P
0 g
s
.70719 .99644 m .70687 .99398 L .74396 .99618 L .511 .018 .022 r
F
.74396 .99618 m .71757 .9848 L p .70921 .91076 L .305 .36 .755 r
F P
0 g
s
.71757 .9848 m .69927 .97691 L .70139 .90907 L p .305 .36 .755 r
F P
0 g
s
.70139 .90907 m .70139 .8749 L p .70602 .89006 L .347 .283 .642 r
F P
0 g
s
.71255 .91149 m .70139 .90907 L .70602 .89006 L .347 .283 .642 r
F
.70139 .90907 m .69927 .97691 L p .69071 .95301 L .945 .896 .747 r
F P
0 g
s
.69629 .91033 m .65352 .88252 L .69409 .87484 L .954 .779 .626 r
F
.65178 .87448 m .69409 .87484 L p .65352 .88252 L F P
0 g
s
.66352 .91843 m .64101 .87438 L .69629 .91033 L .954 .779 .626 r
F
.67711 .91507 m .70139 .90907 L .69071 .95301 L .945 .896 .747 r
F
.70627 .99327 m .70685 .9977 L p .70136 .99337 L .628 .114 .004 r
F P
0 g
s
.70177 .99393 m .70136 .99337 L .70685 .9977 L .628 .114 .004 r
F
.69927 .97691 m .70497 .97937 L p .70139 .99365 L .511 .018 .022 r
F P
0 g
s
.66253 .87438 m .70305 .85625 L .70247 .87477 L p .945 .896 .747 r
F P
0 g
s
.70972 .87484 m .70139 .8749 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70139 .90907 m .70139 .99256 L p .69629 .91033 L .954 .779 .626 r
F P
0 g
s
.69629 .91033 m .69409 .87484 L .70139 .90907 L .954 .779 .626 r
F
.69409 .87484 m .70139 .8749 L .70139 .90907 L p F P
0 g
s
.70247 .87477 m .70305 .85625 L p .70514 .87475 L .305 .36 .755 r
F P
0 g
s
.70305 .85625 m .70845 .87472 L .70514 .87475 L .305 .36 .755 r
F
.77017 .87438 m .70972 .87484 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .74865 .87438 L .77017 .87438 L .012 .587 .719 r
F
.7598 .87429 m .77017 .87438 L p .74865 .87438 L F P
0 g
s
.74865 .87438 m .70835 .87438 L p .70305 .85625 L .305 .36 .755 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 .924 L p .347 .283 .642 r
F P
0 g
s
.74693 .91895 m .74396 .99618 L p .71965 .91303 L .305 .36 .755 r
F P
0 g
s
.71965 .91303 m .74396 .99618 L .70921 .91076 L .305 .36 .755 r
F
.72562 1.0053 m .74396 .99618 L .74693 .91895 L p .948 .9 .745 r
F P
0 g
s
.77017 .924 m .77017 1.10042 L p .73257 .97714 L .347 .283 .642 r
F P
0 g
s
.73257 .97714 m .71255 .91149 L .74693 .91895 L .347 .283 .642 r
F
.73257 .97714 m .74693 .91895 L .77017 .924 L F
.71255 .91149 m .70139 .8749 L .77017 .924 L F
.71312 .89071 m .74865 .87438 L .74693 .91895 L p .305 .36 .755 r
F P
0 g
s
.71312 .89071 m .74693 .91895 L .71965 .91303 L .305 .36 .755 r
F
.70514 .87475 m .71965 .91303 L .70921 .91076 L F
.70845 .87472 m .71965 .91303 L .70514 .87475 L F
.70305 .85625 m .74865 .87438 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.70996 .87384 m .7598 .87429 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.70559 .87438 m .70996 .87384 L .74865 .87438 L F
.66253 .87438 m .70305 .85625 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.64101 .87438 m .70996 .87384 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .69409 .87484 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.69409 .87484 m .64101 .87438 L p .70247 .87477 L .012 .587 .719 r
F P
0 g
s
.70247 .87477 m .70139 .90907 L p .66253 .87438 L .945 .896 .747 r
F P
0 g
s
.70139 .90907 m .70247 .87477 L p .70921 .91076 L .305 .36 .755 r
F P
0 g
s
.70514 .87475 m .70921 .91076 L .70247 .87477 L .305 .36 .755 r
F
.7082 .89298 m .66253 .87438 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.74865 .87438 m .7082 .89298 L p .70559 .87438 L .486 0 0 r
F P
0 g
s
.70921 .91076 m .71757 .9848 L .70139 .90907 L .305 .36 .755 r
F
.70706 .99543 m .70384 .9938 L .70687 .99398 L .511 .018 .022 r
F
.70719 .99644 m .70384 .9938 L .70706 .99543 L F
.70719 .99644 m .70139 .99365 L .70384 .9938 L F
.70685 .99485 m .70719 .99644 L .70714 .99606 L .755 .49 0 r
F
.70177 .99393 m .70139 .99365 L .70136 .99337 L .628 .114 .004 r
F
.70139 .99365 m .70647 .99088 L .70687 .99398 L .511 .018 .022 r
F
.70647 .99088 m .71757 .9848 L .70687 .99398 L F
.70139 .99365 m .70497 .97937 L .70647 .99088 L F
.70136 .99337 m .70633 .99084 L .70661 .99197 L p .869 .8 .779 r
F P
0 g
s
.70633 .99084 m .70685 .99485 L p .70714 .99606 L .755 .49 0 r
F P
0 g
s
.70633 .99084 m .70714 .99606 L .70663 .9921 L .755 .49 0 r
F
.70661 .99197 m .70633 .99084 L p .70663 .9921 L F P
0 g
s
.70497 .97937 m .71757 .9848 L p .70647 .99088 L .511 .018 .022 r
F P
0 g
s
.70136 .99337 m .70633 .99084 L .70635 .991 L p .379 0 .039 r
F P
0 g
s
.70635 .991 m .70685 .99485 L p .70136 .99337 L .379 0 .039 r
F P
0 g
s
.74383 1.01405 m .7052 .99449 L .74022 1.00219 L .347 .283 .642 r
F
.74819 1.02833 m .70524 .9955 L .74383 1.01405 L F
.70172 .99373 m .70136 .99337 L .70685 .99485 L .379 0 .039 r
F
.70524 .9955 m .70139 .99256 L .74383 1.01405 L .347 .283 .642 r
F
.77017 1.10042 m .71544 1.01458 L .74819 1.02833 L F
.71544 1.01458 m .70271 .99463 L .7209 1.00811 L F
.71544 1.01458 m .7209 1.00811 L .74819 1.02833 L F
.70786 1.01149 m .71003 1.07251 L .71021 1.01047 L .438 .526 .85 r
F
.77017 1.10042 m .70247 1.01384 L .71178 1.00978 L .347 .283 .642 r
F
.7075 1.00147 m .70247 1.01384 L .70786 1.01149 L .438 .526 .85 r
F
.70733 1.00139 m .70247 1.01384 L .7075 1.00147 L F
.70139 1.09633 m .69265 1.06418 L .70012 1.02455 L .954 .779 .626 r
F
.70139 1.01778 m .70139 1.03123 L p .70012 1.02455 L F P
0 g
s
.70139 1.03123 m .70139 1.09633 L p .70012 1.02455 L .954 .779 .626 r
F P
0 g
s
.77017 1.10042 m .70139 1.09633 L .70139 1.01778 L p .347 .283 .642 r
F P
0 g
s
.70735 1.00156 m .696 1.03763 L p .70685 .9977 L 0 0 .095 r
F P
0 g
s
.696 1.03763 m .70012 1.02455 L p .66977 1.06874 L .486 .481 .777 r
F P
0 g
s
.70676 1.00113 m .70209 1.014 L .70732 1.00139 L .438 .526 .85 r
F
.70209 1.014 m .69809 1.02504 L .70247 1.01384 L F
.70685 .9977 m .70733 1.00139 L p .70177 .99393 L .628 .114 .004 r
F P
0 g
s
.70718 1.00132 m .70177 .99393 L .70733 1.00139 L .628 .114 .004 r
F
.70209 1.014 m .70247 1.01384 L .70749 1.00099 L .438 .526 .85 r
F
.69598 1.01666 m .69809 1.02504 L p .70209 1.014 L F P
0 g
s
.70718 1.00132 m .70206 .9989 L .70139 .99365 L .628 .114 .004 r
F
.70718 1.00132 m .70139 .99365 L .70177 .99393 L F
.70271 .99463 m .70139 .99256 L .74819 1.02833 L .347 .283 .642 r
F
.70271 .99463 m .70139 .99365 L .7022 .99383 L F
.70207 .999 m .70206 .9989 L .70718 1.00132 L .628 .114 .004 r
F
.70139 .99365 m .70139 1.0143 L p .69546 .99866 L .954 .779 .626 r
F P
0 g
s
.69546 .99866 m .6914 .99846 L p .70124 .99379 L .379 0 .039 r
F P
0 g
s
.70207 .999 m .70139 .99365 L .70719 .99644 L .511 .018 .022 r
F
.70207 .999 m .70719 .99644 L .70771 1.00042 L F
.70743 .99928 m .70098 .99356 L .70172 .99373 L .379 0 .039 r
F
.69546 .99866 m .69491 .99721 L .70139 .99365 L .954 .779 .626 r
F
.6914 .99846 m .70098 .99356 L p .70124 .99379 L .379 0 .039 r
F P
0 g
s
.70724 .99911 m .69546 .99866 L .70124 .99379 L .379 0 .039 r
F
.70207 .999 m .69546 .99866 L p .70724 .99911 L F P
0 g
s
.6914 .99846 m .69598 1.01666 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.70743 .99928 m .69546 .99866 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.69546 .99866 m .6914 .99846 L p .69998 1.01058 L .438 .526 .85 r
F P
0 g
s
.69129 .99606 m .69884 .99457 L .69103 .99828 L .855 .879 .855 r
F
.69083 .99618 m .69003 .99876 L p .69522 .99886 L .486 .481 .777 r
F P
0 g
s
.70707 1.00026 m .69598 1.01666 L .70209 1.014 L .438 .526 .85 r
F
.70682 1.0002 m .69598 1.01666 L .70707 1.00026 L F
.70139 1.01778 m .69859 1.01653 L .69491 .99721 L .954 .779 .626 r
F
.70139 1.0143 m .70139 1.01778 L p .69491 .99721 L F P
0 g
s
.70207 .999 m .69491 .99721 L .69522 .99886 L .486 .481 .777 r
F
.69491 .99721 m .69083 .99618 L .69522 .99886 L F
.69003 .99876 m .66842 1.06807 L p .69717 1.00907 L F P
0 g
s
.70207 .999 m .69522 .99886 L .69717 1.00907 L .486 .481 .777 r
F
.69522 .99886 m .69003 .99876 L .69717 1.00907 L F
.69869 1.01704 m .66977 1.06874 L .70012 1.02455 L F
.70012 1.02455 m .69859 1.01653 L .70139 1.01778 L .954 .779 .626 r
F
.66842 1.06807 m .66977 1.06874 L p .70735 1.00156 L .486 .481 .777 r
F P
0 g
s
.66977 1.06874 m .684 1.07578 L .696 1.03763 L p .486 .481 .777 r
F P
0 g
s
.70735 1.00156 m .70207 .999 L p .66842 1.06807 L .486 .481 .777 r
F P
0 g
s
.69265 1.06418 m .67708 1.00696 L .69859 1.01653 L .954 .779 .626 r
F
.69265 1.06418 m .69859 1.01653 L .70012 1.02455 L F
.69859 1.01653 m .68085 1.00864 L .69491 .99721 L F
.68085 1.00864 m .68012 1.0053 L .69491 .99721 L F
.70139 1.01778 m .70139 1.0143 L p .70247 1.01384 L .347 .283 .642 r
F P
0 g
s
.70012 1.02455 m .70735 1.00156 L p .69869 1.01704 L .486 .481 .777 r
F P
0 g
s
.70422 1.01594 m .69077 .9962 L .69083 .99618 L .511 .018 .022 r
F
.77017 1.10042 m .70201 1.01852 L .7032 1.01477 L .347 .283 .642 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L F P
0 g
s
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .55502 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.36616 1.0217 m .63384 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .43703 1.04577 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.39014 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.29653 1.043 m .32813 1.04365 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.42289 1.09692 m .36432 1.09692 L p .39845 1.08739 L .682 .404 .495 r
F P
0 g
s
.43099 1.07831 m .42289 1.09692 L .39845 1.08739 L .682 .404 .495 r
F
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .42289 1.09692 L .682 .404 .495 r
F
.44479 1.09692 m .42289 1.09692 L p .44497 1.07958 L F P
0 g
s
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.63384 1.0217 m .55502 1.07831 L .55468 1.04379 L .682 .404 .495 r
F
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63614 1.043 m .67151 1.043 L p .63572 1.05936 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.55483 1.09633 m .63572 1.05936 L .63551 1.06739 L F
.63572 1.05936 m .67151 1.043 L .63551 1.06739 L F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.60506 1.07831 m .6913 1.07831 L .70139 1.09633 L F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.69265 1.06418 m .67703 1.05284 L .67708 1.00696 L .954 .779 .626 r
F
.67704 1.04273 m .65736 1.01775 L .67708 1.00696 L F
.67703 1.05284 m .67151 1.043 L .67704 1.04273 L F
.67151 1.043 m .65736 1.01775 L .67704 1.04273 L F
.67151 1.043 m .69746 1.04516 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.69265 1.06418 m .68599 1.06885 L .67703 1.05284 L .954 .779 .626 r
F
.70139 1.09633 m .68639 1.09735 L p .69265 1.06418 L F P
0 g
s
.68639 1.09735 m .64101 1.10042 L p .69265 1.06418 L .954 .779 .626 r
F P
0 g
s
.70347 1.043 m .70139 1.09633 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.67151 1.043 m .64101 1.02671 L .65736 1.01775 L .954 .779 .626 r
F
.67703 1.05284 m .66397 1.04337 L .67151 1.043 L F
.66397 1.04337 m .64101 1.02671 L .67151 1.043 L F
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.63772 1.04435 m .65515 1.0438 L .63614 1.043 L F
.63806 1.04464 m .64101 1.04449 L .63772 1.04435 L F
.64101 1.04449 m .65515 1.0438 L .63772 1.04435 L F
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .60986 1.04601 L .6333 1.04487 L .066 0 0 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L F
.6395 1.10246 m .63806 1.04502 L .63593 1.05141 L 0 0 .063 r
F
.67703 1.05284 m .64101 1.04449 L .66397 1.04337 L .954 .779 .626 r
F
.64101 1.10042 m .64101 1.04449 L p .67703 1.05284 L F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L .066 0 0 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.68599 1.06885 m .64101 1.10042 L .67703 1.05284 L .954 .779 .626 r
F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .70996 1.04757 L .6578 1.04524 L .333 .272 .638 r
F
.63806 1.04502 m .63614 1.043 L .63593 1.05141 L 0 0 .063 r
F
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .70775 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L .066 0 0 r
F
.6395 1.10246 m .63919 1.05309 L .6371 1.00646 L 0 0 .063 r
F
.63919 1.05309 m .63854 .95086 L .63756 .98856 L F
.63919 1.05309 m .63756 .98856 L .6371 1.00646 L F
.55483 1.09633 m .63614 1.043 L .63572 1.05936 L .678 .717 .878 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.63538 1.08458 m .63568 1.09692 L p .60923 1.09451 L .682 .404 .495 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L 0 0 .026 r
F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.63538 1.08458 m .60923 1.09451 L .43099 1.07831 L .682 .404 .495 r
F
.63522 1.07831 m .63538 1.08458 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p .732 .598 .026 r
F P
0 g
s
.63568 1.09692 m .44479 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.55468 1.04379 m .55502 1.07831 L .44498 1.07831 L .682 .404 .495 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.50802 1.25704 m .54018 1.25552 L .52667 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .54517 1.25817 L F
.54018 1.25552 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.51938 1.25967 m .51947 1.25865 L .52667 1.25967 L .365 .792 .97 r
F
.452 1.25967 m .51947 1.25865 L .51938 1.25967 L F
.452 1.25967 m .50802 1.25704 L .51947 1.25865 L F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L .365 .792 .97 r
F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.52783 1.09787 m .46974 1.09988 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .39014 1.04601 L p .35223 1.04479 L .066 0 0 r
F P
0 g
s
.35223 1.04479 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.3516 1.04413 m .29653 1.043 L .35223 1.04479 L F
.35899 1.04449 m .35223 1.04479 L .39014 1.04601 L F
.3516 1.04413 m .35223 1.04479 L .35899 1.04449 L F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L .066 0 0 r
F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36257 1.04436 m .36228 1.04465 L .39014 1.04601 L .066 0 0 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L .066 0 0 r
F
.44344 1.04601 m .36386 1.043 L .363 1.04391 L F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.46974 1.09988 m .46771 1.09965 L .484 1.09787 L .09 0 0 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L .063 .051 .53 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L .09 0 0 r
F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.55468 1.04379 m .44498 1.07831 L .44502 1.07439 L .682 .404 .495 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37209 1.26039 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37209 1.26039 m .37083 1.25133 L p .37121 1.27211 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .37209 1.26039 L .37121 1.27211 L .763 .623 .059 r
F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36868 1.3059 m .36433 1.3007 L .36742 1.29994 L p .823 .35 .073 r
F P
0 g
s
.36742 1.29994 m .36915 1.29952 L p .36904 1.3011 L .823 .35 .073 r
F P
0 g
s
.36904 1.3011 m .36868 1.3059 L .36742 1.29994 L .823 .35 .073 r
F
.37209 1.3207 m .36901 1.29994 L .36955 1.32905 L .763 .623 .059 r
F
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p F P
0 g
s
.36955 1.26755 m .36904 1.29866 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36904 1.29866 m .36901 1.29994 L p .37203 1.3203 L .763 .623 .059 r
F P
0 g
s
.37209 1.3207 m .36904 1.29866 L .37203 1.3203 L .763 .623 .059 r
F
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L F P
0 g
s
.41389 1.27286 m .39481 1.2932 L .36915 1.29952 L p .741 .988 .787 r
F P
0 g
s
.36955 1.26755 m .36904 1.29866 L p .39631 1.27701 L .693 .453 .555 r
F P
0 g
s
.39044 1.27014 m .39631 1.27701 L .403 1.2717 L .693 .453 .555 r
F
.36955 1.26755 m .39631 1.27701 L .39044 1.27014 L F
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.58611 1.27286 m .56651 1.2932 L .54207 1.29994 L p .714 .977 .761 r
F P
0 g
s
.58611 1.27286 m .54207 1.29994 L .54619 1.29661 L .714 .977 .761 r
F
.41389 1.27286 m .36915 1.29952 L .36904 1.29866 L .741 .988 .787 r
F
.41389 1.27286 m .36904 1.29866 L .37162 1.29661 L F
.43308 1.29558 m .41389 1.27286 L .39481 1.2932 L p .519 .424 .687 r
F P
0 g
s
.36433 1.3007 m .38368 1.27999 L .41389 1.27286 L p .741 .988 .787 r
F P
0 g
s
.43308 1.29558 m .41389 1.27286 L .39631 1.27701 L p .82 .344 .063 r
F P
0 g
s
.43308 1.29558 m .39631 1.27701 L .40444 1.28654 L .82 .344 .063 r
F
.36904 1.3011 m .36955 1.32905 L .38823 1.32905 L p .69 .689 .843 r
F P
0 g
s
.36904 1.3011 m .38823 1.32905 L .39631 1.32055 L .69 .689 .843 r
F
.39481 1.2932 m .38489 1.32056 L .37136 1.3046 L .823 .35 .073 r
F
.36915 1.29952 m .39481 1.2932 L p .36868 1.3059 L F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.39481 1.2932 m .41389 1.31592 L .38368 1.32387 L p .823 .35 .073 r
F P
0 g
s
.39481 1.2932 m .41389 1.31592 L .43308 1.29558 L p .519 .424 .687 r
F P
0 g
s
.41389 1.31592 m .43308 1.29558 L .41588 1.29994 L p .734 .985 .78 r
F P
0 g
s
.36901 1.29994 m .36904 1.3011 L p .41057 1.30554 L .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .41057 1.30554 L .41135 1.30471 L .69 .689 .843 r
F
.41389 1.31592 m .41588 1.29994 L .40769 1.30856 L .734 .985 .78 r
F
.56885 1.32219 m .57381 1.32299 L .57341 1.3227 L .69 .689 .843 r
F
.36901 1.29994 m .56863 1.32241 L .56885 1.32219 L F
.56863 1.32241 m .57381 1.32299 L .56885 1.32219 L F
.41135 1.30471 m .41057 1.30554 L .57381 1.32299 L F
.39631 1.32055 m .41389 1.31592 L p .40769 1.30856 L .734 .985 .78 r
F P
0 g
s
.40822 1.32905 m .58215 1.32905 L p .36904 1.3011 L .69 .689 .843 r
F P
0 g
s
.58215 1.32905 m .63045 1.32905 L p .57381 1.32299 L .69 .689 .843 r
F P
0 g
s
.36904 1.3011 m .58215 1.32905 L .57381 1.32299 L .69 .689 .843 r
F
.56651 1.2932 m .58611 1.31592 L .57045 1.32055 L p .812 .329 .035 r
F P
0 g
s
.56651 1.2932 m .57045 1.32055 L .56154 1.31408 L .812 .329 .035 r
F
.56651 1.2932 m .58611 1.31592 L .60583 1.29558 L p .524 .428 .688 r
F P
0 g
s
.57045 1.32055 m .58611 1.31592 L p .58213 1.30856 L .705 .973 .754 r
F P
0 g
s
.54207 1.29994 m .56651 1.2932 L p .56154 1.31408 L .812 .329 .035 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.58611 1.31592 m .60583 1.29558 L .59053 1.29994 L p .705 .973 .754 r
F P
0 g
s
.59053 1.29994 m .54207 1.29994 L p .57875 1.31202 L .69 .689 .843 r
F P
0 g
s
.59053 1.29994 m .57921 1.30317 L p .58213 1.30856 L .705 .973 .754 r
F P
0 g
s
.58611 1.31592 m .59053 1.29994 L .58213 1.30856 L .705 .973 .754 r
F
.63045 1.32905 m .63099 1.29994 L .59053 1.29994 L p .69 .689 .843 r
F P
0 g
s
.57875 1.31202 m .63045 1.32905 L .59053 1.29994 L .69 .689 .843 r
F
.41588 1.29994 m .36901 1.29994 L p .4245 1.30612 L F P
0 g
s
.60583 1.29558 m .58611 1.27286 L .56651 1.2932 L p .524 .428 .688 r
F P
0 g
s
.403 1.2717 m .39643 1.27716 L .55161 1.29223 L .693 .453 .555 r
F
.403 1.2717 m .55161 1.29223 L .55389 1.29039 L F
.57045 1.27701 m .58611 1.27286 L p .54619 1.29661 L .714 .977 .761 r
F P
0 g
s
.41588 1.29994 m .43308 1.29558 L p .40444 1.28654 L .82 .344 .063 r
F P
0 g
s
.41588 1.29994 m .59053 1.29994 L p .39643 1.27716 L .693 .453 .555 r
F P
0 g
s
.59053 1.29994 m .60583 1.29558 L p .57879 1.28654 L .809 .323 .024 r
F P
0 g
s
.59053 1.29994 m .63099 1.29994 L p .58677 1.29565 L .693 .453 .555 r
F P
0 g
s
.39643 1.27716 m .59053 1.29994 L .58677 1.29565 L .693 .453 .555 r
F
.54207 1.29994 m .41588 1.29994 L p .52524 1.31733 L .69 .689 .843 r
F P
0 g
s
.40822 1.26755 m .55563 1.28899 L .57045 1.27701 L .693 .453 .555 r
F
.58215 1.26755 m .56216 1.26755 L p .57045 1.27701 L F P
0 g
s
.56216 1.26755 m .40822 1.26755 L p .57045 1.27701 L .693 .453 .555 r
F P
0 g
s
.60583 1.29558 m .58611 1.27286 L .57045 1.27701 L p .809 .323 .024 r
F P
0 g
s
.403 1.2717 m .63099 1.29994 L .40822 1.26755 L .693 .453 .555 r
F
.5592 1.27999 m .56429 1.2817 L p .53931 1.3007 L .714 .977 .761 r
F P
0 g
s
.54619 1.29661 m .53931 1.3007 L .57045 1.27701 L .714 .977 .761 r
F
.60583 1.29558 m .57045 1.27701 L .57879 1.28654 L .809 .323 .024 r
F
.55563 1.28899 m .63099 1.29994 L .58215 1.26755 L .693 .453 .555 r
F
.57045 1.27701 m .5592 1.27999 L p .57879 1.28654 L .809 .323 .024 r
F P
0 g
s
.55389 1.29039 m .55161 1.29223 L .63099 1.29994 L .693 .453 .555 r
F
.5592 1.27999 m .57921 1.30317 L .59053 1.29994 L p .809 .323 .024 r
F P
0 g
s
.57879 1.28654 m .5592 1.27999 L .59053 1.29994 L .809 .323 .024 r
F
.36901 1.29994 m .41588 1.29994 L p .39643 1.27716 L .693 .453 .555 r
F P
0 g
s
.40444 1.28654 m .39148 1.28245 L .41588 1.29994 L .82 .344 .063 r
F
.36904 1.29866 m .36901 1.29994 L p .403 1.2717 L .693 .453 .555 r
F P
0 g
s
.38368 1.27999 m .40315 1.30317 L .41588 1.29994 L p .82 .344 .063 r
F P
0 g
s
.39148 1.28245 m .38368 1.27999 L .41588 1.29994 L .82 .344 .063 r
F
.4245 1.30612 m .52524 1.31733 L .41588 1.29994 L .69 .689 .843 r
F
.52524 1.31733 m .63045 1.32905 L .54207 1.29994 L F
.54207 1.29994 m .53931 1.3007 L p .54407 1.29787 L .714 .977 .761 r
F P
0 g
s
.54619 1.29661 m .54207 1.29994 L .54407 1.29787 L .714 .977 .761 r
F
.57045 1.32055 m .5592 1.32387 L p .56154 1.31408 L .812 .329 .035 r
F P
0 g
s
.57921 1.30317 m .5592 1.32387 L .57045 1.32055 L p .705 .973 .754 r
F P
0 g
s
.58213 1.30856 m .57921 1.30317 L .57045 1.32055 L .705 .973 .754 r
F
.41588 1.29994 m .40315 1.30317 L p .40769 1.30856 L .734 .985 .78 r
F P
0 g
s
.57341 1.3227 m .57381 1.32299 L .63045 1.32905 L .69 .689 .843 r
F
.5592 1.32387 m .53931 1.3007 L .54207 1.29994 L p .812 .329 .035 r
F P
0 g
s
.56154 1.31408 m .5592 1.32387 L .54207 1.29994 L .812 .329 .035 r
F
.40315 1.30317 m .38368 1.32387 L .39631 1.32055 L p .734 .985 .78 r
F P
0 g
s
.40769 1.30856 m .40315 1.30317 L .39631 1.32055 L .734 .985 .78 r
F
.38823 1.32905 m .40822 1.32905 L p .39631 1.32055 L .69 .689 .843 r
F P
0 g
s
.36913 1.30645 m .36868 1.3059 L p .36912 1.30568 L .823 .35 .073 r
F P
0 g
s
.37136 1.3046 m .36913 1.30645 L .36912 1.30568 L .823 .35 .073 r
F
.38368 1.32387 m .36913 1.30645 L p .37136 1.3046 L F P
0 g
s
.38489 1.32056 m .38368 1.32387 L .37136 1.3046 L .823 .35 .073 r
F
.63099 1.29994 m .63045 1.26755 L .58215 1.26755 L p .693 .453 .555 r
F P
0 g
s
.40822 1.26755 m .36955 1.26755 L p .403 1.2717 L .693 .453 .555 r
F P
0 g
s
.37162 1.29661 m .36904 1.29866 L .36896 1.2981 L .741 .988 .787 r
F
.39631 1.27701 m .38368 1.27999 L p .40444 1.28654 L .82 .344 .063 r
F P
0 g
s
.36896 1.2981 m .36904 1.29866 L .36433 1.3007 L .741 .988 .787 r
F
.36915 1.29952 m .36742 1.29994 L p .36904 1.29866 L F P
0 g
s
.36742 1.29994 m .36433 1.3007 L p .36904 1.29866 L .741 .988 .787 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46974 1.09988 m .46368 1.10009 L .46771 1.09965 L F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.66397 1.04337 m .64101 1.04449 L .64101 1.02671 L .954 .779 .626 r
F
.69239 .99858 m .67129 1.0014 L .69077 .9962 L .511 .018 .022 r
F
.68012 1.0053 m .67129 1.0014 L p .69239 .99858 L F P
0 g
s
.67129 1.0014 m .65947 .99618 L p .70136 .99337 L .511 .018 .022 r
F P
0 g
s
.69927 .97691 m .65947 .99618 L .66141 .91895 L p .945 .896 .747 r
F P
0 g
s
.65947 .99618 m .67546 1.00324 L p .6662 .98194 L .293 .353 .754 r
F P
0 g
s
.67546 1.00324 m .68012 1.0053 L p .6662 .98194 L .293 .353 .754 r
F P
0 g
s
.67227 .96907 m .6662 .98194 L .68012 1.0053 L .293 .353 .754 r
F
.66141 .91895 m .65947 .99618 L p .67227 .96907 L F P
0 g
s
.64101 1.02671 m .64101 .924 L p .67708 1.00696 L .954 .779 .626 r
F P
0 g
s
.64101 .924 m .64101 .87438 L p .65366 .92087 L .954 .779 .626 r
F P
0 g
s
.67708 1.00696 m .64101 .924 L .65366 .92087 L .954 .779 .626 r
F
.67711 .91507 m .69927 .97691 L .66141 .91895 L .945 .896 .747 r
F
.66869 .97611 m .64101 .87438 L .70139 .99256 L .954 .779 .626 r
F
.66141 .91895 m .66253 .87438 L p .67711 .91507 L .945 .896 .747 r
F P
0 g
s
.66253 .87438 m .70139 .90907 L .67711 .91507 L .945 .896 .747 r
F
.7082 .89298 m .66253 .87438 L .66141 .91895 L p .293 .353 .754 r
F P
0 g
s
.70139 .99256 m .66352 .91843 L .69629 .91033 L .954 .779 .626 r
F
.7082 .89298 m .66141 .91895 L .67227 .96907 L .293 .353 .754 r
F
.64101 .87438 m .65178 .87448 L p .65352 .88252 L .954 .779 .626 r
F P
0 g
s
.70996 .87384 m .65289 .87429 L p .64101 1.04449 L .333 .272 .638 r
F P
0 g
s
.65289 .87429 m .64101 .87438 L .64101 .924 L p .333 .272 .638 r
F P
0 g
s
.64101 .924 m .64101 1.04449 L p .65289 .87429 L .333 .272 .638 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.67708 1.00696 m .66869 .97611 L .69155 .98838 L .954 .779 .626 r
F
.70098 .99356 m .70136 .99337 L p .70172 .99373 L .379 0 .039 r
F P
0 g
s
.70207 .999 m .69083 .99618 L .70136 .99337 L .511 .018 .022 r
F
.69083 .99618 m .69154 .99391 L p .69129 .99606 L .855 .879 .855 r
F P
0 g
s
.69154 .99391 m .70136 .99337 L p .69129 .99606 L .855 .879 .855 r
F P
0 g
s
.69154 .99391 m .69083 .99618 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69491 .99721 m .69455 .99537 L .70139 .99365 L .954 .779 .626 r
F
.70207 .999 m .69455 .99537 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69455 .99537 m .69154 .99391 L p .69491 .99721 L .486 .481 .777 r
F P
0 g
s
.69491 .99721 m .69424 .99545 L .69455 .99537 L .954 .779 .626 r
F
.69455 .99537 m .69154 .99391 L p .6946 .99536 L .628 .114 .004 r
F P
0 g
s
.69154 .99391 m .70136 .99337 L p .70139 .99365 L .628 .114 .004 r
F P
0 g
s
.70206 .9989 m .6946 .99536 L .70139 .99365 L .628 .114 .004 r
F
.6946 .99536 m .69154 .99391 L .70139 .99365 L F
.70422 1.01594 m .69083 .99618 L .70207 .999 L .511 .018 .022 r
F
.67708 1.00696 m .68406 .998 L .69491 .99721 L .954 .779 .626 r
F
.68406 .998 m .69155 .98838 L .69424 .99545 L F
.68406 .998 m .69424 .99545 L .69491 .99721 L F
.69424 .99545 m .69155 .98838 L .70139 .99365 L F
.70207 .999 m .69455 .99537 L p .70206 .9989 L .628 .114 .004 r
F P
0 g
s
.69455 .99537 m .6946 .99536 L .70206 .9989 L .628 .114 .004 r
F
.70743 .99928 m .70207 .999 L p .70724 .99911 L .379 0 .039 r
F P
0 g
s
.70685 .99485 m .70743 .99928 L p .70172 .99373 L .379 0 .039 r
F P
0 g
s
.74022 1.00219 m .70139 .99256 L .72241 .94381 L .347 .283 .642 r
F
.7052 .99449 m .70139 .99256 L .74022 1.00219 L F
.70139 .99256 m .70139 .90907 L p .72241 .94381 L F P
0 g
s
.72241 .94381 m .70139 .90907 L .71255 .91149 L .347 .283 .642 r
F
.70771 1.00042 m .71021 1.01047 L p .70719 .99644 L .755 .49 0 r
F P
0 g
s
.70743 .99928 m .70676 1.00113 L .70749 1.00099 L .438 .526 .85 r
F
.70676 1.00113 m .70732 1.00139 L .70749 1.00099 L F
.70733 1.00139 m .70735 1.00156 L p .70718 1.00132 L .628 .114 .004 r
F P
0 g
s
.71021 1.01047 m .70771 1.00042 L p .70786 1.01149 L .438 .526 .85 r
F P
0 g
s
.70747 1.00036 m .70786 1.01149 L .70771 1.00042 L .438 .526 .85 r
F
.71178 1.00978 m .71021 1.01047 L .7092 1.00578 L .347 .283 .642 r
F
.70749 1.00099 m .70733 1.00139 L .7075 1.00147 L .438 .526 .85 r
F
.70735 1.00156 m .70207 .999 L p .70718 1.00132 L .628 .114 .004 r
F P
0 g
s
.72562 1.0053 m .70422 1.01594 L p .70207 .999 L .511 .018 .022 r
F P
0 g
s
.70207 .999 m .72395 1.00449 L .72562 1.0053 L .511 .018 .022 r
F
.70139 .99256 m .70139 .99365 L p .66869 .97611 L .954 .779 .626 r
F P
0 g
s
.70139 .99365 m .70139 .99256 L p .7022 .99383 L .347 .283 .642 r
F P
0 g
s
.70422 1.01594 m .7082 .89298 L p .67227 .96907 L .293 .353 .754 r
F P
0 g
s
.70422 1.01594 m .68012 1.0053 L p .69239 .99858 L .511 .018 .022 r
F P
0 g
s
.68012 1.0053 m .70422 1.01594 L p .67227 .96907 L .293 .353 .754 r
F P
0 g
s
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55656 1.04601 m .55716 1.10469 L .64049 1.10469 L p .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L F P
0 g
s
.63806 1.04502 m .6371 1.00646 L .63614 1.043 L 0 0 .063 r
F
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.5554 1.043 m .6333 1.04487 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p F P
0 g
s
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L 0 0 .063 r
F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .68665 1.06543 L .333 .272 .638 r
F P
0 g
s
.68085 1.00864 m .67708 1.00696 L .68012 1.0053 L .954 .779 .626 r
F
.70743 .99928 m .70682 1.0002 L .70707 1.00026 L .438 .526 .85 r
F
.70771 1.00042 m .70719 .99644 L .72395 1.00449 L .511 .018 .022 r
F
.70685 .99485 m .70743 .99928 L .70771 1.00042 L p .755 .49 0 r
F P
0 g
s
.70685 .99485 m .70771 1.00042 L .70719 .99644 L .755 .49 0 r
F
.70422 1.01594 m .72562 1.0053 L p .72602 1.00307 L .948 .9 .745 r
F P
0 g
s
.72309 .9558 m .70422 1.01594 L .72602 1.00307 L .948 .9 .745 r
F
.70771 1.00042 m .70743 .99928 L p .70747 1.00036 L .438 .526 .85 r
F P
0 g
s
.74865 .87438 m .7082 .89298 L .70422 1.01594 L p .948 .9 .745 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.74865 .87438 m .72309 .9558 L .72602 1.00307 L .948 .9 .745 r
F
.74693 .91895 m .74865 .87438 L p .72562 1.0053 L F P
0 g
s
.77017 1.10042 m .72099 1.02407 L .72113 1.02351 L .347 .283 .642 r
F
.63923 .17502 m .64415 .18085 L .6625 .18295 L p .635 .107 0 r
F P
0 g
s
.37051 .17502 m .37461 .18085 L .39375 .18295 L p .647 .128 0 r
F P
0 g
s
.66658 .19117 m .6625 .18295 L .64415 .18085 L p .766 .338 .234 r
F P
0 g
s
.39716 .19117 m .39375 .18295 L .37461 .18085 L p .769 .351 .256 r
F P
0 g
s
.64415 .18085 m .64819 .18909 L .66658 .19117 L p .766 .338 .234 r
F P
0 g
s
.66957 .20145 m .66658 .19117 L .64819 .18909 L p .826 .492 .423 r
F P
0 g
s
.37461 .18085 m .37799 .18909 L .39716 .19117 L p .769 .351 .256 r
F P
0 g
s
.39967 .20145 m .39716 .19117 L .37799 .18909 L p .824 .498 .437 r
F P
0 g
s
.65256 .23763 m .65044 .25087 L .66884 .25277 L p .83 .779 .804 r
F P
0 g
s
.66884 .25277 m .67098 .23957 L .65256 .23763 L p .83 .779 .804 r
F P
0 g
s
.38164 .23763 m .37986 .25087 L .39906 .25277 L p .827 .773 .801 r
F P
0 g
s
.39906 .25277 m .40085 .23957 L .38164 .23763 L p .827 .773 .801 r
F P
0 g
s
.64819 .18909 m .65117 .1994 L .66957 .20145 L p .826 .492 .423 r
F P
0 g
s
.67135 .21331 m .66957 .20145 L .65117 .1994 L p .85 .598 .557 r
F P
0 g
s
.37799 .18909 m .38047 .1994 L .39967 .20145 L p .824 .498 .437 r
F P
0 g
s
.40117 .21331 m .39967 .20145 L .38047 .1994 L p .846 .598 .564 r
F P
0 g
s
.6534 .22423 m .65256 .23763 L .67098 .23957 L p .847 .732 .737 r
F P
0 g
s
.67098 .23957 m .67183 .22621 L .6534 .22423 L p .847 .732 .737 r
F P
0 g
s
.38234 .22423 m .38164 .23763 L .40085 .23957 L p .842 .727 .737 r
F P
0 g
s
.40085 .23957 m .40156 .22621 L .38234 .22423 L p .842 .727 .737 r
F P
0 g
s
.65117 .1994 m .65293 .21129 L .67135 .21331 L p .85 .598 .557 r
F P
0 g
s
.67183 .22621 m .67135 .21331 L .65293 .21129 L p .854 .674 .657 r
F P
0 g
s
.38047 .1994 m .38195 .21129 L .40117 .21331 L p .846 .598 .564 r
F P
0 g
s
.40156 .22621 m .40117 .21331 L .38195 .21129 L p .849 .671 .66 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.40614 .36334 m .37538 .36823 L .37538 .18543 L p .334 .273 .638 r
F P
0 g
s
.31883 .19772 m .31844 .18408 L .33888 .18629 L p .855 .674 .657 r
F P
0 g
s
.33888 .18629 m .33928 .19989 L .31883 .19772 L p .855 .674 .657 r
F P
0 g
s
.3396 .17219 m .33888 .18629 L .31844 .18408 L p .847 .732 .737 r
F P
0 g
s
.32032 .21027 m .31883 .19772 L .33928 .19989 L p .85 .598 .557 r
F P
0 g
s
.33928 .19989 m .34079 .2124 L .32032 .21027 L p .85 .598 .557 r
F P
0 g
s
.37538 .36823 m .33292 .36782 L .33292 .2218 L p .727 .594 .707 r
F P
0 g
s
.33303 .22185 m .37538 .36823 L .33292 .2218 L .727 .594 .707 r
F
.3431 .22883 m .37538 .36823 L .33303 .22185 L F
.33416 .22237 m .33303 .22185 L .33292 .22148 L F
.3431 .22883 m .33303 .22185 L .33416 .22237 L F
.34334 .22331 m .34494 .22736 L p .33949 .22484 L .767 .342 .241 r
F P
0 g
s
.33416 .22237 m .34334 .22331 L p .33949 .22484 L .767 .342 .241 r
F P
0 g
s
.32032 .21027 m .34079 .2124 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.33292 .2218 m .33292 .22148 L p .33303 .22185 L .727 .594 .707 r
F P
0 g
s
.34079 .2124 m .34334 .22331 L .33416 .22237 L p .826 .493 .425 r
F P
0 g
s
.34079 .2124 m .33416 .22237 L .32862 .21837 L .826 .493 .425 r
F
.31844 .18408 m .31915 .16993 L .3396 .17219 L p .847 .732 .737 r
F P
0 g
s
.34141 .15814 m .3396 .17219 L .31915 .16993 L p .83 .779 .804 r
F P
0 g
s
.31915 .16993 m .32094 .15584 L .34141 .15814 L p .83 .779 .804 r
F P
0 g
s
.34425 .14475 m .34141 .15814 L .32094 .15584 L p .803 .817 .862 r
F P
0 g
s
.32094 .15584 m .32374 .1424 L .34425 .14475 L p .803 .817 .862 r
F P
0 g
s
.31844 .18408 m .3185 .18604 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.3185 .18604 m .31883 .19772 L p .31994 .18525 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .3185 .18604 L .31994 .18525 L 0 0 .449 r
F
.31915 .16993 m .31844 .18408 L p .32374 .1424 L F P
0 g
s
.31883 .19772 m .32032 .21027 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32094 .15584 L .31915 .16993 L p 0 0 .449 r
F P
0 g
s
.32284 .22121 m .3209 .2128 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.3209 .2128 m .32032 .21027 L p .32862 .21837 L .826 .493 .425 r
F P
0 g
s
.32032 .21027 m .32284 .22121 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32442 .18281 m .33292 .18488 L p .33299 .17815 L .289 .763 .934 r
F P
0 g
s
.32862 .21837 m .33292 .22148 L .32284 .22121 L .826 .493 .425 r
F
.33205 .22216 m .32284 .22121 L p .33292 .22148 L F P
0 g
s
.32442 .31439 m .33205 .22216 L .33292 .36782 L .959 .783 .621 r
F
.31219 .23756 m .32442 .22807 L .32442 .31439 L F
.32442 .22807 m .33205 .22216 L .32442 .31439 L F
.33292 .2218 m .33292 .36782 L p .33205 .22216 L F P
0 g
s
.32442 .22527 m .32284 .22121 L .33205 .22216 L p .767 .342 .241 r
F P
0 g
s
.32284 .22121 m .32442 .22527 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32442 .22527 L .32442 .16584 L 0 0 .449 r
F
.30264 .17751 m .32442 .20913 L .31219 .23756 L .959 .783 .621 r
F
.32442 .20913 m .33292 .22148 L .32442 .22807 L F
.32442 .20913 m .32442 .22807 L .31219 .23756 L F
.32983 .22662 m .32962 .22372 L p .33416 .22237 L .767 .342 .241 r
F P
0 g
s
.32629 .23008 m .32442 .22527 L p .32617 .22475 L .767 .342 .241 r
F P
0 g
s
.33205 .22216 m .33416 .22237 L p .32442 .22527 L .767 .342 .241 r
F P
0 g
s
.33292 .18488 m .33292 .22148 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.32442 .18281 m .33292 .18488 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.37538 .25215 m .37538 .36823 L p .34494 .23677 L .727 .594 .707 r
F P
0 g
s
.3431 .22883 m .34494 .23016 L .34494 .23677 L .727 .594 .707 r
F
.34494 .23016 m .37538 .25215 L .34494 .23677 L F
.37538 .18543 m .40614 .17886 L p .3724 .17036 L .289 .763 .934 r
F P
0 g
s
.34425 .14475 m .34377 .18566 L .34459 .18523 L 0 0 .454 r
F
.34425 .14475 m .34459 .18523 L .34494 .16812 L F
.34459 .18523 m .34494 .22736 L .34494 .18504 L F
.34459 .18523 m .34494 .18504 L .34494 .16812 L F
.33888 .18629 m .33928 .19989 L p .34425 .14475 L F P
0 g
s
.3396 .17219 m .33888 .18629 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.33928 .19989 m .34079 .2124 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34079 .2124 m .34334 .22331 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34494 .18504 m .37538 .18543 L p .36057 .17668 L .289 .763 .934 r
F P
0 g
s
.34425 .14475 m .34141 .15814 L .3396 .17219 L p 0 0 .454 r
F P
0 g
s
.32374 .1424 m .34027 .17419 L .34424 .17203 L 0 0 .449 r
F
.34334 .22331 m .34494 .22736 L p .34459 .18523 L 0 0 .454 r
F P
0 g
s
.34377 .18566 m .34334 .22331 L .34459 .18523 L 0 0 .454 r
F
.37538 .18543 m .37538 .25215 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.33292 .18488 m .34494 .18504 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.34494 .18504 m .37538 .18543 L p .34494 .20392 L .727 .594 .707 r
F P
0 g
s
.36057 .17668 m .37538 .18543 L .3724 .17036 L .289 .763 .934 r
F
.38195 .21129 m .38234 .22423 L .40156 .22621 L p .849 .671 .66 r
F P
0 g
s
.37538 .18543 m .40614 .17886 L .40614 .36334 L p .334 .273 .638 r
F P
0 g
s
.40614 .17886 m .40726 .16878 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.34494 .14545 m .36507 .17428 L .37032 .17148 L 0 0 .454 r
F
.34494 .14573 m .365 .17432 L .34494 .14545 L F
.365 .17432 m .36507 .17428 L .34494 .14545 L F
.38567 .20378 m .38567 .20377 L .34494 .14545 L F
.40726 .16878 m .38567 .16327 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.3724 .17036 m .40614 .17886 L .38088 .16583 L .289 .763 .934 r
F
.40726 .16878 m .38567 .16327 L p .38567 .20711 L .965 .788 .614 r
F P
0 g
s
.39906 .21805 m .38567 .20711 L .38567 .29843 L .965 .788 .614 r
F
.40726 .16878 m .38567 .20711 L .39906 .21805 L F
.38245 .21715 m .38641 .20482 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37774 .22751 m .38245 .21715 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37251 .23546 m .37774 .22751 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38245 .21715 m .38567 .20711 L p .36869 .20333 L .763 .856 .919 r
F P
0 g
s
.38245 .21715 m .36869 .20333 L .36701 .20398 L .763 .856 .919 r
F
.39138 .17653 m .39216 .16186 L p .38947 .1609 L 0 0 .454 r
F P
0 g
s
.34425 .14475 m .38947 .17524 L .38947 .1609 L 0 0 .454 r
F
.38947 .17524 m .39138 .17653 L .38947 .1609 L F
.38943 .19108 m .39138 .17653 L p .34425 .14475 L F P
0 g
s
.34494 .20392 m .37538 .25215 L .34494 .23016 L .727 .594 .707 r
F
.36699 .24067 m .37251 .23546 L p .34494 .14697 L 0 0 .454 r
F P
0 g
s
.34425 .14475 m .34494 .14766 L .34494 .14697 L 0 0 .454 r
F
.34494 .14766 m .36699 .24067 L .34494 .14697 L F
.33292 .18488 m .34494 .20392 L .3431 .22883 L .727 .594 .707 r
F
.34494 .20392 m .34494 .23016 L .3431 .22883 L F
.36143 .24294 m .36699 .24067 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.35607 .24222 m .36143 .24294 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.35114 .23857 m .35607 .24222 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.34684 .23217 m .35114 .23857 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37707 .16107 m .36466 .16091 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.32374 .1424 m .35697 .16509 L .36466 .16091 L 0 0 .449 r
F
.36466 .15717 m .36466 .16091 L .36879 .15866 L F
.32374 .1424 m .36466 .16091 L .36466 .15717 L F
.34494 .16812 m .34494 .18064 L .34533 .18131 L 0 0 .454 r
F
.34494 .18064 m .34494 .22736 L .34533 .18131 L F
.34494 .22736 m .34684 .23217 L p .34533 .18131 L F P
0 g
s
.34095 .17381 m .34494 .18504 L .3469 .18399 L .289 .763 .934 r
F
.33984 .17442 m .34494 .18504 L .34095 .17381 L F
.33292 .18488 m .34494 .18504 L p .33984 .17442 L F P
0 g
s
.35682 .22537 m .36147 .21497 L p .34027 .17419 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .3371 .17591 L .34027 .17419 L 0 0 .449 r
F
.33299 .17815 m .33292 .18488 L .33984 .17442 L .289 .763 .934 r
F
.3371 .17591 m .35682 .22537 L .34027 .17419 L 0 0 .449 r
F
.33316 .16049 m .33984 .17442 L .34095 .17381 L .289 .763 .934 r
F
.35993 .16348 m .38088 .16583 L .36466 .16091 L F
.38234 .20439 m .36947 .20303 L p .38567 .20711 L .763 .856 .919 r
F P
0 g
s
.365 .17432 m .38567 .20378 L .36507 .17428 L 0 0 .454 r
F
.32374 .1424 m .34949 .16917 L .35697 .16509 L 0 0 .449 r
F
.35993 .16348 m .3724 .17036 L .38088 .16583 L .289 .763 .934 r
F
.32374 .1424 m .34424 .17203 L .34949 .16917 L 0 0 .449 r
F
.33316 .16049 m .35523 .16604 L .35993 .16348 L .289 .763 .934 r
F
.35523 .16604 m .3724 .17036 L .35993 .16348 L F
.38641 .20482 m .38943 .19108 L p .37032 .17148 L 0 0 .454 r
F P
0 g
s
.36507 .17428 m .38641 .20482 L .37032 .17148 L 0 0 .454 r
F
.37707 .16107 m .36466 .20489 L .36709 .20395 L .728 .594 .707 r
F
.33316 .16049 m .36057 .17668 L .3724 .17036 L .289 .763 .934 r
F
.37707 .16107 m .36466 .16091 L p .36466 .20489 L .728 .594 .707 r
F P
0 g
s
.36538 .20259 m .36837 .1888 L p .36466 .18493 L 0 0 .449 r
F P
0 g
s
.34864 .16963 m .3469 .18399 L .36057 .17668 L .289 .763 .934 r
F
.34949 .16917 m .36466 .20106 L .36466 .18493 L 0 0 .449 r
F
.36466 .20106 m .36538 .20259 L .36466 .18493 L F
.34095 .17381 m .3469 .18399 L .34864 .16963 L .289 .763 .934 r
F
.34424 .17203 m .36538 .20259 L .34949 .16917 L 0 0 .449 r
F
.37707 .16107 m .36709 .20395 L .36947 .20303 L .728 .594 .707 r
F
.37707 .16107 m .37707 .19842 L p .37959 .20127 L .965 .788 .614 r
F P
0 g
s
.36947 .20303 m .38234 .20439 L p .37707 .19842 L .805 .825 .867 r
F P
0 g
s
.38567 .20711 m .36947 .20303 L .36869 .20333 L .763 .856 .919 r
F
.38567 .16327 m .37707 .16107 L p .38088 .16583 L .289 .763 .934 r
F P
0 g
s
.37774 .22751 m .38245 .21715 L .36147 .21497 L p .702 .876 .963 r
F P
0 g
s
.36147 .21497 m .38245 .21715 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36538 .20259 m .36466 .20489 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36466 .20489 m .36147 .21497 L p .36701 .20398 L .763 .856 .919 r
F P
0 g
s
.36147 .21497 m .36538 .20259 L p .34424 .17203 L 0 0 .449 r
F P
0 g
s
.34027 .17419 m .36147 .21497 L .34424 .17203 L 0 0 .449 r
F
.35166 .23335 m .35682 .22537 L p .32374 .1424 L F P
0 g
s
.35114 .23857 m .35607 .24222 L .33542 .24016 L p .415 0 0 r
F P
0 g
s
.34071 .24087 m .33542 .24016 L .35607 .24222 L p .091 0 0 r
F P
0 g
s
.35607 .24222 m .36143 .24294 L .34071 .24087 L p .091 0 0 r
F P
0 g
s
.33542 .24016 m .33054 .2365 L .35114 .23857 L p .415 0 0 r
F P
0 g
s
.34621 .23858 m .34071 .24087 L .36143 .24294 L p .227 .73 .902 r
F P
0 g
s
.36143 .24294 m .36699 .24067 L .34621 .23858 L p .227 .73 .902 r
F P
0 g
s
.34684 .23217 m .35114 .23857 L .33054 .2365 L p .643 .122 0 r
F P
0 g
s
.35166 .23335 m .34621 .23858 L .36699 .24067 L p .459 .841 .986 r
F P
0 g
s
.36699 .24067 m .37251 .23546 L .35166 .23335 L p .459 .841 .986 r
F P
0 g
s
.35682 .22537 m .35166 .23335 L .37251 .23546 L p .608 .877 .991 r
F P
0 g
s
.37251 .23546 m .37774 .22751 L .35682 .22537 L p .608 .877 .991 r
F P
0 g
s
.36147 .21497 m .35682 .22537 L .37774 .22751 L p .702 .876 .963 r
F P
0 g
s
.36466 .21438 m .36013 .20664 L .33316 .34966 L .728 .594 .707 r
F
.34684 .23217 m .34466 .23194 L p .34406 .2294 L .767 .342 .241 r
F P
0 g
s
.34466 .23194 m .32629 .23008 L p .34406 .2294 L .767 .342 .241 r
F P
0 g
s
.33292 .22148 m .33292 .18488 L p .3425 .22623 L .727 .594 .707 r
F P
0 g
s
.3425 .22623 m .3431 .22883 L .33416 .22237 L .727 .594 .707 r
F
.3425 .22623 m .33416 .22237 L .33292 .22148 L F
.33949 .22484 m .34406 .2294 L .32629 .23008 L .767 .342 .241 r
F
.34494 .22736 m .34684 .23217 L p .33949 .22484 L F P
0 g
s
.33054 .2365 m .32629 .23008 L .34684 .23217 L p .643 .122 0 r
F P
0 g
s
.34621 .23858 m .35166 .23335 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33316 .16049 m .33299 .17815 L .33984 .17442 L .289 .763 .934 r
F
.33949 .22484 m .32629 .23008 L .33416 .22237 L .767 .342 .241 r
F
.34071 .24087 m .34621 .23858 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33292 .22148 m .33292 .2218 L p .33205 .22216 L .959 .783 .621 r
F P
0 g
s
.33416 .22237 m .33205 .22216 L p .33292 .22148 L .826 .493 .425 r
F P
0 g
s
.33542 .24016 m .34071 .24087 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.33316 .16049 m .33316 .21709 L p .36013 .20664 L .728 .594 .707 r
F P
0 g
s
.33054 .2365 m .33542 .24016 L p .32442 .14812 L 0 0 .449 r
F P
0 g
s
.33316 .21709 m .33316 .34966 L p .36013 .20664 L .728 .594 .707 r
F P
0 g
s
.38567 .16327 m .37707 .16107 L p .37959 .20127 L .965 .788 .614 r
F P
0 g
s
.38567 .20816 m .37959 .20127 L .38567 .29843 L .965 .788 .614 r
F
.38567 .16327 m .37959 .20127 L .38567 .20816 L F
.37707 .19842 m .37707 .16107 L p .36947 .20303 L .728 .594 .707 r
F P
0 g
s
.38567 .20378 m .38641 .20482 L .38567 .20377 L 0 0 .454 r
F
.38641 .20482 m .38943 .19108 L .36859 .18882 L p .805 .825 .867 r
F P
0 g
s
.36859 .18882 m .36837 .1888 L p .36928 .1896 L .805 .825 .867 r
F P
0 g
s
.38641 .20482 m .36859 .18882 L .36928 .1896 L .805 .825 .867 r
F
.38641 .20482 m .37834 .19765 L .37707 .19842 L F
.38234 .20439 m .38641 .20482 L p .37707 .19842 L F P
0 g
s
.38567 .29843 m .37959 .20127 L .37707 .3501 L .965 .788 .614 r
F
.37707 .19842 m .37707 .3501 L p .37959 .20127 L F P
0 g
s
.37707 .20008 m .37707 .19842 L p .36947 .20303 L .728 .594 .707 r
F P
0 g
s
.36837 .1888 m .36538 .20259 L .36947 .20303 L p .805 .825 .867 r
F P
0 g
s
.37834 .19765 m .36837 .1888 L .36947 .20303 L .805 .825 .867 r
F
.36947 .20303 m .36538 .20259 L p .36869 .20333 L .763 .856 .919 r
F P
0 g
s
.36709 .20395 m .36466 .20489 L .36466 .21438 L .728 .594 .707 r
F
.36837 .1888 m .3703 .1742 L p .35697 .16509 L 0 0 .449 r
F P
0 g
s
.34949 .16917 m .36837 .1888 L .35697 .16509 L 0 0 .449 r
F
.33316 .16049 m .34095 .17381 L .34864 .16963 L .289 .763 .934 r
F
.36466 .16091 m .33316 .16049 L p .35993 .16348 L F P
0 g
s
.35697 .16509 m .3703 .1742 L .36879 .15866 L 0 0 .449 r
F
.36466 .16091 m .33316 .16049 L p .36466 .21438 L .728 .594 .707 r
F P
0 g
s
.3703 .1742 m .37107 .15948 L p .36879 .15866 L 0 0 .449 r
F P
0 g
s
.33316 .34966 m .37707 .3501 L .37707 .20008 L p .728 .594 .707 r
F P
0 g
s
.36709 .20395 m .33316 .34966 L .37707 .20008 L .728 .594 .707 r
F
.36701 .20398 m .36869 .20333 L .36538 .20259 L .763 .856 .919 r
F
.38567 .20711 m .38641 .20482 L .38234 .20439 L p F P
0 g
s
.34425 .14475 m .34494 .14573 L .34494 .14545 L 0 0 .454 r
F
.32629 .23008 m .33054 .2365 L p .32442 .15184 L 0 0 .449 r
F P
0 g
s
.32374 .1424 m .32442 .16584 L .32442 .15184 L 0 0 .449 r
F
.32442 .16584 m .32629 .23008 L .32442 .15184 L F
.32374 .1424 m .32442 .15184 L .32442 .14812 L F
.32442 .15184 m .33054 .2365 L .32442 .14812 L F
.32442 .22527 m .32629 .23008 L p .32442 .16584 L F P
0 g
s
.30264 .17751 m .32442 .18281 L p .32442 .20913 L .959 .783 .621 r
F P
0 g
s
.30264 .17751 m .32442 .18281 L p .33316 .16049 L .289 .763 .934 r
F P
0 g
s
.33316 .16049 m .32442 .18281 L .33299 .17815 L .289 .763 .934 r
F
.33292 .36782 m .30264 .36233 L .30264 .17751 L p .959 .783 .621 r
F P
0 g
s
.30264 .36233 m .30231 .35481 L .30231 .1674 L p .717 .586 .01 r
F P
0 g
s
.30231 .1674 m .30264 .17751 L .30264 .36233 L p .717 .586 .01 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.33292 .36782 m .37538 .36823 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.30264 .36233 m .33292 .36782 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.65293 .21129 m .6534 .22423 L .67183 .22621 L p .854 .674 .657 r
F P
0 g
s
.40726 .35584 m .40614 .36334 L .40614 .17886 L p 0 0 .035 r
F P
0 g
s
.30231 .35481 m .33316 .34966 L .33316 .16049 L p .316 .258 .632 r
F P
0 g
s
.33316 .16049 m .30231 .1674 L .30264 .17751 L p .289 .763 .934 r
F P
0 g
s
.33316 .16049 m .30231 .1674 L .30231 .35481 L p .316 .258 .632 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37538 .36823 m .40614 .36334 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.40614 .36334 m .40726 .35584 L p .33316 .34966 L .224 .73 .894 r
F P
0 g
s
.33316 .34966 m .30231 .35481 L .30264 .36233 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40614 .17886 m .40726 .16878 L .40726 .35584 L p 0 0 .035 r
F P
0 g
s
.37707 .3501 m .40726 .35584 L .40726 .16878 L p .965 .788 .614 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.40726 .35584 m .37707 .3501 L .33316 .34966 L p .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60449 .19772 m .60401 .18408 L .62357 .18629 L p .86 .677 .654 r
F P
0 g
s
.62357 .18629 m .62406 .19989 L .60449 .19772 L p .86 .677 .654 r
F P
0 g
s
.62445 .17219 m .62357 .18629 L .60401 .18408 L p .852 .738 .737 r
F P
0 g
s
.6063 .21027 m .60449 .19772 L .62406 .19989 L p .855 .597 .549 r
F P
0 g
s
.62406 .19989 m .62589 .2124 L .6063 .21027 L p .855 .597 .549 r
F P
0 g
s
.66121 .36823 m .61897 .36782 L .61897 .2218 L p .727 .594 .707 r
F P
0 g
s
.61908 .22185 m .66121 .36823 L .61897 .2218 L .727 .594 .707 r
F
.6291 .22883 m .66121 .36823 L .61908 .22185 L F
.6202 .22237 m .61908 .22185 L .61897 .22148 L F
.6291 .22883 m .61908 .22185 L .6202 .22237 L F
.62898 .22331 m .63092 .22736 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.6202 .22237 m .62898 .22331 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.6063 .21027 m .62589 .2124 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.61897 .2218 m .61897 .22148 L p .61908 .22185 L .727 .594 .707 r
F P
0 g
s
.62589 .2124 m .62898 .22331 L .6202 .22237 L p .828 .487 .409 r
F P
0 g
s
.62589 .2124 m .6202 .22237 L .61469 .21837 L .828 .487 .409 r
F
.60401 .18408 m .60488 .16993 L .62445 .17219 L p .852 .738 .737 r
F P
0 g
s
.62665 .15814 m .62445 .17219 L .60488 .16993 L p .833 .786 .806 r
F P
0 g
s
.60488 .16993 m .60706 .15584 L .62665 .15814 L p .833 .786 .806 r
F P
0 g
s
.63008 .14475 m .62665 .15814 L .60706 .15584 L p .805 .823 .866 r
F P
0 g
s
.60706 .15584 m .61046 .1424 L .63008 .14475 L p .805 .823 .866 r
F P
0 g
s
.60401 .18408 m .60408 .18604 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.60408 .18604 m .60449 .19772 L p .60584 .18525 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .60408 .18604 L .60584 .18525 L .001 .001 .5 r
F
.62357 .18629 m .62364 .18824 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.62364 .18824 m .62406 .19989 L p .62542 .18746 L .009 .007 .504 r
F P
0 g
s
.63008 .14475 m .62364 .18824 L .62542 .18746 L .009 .007 .504 r
F
.62445 .17219 m .62357 .18629 L p .63008 .14475 L F P
0 g
s
.62406 .19989 m .62589 .2124 L p .62749 .18655 L .009 .007 .504 r
F P
0 g
s
.63008 .14475 m .62542 .18746 L .62749 .18655 L .009 .007 .504 r
F
.62542 .18746 m .62406 .19989 L .62749 .18655 L F
.66121 .18543 m .69459 .17886 L p .66425 .17036 L .289 .763 .934 r
F P
0 g
s
.62589 .2124 m .62898 .22331 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63092 .18504 m .66121 .18543 L p .6499 .17668 L .289 .763 .934 r
F P
0 g
s
.62898 .22331 m .63092 .22736 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.66121 .18543 m .66121 .25215 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.63092 .18504 m .66121 .18543 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.66121 .25215 m .66121 .36823 L p .63092 .23677 L .727 .594 .707 r
F P
0 g
s
.6291 .22883 m .63092 .23016 L .63092 .23677 L .727 .594 .707 r
F
.63092 .23016 m .66121 .25215 L .63092 .23677 L F
.63008 .14475 m .63092 .22736 L .63092 .16812 L .009 .007 .504 r
F
.61897 .18488 m .63092 .20392 L .6291 .22883 L .727 .594 .707 r
F
.63092 .20392 m .66121 .25215 L .63092 .23016 L F
.63092 .20392 m .63092 .23016 L .6291 .22883 L F
.69459 .17886 m .69975 .16878 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63092 .14766 m .63811 .18187 L .64047 .18083 L .009 .007 .504 r
F
.63092 .1487 m .65094 .24294 L .63092 .14766 L F
.64444 .24222 m .65094 .24294 L p .63092 .1487 L F P
0 g
s
.63092 .15045 m .64444 .24222 L .63092 .1487 L .009 .007 .504 r
F
.66425 .17036 m .69459 .17886 L .67455 .16583 L .289 .763 .934 r
F
.69459 .36334 m .66121 .36823 L .66121 .18543 L p .363 .296 .647 r
F P
0 g
s
.66121 .18543 m .69459 .17886 L .69459 .36334 L p .363 .296 .647 r
F P
0 g
s
.69975 .35584 m .69459 .36334 L .69459 .17886 L p 0 0 .158 r
F P
0 g
s
.69459 .17886 m .69975 .16878 L .69975 .35584 L p 0 0 .158 r
F P
0 g
s
.69975 .16878 m .68036 .16327 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63008 .14475 m .68036 .17268 L .68036 .15954 L .009 .007 .504 r
F
.69975 .16878 m .68036 .16327 L p .68036 .20711 L .976 .797 .597 r
F P
0 g
s
.6499 .17668 m .66121 .18543 L .66425 .17036 L .289 .763 .934 r
F
.67645 .21715 m .68126 .20482 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67074 .22751 m .67645 .21715 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67645 .21715 m .68036 .20711 L p .6643 .20333 L .763 .862 .923 r
F P
0 g
s
.67645 .21715 m .6643 .20333 L .66263 .20398 L .763 .862 .923 r
F
.63008 .14475 m .68036 .18722 L .68036 .17268 L .009 .007 .504 r
F
.68126 .20482 m .68493 .19108 L p .63008 .14475 L F P
0 g
s
.66439 .23546 m .67074 .22751 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65769 .24067 m .66439 .23546 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63845 .23857 m .64444 .24222 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.63323 .23217 m .63845 .23857 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67264 .16107 m .66029 .16091 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.63008 .14475 m .63092 .1487 L .63092 .14766 L .009 .007 .504 r
F
.63008 .14475 m .63092 .15045 L .63092 .1487 L F
.63008 .14475 m .62665 .15814 L .62445 .17219 L p F P
0 g
s
.61046 .1424 m .65093 .16509 L .66029 .16091 L .001 .001 .5 r
F
.66029 .15717 m .66029 .16091 L .66532 .15866 L F
.61046 .1424 m .66029 .16091 L .66029 .15717 L F
.65094 .24294 m .65769 .24067 L p .64047 .18083 L .009 .007 .504 r
F P
0 g
s
.63811 .18187 m .65094 .24294 L .64047 .18083 L .009 .007 .504 r
F
.63092 .22736 m .63323 .23217 L p .63092 .16812 L F P
0 g
s
.61897 .18488 m .63092 .18504 L p .63092 .20392 L .727 .594 .707 r
F P
0 g
s
.61897 .18488 m .63092 .18504 L p .63008 .17442 L .289 .763 .934 r
F P
0 g
s
.61046 .1424 m .63543 .17203 L .64182 .16917 L .001 .001 .5 r
F
.65453 .16348 m .67455 .16583 L .66029 .16091 L .289 .763 .934 r
F
.67737 .20439 m .66508 .20303 L p .68036 .20711 L .763 .862 .923 r
F P
0 g
s
.65453 .16348 m .66425 .17036 L .67455 .16583 L .289 .763 .934 r
F
.61046 .1424 m .64182 .16917 L .65093 .16509 L .001 .001 .5 r
F
.62897 .16049 m .64881 .16604 L .65453 .16348 L .289 .763 .934 r
F
.64881 .16604 m .66425 .17036 L .65453 .16348 L F
.62897 .16049 m .6499 .17668 L .66425 .17036 L F
.67264 .16107 m .66029 .16091 L p .66029 .20489 L .728 .594 .707 r
F P
0 g
s
.66482 .1888 m .66717 .1742 L p .65093 .16509 L .001 .001 .5 r
F P
0 g
s
.64182 .16917 m .66482 .1888 L .65093 .16509 L .001 .001 .5 r
F
.67264 .16107 m .66029 .20489 L .66271 .20395 L .728 .594 .707 r
F
.66293 .203 m .66271 .20395 L .6643 .20333 L F
.66293 .203 m .66508 .20303 L .66725 .2017 L F
.67264 .16107 m .67264 .19842 L p .6749 .20127 L .976 .797 .597 r
F P
0 g
s
.66508 .20303 m .67737 .20439 L p .67264 .19842 L .807 .833 .87 r
F P
0 g
s
.68036 .20711 m .66508 .20303 L .6643 .20333 L .763 .862 .923 r
F
.68036 .16327 m .67264 .16107 L p .67455 .16583 L .289 .763 .934 r
F P
0 g
s
.67074 .22751 m .67645 .21715 L .65642 .21497 L p .698 .88 .965 r
F P
0 g
s
.65642 .21497 m .67645 .21715 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.66118 .20259 m .66029 .20489 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.66029 .20489 m .65642 .21497 L p .66263 .20398 L .763 .862 .923 r
F P
0 g
s
.64079 .16963 m .63092 .18504 L .6499 .17668 L .289 .763 .934 r
F
.61046 .1424 m .63059 .17419 L .63444 .17247 L .001 .001 .5 r
F
.63008 .17442 m .63092 .18504 L .64079 .16963 L .289 .763 .934 r
F
.61046 .1424 m .66029 .20489 L .66029 .20154 L .001 .001 .5 r
F
.62173 .17815 m .61897 .18488 L .63008 .17442 L .289 .763 .934 r
F
.65076 .22537 m .65642 .21497 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .63008 .17442 L .64079 .16963 L .289 .763 .934 r
F
.65642 .21497 m .66029 .20489 L p .63444 .17247 L .001 .001 .5 r
F P
0 g
s
.63059 .17419 m .65642 .21497 L .63444 .17247 L .001 .001 .5 r
F
.66029 .20489 m .66118 .20259 L p .66029 .20154 L F P
0 g
s
.64444 .24222 m .65094 .24294 L .63114 .24087 L p .078 0 0 r
F P
0 g
s
.6113 .22527 m .60937 .22121 L .61818 .22216 L p .764 .329 .217 r
F P
0 g
s
.61469 .21837 m .61897 .22148 L .60937 .22121 L .828 .487 .409 r
F
.61818 .22216 m .60937 .22121 L p .61897 .22148 L F P
0 g
s
.60937 .22121 m .60701 .2128 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.60701 .2128 m .6063 .21027 L p .61469 .21837 L .828 .487 .409 r
F P
0 g
s
.60937 .22121 m .6113 .22527 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.6113 .22807 m .61818 .22216 L .6113 .31439 L .971 .792 .606 r
F
.6113 .31439 m .61818 .22216 L .61897 .36782 L F
.61897 .2218 m .61897 .36782 L p .61818 .22216 L F P
0 g
s
.61046 .1424 m .6113 .22527 L .6113 .16584 L .001 .001 .5 r
F
.60449 .19772 m .6063 .21027 L p .61046 .1424 L F P
0 g
s
.6063 .21027 m .60937 .22121 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.59163 .17751 m .6113 .20913 L .60026 .23756 L .971 .792 .606 r
F
.6113 .20913 m .61897 .22148 L .6113 .22807 L F
.6113 .20913 m .6113 .22807 L .60026 .23756 L F
.6202 .22237 m .6178 .22517 L .61763 .22321 L .764 .329 .217 r
F
.6178 .22517 m .61358 .23008 L .61763 .22321 L F
.61358 .23008 m .6113 .22527 L p .61763 .22321 L F P
0 g
s
.61897 .22148 m .61897 .2218 L p .61818 .22216 L .971 .792 .606 r
F P
0 g
s
.61818 .22216 m .6202 .22237 L p .6113 .22527 L .764 .329 .217 r
F P
0 g
s
.62469 .24016 m .62424 .23707 L .63845 .23857 L p .397 0 0 r
F P
0 g
s
.6113 .18281 m .61897 .18488 L p .62173 .17815 L .289 .763 .934 r
F P
0 g
s
.60488 .16993 m .60401 .18408 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.61897 .18488 m .61897 .22148 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.59163 .17751 m .6113 .18281 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.6113 .18281 m .61897 .18488 L p .6113 .20913 L .971 .792 .606 r
F P
0 g
s
.61897 .20012 m .61897 .18488 L p .62361 .20501 L .727 .594 .707 r
F P
0 g
s
.62361 .20501 m .6291 .22883 L .61897 .20012 L .727 .594 .707 r
F
.61897 .22148 m .61897 .20012 L p .6291 .22883 L F P
0 g
s
.63323 .23217 m .61358 .23008 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.63092 .22736 m .63323 .23217 L p .62551 .22484 L .764 .329 .217 r
F P
0 g
s
.62551 .22484 m .61358 .23008 L .6202 .22237 L .764 .329 .217 r
F
.61875 .2365 m .61358 .23008 L .63323 .23217 L p .631 .1 0 r
F P
0 g
s
.63323 .23217 m .63845 .23857 L .61875 .2365 L p .631 .1 0 r
F P
0 g
s
.63845 .23857 m .64444 .24222 L .62469 .24016 L p .397 0 0 r
F P
0 g
s
.63114 .24087 m .62469 .24016 L .64444 .24222 L p .078 0 0 r
F P
0 g
s
.62469 .24016 m .63114 .24087 L p .6113 .14636 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .6113 .14812 L .6113 .14636 L .001 .001 .5 r
F
.6113 .14812 m .62469 .24016 L .6113 .14636 L F
.6202 .22237 m .61818 .22216 L p .61897 .22148 L .828 .487 .409 r
F P
0 g
s
.61875 .2365 m .62469 .24016 L p .6113 .14812 L .001 .001 .5 r
F P
0 g
s
.61046 .1424 m .6113 .15184 L .6113 .14812 L .001 .001 .5 r
F
.6113 .15184 m .61875 .2365 L .6113 .14812 L F
.6113 .22527 m .61358 .23008 L p .6113 .16584 L F P
0 g
s
.60026 .23756 m .6113 .22807 L .6113 .31439 L .971 .792 .606 r
F
.63782 .23858 m .63114 .24087 L .65094 .24294 L p .229 .73 .903 r
F P
0 g
s
.65094 .24294 m .65769 .24067 L .63782 .23858 L p .229 .73 .903 r
F P
0 g
s
.64446 .23335 m .63782 .23858 L .65769 .24067 L p .454 .84 .984 r
F P
0 g
s
.65769 .24067 m .66439 .23546 L .64446 .23335 L p .454 .84 .984 r
F P
0 g
s
.65076 .22537 m .64446 .23335 L .66439 .23546 L p .602 .879 .992 r
F P
0 g
s
.66439 .23546 m .67074 .22751 L .65076 .22537 L p .602 .879 .992 r
F P
0 g
s
.65642 .21497 m .65076 .22537 L .67074 .22751 L p .698 .88 .965 r
F P
0 g
s
.66029 .21438 m .65579 .20664 L .62897 .34966 L .728 .594 .707 r
F
.64446 .23335 m .65076 .22537 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.63782 .23858 m .64446 .23335 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .62173 .17815 L .63008 .17442 L .289 .763 .934 r
F
.63543 .17203 m .66118 .20259 L .64182 .16917 L .001 .001 .5 r
F
.63114 .24087 m .63782 .23858 L p .61046 .1424 L F P
0 g
s
.62897 .16049 m .62897 .21709 L p .65579 .20664 L .728 .594 .707 r
F P
0 g
s
.62897 .21709 m .62897 .34966 L p .65579 .20664 L .728 .594 .707 r
F P
0 g
s
.68036 .16327 m .67264 .16107 L p .6749 .20127 L .976 .797 .597 r
F P
0 g
s
.68036 .20816 m .6749 .20127 L .68036 .29843 L .976 .797 .597 r
F
.68036 .16327 m .6749 .20127 L .68036 .20816 L F
.67264 .16107 m .66293 .203 L .66725 .2017 L .728 .594 .707 r
F
.67264 .20008 m .67264 .19842 L p .66725 .2017 L F P
0 g
s
.67264 .19842 m .67264 .16107 L p .66725 .2017 L .728 .594 .707 r
F P
0 g
s
.68126 .20482 m .68493 .19108 L .68473 .19105 L p .807 .833 .87 r
F P
0 g
s
.68473 .19105 m .66503 .18882 L p .67395 .19762 L .807 .833 .87 r
F P
0 g
s
.68126 .20482 m .68473 .19105 L .67395 .19762 L .807 .833 .87 r
F
.66503 .18882 m .66482 .1888 L p .66564 .1896 L F P
0 g
s
.68126 .20482 m .66503 .18882 L .66564 .1896 L .807 .833 .87 r
F
.68126 .20482 m .6739 .19765 L .67264 .19842 L F
.67737 .20439 m .68126 .20482 L p .67264 .19842 L F P
0 g
s
.68036 .29843 m .6749 .20127 L .67264 .3501 L .976 .797 .597 r
F
.67264 .19842 m .67264 .3501 L p .6749 .20127 L F P
0 g
s
.66482 .1888 m .66118 .20259 L .66508 .20303 L p .807 .833 .87 r
F P
0 g
s
.6739 .19765 m .66482 .1888 L .66508 .20303 L .807 .833 .87 r
F
.66293 .203 m .6643 .20333 L .66508 .20303 L .728 .594 .707 r
F
.66725 .2017 m .66508 .20303 L .67264 .20008 L F
.66508 .20303 m .66118 .20259 L p .6643 .20333 L .763 .862 .923 r
F P
0 g
s
.66271 .20395 m .66029 .20489 L .66029 .21438 L .728 .594 .707 r
F
.66118 .20259 m .66482 .1888 L p .64182 .16917 L .001 .001 .5 r
F P
0 g
s
.66029 .16091 m .62897 .16049 L p .65453 .16348 L .289 .763 .934 r
F P
0 g
s
.65093 .16509 m .66717 .1742 L .66532 .15866 L .001 .001 .5 r
F
.66029 .16091 m .62897 .16049 L p .66029 .21438 L .728 .594 .707 r
F P
0 g
s
.66717 .1742 m .6681 .15948 L p .66532 .15866 L .001 .001 .5 r
F P
0 g
s
.62897 .34966 m .67264 .3501 L .67264 .20008 L p .728 .594 .707 r
F P
0 g
s
.66271 .20395 m .62897 .34966 L .67264 .20008 L .728 .594 .707 r
F
.66263 .20398 m .6643 .20333 L .66118 .20259 L .763 .862 .923 r
F
.68036 .20711 m .68126 .20482 L .67737 .20439 L p F P
0 g
s
.69238 .21805 m .68036 .20711 L .68036 .29843 L .976 .797 .597 r
F
.69975 .16878 m .68036 .20711 L .69238 .21805 L F
.68493 .19108 m .6873 .17653 L p .68036 .17268 L .009 .007 .504 r
F P
0 g
s
.68036 .18722 m .68493 .19108 L .68036 .17268 L .009 .007 .504 r
F
.6873 .17653 m .68824 .16186 L p .68544 .16104 L F P
0 g
s
.68036 .15954 m .68165 .1627 L .68544 .16104 L .009 .007 .504 r
F
.68165 .1627 m .6873 .17653 L .68544 .16104 L F
.68036 .17268 m .6873 .17653 L .68036 .15954 L F
.61358 .23008 m .61875 .2365 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.59163 .17751 m .6113 .18281 L p .62897 .16049 L .289 .763 .934 r
F P
0 g
s
.62897 .16049 m .6113 .18281 L .62173 .17815 L .289 .763 .934 r
F
.61897 .36782 m .59163 .36233 L .59163 .17751 L p .971 .792 .606 r
F P
0 g
s
.61046 .1424 m .60706 .15584 L .60488 .16993 L p .001 .001 .5 r
F P
0 g
s
.62897 .16049 m .59535 .1674 L .59163 .17751 L p .289 .763 .934 r
F P
0 g
s
.59163 .36233 m .59535 .35481 L .59535 .1674 L p 0 0 .115 r
F P
0 g
s
.59535 .1674 m .59163 .17751 L .59163 .36233 L p 0 0 .115 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59535 .35481 m .62897 .34966 L .62897 .16049 L p .348 .284 .643 r
F P
0 g
s
.62897 .16049 m .59535 .1674 L .59535 .35481 L p .348 .284 .643 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61897 .36782 m .66121 .36823 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.59163 .36233 m .61897 .36782 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.62897 .34966 m .59535 .35481 L .59163 .36233 L p .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.66121 .36823 m .69459 .36334 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67264 .3501 m .69975 .35584 L .69975 .16878 L p .976 .797 .597 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.69459 .36334 m .69975 .35584 L p .62897 .34966 L .224 .73 .894 r
F P
0 g
s
.69975 .35584 m .67264 .3501 L .62897 .34966 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.40315 1.30317 m .38368 1.27999 L .36433 1.3007 L p .515 .42 .686 r
F P
0 g
s
.36433 1.3007 m .38368 1.32387 L .40315 1.30317 L p .515 .42 .686 r
F P
0 g
s
.57921 1.30317 m .5592 1.27999 L .53931 1.3007 L p .52 .425 .687 r
F P
0 g
s
.53931 1.3007 m .5592 1.32387 L .57921 1.30317 L p .52 .425 .687 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.34799 .13256 m .34425 .14475 L .32374 .1424 L p .764 .847 .913 r
F P
0 g
s
.35249 .12211 m .34799 .13256 L .34425 .14475 L p 0 0 .454 r
F P
0 g
s
.35757 .11385 m .35249 .12211 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.36301 .10816 m .35757 .11385 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.36859 .10533 m .36301 .10816 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37405 .10551 m .36859 .10533 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.37915 .10873 m .37405 .10551 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38366 .11488 m .37915 .10873 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.38737 .12371 m .38366 .11488 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39011 .13483 m .38737 .12371 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39173 .14774 m .39011 .13483 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.39216 .16186 m .39173 .14774 L p .34425 .14475 L 0 0 .454 r
F P
0 g
s
.63463 .13256 m .63008 .14475 L .61046 .1424 L p .764 .853 .917 r
F P
0 g
s
.64009 .12211 m .63463 .13256 L .63008 .14475 L p .009 .007 .504 r
F P
0 g
s
.64625 .11385 m .64009 .12211 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65286 .10816 m .64625 .11385 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.65963 .10533 m .65286 .10816 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.66625 .10551 m .65963 .10533 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67245 .10873 m .66625 .10551 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.67793 .11488 m .67245 .10873 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68243 .12371 m .67793 .11488 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68575 .13483 m .68243 .12371 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68772 .14774 m .68575 .13483 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.68824 .16186 m .68772 .14774 L p .63008 .14475 L .009 .007 .504 r
F P
0 g
s
.32374 .1424 m .32743 .13016 L .34799 .13256 L p .764 .847 .913 r
F P
0 g
s
.35249 .12211 m .34799 .13256 L .32743 .13016 L p .708 .867 .957 r
F P
0 g
s
.61046 .1424 m .61496 .13016 L .63463 .13256 L p .764 .853 .917 r
F P
0 g
s
.64009 .12211 m .63463 .13256 L .61496 .13016 L p .705 .872 .96 r
F P
0 g
s
.32743 .13016 m .33188 .11967 L .35249 .12211 L p .708 .867 .957 r
F P
0 g
s
.33188 .11967 m .32743 .13016 L .32374 .1424 L p 0 0 .449 r
F P
0 g
s
.35757 .11385 m .35249 .12211 L .33188 .11967 L p .622 .872 .989 r
F P
0 g
s
.33188 .11967 m .3369 .11138 L .35757 .11385 L p .622 .872 .989 r
F P
0 g
s
.3369 .11138 m .33188 .11967 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36301 .10816 m .35757 .11385 L .3369 .11138 L p .487 .846 .993 r
F P
0 g
s
.3369 .11138 m .34227 .10566 L .36301 .10816 L p .487 .846 .993 r
F P
0 g
s
.34227 .10566 m .3369 .11138 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36859 .10533 m .36301 .10816 L .34227 .10566 L p .275 .753 .931 r
F P
0 g
s
.34227 .10566 m .34778 .10281 L .36859 .10533 L p .275 .753 .931 r
F P
0 g
s
.34778 .10281 m .34227 .10566 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37405 .10551 m .36859 .10533 L .34778 .10281 L p 0 .547 .745 r
F P
0 g
s
.34778 .10281 m .35317 .10298 L .37405 .10551 L p 0 .547 .745 r
F P
0 g
s
.35317 .10298 m .34778 .10281 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.35822 .10621 m .35317 .10298 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36267 .11237 m .35822 .10621 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36634 .12121 m .36267 .11237 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.36904 .13237 m .36634 .12121 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37064 .14532 m .36904 .13237 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.37107 .15948 m .37064 .14532 L p .32374 .1424 L 0 0 .449 r
F P
0 g
s
.61496 .13016 m .62038 .11967 L .64009 .12211 L p .705 .872 .96 r
F P
0 g
s
.62038 .11967 m .61496 .13016 L .61046 .1424 L p .001 .001 .5 r
F P
0 g
s
.64625 .11385 m .64009 .12211 L .62038 .11967 L p .617 .874 .99 r
F P
0 g
s
.62038 .11967 m .62649 .11138 L .64625 .11385 L p .617 .874 .99 r
F P
0 g
s
.62649 .11138 m .62038 .11967 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65286 .10816 m .64625 .11385 L .62649 .11138 L p .483 .845 .992 r
F P
0 g
s
.62649 .11138 m .63303 .10566 L .65286 .10816 L p .483 .845 .992 r
F P
0 g
s
.63303 .10566 m .62649 .11138 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65963 .10533 m .65286 .10816 L .63303 .10566 L p .276 .754 .932 r
F P
0 g
s
.63303 .10566 m .63974 .10281 L .65963 .10533 L p .276 .754 .932 r
F P
0 g
s
.63974 .10281 m .63303 .10566 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66625 .10551 m .65963 .10533 L .63974 .10281 L p 0 .558 .757 r
F P
0 g
s
.63974 .10281 m .64631 .10298 L .66625 .10551 L p 0 .558 .757 r
F P
0 g
s
.64631 .10298 m .63974 .10281 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65245 .10621 m .64631 .10298 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.65788 .11237 m .65245 .10621 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66234 .12121 m .65788 .11237 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66563 .13237 m .66234 .12121 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.66758 .14532 m .66563 .13237 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.6681 .15948 m .66758 .14532 L p .61046 .1424 L .001 .001 .5 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.37915 .10873 m .37405 .10551 L .35317 .10298 L p .368 0 0 r
F P
0 g
s
.67245 .10873 m .66625 .10551 L .64631 .10298 L p .347 0 0 r
F P
0 g
s
.35317 .10298 m .35822 .10621 L .37915 .10873 L p .368 0 0 r
F P
0 g
s
.64631 .10298 m .65245 .10621 L .67245 .10873 L p .347 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.38366 .11488 m .37915 .10873 L .35822 .10621 L p .621 .083 0 r
F P
0 g
s
.67793 .11488 m .67245 .10873 L .65245 .10621 L p .607 .059 0 r
F P
0 g
s
.35822 .10621 m .36267 .11237 L .38366 .11488 L p .621 .083 0 r
F P
0 g
s
.65245 .10621 m .65788 .11237 L .67793 .11488 L p .607 .059 0 r
F P
0 g
s
.38737 .12371 m .38366 .11488 L .36267 .11237 L p .762 .323 .207 r
F P
0 g
s
.68243 .12371 m .67793 .11488 L .65788 .11237 L p .758 .307 .18 r
F P
0 g
s
.36267 .11237 m .36634 .12121 L .38737 .12371 L p .762 .323 .207 r
F P
0 g
s
.39011 .13483 m .38737 .12371 L .36634 .12121 L p .829 .486 .406 r
F P
0 g
s
.65788 .11237 m .66234 .12121 L .68243 .12371 L p .758 .307 .18 r
F P
0 g
s
.68575 .13483 m .68243 .12371 L .66234 .12121 L p .831 .479 .389 r
F P
0 g
s
.3703 .1742 m .36837 .1888 L .38943 .19108 L p .834 .786 .807 r
F P
0 g
s
.38943 .19108 m .39138 .17653 L .3703 .1742 L p .834 .786 .807 r
F P
0 g
s
.66717 .1742 m .66482 .1888 L .68493 .19108 L p .838 .794 .809 r
F P
0 g
s
.68493 .19108 m .6873 .17653 L .66717 .1742 L p .838 .794 .809 r
F P
0 g
s
.36634 .12121 m .36904 .13237 L .39011 .13483 L p .829 .486 .406 r
F P
0 g
s
.39173 .14774 m .39011 .13483 L .36904 .13237 L p .855 .597 .548 r
F P
0 g
s
.66234 .12121 m .66563 .13237 L .68575 .13483 L p .831 .479 .389 r
F P
0 g
s
.68772 .14774 m .68575 .13483 L .66563 .13237 L p .86 .597 .539 r
F P
0 g
s
.37107 .15948 m .3703 .1742 L .39138 .17653 L p .852 .738 .737 r
F P
0 g
s
.39138 .17653 m .39216 .16186 L .37107 .15948 L p .852 .738 .737 r
F P
0 g
s
.6681 .15948 m .66717 .1742 L .6873 .17653 L p .857 .744 .738 r
F P
0 g
s
.6873 .17653 m .68824 .16186 L .6681 .15948 L p .857 .744 .738 r
F P
0 g
s
.36904 .13237 m .37064 .14532 L .39173 .14774 L p .855 .597 .548 r
F P
0 g
s
.39216 .16186 m .39173 .14774 L .37064 .14532 L p .86 .678 .654 r
F P
0 g
s
.66563 .13237 m .66758 .14532 L .68772 .14774 L p .86 .597 .539 r
F P
0 g
s
.68824 .16186 m .68772 .14774 L .66758 .14532 L p .866 .681 .65 r
F P
0 g
s
.37064 .14532 m .37107 .15948 L .39216 .16186 L p .86 .678 .654 r
F P
0 g
s
.66758 .14532 m .6681 .15948 L .68824 .16186 L p .866 .681 .65 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool800000;<0oooo2000003O0?oo
o`00g03oool2000000D0001b0P0000000`1N000000000000000400000:/0oooo0P0000050000O`80
00000P1H000500000=T0oooo003K0?ooo`03000000000780001b00L0001b1000000305h000@00000
Y@3oool2000000T0001o1@00000205P000@00000e@3oool00=X0oooo00<000000000LP0007802@00
07800`000000WQD009hE00060000000305h00000000000000:80oooo00<000000000O`0007l02`00
07l00`000000V`l009/?000800000=<0oooo003I0?ooo`03000000000780001b00X0001b00<00000
09hE002N5@001P2N5@04000009l0oooo0P00000?0000O`030000002K3`00V`l000D0V`l01000003A
0?ooo`00f03oool00`000000001b0000LP0<0000LP030000002N5@00WQD000T0WQD000<000000?oo
o`3oool0V`3oool00`000000001o0000O`0@0000O`030000002K3`00V`l000P0V`l000<000000?oo
o`3oool0cP3oool00=L0oooo00<000000000LP0007803P000784000000L0WQD000<000000?ooo`3o
ool0VP3oool00`000000001o0000O`0B0000O`<000001`2K3`000`000000oooo0?ooo`3>0?ooo`00
eP3oool00`000000001b0000LP0?0000LP0400000033DS@0`e8d0<=B=0H000000P2N5@000`000000
oooo0?ooo`2H0?ooo`030000000007l0001o01<0001o00<000000<9>;P32CRh01P00000209/?0003
0000003oool0oooo0<d0oooo003F0?ooo`03000000000780001b0100001b00<000000<=B=033DS@0
1P33DS@4000009T0oooo5`0007l00`000000`Th^0<9>;P050<9>;P@00000cP3oool00=D0oooo00<0
00000000LP0007804@0007800`000000`e8d0<=B=0090<=B=0030000003oool0oooo09H0oooo00<0
00000000O`0007l05@0007l00`000000`Th^0<9>;P090<9>;P030000003oool0oooo0</0oooo003E
0?ooo`03000000000780001b0140001b00<000000<=B=033DS@02P33DS@00`000000oooo0?ooo`2E
0?oooaP0001o00<000000<9>;P32CRh02@32CRh00`000000oooo0?ooo`3;0?ooo`00e03oool00`00
0000001b0000LP0C0000LP0300000033DS@0`e8d00T0`e8d00<000000?ooo`3oool0U03oool00`00
0000001o0000O`0G0000O`0300000032CRh0`Th^00T0`Th^00<000000?ooo`3oool0bP3oool00=@0
oooo5P000787000000H0`e8d00<000000?ooo`3oool0TP3oool00`000000001o0000O`0H0000O`L0
00001@32CRh00`000000oooo0?ooo`3:0?ooo`00d`3oool00`000000001b0000LP0D0000LP030000
003DO6L0e7aW00@0e7aW1`00002D0?oooa/0001o00<000000=AjH`3DNV<0103DNV<700000</0oooo
003C0?oooaP0001b00<000000=AlI`3DO6L02@3DO6L00`000000oooo0?ooo`2A0?ooo`0300000000
07l0001o01X0001o00<000000=AjH`3DNV<02@3DNV<00`000000oooo0?ooo`390?ooo`00dP3oool0
0`000000001b0000LP0F0000LP030000003DO6L0e7aW00T0e7aW00<000000?ooo`3oool0T@3ooolM
0000O`030000003DNV<0e7YS00T0e7YS00<000000?ooo`3oool0b@3oool00=80oooo00<000000000
LP0007805P0007800`000000e7aW0=AlI`0:0=AlI`030000003oool0oooo08l0oooo00<000000000
O`0007l06`0007l00`000000e7YS0=AjH`0:0=AjH`030000003oool0oooo0<P0oooo003A0?ooo`03
000000000780001b01L0001b00<000000=AlI`3DO6L02P3DO6L00`000000oooo0?ooo`2?0?oooah0
001o00<000000=AjH`3DNV<02P3DNV<00`000000oooo0?ooo`380?ooo`00d@3oool00`000000001b
0000LP0H0000LP030000003DO6L0e7aW00T0e7aW00<000000?ooo`3oool0SP3oool00`000000001o
0000O`0M0000O`030000003DNV<0e7YS00T0e7YS00<000000?ooo`3oool0b03oool00=40oooo00<0
00000000LP00078060000784000000P0e7aW00<000000?ooo`3oool0SP3ooolP0000O`@00000203D
NV<00`000000oooo0?ooo`380?ooo`00d03oool00`000000001b0000LP0I0000LP040000003JV8`0
fYR<0=ZHS0H000000`3DO6L00`000000oooo0?ooo`2<0?ooo`030000000007l0001o01h0001o00@0
00000=bHR@3LV8T0g9R91P0000030=AjH`030000003oool0oooo0<L0oooo003@0?ooo`0300000000
0780001b01T0001b00<000000=ZHS03JV8`01`3JV8`4000008h0oooo8@0007l00`000000g9R90=bH
R@070=bHR@@00000b@3oool00=00oooo00<000000000LP0007806@0007800`000000fYR<0=ZHS00:
0=ZHS0030000003oool0oooo08/0oooo00<000000000O`0007l0800007l00`000000g9R90=bHR@09
0=bHR@030000003oool0oooo0<L0oooo003@0?oooa`0001b00<000000=ZHS03JV8`02P3JV8`00`00
0000oooo0?ooo`2;0?ooob<0001o00<000000=bHR@3LV8T02@3LV8T00`000000oooo0?ooo`370?oo
o`00c`3oool00`000000001b0000LP0K0000LP030000003JV8`0fYR<00T0fYR<00<000000?ooo`3o
ool0RP3oool00`000000001o0000O`0Q0000O`030000003LV8T0g9R900X0g9R900<000000?ooo`3o
ool0aP3oool00<l0oooo7P0007800`000000fYR<0=ZHS0090=ZHS0030000003oool0oooo08X0oooo
900007l00`000000g9R90=bHR@0:0=bHR@030000003oool0oooo0<H0oooo003?0?oooah0001b00<0
00000=ZHS03JV8`02P3JV8`00`000000oooo0?ooo`290?ooo`030000000007l0001o0280001o00<0
00000=bHR@3LV8T02@3LV8T00`000000oooo0?ooo`360?ooo`00c`3ooolN0000LP@000002@3JV8`0
0`000000oooo0?ooo`290?ooo`030000000007l0001o0280001o100000080=bHR@030000003oool0
oooo0<H0oooo003>0?ooo`03000000000780001b00H0001b00<0cM7L0000LP0007804`0007801000
0000g:fW0=b]Y`3L[JL6000000<0fYR<00<000000?ooo`3oool0R03oool00`000000001o0000O`08
0000O`030<kBg@0007l0001o01P0001o00@000000=f^YP3M[ZH0gJjV1P0000030=bHR@030000003o
ool0oooo0<D0oooo003>0?ooo`03000000000780001b01`0001b00<000000=b]Y`3L[JL01`3L[JL4
000008X0oooo00<000000000O`0007l02`0007l00`020H40001o0000O`0E0000O`030000003M[ZH0
gJjV00L0gJjV100000370?ooo`00cP3oool00`000000001b0000LP0;0000LP030000M0000780001b
00h0001b00<000000=b]Y`3L[JL02P3L[JL00`000000oooo0?ooo`280?ooo`030000000007l0001o
00h0001o00<00P610000O`0007l04P0007l00`000000gJjV0=f^YP0:0=f^YP030000003oool0oooo
0<D0oooo003>0?ooo`03000000000780001b00h0001b00<0001d0000LP0007802`0007800`000000
g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08P0oooo00<000000000O`0007l04P0007l00`020H40
001o0000O`0>0000O`030000003M[ZH0gJjV00X0gJjV00<000000?ooo`3oool0a@3oool00<d0oooo
00<000000000LP0007804P0007800`0007@0001b0000LP080000LP030000003L[JL0g:fW00X0g:fW
00<000000?ooo`3oool0Q`3oool010000000001o0000O`3>d]dE0000O`030081P@0007l0001o00/0
001o00<000000=f^YP3M[ZH02P3M[ZH00`000000oooo0?ooo`350?ooo`00c@3oool00`000000001b
0000LP0D0000LP030000M0000780001b00H0001b00<000000=b]Y`3L[JL02P3L[JL00`000000oooo
0?ooo`270?ooo`040000000007l0001o0<kBgAP0001o00<00P610000O`0007l0200007l00`000000
gJjV0=f^YP0:0=f^YP030000003oool0oooo0<D0oooo003=0?ooo`03000000000780001b01L0001b
00<0001d0000LP0007800`0007800`000000g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08L0oooo
00@000000000O`0007l000006`0007l20081P@H0001o00<000000=f^YP3M[ZH02P3M[ZH00`000000
oooo0?ooo`350?ooo`00c@3oool010000000e<O=0000LP3DaldH0000LP80001d0P0007800`000000
g:fW0=b]Y`0:0=b]Y`030000003oool0oooo08L0oooo00@000000000O`0007l0eLW>7P0007l20081
P@<0001o00<000000=f^YP3M[ZH02P3M[ZH00`000000oooo0?ooo`350?ooo`00c@3oool010000000
e<O=0000LP3DaldK0000LP030000M00000000000008000002@3L[JL00`000000oooo0?ooo`270?oo
o`040000000007l0001o0=G9cR40001o0P020H44000000T0gJjV00<000000?ooo`3oool0a@3oool0
0<d0oooo00@000000000LP000780e<O=0P00078G000000<0001b00@000000=Zl_03J_;`0f[bl1P00
00030=b]Y`030000003oool0oooo08L0oooo00@000000000O`0007l0eLW>200007lG000000@0001o
00@000000=^n_03K_[`0fkjl1P0000030=f^YP030000003oool0oooo0<D0oooo003=0?ooo`H00000
0P1@@Z400`000000^YRd0;ZH]00A0;ZH]0@0001b00<000000=Zl_03J_;`01`3J_;`4000008T0oooo
00<000000000O`0007l00`0007l600000080FDRT00<000000;ZH]02jV;@04@2jV;@50000O`030000
003K_[`0fkjl00L0fkjl100000370?ooo`00b@3oool5000000L0D4:Q00<000000;ZH]02jV;@04@2j
V;@40000LP030000003J_;`0f[bl00X0f[bl00<000000?ooo`3oool0QP3oool00`000000001o0000
0004000000P0FDRT00<000000;ZH]02jV;@04@2jV;@50000O`030000003K_[`0fkjl00X0fkjl00<0
00000?ooo`3oool0a@3oool00<@0oooo1@00000<0512X@030000002jV;@0^YRd0140^YRd10000780
0`000000f[bl0=Zl_00:0=Zl_0<00000PP3oool6000000d0FDRT00<000000;ZH]02jV;@04@2jV;@5
0000O`030000003K_[`0fkjl00X0fkjl00<000000?ooo`3oool0a@3oool00<40oooo0`00000A0512
X@030000002jV;@0^YRd0140^YRd0`0007800`000000f[bl0=Zl_00;0=Zl_0030000003gbId0mlVM
00D00000NP3oool3000001<0FDRT00<000000;ZH]02jV;@04@2jV;@40000O`030000003K_[`0fkjl
00/0fkjl1@0000330?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140
^YRd0`0007800`000000f[bl0=Zl_00;0=Zl_0030000003gbId0mlVM00D0mlVM0`00001g0?ooo`03
0000001IB:@0FDRT01<0FDRT00<000000;ZH]02jV;@04@2jV;@40000O`030000003K_[`0fkjl00/0
fkjl00<000000?W<V03ic9P00P3ic9P300000<00oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@04@2jV;@30000LP030000003J_;`0f[bl00/0f[bl00<000000?O9W@3gbId0
1`3gbId00`000000oooo0?ooo`1d0?ooo`8000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o
00<000000=^n_03K_[`02P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LP030000003J
_;`0f[bl00/0f[bl00<000000?O9W@3gbId01`3gbId00`000000oooo0?ooo`1d0?ooo`8000005@1I
B:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<000000=^n_03K_[`02P3K_[`00`000000nLbH0?W<
V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@04@2jV;@30000LP030000003J_;`0f[bl00/0f[bl00<000000?O9W@3gbId01`3gbId0
0`000000oooo0?ooo`1d0?ooo`8000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<00000
0=^n_03K_[`02P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LPL000001`3J_;`00`00
0000mlVM0?O9W@060?O9W@800000MP3oool2000001D0FDRT00<000000;ZH]02jV;@04@2jV;@40000
O`L000001P3K_[`00`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`03
0000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@30000LP030000003EbLh0eLW>00@0
eLW>200000080?O9W@800000M@3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140
^YRd100007l00`000000e/_?0=K;c`040=K;c`L000001`3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd0`0007800`000000eLW>
0=G9cP0;0=G9cP030000003gbId0mlVM00H0mlVM0P00001e0?ooo`030000000001d0000001D0FDRT
00<000000;ZH]02jV;@04@2jV;@40000O`030000003Fbll0e/_?00X0e/_?00<000000?W<V03ic9P0
1@3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd0140^YRd0`0007800`000000eLW>0=G9cP0;0=G9cP030000003gbId0mlVM00L0mlVM00<0
00000?ooo`3oool0L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd1000
07l00`000000e/_?0=K;c`0:0=K;c`030000003ic9P0nLbH00D0nLbH00<000000?ooo`3oool0_P3o
ool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A0;ZH]0<0001b00<00000
0=G9cP3EbLh02`3EbLh00`000000mlVM0?O9W@070?O9W@030000003oool0oooo07<0oooo00<00000
00007@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0@0001o00<000000=K;c`3Fbll02P3Fbll0
0`000000nLbH0?W<V0050?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@04@2jV;@20000LP030000003EbLh0eLW>00`0eLW>00<000000?O9
W@3gbId01`3gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH
]02jV;@04@2jV;@30000O`030000003Fbll0e/_?00/0e/_?00<000000?W<V03ic9P01@3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140
^YRd0P0007800`000000eLW>0=G9cP0;0=G9cP030000003gbId0mlVM00P0mlVM00<000000?ooo`3o
ool0L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0`0007l00`000000
e/_?0=K;c`0:0=K;c`030000003ic9P0nLbH00H0nLbH00<000000?ooo`3oool0_P3oool00<40oooo
00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A0;ZH]080001b00<000000=G9cP3EbLh0
2`3EbLh00`000000mlVM0?O9W@080?O9W@030000003oool0oooo07<0oooo00<0000000007@000000
5@1IB:@00`000000^YRd0;ZH]00A0;ZH]0<0001o00<000000=K;c`3Fbll02P3Fbll00`000000nLbH
0?W<V0060?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@04@2jV;@20000LP030000003EbLh0eLW>00/0eLW>00<000000?O9W@3gbId0203g
bId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2j
V;@30000O`030000003Fbll0e/_?00X0e/_?00<000000?W<V03ic9P01P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd0P000784
000000X0eLW>00<000000?O9W@3gbId0203gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0
000001D0FDRT00<000000;ZH]02jV;@04@2jV;@30000O`@000002@3Fbll00`000000nLbH0?W<V006
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@04@2jV;@20000LP040000003>dmd0c]?M0<kCg@L000000`3EbLh00`000000mlVM0?O9W@08
0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00A
0;ZH]0<0001o00@000000<kEgP3>eMh0c]GN1P0000030=K;c`030000003ic9P0nLbH00H0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00A
0;ZH]080001b00<000000<kCg@3>dmd0203>dmd4000000X0mlVM00<000000?ooo`3oool0L`3oool0
0`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0`0007l00`000000c]GN0<kEgP07
0<kEgP@00000203ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512
X@030000002jV;@0^YRd0140^YRd00<0001b0000003>dmd03@3>dmd00`000000mlVM0?O9W@080?O9
W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH
]080001o00<000000<kEgP3>eMh02`3>eMh00`000000nLbH0?W<V0060?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@04@2jV;@00`000780
00000<kCg@0<0<kCg@030000003gbId0mlVM00T0mlVM00<000000?ooo`3oool0L`3oool00`000000
000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0P0007l00`000000c]GN0<kEgP0;0<kEgPT0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00A0;ZH]0030000LP000000c]?M00`0c]?M00<000000?O9W@3gbId02@3gbId00`000000oooo
0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@20000O`030000
003>eMh0c]GN00X0c]GN00<000000?W<V03ic9P01`3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3o
ool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd0140^YRd00<0001b0000003>dmd01P3>
dmd00`3gbId0c]?M0<kCg@030<kCg@030000003gbId0mlVM00T0mlVM00<000000?ooo`3oool0L`3o
ool00`000000000M0000000E05U8Y0030000002jV;@0^YRd0140^YRd0P0007l00`000000c]GN0<kE
gP0:0<kEgPX0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z40
0`000000^YRd0;ZH]00A0;ZH]0030000003>dmd0c]?M00@0c]?M00<0^YRd0000003>dmd01@3>dmd0
0`000000mlVM0?O9W@090?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@0
0`000000^YRd0;ZH]00A0;ZH]0030000O`000000c]GN00@0c]GN00<0^YRd0000003>eMh01@3>eMh:
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@04@2jV;@00`000000c]?M0<kCg@020<kCg@<0^YRd00<000000?O9W@3>dmd00`3>dmd00`00
0000mlVM0?O9W@0:0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00B0;ZH]0030000003>eMh0c]GN00@0^YRd00<000000?W<V03>eMh00`3>eMh00`00
0000nLbH0?W<V0080?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140
D4:Q00<000000;ZH]02jV;@04@2jV;@4000000@0^YRd00<000000?O9W@3gbId00`3>dmd00`000000
mlVM0?O9W@0:0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000
^YRd0;ZH]00A0;ZH]0040000O`0000000000000000@0^YRd00<000000?W<V03ic9P00`3>eMh;0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@04@2jV;@00`000000^YRd0;ZH]0050;ZH]0030000003gbId0mlVM00@00000303gbId00`000000
oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@00`000000
`mc/0;ZH]0050;ZH]0030000003ic9P0nLbH00<000002`3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd00h0^YRd00<0001b0;ZH]02jV;@0
202jV;@01@000000mlVM0?O9W@3gbId0`m_[00800000303gbId00`000000oooo0?ooo`1c0?ooo`03
0000000001d0000001D0FDRT00<000000;ZH]02jV;@03P2jV;@00`0007l0^YRd0;ZH]0080;ZH]006
0000003ic9P0nLbH0?W<V033g>`000002`3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`00
0000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId00P3gbId00`00
0000mlVM0?O9W@0;0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0080
mlVM00<000000?O9W@3gbId02`3gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0
FDRT00<000000;ZH]02jV;@04P2jV;@00`33g>`0^YRd0;ZH]0040;ZH]0030000003ic9P0nLbH00h0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000000M
0000000E05U8Y0030000002jV;@0^YRd0180^YRd00<0`mc/0;ZH]02jV;@0102jV;@00`000000nLbH
0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<0
000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I
0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000000M0000000E
05U8Y0030000002jV;@0^YRd0140^YRd00<0`mc/0;ZH]02jV;@01@2jV;@00`000000nLbH0?W<V00>
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<000000000
7@0000005@1IB:@00`000000^YRd0;ZH]00A0;ZH]0030000002jV;@0^YRd00D0^YRd00<000000?W<
V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@03
0000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`03
0000000001d0000001D0FDRT00<000000;ZH]02jV;@04@2jV;@00`2bhOL0^YRd0;ZH]0050;ZH]003
0000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z40
4@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0
L`3oool00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@0
0`000000^YRd0;ZH]00@0;ZH]0030;;Qm`2jV;@0^YRd00H0^YRd00<000000?W<V03ic9P03P3ic9P0
0`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd
01T0^YRd00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d00000
01D0FDRT00<000000;ZH]02jV;@0402jV;@00`2bhOL0^YRd0;ZH]0060;ZH]0030000003ic9P0nLbH
00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000
^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?ooo`3oool0L`3oool00`000000
000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000
oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd
00<000000?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003oool0oooo07<0oooo00<0000000007@0000005@1IB:@00`000000^YRd0;ZH
]00?0;ZH]00309[Qo@2jV;@0^YRd00L0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<00000
0?O9W@3gbId0403gbId00`000000oooo0?ooo`1c0?ooo`030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@03`2jV;@00`2JhOd0^YRd0;ZH]0070;ZH]0030000003ic9P0nLbH00h0nLbH00<00000
0?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH
]0030000003gbId0mlVM0100mlVM0`00001`0?ooo`@0000000<0000M0000001IB:@0501IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100
mlVM00<000000?C7X03daj000`00001]0?ooo`060000001PCjH0H4nV0000000001d000005@1IB:@0
0`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool0
0<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM
0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Z0?ooo`8000000P1PCjH00`00
0000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0
^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06X0
oooo0P000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@03P2jV;@00`000000
^YRd0;ZH]0080;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo
00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM
00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV
00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00>0;ZH]00307CGn`2jV;@0^YRd00P0^YRd
00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512
X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7
X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000
000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?oo
o`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<00000
0?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<00000
00007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<00000
0?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512
X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId01P000000m<NP0?C7X03daj00
GDbU000006/0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd00d0^YRd00<000000;ZH]02jV;@02@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@060000003daj00m<NP05e<Y@3daj000000
J`3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@0
6@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@
@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003d
aj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00GDbU0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@060?O9
W@0305E5X`3gbId0mlVM00L0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?oo
o`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH
]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@
@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03d
aj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@00
00005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3o
ool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000
003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000
000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000
003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@
@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3d
aj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1I
B:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3o
ool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0
mlVM0100mlVM00<0000005e<Y@3daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l0
00000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0
nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`00
0000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM00D0mlVM00<0EDFS0?O9W@3gbId0203gbId00`00
0000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`00
0000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`00
0000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0
^YRd00<000000?O9W@3gbId01@3gbId00`1EAJ<0mlVM0?O9W@080?O9W@030000003daj00m<NP0080
m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0
FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0
oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM
0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O
00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH
0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<0
00000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<0
00000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<0
00000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo0031
0?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@
0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002
061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>
0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH
]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?oo
o`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH
]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`03
0000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@040?O9W@03
05E5X`3gbId0mlVM00T0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`03
0000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]003
0000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z40
4@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM00@0mlVM00<0EDFS0?O9W@3gbId0
2@3gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`000000
0P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003o
ool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool0
0`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId0
0`000000m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH0
0`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P0
0`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd
01T0^YRd00<000000?O9W@3gbId0403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo
06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd
01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000
D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0403gbId00`000000
m<NP0?C7X0020?C7X0030000003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000
000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000
oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd
00<000000?O9W@3gbId00`3gbId00`1EAJ<0mlVM0?O9W@0:0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@030?O9W@0305E5X`3gbId0mlVM00X0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?oo
o`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH
]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<00000
0512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<00000
0?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<00000
00007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<00000
0?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH
]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?oo
o`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH
]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@
@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03d
aj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@00
00005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3o
ool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000
003gbId0mlVM0080mlVM00<0EDFS0?O9W@3gbId02`3gbId00`000000m<NP0?C7X0020?C7X0030000
003oool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000
002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3o
ool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId00P3g
bId00`1EAJ<0mlVM0?O9W@0;0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3o
ool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2j
V;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40
D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@020?O9W@0305E5X`3gbId0
mlVM00/0mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l0
00000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0
nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`00
0000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`00
0000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`00
0000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40
oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100
mlVM00<000000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080
H4nV00<0000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0
nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd
0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<000000?C7X03daj000P3daj000`000000oooo
0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0000000007@0000005@1IB:@00`000000^YRd
0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<0
00000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I0;ZH]0030000003gbId0mlVM0100mlVM00<0
00000?C7X03daj000P3daj000`000000oooo0?ooo`1Y0?ooo`030000000001l000000080H4nV00<0
000000007@0000005@1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<0
00000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00I
0;ZH]0050000003gbId0mlVM0?O9W@1EAJ<03P3gbId00`000000m<NP0?C7X0020?C7X0030000003o
ool0oooo06T0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y0030000002j
V;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool0
0`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00D000000?O9W@3gbId0mlVM05E5
X`0>0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9
W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?
YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3o
ool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02j
V;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000
001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000
003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000
000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000
003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2j
V;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3o
ool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2j
V;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40
D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@010000000mlVM0?O9W@1EAJ<?0?O9W@030000003d
aj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP0300000000
01d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003o
ool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@0
0`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool0
0`000000000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@0
0`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q
0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP
0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d00000
01D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo
0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000
mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000
000O00000002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000
nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q
00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP
00<000000?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT
00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo
00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9
W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O0000
0002061?YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<
V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<00000
0;ZH]02jV;@06@2jV;@00`000000mlVM05E5X`0@0?O9W@030000003daj00m<NP0080m<NP00<00000
0?ooo`3oool0J@3oool00`000000000O00000002061?YP030000000001d0000001D0FDRT00<00000
0;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?oo
o`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02jV;@06@2jV;@00`000000mlVM0?O9W@0@0?O9
W@030000003daj00m<NP0080m<NP00<000000?ooo`3oool0J@3oool00`000000000O00000002061?
YP030000000001d0000001D0FDRT00<000000;ZH]02jV;@06@2jV;@00`000000nLbH0?W<V00>0?W<
V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140D4:Q00<000000;ZH]02j
V;@06@2jV;@00`000000mlVM0?O9W@0@0?O9W@030000003daj00m<NP0080m<NP00<000000?ooo`3o
ool05P3oooll000001L0oooo00<0000000007`0000000P1PCjH00`000000000M0000000E05U8Y003
0000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00
`@3oool00`000000D4:Q0512X@0A0512X@030000002jV;@0^YRd01T0^YRd00<000000?O9W@3gbId0
403gbId00`000000m<NP0?C7X0020?C7X0030000003oool0oooo0080oooo5000000909j1/`030000
002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D000000<0oooo00<0000000007`000000
0P1PCjH00`000000000M0000000E05U8Y0030000002jV;@0^YRd01T0^YRd00<000000?W<V03ic9P0
3P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0512X@0A0512X@030000002j
V;@0^YRd01T0^YRd00<000000?O9W@3gbId02@3gbIdA000001d0WX6c00<000000;BC]02dTk@09P2d
Tk@00`000000b:Bc0<RT/`0K0<RT/a4000003`1IB:@00`000000^YRd0;ZH]00I0;ZH]0030000003i
c9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool00<40oooo00<000000512X@1@@Z404@1@@Z40
0`000000^YRd0;ZH]00I0;ZH]0`000001P24K:l00`000000WX6c09j1/`0U09j1/`030000002dTk@0
]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`040=^b[``000000`1IB:@0
0`000000^YRd0;ZH]00I0;ZH]0030000003ic9P0nLbH00h0nLbH00<000000?ooo`3oool0_P3oool0
0<40oooo00<000000512X@1@@Z404@1@@Z400`000000^YRd0;ZH]00=0;ZH]0`000004P24K:l00`00
0000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b[`0@0=^b[``000004`2jV;@00`00
0000nLbH0?W<V00>0?W<V0030000003oool0oooo0;h0oooo00310?ooo`030000001@@Z40D4:Q0140
D4:Q00<000000;ZH]02jV;@00`2jV;@:000001P0Q6b_6`00001@03Rji1D000007P3K/Zl:000000T0
^YRd00<000000?W<V03ic9P03P3ic9P00`000000oooo0?ooo`2n0?ooo`00`@3oool00`000000D4:Q
0512X@0?0512X@P000000`1SD:L00`000000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_
00@000000>c0Y`3/`:L0k<2W200000000`2jV;@000000?W<V00?0?W<V0030000003oool0oooo0;h0
oooo00310?ooo`030000001@@Z40D4:Q00L0D4:Q2000000;06=@Y`0300000024K:l0Q6b_00@0Q6b_
3000002N03Rji0`000001P3K/Zl00`000000k<2W0>c0Y`090>c0Y`P000002P3ic9P00`000000oooo
0?ooo`2n0?ooo`00`@3oool00`000000D4:Q0000000700000100He2W2P00002f03Rji0L000004`3/
`:L800000080nLbH00<000000?ooo`3oool0_P3oool00;d0oooo1P00000@06=@Y`P00000bP0h^^@8
00000100k<2W1P00002m0?ooo`00^03oool500000080=RbH00<0000006=@Y`1SD:L02@1SD:L80000
0=X0>;[T2000000;0>c0Y`030000003jc9P0n/bH00D00000^03oool00;<0oooo1@00000703H/V003
0000001SD:L0He2W0080He2W1`00003Z03Rji0P000000`3/`:L00`000000n/bH0?[<V0050?[<V0@0
0000]03oool00:h0oooo1@00000:03H/V0H00000nP0h^^@4000000/0n/bH1@00002_0?ooo`00Z@3o
ool5000000/0=RbH1000003o03Rji0H0>;[T1000000;0?[<V0D00000ZP3oool00:D0oooo1000000<
03H/V0@00000o`0h^^@>03Rji0@00000303jc9P400000:H0oooo002S0?ooo`80000000<0001l0000
000f;9P02@0f;9P400000?l0>;[T5P0h^^@4000000X0n/bH00<000000?o@O00000000P00002S0?oo
o`00X03oool3000000<0001l00<0000003H/V00f;9P0100f;9P400000?l0>;[T7P0h^^@4000000H0
n/bH00<000000?o@O03od7`00P3od7`300000:00oooo002M0?ooo`<000001P0007`00`000000=RbH
03H/V00400000?l0>;[T9P0h^^@400000080n/bH00<000000?o@O03od7`01@3od7`2000009h0oooo
002K0?ooo`800000200007`400000?l0>;[T;P0h^^@3000000T0om1l0`00002K0?ooo`00V03oool3
000000P0001l0P00003o03Rji3H0>;[T0`0000080?o@O0<00000V03oool009H0oooo0P0000080000
O0<00000o`0h^^@k03Rji0<00000203od7`2000009H0oooo002D0?ooo`<000001P0007`300000?l0
>;[T@@0h^^@2000000L0om1l0`00002D0?ooo`00T`3oool010000000001;0000B`0000040000O080
0000o`0h^^A603Rji0<00000103od7`010000000l<A;0?34B`00002C0?ooo`00T@3oool2000000<0
001;00<000000000O00000000P00003_03Rji0030000000h^^@0>;[T05P0>;[T0`0000000`3od7`0
00000?34B`020?34B`800000T@3oool00900oooo00<000000000B`0004/00`0004/200000?l0>;[T
D@0h^^@2000000D0l<A;00<000000?ooo`3oool0SP3oool008h0oooo0P0000040000B`800000o`0h
^^AE03Rji0800000103`a4/2000008h0oooo002=0?ooo`030000000004/0001;00<0001;00<00000
03Rji00h^^@0o`0h^^AG03Rji0030000003`a4/0l<A;00<0l<A;00<000000?ooo`3oool0R`3oool0
08d0oooo00@000000000B`0004/0001;0P00003o03Rji5/0>;[T0P0000030?34B`030000003oool0
oooo08/0oooo002=0?ooo`040000000004/0001;00000?l0>;[TG`0h^^@010000000l<A;0?34B`00
002=0?ooo`00S@3oool300000?l0>;[TH@0h^^@3000008d0oooo002<0?ooo`800000o`0h^^AU03Rj
i0800000S03oool008`0oooo0P00000M03Rji0@0>K[TT00h^^@00`000000>;[T03Rji02`03Rji080
0000S03oool008`0oooo0P00000k03Rji0L0>K[TIP0h^^@908ab/@030000003F[k40eZna00d0eZna
X`0h^^@2000008`0oooo002<0?ooo`030000000h^^@0>;[T05L0>;[T300i^^@j03Rji0030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000>;[T03Rji02L03Rji0800000S03o
ool008`0oooo00<0000003Rji00h^^@0M@0h^^@?03Vji1L0>;[T0P0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02E
03Rji0030000003oool0oooo08X0oooo002<0?ooo`030000000h^^@0>;[T0980>;[T0`0i^^@00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@030?k?LA00>;[T1`0i^^B303Rji0030000003oool0oooo08X0oooo002<0?ooo`03
0000000h^^@0>;[T09D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00N03Rji0P0
>K[TK`0h^^@00`000000oooo0?ooo`2:0?ooo`00S@3oool00`000000>;[T03Rji02D03Rji0030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0<00h^^@903Vji5/0>;[T00<000000?ooo`3oool0
R`3oool008h0oooo0P00002D03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@03@0h
^^@@03Vji2H0>;[T1`0i^^A803Rji0800000SP3oool00900oooo00<0000003Rji00h^^@0T@0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T02d0>;[T300i^^@M03Rji0D0>K[T=P0h^^@0
0`000000oooo0?ooo`2>0?ooo`00T@3oool00`000000>;[T03Rji02@03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0C@0h^^@803Vji1<0>;[T100i^^@T03Rji0030000003oool0oooo
08l0oooo002B0?ooo`800000T00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06d0
>;[T100i^^@:03Rji080>K[T4@0h^^@200000980oooo002D0?ooo`030000000h^^@0>;[T08d0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0100eZna
00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji02=03Rji0030000003oool0oooo0980oooo
002F0?ooo`800000S00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0>;[T08X0>;[T0P00
002F0?ooo`00V03oool2000008X0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji028
03Rji0800000V03oool009X0oooo0`00002703Rji003000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rj
i00h^^@0Q@0h^^@3000009X0oooo002M0?ooo`800000Q@0h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000000h^^@0>;[T08<0>;[T0P00002M0?ooo`00W`3oool2000008<0>;[T00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000>;[T03Rji02103Rji0800000W`3oool00:40oooo1000001o03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0O@0h^^@400000:40oooo002U0?ooo`D00000NP0h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T07P0>;[T1@00002U0?ooo`00ZP3oool50000
07D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01c03Rji0D00000ZP3oool00:l0
oooo1@00001`03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0KP0h^^@500000:l0
oooo002d0?ooo`D00000J`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T06T0>;[T
1@00002d0?ooo`00^@3oool5000006H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i01T03Rji0D00000^@3oool00;h0oooo1@00001Q03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0G`0h^^@500000;h0oooo00330?ooo`D00000G00h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k400`2=Lk40eZna000000070?k?
L@030000000h^^@0>;[T05X0>;[T1@0000330?ooo`00b03oool5000005L0>;[T00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00l0eZna00<0SG>a0=J_/@00
00001`3ncg400`000000>;[T03Rji01E03Rji0D00000b03oool00<d0oooo1`00001@03Rji0030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0?0=J_/@0308ec
/@3F[k40000000L0o/ma00<0000003Rji00h^^@0CP0h^^@700000<d0oooo003D0?ooo`X00000AP0h
^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04@0>;[T2P00003D0?ooo`00gP3oool:
000003`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00j03Rji0X00000gP3oool0
0>P0oooo3@00000_03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0;@0h^^@=0000
0>P0oooo003e0?oooa0000007`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T01d0
>;[T4000003e0?ooo`00o`3oool60?oooaT000001P0h^^@00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o0?oooal0oooo1`0000070000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@L00000o`3o
oolO0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@0508ec/@3F[k40eZna0=J_/@00
00001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0eZna00D0SG>a0=J_/@3F[k40
eZna000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403@3F[k401@2=Lk40eZna
0=J_/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0<0=J_/@0308ec/@3F[k40eZna0080eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00`0eZna00<0SG>a0=J_/@3F[k400P3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40303F[k40
0`2=Lk40eZna0=J_/@020=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0;0=J_/@0308ec/@3F[k40eZna
00<0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00/0
eZna00<0SG>a0=J_/@3F[k400`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k402P3F[k400`2=Lk40eZna
0=J_/@040=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0:0=J_/@0308ec/@3F[k40eZna00@0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna00X0eZna00<0SG>a0=J_/@3F[k40103F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k402@3F[k400`2=Lk40eZna0=J_/@050=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@090=J_/@0308ec/@3F[k40eZna00D0eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna00P0eZna00<0SG>a0=J_/@3F[k401P3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k40203F[k400`2=Lk40eZna0=J_/@060=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@070=J_/@0308ec/@3F[k40eZna00L0eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna00L0eZna00<0SG>a0=J_/@3F[k401`3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k401P3F[k400`2=Lk40eZna0=J_/@080=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@060=J_/@0308ec/@3F[k40eZna00P0eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna00D0eZna00<0SG>a0=J_/@3F[k402@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40103F[k40
0`2=Lk40eZna0=J_/@0:0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00``3oool3000005h0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`800000
4@3oool00`000000NUVP07YIX005000005T0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj0000000000003`3oool00`000000NUVP07YI
X00607YIX0<00000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool00`000000
Nfjj07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YIX0800000EP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k400`3F[k400`2=Lk40
eZna0=J_/@0;0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
Z03oool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000NUVP07YIX00807YIX0030000
003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool02`3oool00`000000NUVP07YI
X00807YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool0
0`000000NUVP07YIX00707YIX0800000E`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YI
X01jFJ001`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001jFJ00NUVP00P0
NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00oooo0?ooo`090?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?oo
o`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000
oooo00T0oooo00<0000007YIX01jFJ001`1jFJ02000005P0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0`7T00000
003oool0203oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00L0
Nfjj0P0000090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^
^P0807]^^P030<1i00000000oooo00L0oooo00<0000007YIX01jFJ001`1jFJ02000005T0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0
Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00L0NUVP00<0gKjj0000003oool0F@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k400P3F[k40
0`2=Lk40eZna0=J_/@0<0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool00`000000NUVP07YIX00807YI
X0030000003oool0oooo05P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01@3oool00`000000
NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`050?ooo`030000
001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P8000001@3oool00`000000NUVP07YI
X00807YIX0800000FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool00`000000NUVP07YIX00707YI
X0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:`0
oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YIX01jFJ001`1jFJ02000005/0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000
001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0NUVP0P00001K0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool00`000000Nfjj07]^
^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`030000001kK[X0
Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP0P00001L0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool2000000T0Nfjj00D0`7T00000
003oool0oooo0000000907YIX0800000G03oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X2000000030?ooo`000000NUVP
00T0NUVP0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[P3oool00`000000Nfjj07]^^P0707]^^P@00000201jFJ000`3M_[X000000000001M0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj
07]^^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002^0?ooo`8000002@1kK[X3000000T0NUVP0P00001M0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P07
07]^^P800000201jFJ00103M_[X0NUVP0<S7AP00001M0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0707]^^P8000002@1jFJ02
000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?oo
o`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001`1jFJ02000005h0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`8000002@1kK[X00`000000
NUVP07YIX00707YIX0800000GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00;00oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00707YIX0030<S7
AP000000oooo05d0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002`0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X0
0`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/@3oool00`000000
Nfjj07]^^P0707]^^P030000001jFJ00NUVP00D0NUVP00<0b<M60000003oool0GP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo00<0000007]^^P1kK[X0
201kK[X00`000000NUVP07YIX00307YIX0<00000G`3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00@000000=J_/@3F[k40SG>a403F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P060000001jFJ00NUVP07YIX03M
_[X0NUVP0P00001P0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00/@3oool2000000T0Nfjj00<0000007YIX01jFJ000`1jFJ0200000600oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`030000001kK[X0Nfjj00L0Nfjj
00<0000007YIX01jFJ000`1jFJ000`38adH000000?ooo`1O0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`000000Nfjj07]^^P0807]^^P040000001j
FJ00gKjj07YIX0<00000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00;80oooo0P00000907]^^P040000001jFJ00NUVP07YIX0800000H@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo0P00000907]^^P040000001j
FJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00;<0oooo00<0000007]^^P1kK[X01`1kK[X01P000000gKjj07YIX01jFJ00b<M600000640
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`030000
001kK[X0Nfjj00P0Nfjj00<0000007YIX00000000P00001Q0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo0P00
000907]^^P040000001jFJ00000000000680oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002d0?ooo`030000001kK[X0Nfjj00L0Nfjj00@0000007YIX038adH00000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;@0oooo00<0
000007]^^P1kK[X0201kK[X300000680oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002^0?ooob<00000D`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo3P00000<04PkWP030000003aa:<0lLBS00`0lLBS3`00001<0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000o`3ooolR
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool;000000T03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP070?o@
QP/00000o`3ooolG0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0E03oool300000;d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0580oooo
0P00000307`000800000^`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0D03oool2000000L0O0000`00
002h0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`1>0?ooo`800000301l000200000;H0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo04`0oooo0P00000@07`000<00000/`3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0BP3oool2000001D0O0000P00002a0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`170?ooo`<00000
6@1l000300000:h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04D0oooo0P00000O07`000800000[03o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0@`3oool2000002<0O0000`00002Y0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`110?ooo`800000:01l000200000:L0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03l0
oooo0P00000/07`000<00000Y03oool00:00oooo00<0000004PkWP18>ih01018>ihX000000P0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`8000001P1l000X000000<0O000
0P00002R0?ooo`00T`3ooolD00000180AcZN00<000000?75X`3aaJ<04`3aaJ<G00000300oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3ooolJ00000180EDFS00<000000?G8WP3eb9h0403eb9hD000009<0oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0_000001<03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QRl0
00000P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75Xc@00000
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om262@00000800D002400000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC
]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26
@02]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<0
00000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/2
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440
[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000
003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]
I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000002]I7/0
[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=
2hH000000;BC]00Y0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440
[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d
0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`80
0000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;40[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk05d0[FAk00<0[[KO0:eTN`2]I7/0DP2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1T0:eTN`030:jfg`2]I7/0[FAk04/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk06l0[FAk00<0[[KO0:eT
N`2]I7/0@02]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`1f0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/0
0`2^]]l0[FAk0:eTN`0b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk08@0[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80
[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ
0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<04`3aaJ<G00000;@0[KSQ6`00000A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0
[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl
501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<0
00000:iUO02^IG`05@2^IG`D05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<00000
0:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
0140lLFS602^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0403aaJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^
IG`05`2^IG`B05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75Xa/0[VEl00<000000:fhh@2]^>40
/02]^>42000001X0[VEl4@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]
^>40[KSQ0;00[KSQ0P00000J0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00h0lLFS5@2^IG`0
0`3aaJ<0[VEl0:iUO0040:iUO0030000002]^>40[KSQ0;00[KSQ0P00000K0:iUO100EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00h0lLFS702^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0=0?75Xad0[VEl00<000000:fhh@2]^>40/02]^>42000001`0
[VEl3`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ0;00[KSQ
0P00000L0:iUO0l0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fh
h@2`0:fhh@030000002^IG`0[VEl01`0[VEl3P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<O
0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0;0?75Xal0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M0:iU
O0d0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00X0lLFS802^IG`00`000000[KSQ0:fhh@2`0:fhh@03
0000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<Q0:iUO0030000
002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`090?75Xb40[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS00P0lLFS8P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0
[VEl0200[VEl2P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0203aaJ<R0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`070?75Xb<0
[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00Q0:iUO0T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240[VEl
2@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`01@2^IG`00`1EAJ<0[VEl0:iUO00J0:iUO0P0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS00D0lLFS9@2^IG`00`000000[KSQ0:fhh@0b0:fhh@030;^I1P2]^>40[KSQ04H0[KSQ00<00000
0:fhh@2]^>40<P2]^>400`000000[VEl0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00D0lLFSFP2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iU
O02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`040?75Xcl0[VEl00<0[KSQ0:iUO02^
IG`06@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^
IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0lLFS
CP2^IG`00`2]^>40[VEl0:iUO00;0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0
<P2^IG`00`000000[VEl0:iUO00T0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0lLFSA@2^
IG`00`2]^>40[VEl0:iUO00D0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^
IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`0
0`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`05@2^IG`0
0`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSB`2^IG`00`2]
^>40[VEl0:iUO00?0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`00
0000[VEl0:iUO00V0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP040000003aaJ<0lLFS0?75Xeh0[VEl00<0^iT60:fh
h@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0F02^IG`00`2]^>40[VEl0:iUO0040:iUO0030;^I1P2]^>40[KSQ04H0
[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00W0:iUO0<0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000
002^IG`0[VEl02P0[VEl0P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`L000007`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<0
00000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN01h0mLRN1`00
002C0?ooo`00VP3oool<000001<0AcZN00<000000?75X`2^IG`0G`2^IG`00`2kV@H0[KSQ0:fhh@16
0:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:@2^IG`00`1EAJ<000000?G8WP0B
0?G8WP`00000VP3oool00:H0oooo3@00000604LjWP030000002^IG`0[VEl05l0[VEl00<0^iT60000
00000000A`00000d0:iUO0030000002^IG`0[VEl02X0[VEl00<000000?G8WP3eb9h0103eb9h=0000
0:H0oooo002c0?ooofX000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000000006L0
0000/`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]
^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]
^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool0
0;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`00
00H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0
[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000
oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<0
00000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fh
hP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g
0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]
^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP03
0000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3o
ool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0
oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000
[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0
[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo
002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<00000
0?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`03
0000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]
^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0
^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80
[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>80
0`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0
oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo
0?ooo`2h0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<00000
0:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N
0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?oo
o`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80
G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000
003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo0P00001O0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80
[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo0P00001O0:fhhP030000003oool0
oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR00<000000?ooo`3oool03@3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0=0?ooo`030000002]^>80[KSR05d0[KSR00<000000?ooo`3oool0^@3oool00;/0
ooooH@00000?0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo00d0ooooH@00002k0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00<040f700D0om29010=Q`0@3HL040f70000000D0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7
010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo
0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`02010=Q`030?o@R@0@
3HL040f7008040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool01@000000
40f7010=Q`0@3HL0om2900D040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00@00000010=Q`0@3HL0om291P0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0X0om27
00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3o
ool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01P0@3HL00`3od8T000000;BC]00C0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00>d0oooo
?`000009010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8Lo00000>d0oooo
003]0?ooo`03000000231@H0P`D600@0P`D600<0GL[h08<51P231@H0=@231@H7010=Q`0308<51P0@
3HL0000001@0]9>d00<000000?o@Q`3od8L01P3od8Lo08<51P030000003oool0oooo0>/0oooo003]
0?ooo`03000000231@H0P`D600/0P`D600<0GL[h08<51P231@H0;`231@H8010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01@3od8M008<51P030000003oool0oooo0>/0oooo003]0?oo
o`03000000231@H0P`D60180P`D600<0GL[h08<51P231@H0:@231@H7010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L0103od8M108<51P030000003oool0oooo0>/0oooo003]0?ooo`03
000000231@H0P`D601P0P`D60`1Mb_PT08<51P<040f700@0P`D6010=Q`0@3HL00000502dTk@00`00
0000om270?o@Q`030?o@Qd80P`D600<000000?ooo`3oool0j`3oool00>`0oooo00<0000008<51P23
1@H080231@H305g:n1l0P`D6100@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om270080
om27@`231@H00`000000oooo0?ooo`3[0?ooo`00k03oool00`000000P`D608<51P0W08<51P<00000
6@231@H3010=Q`030000002dTk@0]9>d0180]9>d00@000000?o@Q`3od8L0om27A@231@H00`000000
oooo0?ooo`3Z0?ooo`00k03oool00`000000P`D608<51P0]08<51PD0/:oG4P231@H2010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0AP231@H00`000000oooo0?ooo`3Z0?ooo`00k03o
ool00`000000P`D608<51P0d08<51PD0/:oG30231@H00`0@3HL000000;BC]00C0;BC]0030000003o
d8L0P`D601d0P`D61@2`[mLT08<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0
P`D603/0P`D600<0/:oG0000000@3HL00P0@3HL608<51P030000002dTk@0]9>d0180]9>d00<00000
08<51P231@H0:`231@H90;2_ea80P`D600<000000?ooo`3oool0jP3oool00>`0oooo00<0000008<5
1P231@H0@P231@H400000540P`D63P00003/0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP03
0000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>00X0/G>>00<0/:oG0;5cSP2aLhh0
U`2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/G>>0;5cSP0=0;5cSP800000KP2aLhh2000002D0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;5cSP2aLhh02@2aLhh400000080dEP@JP2aLhh400000080ce869@2aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP060;5cSP<000001`3AF11V0;5cSP<000001`3?
DPHT0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>00D0/G>>00<00000
08=[[`0000002@3AF11T0;5cSP0300000025K:l0000000T0ce868`2aLhh00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/G>>0;5cSP040;5cSP0500000023Jjl0Pf^_08=[[`0000000P3AF100
0`2aLhh0dEP@0=5H40030=5H46<0/G>>00D0000008E/[`25K:l0QFb_000000080<mB1R<0/G>>00<0
00000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh00`2aLhh00`000000Pf^_08=[[`02
08=[[`030000003AF100dEP@00L0dEP@H@2aLhh00`000000QFb_08E/[`0308E/[`030000003?DPH0
ce8600H0ce868P2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP030;5c
SP0300000023Jjl0Pf^_00<0Pf^_00<000000=5H403AF1001`3AF11P0;5cSP0300000025K:l0QFb_
00<0QFb_00<000000<mB1P3?DPH01`3?DPHQ0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`03
0000002aLhh0/G>>0080/G>>00<0000008=[[`23Jjl01@23Jjl00`000000dEP@0=5H40060=5H4500
/G>>00<0om270;5cSP2aLhh0302aLhh00`000000QFb_08E/[`0508E/[`030000003?DPH0ce8600H0
ce868@2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool01@000000/G>>0;5cSP2aLhh0000000T0
Pf^_00<000000=5H403AF1001P3AF11G0;5cSP030000002aLhh0/G>>00<0/G>>00<0000008E/[`25
K:l01`25K:l00`000000ce860<mB1P060<mB1R00/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00@000000;5cSP2aLhh000002`23Jjl00`000000dEP@0=5H40060=5H45/0/G>>00<0000008E/[`25
K:l02@25K:l00`000000ce860<mB1P060<mB1Ql0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;5cSP0000003023Jjl00`000000dEP@0=5H40070=5H45T0/G>>00<0000008E/[`25K:l0
2`25K:l00`000000ce860<mB1P060<mB1Qh0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo0P00
000>08=[[`030000003AF100dEP@00L0dEP@E`2aLhh00`000000QFb_08E/[`0=08E/[`030000003?
DPH0ce8600H0ce867@2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000Pf^_08=[[`0>
08=[[`030000003AF100dEP@00L0dEP@E@2aLhh00`000000QFb_08E/[`0?08E/[`030000003?DPH0
ce8600H0ce86702aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000Pf^_08=[[`0?08=[
[`030000003AF100dEP@00L0dEP@E02aLhh00`000000QFb_08E/[`0@08E/[`030000003?DPH0ce86
00H0ce866`2aLhh00`000000oooo0?ooo`3Z0?ooo`00j`3oool00`000000Pf^_08=[[`0A08=[[`03
0000003AF100dEP@00L0dEP@DP2aLhh00`000000QFb_08E/[`0A08E/[`030000003?DPH0ce8600L0
ce866P2aLhh00`000000oooo0?ooo`3Z0?ooo`00jP3oool00`000000Pf^_08=[[`0B08=[[`030000
003AF100dEP@00H0dEP@D`00000E08E/[`030000003?DPH0ce8600D0ce867000003/0?ooo`00j@3o
ool00`000000Pf^_08=[[`0D08=[[`040000003AF100dEP@0=5H40@0000000<0^oc70;2`e`2`/=L0
CP2`/=L00`000000QFb_08E/[`0E08E/[`030000003?DPH0ce8600@0000000<0]?W10;2`e`2`/=L0
602`/=L00`000000oooo0?ooo`3Z0?ooo`00jP3oool00`000000Pf^_08=[[`0D08=[[`<00000102k
o<MB0;2`e`0300000025K:l0QFb_01D0QFb_0P0000040;Ci`A/0/;3G00<000000?ooo`3oool0jP3o
ool00>X0oooo0P00000D08=[[`030000002ko<L0^oc700@0^oc7E02`/=L00`000000QFb_08E/[`0C
08E/[`030000002dnL40]?W100<0]?W1702`/=L00`000000oooo0?ooo`3Z0?ooo`00j`3oool20000
0180Pf^_00<000000;_la`2ko<L0102ko<MF0;2`e`0300000025K:l0QFb_0140QFb_00<000000;Ci
`@2dnL400`2dnL4M0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`0300000023Jjl0Pf^_00l0
Pf^_00<000000;_la`2ko<L0102ko<MG0;2`e`0300000025K:l0QFb_0100QFb_00<000000;Ci`@2d
nL400`2dnL4N0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`8000003`23Jjl00`000000^oc7
0;_la`040;_laad0/;3G00<0/GB?0;2`e`2`/=L0>@2`/=L00`000000QFb_08E/[`0>08E/[`030000
002dnL40]?W100<0]?W17`2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0000
000=08=[[`030000002ko<L0^oc700@0^oc79`2`/=L00`2aM8l0/;3G0;2`e`0a0;2`e`0300000025
K:l0QFb_00`0QFb_00<000000;Ci`@2dnL400`2dnL4P0;2`e`030000003oool0oooo0>X0oooo003/
0?ooo`040000002`/=L0/;3G000000/0Pf^_00<000000;_la`2ko<L0102ko<La0;2`e`80/GB?:P2`
/=L00`000000QFb_08E/[`0:08E/[`030000002dnL40]?W100<0]?W18@2`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool01@000000/;3G0;2`e`2`/=L0000000X0Pf^_00<000000;_la`2ko<L00`2k
o<Lj0;2`e`<0/GB?8P2`/=L00`000000QFb_08E/[`0808E/[`030000002dnL40]?W100<0]?W18P2`
/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`020;2`e`0300000023Jjl0
Pf^_00H0Pf^_00<000000;_la`2ko<L00`2ko<M40;2`e`<0/GB?6P2`/=L00`000000QFb_08E/[`06
08E/[`030000002dnL40]?W100<0]?W18`2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`00
0000/;3G0;2`e`030;2`e`0300000023Jjl0Pf^_00@0Pf^_00<000000;_la`2ko<L00`2ko<M>0;2`
e`<0/GB?4P2`/=L00`000000QFb_08E/[`0408E/[`030000002dnL40]?W100<0]?W1902`/=L00`00
0000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`030;2`e`0300000023Jjl0Pf^_00<0
Pf^_00<000000;_la`2ko<L00`2ko<MG0;2`e`@0/GB?2@2`/=L00`000000QFb_08E/[`0308E/[`03
0000002dnL40]?W100<0]?W19@2`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G
0;2`e`040;2`e`0500000023Jjl0Pf^_08=[[`000000102ko<L200000600/;3G0`0000020;2`e`05
00000025K:l0QFb_08E/[`000000102dnL42000002D0/;3G00<000000?ooo`3oool0jP3oool00>`0
oooo00<000000;2`e`2`/=L01@2`/=L010000000Pf^_0000002ko<L4000006P0/;3G00@0000008E/
[`000000]?W11000000W0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G
00H0/;3G0`00001]0;2`e`<000001`2`/=L308H;3B40/;3G00<000000?ooo`3oool0jP3oool00>`0
oooo00<000000;2`e`2`/=L0R@2`/=L208H;3AT0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;2`e`2`/=L0TP2`/=L208H;3A00/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<0
00000;2`e`2`/=L0V`2`/=L00`262`d0/;3G0;2`e`060;2`e`030000003oool0oooo0>X0oooo003/
0?ooojP00000k03oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?oo
o`00k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo003]0?ooo`030000
001Fb?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3oool00>d0oooo00<0000005K8m@1Fb?D0XP1F
b?D00`000000oooo0?ooo`3[0?ooo`00k@3ooonV00000>d0oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.6141 .41312 m .6141 .24575 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.65296 .41278 m .64196 .41287 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.64196 .41287 m .6141 .41312 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.6469 .2622 m .64196 .26081 L .64196 .25948 L .999 .816 .48 r
F
.64719 .23713 m .64756 .24995 L .6469 .2622 L p F P
0 g
s
.6469 .2622 m .64756 .24995 L .66625 .24811 L p .531 .394 .639 r
F P
0 g
s
.64756 .24995 m .64719 .23713 L .66588 .23525 L p .54 .462 .716 r
F P
0 g
s
.66588 .23525 m .66625 .24811 L .64756 .24995 L p .54 .462 .716 r
F P
0 g
s
.6458 .22426 m .64719 .23713 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.64344 .21188 m .6458 .22426 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.66625 .24811 m .66559 .26039 L .6469 .2622 L p .531 .394 .639 r
F P
0 g
s
.64522 .27336 m .6469 .2622 L .66559 .26039 L p .513 .309 .541 r
F P
0 g
s
.65296 .41278 m .65296 .27986 L p .66071 .31485 L .316 .258 .632 r
F P
0 g
s
.65296 .27986 m .65296 .27839 L p .6533 .27998 L .316 .258 .632 r
F P
0 g
s
.6533 .27998 m .66071 .31485 L .65296 .27986 L .316 .258 .632 r
F
.65928 .2826 m .66071 .29106 L .65411 .28027 L F
.65928 .2826 m .65411 .28027 L .6577 .28155 L F
.66071 .29106 m .66071 .31485 L .65296 .27839 L F
.6577 .28155 m .66134 .28121 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.64541 .27334 m .66374 .2716 L p .65214 .27784 L .48 .2 .41 r
F P
0 g
s
.66287 .27215 m .65217 .27786 L .66374 .2716 L .48 .2 .41 r
F
.65217 .27786 m .6426 .28297 L .65214 .27784 L F
.65217 .27786 m .65214 .27784 L .66374 .2716 L F
.66559 .26039 m .66396 .27136 L p .64522 .27336 L .513 .309 .541 r
F P
0 g
s
.66396 .27136 m .66393 .27158 L .66374 .2716 L p .513 .309 .541 r
F P
0 g
s
.66374 .2716 m .64522 .27336 L p .66396 .27136 L .513 .309 .541 r
F P
0 g
s
.64817 .28183 m .64968 .28121 L .64911 .28736 L .688 .562 .707 r
F
.64196 .28438 m .6426 .28297 L .64623 .28263 L p .422 .05 .224 r
F P
0 g
s
.6426 .28297 m .64522 .27336 L .64541 .27334 L p .48 .2 .41 r
F P
0 g
s
.65214 .27784 m .6426 .28297 L .64541 .27334 L .48 .2 .41 r
F
.6141 .24575 m .64196 .24543 L p .64196 .36551 L .688 .562 .707 r
F P
0 g
s
.61652 .17355 m .6216 .17392 L p .64211 .2455 L .999 .816 .48 r
F P
0 g
s
.6141 .24575 m .64196 .24543 L p .58474 .23183 L .289 .763 .934 r
F P
0 g
s
.58474 .23183 m .64196 .24543 L .63395 .24154 L .289 .763 .934 r
F
.6469 .2622 m .64099 .24495 L .64211 .2455 L .999 .816 .48 r
F
.64099 .24495 m .61652 .17355 L .64211 .2455 L F
.6469 .2622 m .64196 .21668 L .64344 .21188 L F
.63624 .19063 m .64021 .20051 L p .64525 .24702 L F P
0 g
s
.6469 .2622 m .64459 .2467 L .64525 .24702 L .999 .816 .48 r
F
.64459 .2467 m .63624 .19063 L .64525 .24702 L F
.64719 .23713 m .6458 .22426 L .6645 .22234 L p .544 .522 .782 r
F P
0 g
s
.6645 .22234 m .66588 .23525 L .64719 .23713 L p .544 .522 .782 r
F P
0 g
s
.63168 .18268 m .63624 .19063 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62673 .17702 m .63168 .18268 L p .64386 .24635 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .64305 .24595 L .64386 .24635 L .999 .816 .48 r
F
.64305 .24595 m .62673 .17702 L .64386 .24635 L F
.6216 .17392 m .62673 .17702 L p .6469 .2622 L F P
0 g
s
.6117 .17594 m .61652 .17355 L p .64099 .24495 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .63958 .24427 L .64099 .24495 L .999 .816 .48 r
F
.63958 .24427 m .6117 .17594 L .64099 .24495 L F
.60737 .18102 m .6117 .17594 L p .63958 .24427 L F P
0 g
s
.6469 .2622 m .63773 .24337 L .63958 .24427 L .999 .816 .48 r
F
.63773 .24337 m .60737 .18102 L .63958 .24427 L F
.60373 .1886 m .60737 .18102 L p .6469 .2622 L F P
0 g
s
.58474 .23183 m .63395 .24154 L .61933 .23446 L .289 .763 .934 r
F
.60094 .19833 m .60373 .1886 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.59915 .20979 m .60094 .19833 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.58474 .23183 m .61319 .23148 L .60881 .22936 L .289 .763 .934 r
F
.6044 .22723 m .58474 .23183 L p .60881 .22936 L F P
0 g
s
.58474 .23183 m .61933 .23446 L .61319 .23148 L .289 .763 .934 r
F
.59844 .22245 m .59915 .20979 L p .6044 .21555 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .6044 .22735 L .6044 .21555 L .999 .816 .48 r
F
.6645 .22234 m .66588 .23525 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.66217 .20992 m .6645 .22234 L .6458 .22426 L p .542 .577 .839 r
F P
0 g
s
.66217 .20992 m .6645 .22234 L p .66517 .24576 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66458 .24547 L .66517 .24576 L .999 .816 .476 r
F
.66458 .24547 m .66217 .20992 L .66517 .24576 L F
.65296 .2453 m .66071 .24356 L p .61933 .23446 L .289 .763 .934 r
F P
0 g
s
.66588 .23525 m .66625 .24811 L .66559 .26039 L p .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .21473 L .66217 .20992 L .999 .816 .476 r
F
.6458 .22426 m .64344 .21188 L .66217 .20992 L p .542 .577 .839 r
F P
0 g
s
.65897 .19851 m .66217 .20992 L .64344 .21188 L p .535 .629 .891 r
F P
0 g
s
.65897 .19851 m .66071 .2047 L p .66071 .21473 L .999 .816 .476 r
F P
0 g
s
.66071 .2047 m .66217 .20992 L p .66071 .21473 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66351 .26501 L .66322 .26446 L .999 .816 .476 r
F
.66351 .26501 m .66071 .27127 L .66322 .26446 L F
.66322 .26446 m .66071 .27127 L .66071 .26876 L F
.66559 .26039 m .66071 .26876 L .66071 .26666 L F
.64344 .21188 m .64021 .20051 L .65897 .19851 L p .535 .629 .891 r
F P
0 g
s
.65504 .1886 m .65897 .19851 L .64021 .20051 L p .519 .68 .939 r
F P
0 g
s
.65504 .1886 m .65897 .19851 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.64021 .20051 m .63624 .19063 L .65504 .1886 L p .519 .68 .939 r
F P
0 g
s
.65054 .18062 m .65504 .1886 L .63624 .19063 L p .489 .73 .978 r
F P
0 g
s
.65054 .18062 m .65504 .1886 L p .6633 .24484 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66259 .24449 L .6633 .24484 L .999 .816 .476 r
F
.66259 .24449 m .65054 .18062 L .6633 .24484 L F
.63624 .19063 m .63168 .18268 L .65054 .18062 L p .489 .73 .978 r
F P
0 g
s
.64564 .17494 m .65054 .18062 L .63168 .18268 L p .434 .77 .997 r
F P
0 g
s
.64564 .17494 m .65054 .18062 L p .66259 .24449 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66178 .24409 L .66259 .24449 L .999 .816 .476 r
F
.66178 .24409 m .64564 .17494 L .66259 .24449 L F
.61933 .23446 m .64643 .23652 L .61319 .23148 L .289 .763 .934 r
F
.63168 .18268 m .62673 .17702 L .64564 .17494 L p .434 .77 .997 r
F P
0 g
s
.64057 .17182 m .64564 .17494 L .62673 .17702 L p .331 .777 .96 r
F P
0 g
s
.64057 .17182 m .64564 .17494 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65296 .2453 m .66071 .24356 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.61933 .23446 m .66071 .24356 L .64643 .23652 L .289 .763 .934 r
F
.62673 .17702 m .6216 .17392 L .64057 .17182 L p .331 .777 .96 r
F P
0 g
s
.63554 .17144 m .64057 .17182 L .6216 .17392 L p .154 .695 .797 r
F P
0 g
s
.63554 .17144 m .64057 .17182 L p .66085 .24363 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65974 .24309 L .66085 .24363 L .999 .816 .476 r
F
.65974 .24309 m .63554 .17144 L .66085 .24363 L F
.61319 .23148 m .63565 .23121 L .60881 .22936 L .289 .763 .934 r
F
.63078 .17383 m .63554 .17144 L p .65974 .24309 L .999 .816 .476 r
F P
0 g
s
.65835 .2424 m .63078 .17383 L .65974 .24309 L .999 .816 .476 r
F
.64021 .20051 m .64196 .20667 L p .64196 .21668 L .999 .816 .48 r
F P
0 g
s
.64196 .20667 m .64344 .21188 L p .64196 .21668 L .999 .816 .48 r
F P
0 g
s
.62649 .17892 m .63078 .17383 L p .65835 .2424 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65652 .2415 L .65835 .2424 L .999 .816 .476 r
F
.65652 .2415 m .62649 .17892 L .65835 .2424 L F
.61223 .22539 m .6044 .22723 L p .62548 .2262 L .289 .763 .934 r
F P
0 g
s
.65652 .2415 m .62356 .18761 L .62649 .17892 L .999 .816 .476 r
F
.65393 .24022 m .62356 .18767 L .65652 .2415 L F
.62356 .18767 m .62289 .18651 L .62356 .18761 L F
.62356 .18767 m .62356 .18761 L .65652 .2415 L F
.60881 .22936 m .62792 .2274 L .6044 .22723 L .289 .763 .934 r
F
.62792 .2274 m .62548 .2262 L .6044 .22723 L F
.60881 .22936 m .63278 .2298 L .62792 .2274 L F
.63565 .23121 m .63278 .2298 L .60881 .22936 L F
.6141 .41312 m .58587 .40902 L .58587 .24025 L p .931 .76 .648 r
F P
0 g
s
.58587 .24025 m .6141 .24575 L .6141 .41312 L p .931 .76 .648 r
F P
0 g
s
.58474 .23183 m .58587 .24025 L .6141 .24575 L p .289 .763 .934 r
F P
0 g
s
.58587 .40902 m .58474 .40275 L .58474 .23183 L p .748 .611 .042 r
F P
0 g
s
.58474 .23183 m .58587 .24025 L .58587 .40902 L p .748 .611 .042 r
F P
0 g
s
.58474 .23183 m .58474 .40275 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.64196 .25948 m .6044 .25007 L .6044 .23881 L .999 .816 .48 r
F
.6044 .22723 m .58474 .23183 L p .60156 .26953 L .299 .244 .627 r
F P
0 g
s
.6044 .26705 m .60156 .26953 L .6044 .2759 L .299 .244 .627 r
F
.6044 .22723 m .60156 .26953 L .6044 .26705 L F
.60625 .2733 m .60284 .26176 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6104 .28314 m .60625 .2733 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.60625 .2733 m .62539 .27146 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.6044 .26705 m .60625 .2733 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.64196 .26081 m .6044 .2502 L .64196 .25948 L .999 .816 .48 r
F
.6044 .2502 m .60033 .24905 L .6044 .25007 L F
.6044 .2502 m .6044 .25007 L .64196 .25948 L F
.59883 .23575 m .59844 .22245 L p .6469 .2622 L F P
0 g
s
.60284 .26176 m .60033 .24905 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.61223 .22539 m .6044 .22723 L p .6044 .26705 L .299 .244 .627 r
F P
0 g
s
.60495 .26657 m .6044 .26705 L .6044 .26968 L .299 .244 .627 r
F
.61223 .22539 m .6044 .26705 L .60495 .26657 L F
.62539 .27146 m .62356 .2652 L p .61142 .26092 L .525 .629 .897 r
F P
0 g
s
.6134 .26073 m .61142 .26092 L p .62356 .2652 L .525 .629 .897 r
F P
0 g
s
.62539 .27146 m .61142 .26092 L .60795 .26396 L .525 .629 .897 r
F
.6151 .29087 m .6104 .28314 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62014 .29616 m .6151 .29087 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.62527 .29881 m .62014 .29616 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6303 .29872 m .62527 .29881 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.63498 .29594 m .6303 .29872 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.63914 .29061 m .63498 .29594 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.64196 .28699 m .64911 .28736 L .64196 .29507 L .688 .562 .707 r
F
.6426 .28297 m .63914 .29061 L p .6469 .2622 L .999 .816 .48 r
F P
0 g
s
.6469 .2622 m .64522 .27336 L .6426 .28297 L p .999 .816 .48 r
F P
0 g
s
.6481 .28144 m .64874 .28515 L .64196 .28531 L .688 .562 .707 r
F
.64623 .28263 m .6426 .28297 L p .66287 .27215 L .48 .2 .41 r
F P
0 g
s
.64196 .24543 m .65296 .2453 L p .64968 .28121 L .688 .562 .707 r
F P
0 g
s
.64196 .24543 m .64968 .28121 L .64817 .28183 L .688 .562 .707 r
F
.6577 .28155 m .65411 .28027 L .65296 .27839 L .316 .258 .632 r
F
.64196 .36551 m .64975 .28041 L .65296 .41278 L .688 .562 .707 r
F
.65296 .27839 m .65296 .41278 L p .64975 .28041 L F P
0 g
s
.66393 .27158 m .66134 .28121 L .64623 .28263 L p .48 .2 .41 r
F P
0 g
s
.66393 .27158 m .64623 .28263 L .66287 .27215 L .48 .2 .41 r
F
.64196 .28531 m .64874 .28515 L .64196 .28699 L .688 .562 .707 r
F
.64196 .24543 m .6481 .28144 L .64196 .28531 L F
.64874 .28515 m .64911 .28736 L .64196 .28699 L F
.64196 .29507 m .64911 .28736 L .64196 .36551 L F
.63498 .29594 m .63914 .29061 L .65792 .28887 L p .315 0 0 r
F P
0 g
s
.6151 .29087 m .62014 .29616 L .63912 .29442 L p .408 .766 .995 r
F P
0 g
s
.63912 .29442 m .63414 .2891 L .6151 .29087 L p .408 .766 .995 r
F P
0 g
s
.6104 .28314 m .6151 .29087 L .63414 .2891 L p .472 .73 .983 r
F P
0 g
s
.63414 .2891 m .62949 .28134 L .6104 .28314 L p .472 .73 .983 r
F P
0 g
s
.60625 .2733 m .6104 .28314 L .62949 .28134 L p .507 .681 .945 r
F P
0 g
s
.62949 .28134 m .62539 .27146 L .60625 .2733 L p .507 .681 .945 r
F P
0 g
s
.62356 .34904 m .61556 .26168 L .61223 .39797 L .688 .561 .707 r
F
.61223 .22539 m .61223 .25992 L p .61556 .26168 L F P
0 g
s
.62356 .22526 m .61223 .22539 L p .62548 .2262 L .289 .763 .934 r
F P
0 g
s
.64643 .23652 m .64308 .23487 L .61319 .23148 L .289 .763 .934 r
F
.61319 .23148 m .64308 .23487 L .63565 .23121 L F
.63395 .24154 m .65296 .2453 L .61933 .23446 L F
.6303 .29872 m .63498 .29594 L .65381 .29421 L p .134 0 0 r
F P
0 g
s
.65381 .29421 m .64917 .297 L .6303 .29872 L p .134 0 0 r
F P
0 g
s
.62014 .29616 m .62527 .29881 L .6442 .29708 L p .289 .76 .939 r
F P
0 g
s
.65792 .28887 m .65381 .29421 L .63498 .29594 L p .315 0 0 r
F P
0 g
s
.6442 .29708 m .63912 .29442 L .62014 .29616 L p .289 .76 .939 r
F P
0 g
s
.62356 .22526 m .61223 .22539 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62201 .25989 m .61504 .25641 L .61223 .25992 L .534 .576 .843 r
F
.61142 .26092 m .6134 .26073 L p .61223 .25992 L F P
0 g
s
.61556 .26168 m .61223 .25992 L .6134 .26073 L .688 .561 .707 r
F
.6134 .26073 m .62201 .25989 L p .61223 .25992 L .534 .576 .843 r
F P
0 g
s
.61223 .25992 m .61223 .26022 L p .6134 .26073 L .688 .561 .707 r
F P
0 g
s
.61223 .26022 m .61223 .39797 L p .61556 .26168 L .688 .561 .707 r
F P
0 g
s
.62356 .2652 m .62201 .25989 L .6134 .26073 L p .525 .629 .897 r
F P
0 g
s
.61223 .22539 m .6044 .26968 L .6056 .26819 L .299 .244 .627 r
F
.61223 .39797 m .61223 .22539 L p .6044 .2759 L F P
0 g
s
.61142 .26092 m .60284 .26176 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.60033 .24905 m .60284 .26176 L .61142 .26092 L p .534 .576 .843 r
F P
0 g
s
.61504 .25641 m .60033 .24905 L .61142 .26092 L .534 .576 .843 r
F
.6056 .26819 m .6044 .26968 L .6044 .2759 L .299 .244 .627 r
F
.60284 .26176 m .6044 .26705 L p .60795 .26396 L .525 .629 .897 r
F P
0 g
s
.60033 .24905 m .59883 .23575 L p .6044 .23881 L .999 .816 .48 r
F P
0 g
s
.6044 .25007 m .60033 .24905 L .6044 .23881 L .999 .816 .48 r
F
.62014 .19627 m .62289 .18651 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.64196 .24543 m .65296 .2453 L p .63395 .24154 L .289 .763 .934 r
F P
0 g
s
.61836 .20776 m .62014 .19627 L p .66071 .2535 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .25495 L .66071 .2535 L .999 .816 .476 r
F
.66134 .28121 m .66071 .28262 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.65296 .2453 m .66071 .25977 L .65928 .2826 L .316 .258 .632 r
F
.65296 .24632 m .65296 .2453 L p .65317 .24656 L F P
0 g
s
.65317 .24656 m .65928 .2826 L .65296 .24632 L .316 .258 .632 r
F
.65296 .27839 m .65296 .24632 L p .65928 .2826 L F P
0 g
s
.65296 .2453 m .65296 .27839 L p .64975 .28041 L .688 .562 .707 r
F P
0 g
s
.66071 .25495 m .61836 .20776 L .66071 .2535 L .999 .816 .476 r
F
.66374 .2716 m .66393 .27158 L p .66287 .27215 L .48 .2 .41 r
F P
0 g
s
.66071 .25977 m .66071 .28356 L .65928 .2826 L .316 .258 .632 r
F
.62201 .25989 m .61953 .24714 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62539 .27146 m .62201 .25989 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62949 .28134 m .62539 .27146 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.63414 .2891 m .62949 .28134 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.63914 .29061 m .64196 .28438 L p .6577 .28155 L .422 .05 .224 r
F P
0 g
s
.64623 .28263 m .6577 .28155 L p .64196 .28438 L .422 .05 .224 r
F P
0 g
s
.65792 .28887 m .63914 .29061 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.65924 .2821 m .63914 .29061 L .6577 .28155 L .422 .05 .224 r
F
.63912 .29442 m .63414 .2891 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65381 .29421 m .64917 .297 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.65792 .28887 m .65381 .29421 L p .66071 .2744 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66071 .27851 L .66071 .2744 L .999 .816 .476 r
F
.65928 .2826 m .66071 .28356 L .66071 .29106 L .316 .258 .632 r
F
.66071 .28262 m .65792 .28887 L p .65924 .2821 L .422 .05 .224 r
F P
0 g
s
.66071 .27851 m .65792 .28887 L .66071 .2744 L .999 .816 .476 r
F
.68053 .29681 m .68053 .40818 L p .66071 .29106 L .316 .258 .632 r
F P
0 g
s
.66071 .28356 m .68053 .29681 L .66071 .29106 L .316 .258 .632 r
F
.66134 .28121 m .65792 .28887 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .66393 .27158 L .66134 .28121 L p .999 .816 .476 r
F P
0 g
s
.66071 .25977 m .68053 .29681 L .66071 .28356 L .316 .258 .632 r
F
.61766 .22046 m .61836 .20776 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62792 .2274 m .6523 .22491 L .62548 .2262 L .289 .763 .934 r
F
.6523 .22491 m .62356 .22526 L p .62548 .2262 L F P
0 g
s
.68061 .23067 m .6523 .22491 L p .62792 .2274 L .289 .763 .934 r
F P
0 g
s
.63278 .2298 m .68061 .23067 L .62792 .2274 L .289 .763 .934 r
F
.63565 .23121 m .68061 .23067 L .63278 .2298 L F
.64643 .23652 m .68053 .23912 L .64308 .23487 L F
.68053 .23912 m .68061 .23067 L p .63565 .23121 L F P
0 g
s
.64308 .23487 m .68053 .23912 L .63565 .23121 L .289 .763 .934 r
F
.66071 .24356 m .68053 .23912 L p .64643 .23652 L F P
0 g
s
.61805 .23379 m .61766 .22046 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.61953 .24714 m .61805 .23379 L p .66559 .26039 L .999 .816 .476 r
F P
0 g
s
.62527 .29881 m .6303 .29872 L .64917 .297 L p .096 .653 .744 r
F P
0 g
s
.64917 .297 m .6442 .29708 L .62527 .29881 L p .096 .653 .744 r
F P
0 g
s
.6523 .22491 m .62356 .22526 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.64917 .297 m .6442 .29708 L p .66071 .26876 L .999 .816 .476 r
F P
0 g
s
.66071 .27127 m .64917 .297 L .66071 .26876 L .999 .816 .476 r
F
.6442 .29708 m .63912 .29442 L p .66071 .26666 L F P
0 g
s
.66071 .26876 m .6442 .29708 L .66071 .26666 L .999 .816 .476 r
F
.6523 .3976 m .6523 .22491 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.61223 .39797 m .62356 .39786 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62356 .39786 m .6523 .3976 L p .62356 .34904 L .688 .561 .707 r
F P
0 g
s
.62289 .18651 m .62356 .1851 L p .62356 .18761 L .999 .816 .476 r
F P
0 g
s
.62356 .1851 m .62649 .17892 L p .62356 .18761 L .999 .816 .476 r
F P
0 g
s
.66559 .26039 m .65393 .24022 L .65652 .2415 L .999 .816 .476 r
F
.66559 .26039 m .65835 .2424 L .65974 .24309 L F
.68053 .23912 m .68053 .29681 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.66071 .24356 m .68053 .23912 L p .66071 .25977 L .316 .258 .632 r
F P
0 g
s
.6044 .22735 m .59844 .22245 L .6044 .21555 L .999 .816 .48 r
F
.58474 .40275 m .6044 .39933 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.6044 .39933 m .61223 .39797 L p .6044 .2759 L .299 .244 .627 r
F P
0 g
s
.66071 .29106 m .68053 .40818 L .66071 .31485 L .316 .258 .632 r
F
.68053 .40818 m .66071 .41149 L p .66071 .31485 L F P
0 g
s
.66071 .41149 m .65296 .41278 L p .66071 .31485 L .316 .258 .632 r
F P
0 g
s
.68061 .40189 m .68053 .40818 L .68053 .23912 L p 0 0 .003 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6141 .41312 m .65296 .41278 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.65296 .41278 m .68053 .40818 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.68053 .40818 m .68061 .40189 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.68053 .23912 m .68061 .23067 L .68061 .40189 L p 0 0 .003 r
F P
0 g
s
.6523 .3976 m .68061 .40189 L .68061 .23067 L p .936 .764 .644 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58474 .40275 m .58587 .40902 L .6141 .41312 L p .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.3524 .41312 m .3524 .24575 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.39108 .41278 m .38013 .41287 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.38013 .41287 m .3524 .41312 L p .38013 .36551 L .688 .562 .707 r
F P
0 g
s
.38603 .2622 m .38013 .25948 L .38013 .25815 L .999 .816 .524 r
F
.38638 .23713 m .38682 .24995 L .38603 .2622 L p F P
0 g
s
.38603 .2622 m .38682 .24995 L .40476 .24811 L p .523 .385 .635 r
F P
0 g
s
.38682 .24995 m .38638 .23713 L .40432 .23525 L p .533 .457 .716 r
F P
0 g
s
.40432 .23525 m .40476 .24811 L .38682 .24995 L p .533 .457 .716 r
F P
0 g
s
.38472 .22426 m .38638 .23713 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3819 .21188 m .38472 .22426 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.40476 .24811 m .40397 .26039 L .38603 .2622 L p .523 .385 .635 r
F P
0 g
s
.38403 .27336 m .38603 .2622 L .40397 .26039 L p .503 .297 .533 r
F P
0 g
s
.38421 .27334 m .40181 .2716 L p .39033 .27784 L .469 .183 .396 r
F P
0 g
s
.40094 .27215 m .39036 .27786 L .40181 .2716 L .469 .183 .396 r
F
.39036 .27786 m .3809 .28297 L .39033 .27784 L F
.39036 .27786 m .39033 .27784 L .40181 .2716 L F
.40397 .26039 m .40203 .27136 L p .38403 .27336 L .503 .297 .533 r
F P
0 g
s
.40203 .27136 m .40199 .27158 L .40181 .2716 L p .503 .297 .533 r
F P
0 g
s
.40181 .2716 m .38403 .27336 L p .40203 .27136 L .503 .297 .533 r
F P
0 g
s
.39033 .27784 m .3809 .28297 L .38421 .27334 L .469 .183 .396 r
F
.38481 .24732 m .38013 .21668 L .3819 .21188 L .999 .816 .524 r
F
.38603 .2622 m .38406 .24702 L .38481 .24732 L F
.38406 .24702 m .38013 .21668 L .38481 .24732 L F
.3524 .24575 m .38013 .24543 L p .31748 .23183 L .289 .763 .934 r
F P
0 g
s
.37329 .19063 m .37804 .20051 L p .38406 .24702 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38327 .2467 L .38406 .24702 L .999 .816 .524 r
F
.38327 .2467 m .37329 .19063 L .38406 .24702 L F
.38638 .23713 m .38472 .22426 L .40268 .22234 L p .537 .52 .784 r
F P
0 g
s
.40268 .22234 m .40432 .23525 L .38638 .23713 L p .537 .52 .784 r
F P
0 g
s
.36786 .18268 m .37329 .19063 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.36195 .17702 m .36786 .18268 L p .3824 .24635 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38143 .24595 L .3824 .24635 L .999 .816 .524 r
F
.38143 .24595 m .36195 .17702 L .3824 .24635 L F
.35583 .17392 m .36195 .17702 L p .38603 .2622 L F P
0 g
s
.31748 .23183 m .38013 .24543 L .37056 .24154 L .289 .763 .934 r
F
.3524 .24575 m .38013 .24543 L p .38013 .28438 L .688 .562 .707 r
F P
0 g
s
.36298 .29146 m .38013 .28438 L .38013 .36551 L .688 .562 .707 r
F
.3524 .24575 m .38013 .28438 L .36298 .29146 L F
.34976 .17355 m .35583 .17392 L p .38013 .24498 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38013 .2478 L .38013 .24498 L .999 .816 .524 r
F
.38013 .2478 m .34976 .17355 L .38013 .24498 L F
.344 .17594 m .34976 .17355 L p .37897 .24495 L F P
0 g
s
.38603 .2622 m .37729 .24427 L .37897 .24495 L .999 .816 .524 r
F
.37729 .24427 m .344 .17594 L .37897 .24495 L F
.33883 .18102 m .344 .17594 L p .37729 .24427 L F P
0 g
s
.38603 .2622 m .37508 .24337 L .37729 .24427 L .999 .816 .524 r
F
.37508 .24337 m .33883 .18102 L .37729 .24427 L F
.33449 .1886 m .33883 .18102 L p .38603 .2622 L F P
0 g
s
.31748 .23183 m .37056 .24154 L .35312 .23446 L .289 .763 .934 r
F
.33116 .19833 m .33449 .1886 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.32902 .20979 m .33116 .19833 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.31748 .23183 m .34578 .23148 L .34055 .22936 L .289 .763 .934 r
F
.33529 .22723 m .31748 .23183 L p .34055 .22936 L F P
0 g
s
.31748 .23183 m .35312 .23446 L .34578 .23148 L .289 .763 .934 r
F
.32817 .22245 m .32902 .20979 L p .33529 .21555 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .33529 .22735 L .33529 .21555 L .999 .816 .524 r
F
.40268 .22234 m .40432 .23525 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39988 .20992 m .40268 .22234 L .38472 .22426 L p .536 .576 .842 r
F P
0 g
s
.39988 .20992 m .40268 .22234 L p .40347 .24576 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40276 .24547 L .40347 .24576 L .999 .816 .521 r
F
.40276 .24547 m .39988 .20992 L .40347 .24576 L F
.39108 .2453 m .39813 .24356 L p .35312 .23446 L .289 .763 .934 r
F P
0 g
s
.40432 .23525 m .40476 .24811 L .40397 .26039 L p .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .21473 L .39988 .20992 L .999 .816 .521 r
F
.38472 .22426 m .3819 .21188 L .39988 .20992 L p .536 .576 .842 r
F P
0 g
s
.39606 .19851 m .39988 .20992 L .3819 .21188 L p .528 .629 .895 r
F P
0 g
s
.39606 .19851 m .39813 .2047 L p .39813 .21473 L .999 .816 .521 r
F P
0 g
s
.39813 .2047 m .39988 .20992 L p .39813 .21473 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40071 .26506 L .40034 .26429 L .999 .816 .521 r
F
.40071 .26506 m .39813 .26876 L .40034 .26429 L F
.40034 .26429 m .39813 .26876 L .39813 .26666 L F
.3819 .21188 m .37804 .20051 L .39606 .19851 L p .528 .629 .895 r
F P
0 g
s
.39135 .1886 m .39606 .19851 L .37804 .20051 L p .512 .681 .942 r
F P
0 g
s
.39135 .1886 m .39606 .19851 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.37804 .20051 m .37329 .19063 L .39135 .1886 L p .512 .681 .942 r
F P
0 g
s
.38595 .18062 m .39135 .1886 L .37329 .19063 L p .483 .73 .98 r
F P
0 g
s
.38595 .18062 m .39135 .1886 L p .40124 .24484 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40038 .24449 L .40124 .24484 L .999 .816 .521 r
F
.40038 .24449 m .38595 .18062 L .40124 .24484 L F
.37329 .19063 m .36786 .18268 L .38595 .18062 L p .483 .73 .98 r
F P
0 g
s
.3801 .17494 m .38595 .18062 L .36786 .18268 L p .429 .769 .997 r
F P
0 g
s
.3801 .17494 m .38595 .18062 L p .40038 .24449 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39942 .24409 L .40038 .24449 L .999 .816 .521 r
F
.39942 .24409 m .3801 .17494 L .40038 .24449 L F
.35312 .23446 m .38104 .23652 L .34578 .23148 L .289 .763 .934 r
F
.36786 .18268 m .36195 .17702 L .3801 .17494 L p .429 .769 .997 r
F P
0 g
s
.37403 .17182 m .3801 .17494 L .36195 .17702 L p .33 .777 .959 r
F P
0 g
s
.37403 .17182 m .3801 .17494 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39108 .2453 m .39813 .24356 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.35312 .23446 m .39813 .24356 L .38104 .23652 L .289 .763 .934 r
F
.36195 .17702 m .35583 .17392 L .37403 .17182 L p .33 .777 .959 r
F P
0 g
s
.368 .17144 m .37403 .17182 L .35583 .17392 L p .163 .702 .805 r
F P
0 g
s
.368 .17144 m .37403 .17182 L p .39831 .24363 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39698 .24309 L .39831 .24363 L .999 .816 .521 r
F
.39698 .24309 m .368 .17144 L .39831 .24363 L F
.34578 .23148 m .36813 .23121 L .34055 .22936 L .289 .763 .934 r
F
.37804 .20051 m .38013 .20667 L p .38013 .21668 L .999 .816 .524 r
F P
0 g
s
.38013 .20667 m .3819 .21188 L p .38013 .21668 L .999 .816 .524 r
F P
0 g
s
.3623 .17383 m .368 .17144 L p .39698 .24309 L .999 .816 .521 r
F P
0 g
s
.39531 .2424 m .3623 .17383 L .39698 .24309 L .999 .816 .521 r
F
.35717 .17892 m .3623 .17383 L p .40397 .26039 L F P
0 g
s
.39312 .2415 m .35366 .18761 L .35717 .17892 L .999 .816 .521 r
F
.39002 .24022 m .35366 .18767 L .39312 .2415 L F
.35366 .18767 m .35286 .18651 L .35366 .18761 L F
.35366 .18767 m .35366 .18761 L .39312 .2415 L F
.34239 .22539 m .33529 .22723 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.34055 .22936 m .36469 .2298 L .35888 .2274 L .289 .763 .934 r
F
.36813 .23121 m .36469 .2298 L .34055 .22936 L F
.34055 .22936 m .35888 .2274 L .33529 .22723 L F
.34956 .19627 m .35286 .18651 L p .39002 .24022 L .999 .816 .521 r
F P
0 g
s
.38517 .23822 m .34956 .19627 L .39002 .24022 L .999 .816 .521 r
F
.38104 .23652 m .37702 .23487 L .34578 .23148 L .289 .763 .934 r
F
.34578 .23148 m .37702 .23487 L .36813 .23121 L F
.3524 .41312 m .32197 .40902 L .32197 .24025 L p .92 .752 .656 r
F P
0 g
s
.32197 .24025 m .3524 .24575 L .3524 .41312 L p .92 .752 .656 r
F P
0 g
s
.32197 .40902 m .31748 .40275 L .31748 .23183 L p .852 .696 .164 r
F P
0 g
s
.31748 .23183 m .32197 .24025 L .32197 .40902 L p .852 .696 .164 r
F P
0 g
s
.31748 .23183 m .31748 .40275 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.31748 .23183 m .32197 .24025 L .3524 .24575 L p .289 .763 .934 r
F P
0 g
s
.38603 .2622 m .33529 .2502 L .33529 .23881 L .999 .816 .524 r
F
.35888 .2274 m .35597 .2262 L .33529 .22723 L .289 .763 .934 r
F
.33529 .22723 m .31748 .23183 L p .33272 .26953 L .259 .212 .613 r
F P
0 g
s
.33529 .26705 m .33272 .26953 L .33529 .2759 L .259 .212 .613 r
F
.33529 .22723 m .33272 .26953 L .33529 .26705 L F
.3375 .2733 m .33342 .26176 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.34246 .28314 m .3375 .2733 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3375 .2733 m .35585 .27146 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33529 .26705 m .3375 .2733 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.32865 .23575 m .32817 .22245 L p .33529 .22735 L .999 .816 .524 r
F P
0 g
s
.38013 .25815 m .33529 .23864 L .33529 .22735 L .999 .816 .524 r
F
.33529 .23864 m .32865 .23575 L .33529 .22735 L F
.38013 .25948 m .32865 .23575 L .38013 .25815 L F
.33342 .26176 m .33043 .24905 L p .38603 .2622 L F P
0 g
s
.34239 .22539 m .33529 .22723 L p .33529 .26705 L .259 .212 .613 r
F P
0 g
s
.33579 .26657 m .33529 .26705 L .33529 .26968 L .259 .212 .613 r
F
.34239 .22539 m .33529 .26705 L .33579 .26657 L F
.35585 .27146 m .35366 .2652 L p .34166 .26092 L .518 .629 .9 r
F P
0 g
s
.34355 .26073 m .34166 .26092 L p .35366 .2652 L .518 .629 .9 r
F P
0 g
s
.35585 .27146 m .34166 .26092 L .33851 .26396 L .518 .629 .9 r
F
.34807 .29087 m .34246 .28314 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.35407 .29616 m .34807 .29087 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.36021 .29881 m .35407 .29616 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3662 .29872 m .36021 .29881 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.3718 .29594 m .3662 .29872 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.34807 .29087 m .35407 .29616 L .37229 .29442 L p .401 .765 .994 r
F P
0 g
s
.37229 .29442 m .36633 .2891 L .34807 .29087 L p .401 .765 .994 r
F P
0 g
s
.34246 .28314 m .34807 .29087 L .36633 .2891 L p .465 .73 .984 r
F P
0 g
s
.36633 .2891 m .36077 .28134 L .34246 .28314 L p .465 .73 .984 r
F P
0 g
s
.3375 .2733 m .34246 .28314 L .36077 .28134 L p .499 .682 .948 r
F P
0 g
s
.36077 .28134 m .35585 .27146 L .3375 .2733 L p .499 .682 .948 r
F P
0 g
s
.35366 .34904 m .3457 .26168 L .34239 .39797 L .688 .561 .707 r
F
.34239 .22539 m .34239 .25992 L p .3457 .26168 L F P
0 g
s
.35366 .22526 m .34239 .22539 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.37056 .24154 m .39108 .2453 L .35312 .23446 L .289 .763 .934 r
F
.35366 .22526 m .34239 .22539 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35181 .25989 m .34494 .25641 L .34239 .25992 L .527 .575 .846 r
F
.34166 .26092 m .34355 .26073 L p .34239 .25992 L F P
0 g
s
.3457 .26168 m .34239 .25992 L .34355 .26073 L .688 .561 .707 r
F
.34355 .26073 m .35181 .25989 L p .34239 .25992 L .527 .575 .846 r
F P
0 g
s
.34239 .25992 m .34239 .26022 L p .34355 .26073 L .688 .561 .707 r
F P
0 g
s
.34239 .26022 m .34239 .39797 L p .3457 .26168 L .688 .561 .707 r
F P
0 g
s
.35366 .2652 m .35181 .25989 L .34355 .26073 L p .518 .629 .9 r
F P
0 g
s
.34239 .22539 m .33529 .26968 L .33638 .26819 L .259 .212 .613 r
F
.34239 .39797 m .34239 .22539 L p .33529 .2759 L F P
0 g
s
.34166 .26092 m .33342 .26176 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33043 .24905 m .33342 .26176 L .34166 .26092 L p .527 .575 .846 r
F P
0 g
s
.34494 .25641 m .33043 .24905 L .34166 .26092 L .527 .575 .846 r
F
.33638 .26819 m .33529 .26968 L .33529 .2759 L .259 .212 .613 r
F
.33342 .26176 m .33529 .26705 L p .33851 .26396 L .518 .629 .9 r
F P
0 g
s
.33043 .24905 m .32865 .23575 L p .33529 .23881 L .999 .816 .524 r
F P
0 g
s
.33529 .2502 m .33043 .24905 L .33529 .23881 L .999 .816 .524 r
F
.37677 .29061 m .3718 .29594 L p .38603 .2622 L F P
0 g
s
.3809 .28297 m .37677 .29061 L p .38603 .2622 L .999 .816 .524 r
F P
0 g
s
.38603 .2622 m .38403 .27336 L .3809 .28297 L p .999 .816 .524 r
F P
0 g
s
.38438 .28263 m .3809 .28297 L p .40094 .27215 L .469 .183 .396 r
F P
0 g
s
.38013 .24543 m .39108 .2453 L p .38788 .28041 L .688 .562 .707 r
F P
0 g
s
.38625 .28144 m .38788 .28041 L .38725 .28736 L .688 .562 .707 r
F
.38013 .24543 m .38788 .28041 L .38625 .28144 L F
.38013 .28438 m .3809 .28297 L .38438 .28263 L p .406 .026 .202 r
F P
0 g
s
.3809 .28297 m .38403 .27336 L .38421 .27334 L p .469 .183 .396 r
F P
0 g
s
.38013 .24543 m .38725 .28736 L .38013 .29507 L .688 .562 .707 r
F
.39108 .41278 m .39108 .27986 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.39108 .27986 m .39108 .27839 L p .39139 .27998 L .279 .228 .62 r
F P
0 g
s
.39139 .27998 m .39813 .31485 L .39108 .27986 L .279 .228 .62 r
F
.39889 .28121 m .39679 .2821 L .39584 .28172 L .406 .026 .202 r
F
.39683 .2826 m .39813 .29106 L .39139 .27998 L .279 .228 .62 r
F
.39813 .29106 m .39813 .31485 L .39139 .27998 L F
.39539 .28155 m .39139 .27998 L .39108 .27839 L F
.39683 .2826 m .39139 .27998 L .39539 .28155 L F
.38013 .36551 m .38788 .28041 L .39108 .41278 L .688 .562 .707 r
F
.39108 .27839 m .39108 .41278 L p .38788 .28041 L F P
0 g
s
.38438 .28263 m .39539 .28155 L p .38013 .28438 L .406 .026 .202 r
F P
0 g
s
.39584 .28172 m .38013 .28438 L .39539 .28155 L .406 .026 .202 r
F
.38875 .2822 m .38438 .28263 L p .39163 .27808 L .469 .183 .396 r
F P
0 g
s
.40199 .27158 m .38875 .2822 L .39163 .27808 L .469 .183 .396 r
F
.40199 .27158 m .39889 .28121 L .38875 .2822 L p F P
0 g
s
.39539 .28155 m .39889 .28121 L p .39584 .28172 L .406 .026 .202 r
F P
0 g
s
.40199 .27158 m .38438 .28263 L .40094 .27215 L .469 .183 .396 r
F
.39108 .27839 m .39108 .2453 L p .39675 .28208 L .279 .228 .62 r
F P
0 g
s
.39675 .28208 m .39539 .28155 L .39108 .27839 L .279 .228 .62 r
F
.37677 .29061 m .38013 .28438 L p .39584 .28172 L .406 .026 .202 r
F P
0 g
s
.39675 .28208 m .39683 .2826 L .39539 .28155 L .279 .228 .62 r
F
.40397 .26039 m .39813 .27127 L .39813 .26876 L .999 .816 .521 r
F
.39108 .2453 m .39813 .25977 L .39686 .28212 L .279 .228 .62 r
F
.39675 .28208 m .39686 .28212 L .39683 .2826 L F
.39108 .2453 m .39686 .28212 L .39675 .28208 L F
.38013 .29507 m .38725 .28736 L .38013 .36551 L .688 .562 .707 r
F
.39479 .28887 m .37677 .29061 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39889 .28121 m .39813 .28262 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39813 .25977 m .39813 .28356 L .39683 .2826 L .279 .228 .62 r
F
.41618 .29681 m .41618 .40818 L p .39813 .29106 L F P
0 g
s
.39683 .2826 m .39813 .28356 L .39813 .29106 L .279 .228 .62 r
F
.39813 .28356 m .41618 .29681 L .39813 .29106 L F
.40181 .2716 m .40199 .27158 L p .40094 .27215 L .469 .183 .396 r
F P
0 g
s
.39889 .28121 m .39813 .28262 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39813 .28262 m .39479 .28887 L p .39679 .2821 L .406 .026 .202 r
F P
0 g
s
.39813 .28262 m .39479 .28887 L p .39813 .27851 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .28262 L .39813 .27851 L .999 .816 .521 r
F
.38013 .24543 m .39108 .2453 L p .37056 .24154 L .289 .763 .934 r
F P
0 g
s
.39108 .2453 m .39108 .27839 L p .38788 .28041 L .688 .562 .707 r
F P
0 g
s
.34744 .20776 m .34956 .19627 L p .39813 .2535 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39813 .25495 L .39813 .2535 L .999 .816 .521 r
F
.39813 .25495 m .34744 .20776 L .39813 .2535 L F
.35181 .25989 m .34883 .24714 L p .40397 .26039 L F P
0 g
s
.35585 .27146 m .35181 .25989 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36077 .28134 m .35585 .27146 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36633 .2891 m .36077 .28134 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.37229 .29442 m .36633 .2891 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39099 .28456 m .37677 .29061 L .39141 .28379 L .406 .026 .202 r
F
.39099 .28456 m .39141 .28379 L .39584 .28172 L F
.39679 .2821 m .39099 .28456 L .39584 .28172 L F
.3718 .29594 m .37677 .29061 L .39479 .28887 L p .295 0 0 r
F P
0 g
s
.39479 .28887 m .38987 .29421 L .3718 .29594 L p .295 0 0 r
F P
0 g
s
.3662 .29872 m .3718 .29594 L .38987 .29421 L p .115 0 0 r
F P
0 g
s
.38987 .29421 m .38432 .297 L .3662 .29872 L p .115 0 0 r
F P
0 g
s
.38987 .29421 m .38432 .297 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.39479 .28887 m .38987 .29421 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .40199 .27158 L .39889 .28121 L p .999 .816 .521 r
F P
0 g
s
.39813 .25977 m .41618 .29681 L .39813 .28356 L .279 .228 .62 r
F
.38432 .297 m .37837 .29708 L p .39813 .26876 L .999 .816 .521 r
F P
0 g
s
.39813 .27127 m .38432 .297 L .39813 .26876 L .999 .816 .521 r
F
.39813 .29106 m .41618 .40818 L .39813 .31485 L .279 .228 .62 r
F
.3466 .22046 m .34744 .20776 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.35888 .2274 m .38227 .22491 L .35597 .2262 L .289 .763 .934 r
F
.40397 .26039 m .38517 .23822 L .39002 .24022 L .999 .816 .521 r
F
.38227 .22491 m .35366 .22526 L p .35597 .2262 L .289 .763 .934 r
F P
0 g
s
.41288 .23067 m .38227 .22491 L p .35888 .2274 L .289 .763 .934 r
F P
0 g
s
.36469 .2298 m .41288 .23067 L .35888 .2274 L .289 .763 .934 r
F
.36813 .23121 m .41288 .23067 L .36469 .2298 L F
.38104 .23652 m .41618 .23912 L .37702 .23487 L F
.41618 .23912 m .41288 .23067 L p .36813 .23121 L F P
0 g
s
.37702 .23487 m .41618 .23912 L .36813 .23121 L .289 .763 .934 r
F
.34707 .23379 m .3466 .22046 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.34883 .24714 m .34707 .23379 L p .40397 .26039 L .999 .816 .521 r
F P
0 g
s
.36021 .29881 m .3662 .29872 L .38432 .297 L p .105 .66 .753 r
F P
0 g
s
.38432 .297 m .37837 .29708 L .36021 .29881 L p .105 .66 .753 r
F P
0 g
s
.35407 .29616 m .36021 .29881 L .37837 .29708 L p .288 .759 .938 r
F P
0 g
s
.37837 .29708 m .37229 .29442 L .35407 .29616 L p .288 .759 .938 r
F P
0 g
s
.38227 .22491 m .35366 .22526 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.39813 .24356 m .41618 .23912 L p .38104 .23652 L .289 .763 .934 r
F P
0 g
s
.37837 .29708 m .37229 .29442 L p .39813 .26666 L .999 .816 .521 r
F P
0 g
s
.39813 .26876 m .37837 .29708 L .39813 .26666 L .999 .816 .521 r
F
.38227 .3976 m .38227 .22491 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.34239 .39797 m .35366 .39786 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35366 .39786 m .38227 .3976 L p .35366 .34904 L .688 .561 .707 r
F P
0 g
s
.35286 .18651 m .35366 .1851 L p .35366 .18761 L .999 .816 .521 r
F P
0 g
s
.35366 .1851 m .35717 .17892 L p .35366 .18761 L .999 .816 .521 r
F P
0 g
s
.40397 .26039 m .39002 .24022 L .39312 .2415 L .999 .816 .521 r
F
.40397 .26039 m .39531 .2424 L .39698 .24309 L F
.41618 .23912 m .41618 .29681 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.39813 .24356 m .41618 .23912 L p .39813 .25977 L .279 .228 .62 r
F P
0 g
s
.33529 .22735 m .32817 .22245 L .33529 .21555 L .999 .816 .524 r
F
.31748 .40275 m .33529 .39933 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.33529 .39933 m .34239 .39797 L p .33529 .2759 L .259 .212 .613 r
F P
0 g
s
.41618 .40818 m .39813 .41149 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.39813 .41149 m .39108 .41278 L p .39813 .31485 L .279 .228 .62 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.41288 .40189 m .41618 .40818 L .41618 .23912 L p .818 .668 .122 r
F P
0 g
s
.68061 .23067 m .6523 .22491 L .6523 .3976 L p .936 .764 .644 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3524 .41312 m .39108 .41278 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.31748 .40275 m .32197 .40902 L .3524 .41312 L p .224 .73 .894 r
F P
0 g
s
.39108 .41278 m .41618 .40818 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.68061 .40189 m .6523 .3976 L p .58474 .40275 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.41618 .23912 m .41288 .23067 L .41288 .40189 L p .818 .668 .122 r
F P
0 g
s
.38227 .3976 m .41288 .40189 L .41288 .23067 L p .926 .756 .652 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.41618 .40818 m .41288 .40189 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.6523 .3976 m .61223 .39797 L .58474 .40275 L p .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6216 .17392 m .61652 .17355 L .63554 .17144 L p .154 .695 .797 r
F P
0 g
s
.35583 .17392 m .34976 .17355 L .368 .17144 L p .163 .702 .805 r
F P
0 g
s
.61652 .17355 m .6117 .17594 L .63078 .17383 L p .078 0 0 r
F P
0 g
s
.63078 .17383 m .63554 .17144 L .61652 .17355 L p .078 0 0 r
F P
0 g
s
.34976 .17355 m .344 .17594 L .3623 .17383 L p .057 0 0 r
F P
0 g
s
.3623 .17383 m .368 .17144 L .34976 .17355 L p .057 0 0 r
F P
0 g
s
.38227 .3976 m .34239 .39797 L .31748 .40275 L p .224 .73 .894 r
F P
0 g
s
.41288 .40189 m .38227 .3976 L p .31748 .40275 L .224 .73 .894 r
F P
0 g
s
.6117 .17594 m .60737 .18102 L .62649 .17892 L p .276 0 0 r
F P
0 g
s
.62649 .17892 m .63078 .17383 L .6117 .17594 L p .276 0 0 r
F P
0 g
s
.344 .17594 m .33883 .18102 L .35717 .17892 L p .254 0 0 r
F P
0 g
s
.35717 .17892 m .3623 .17383 L .344 .17594 L p .254 0 0 r
F P
0 g
s
.41288 .23067 m .38227 .22491 L .38227 .3976 L p .926 .756 .652 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.60737 .18102 m .60373 .1886 L .62289 .18651 L p .398 .015 .191 r
F P
0 g
s
.62289 .18651 m .62649 .17892 L .60737 .18102 L p .398 .015 .191 r
F P
0 g
s
.33883 .18102 m .33449 .1886 L .35286 .18651 L p .381 0 .166 r
F P
0 g
s
.35286 .18651 m .35717 .17892 L .33883 .18102 L p .381 0 .166 r
F P
0 g
s
.60373 .1886 m .60094 .19833 L .62014 .19627 L p .465 .178 .392 r
F P
0 g
s
.62014 .19627 m .62289 .18651 L .60373 .1886 L p .465 .178 .392 r
F P
0 g
s
.33449 .1886 m .33116 .19833 L .34956 .19627 L p .452 .159 .375 r
F P
0 g
s
.34956 .19627 m .35286 .18651 L .33449 .1886 L p .452 .159 .375 r
F P
0 g
s
.60094 .19833 m .59915 .20979 L .61836 .20776 L p .502 .295 .532 r
F P
0 g
s
.61836 .20776 m .62014 .19627 L .60094 .19833 L p .502 .295 .532 r
F P
0 g
s
.33116 .19833 m .32902 .20979 L .34744 .20776 L p .492 .282 .523 r
F P
0 g
s
.34744 .20776 m .34956 .19627 L .33116 .19833 L p .492 .282 .523 r
F P
0 g
s
.59883 .23575 m .60033 .24905 L .61953 .24714 L p .537 .519 .784 r
F P
0 g
s
.62201 .25989 m .61953 .24714 L .60033 .24905 L p .534 .576 .843 r
F P
0 g
s
.32865 .23575 m .33043 .24905 L .34883 .24714 L p .529 .516 .786 r
F P
0 g
s
.35181 .25989 m .34883 .24714 L .33043 .24905 L p .527 .575 .846 r
F P
0 g
s
.59915 .20979 m .59844 .22245 L .61766 .22046 L p .522 .385 .635 r
F P
0 g
s
.61766 .22046 m .61836 .20776 L .59915 .20979 L p .522 .385 .635 r
F P
0 g
s
.32902 .20979 m .32817 .22245 L .3466 .22046 L p .514 .376 .631 r
F P
0 g
s
.3466 .22046 m .34744 .20776 L .32902 .20979 L p .514 .376 .631 r
F P
0 g
s
.59844 .22245 m .59883 .23575 L .61805 .23379 L p .533 .457 .716 r
F P
0 g
s
.61953 .24714 m .61805 .23379 L .59883 .23575 L p .537 .519 .784 r
F P
0 g
s
.32817 .22245 m .32865 .23575 L .34707 .23379 L p .525 .452 .716 r
F P
0 g
s
.34883 .24714 m .34707 .23379 L .32865 .23575 L p .529 .516 .786 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .7082 .85514 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.74865 .87438 m .7082 .85514 L .70881 .87398 L p .948 .647 .432 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.75791 .87448 m .70139 .8749 L p .74865 .87438 L F P
0 g
s
.70559 .87438 m .70881 .87398 L .77017 .87438 L .012 .587 .719 r
F
.70996 .87384 m .71752 .87391 L p .70881 .87398 L F P
0 g
s
.71752 .87391 m .77017 .87438 L p .70881 .87398 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70305 .89315 m .74865 .87438 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70698 1.0175 m .70305 .89315 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.77017 1.02671 m .77017 .924 L p .73961 1.01195 L .96 .784 .62 r
F P
0 g
s
.72453 1.04899 m .77017 .924 L .75797 .92105 L .96 .784 .62 r
F
.71783 1.0746 m .72531 1.05309 L .72453 1.04899 L F
.72531 1.05309 m .77017 .924 L .72453 1.04899 L F
.77017 1.10042 m .77017 1.02671 L p .72769 1.06558 L F P
0 g
s
.71783 1.0746 m .7306 1.0809 L .72769 1.06558 L .96 .784 .62 r
F
.7306 1.0809 m .77017 1.10042 L .72769 1.06558 L F
.71431 1.00257 m .71493 .99856 L p .71524 1.00018 L 0 0 .367 r
F P
0 g
s
.73175 1.00816 m .70698 1.0175 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.71291 1.01526 m .73175 1.00816 L p .73026 1.00744 L .468 .815 .998 r
F P
0 g
s
.71524 1.00018 m .71468 1.00379 L .73026 1.00744 L .468 .815 .998 r
F
.71468 1.00379 m .71291 1.01526 L .73026 1.00744 L F
.70923 1.00251 m .71431 1.00257 L .71468 1.00379 L p .855 .518 .414 r
F P
0 g
s
.70305 .89315 m .74865 .87438 L .75038 .91922 L p .302 .134 .481 r
F P
0 g
s
.70305 .89315 m .75038 .91922 L .73963 .97056 L .302 .134 .481 r
F
.75038 .91922 m .74865 .87438 L p .73478 .91545 L .948 .647 .432 r
F P
0 g
s
.71559 .99868 m .71931 .98274 L .70996 .99764 L .96 .784 .62 r
F
.71172 1.01571 m .71291 1.01526 L p .71247 1.01268 L .468 .815 .998 r
F P
0 g
s
.7082 .85514 m .66253 .87438 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70881 .87398 m .7082 .85514 L p .70265 .87403 L .29 .123 .473 r
F P
0 g
s
.70559 .87438 m .66253 .87438 L .70881 .87398 L .012 .587 .719 r
F
.70139 .8749 m .65178 .87448 L p .70559 .87438 L F P
0 g
s
.65178 .87448 m .66253 .87438 L .70559 .87438 L .012 .587 .719 r
F
.66253 .87438 m .70305 .89315 L p .70559 .87438 L .495 .816 1 r
F P
0 g
s
.70305 .89315 m .70698 1.0175 L p .66253 .87438 L .946 .648 .442 r
F P
0 g
s
.64101 .924 m .64101 1.04449 L p .67409 .96263 L .333 .272 .638 r
F P
0 g
s
.70698 1.0175 m .68501 1.00816 L p .66253 .87438 L .946 .648 .442 r
F P
0 g
s
.66367 .91922 m .66253 .87438 L p .68501 1.00816 L .946 .648 .442 r
F P
0 g
s
.67409 .96263 m .69423 .91277 L .66367 .91922 L .333 .272 .638 r
F
.67409 .96263 m .66367 .91922 L .64101 .924 L F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.68665 1.06543 m .67644 1.04823 L .6578 1.04524 L F
.70345 1.05256 m .7046 1.04733 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.70996 1.10469 m .70996 1.04757 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.64101 1.10042 m .69229 1.1036 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.69229 1.1036 m .70996 1.10469 L p .70345 1.05256 L .333 .272 .638 r
F P
0 g
s
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .68565 1.08458 L .68 .398 .487 r
F P
0 g
s
.63981 1.07786 m .70996 1.10469 L .63901 1.04601 L .68 .398 .487 r
F
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.50802 1.25704 m .54018 1.25552 L .52667 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .54517 1.25817 L F
.54018 1.25552 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.51938 1.25967 m .51947 1.25865 L .52667 1.25967 L .365 .792 .97 r
F
.452 1.25967 m .51947 1.25865 L .51938 1.25967 L F
.452 1.25967 m .50802 1.25704 L .51947 1.25865 L F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L .365 .792 .97 r
F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.52783 1.09787 m .46974 1.09988 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.36257 1.04436 m .3516 1.04413 L .36228 1.04465 L .066 0 0 r
F
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .36099 1.04601 L p .34335 1.04519 L .066 0 0 r
F P
0 g
s
.34335 1.04519 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L F P
0 g
s
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62791 1.26039 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.26039 m .62917 1.25133 L p .62879 1.27211 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62791 1.26039 L .62879 1.27211 L 0 0 .059 r
F
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.63104 1.30212 m .63096 1.3011 L .63567 1.3007 L .112 0 .073 r
F
.63085 1.29952 m .63258 1.29994 L p .63096 1.3011 L F P
0 g
s
.63258 1.29994 m .63567 1.3007 L p .63096 1.3011 L .112 0 .073 r
F P
0 g
s
.62882 1.30156 m .63088 1.30002 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .63088 1.30002 L .63091 1.30043 L 0 0 .059 r
F
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.63045 1.32905 m .63096 1.3011 L p .60369 1.32055 L .69 .689 .843 r
F P
0 g
s
.597 1.32532 m .60956 1.32672 L .60369 1.32055 L .69 .689 .843 r
F
.60956 1.32672 m .63045 1.32905 L .60369 1.32055 L F
.61632 1.32387 m .58611 1.31592 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.6289 1.29994 m .63045 1.26755 L .63096 1.29866 L 0 0 .059 r
F
.63132 1.29606 m .63567 1.3007 L .63258 1.29994 L p 0 .297 .787 r
F P
0 g
s
.63258 1.29994 m .63085 1.29952 L p .63096 1.29866 L 0 .297 .787 r
F P
0 g
s
.63096 1.29866 m .63132 1.29606 L .63258 1.29994 L 0 .297 .787 r
F
.63079 1.29994 m .63096 1.29866 L .63099 1.29994 L 0 0 .059 r
F
.6289 1.29994 m .63096 1.29866 L .63079 1.29994 L F
.63096 1.29866 m .63045 1.26755 L .61177 1.26755 L p .693 .453 .555 r
F P
0 g
s
.61177 1.26755 m .59178 1.26755 L p .60369 1.27701 L .693 .453 .555 r
F P
0 g
s
.60369 1.27701 m .63096 1.29866 L .61177 1.26755 L .693 .453 .555 r
F
.60521 1.29321 m .60519 1.2932 L p .60522 1.29321 L 0 .297 .787 r
F P
0 g
s
.60522 1.29321 m .63132 1.29606 L .60521 1.29321 L 0 .297 .787 r
F
.63085 1.29952 m .60521 1.29321 L p .63132 1.29606 L F P
0 g
s
.624 1.29783 m .63085 1.29952 L p .63001 1.29982 L .112 0 .073 r
F P
0 g
s
.58611 1.31592 m .624 1.29783 L .63001 1.29982 L .112 0 .073 r
F
.58611 1.31592 m .60519 1.2932 L .624 1.29783 L p F P
0 g
s
.58611 1.31592 m .63085 1.29952 L .63104 1.30212 L .112 0 .073 r
F
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.43349 1.2932 m .41389 1.27286 L .42955 1.27701 L p 0 .267 .761 r
F P
0 g
s
.43349 1.2932 m .42955 1.27701 L .43846 1.28421 L 0 .267 .761 r
F
.56692 1.29558 m .58611 1.31592 L .60519 1.2932 L p .855 .698 .687 r
F P
0 g
s
.56692 1.29558 m .58611 1.31592 L .60369 1.32055 L p 0 .289 .78 r
F P
0 g
s
.56692 1.29558 m .60369 1.32055 L .59556 1.31198 L 0 .289 .78 r
F
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.45793 1.29994 m .43349 1.2932 L p .43846 1.28421 L 0 .267 .761 r
F P
0 g
s
.41389 1.31592 m .43349 1.2932 L .45793 1.29994 L p .076 0 .035 r
F P
0 g
s
.44611 1.30853 m .597 1.32532 L .45793 1.29994 L .69 .689 .843 r
F
.45793 1.29994 m .46069 1.3007 L p .45381 1.30294 L .076 0 .035 r
F P
0 g
s
.41389 1.31592 m .45793 1.29994 L .45381 1.30294 L .076 0 .035 r
F
.58412 1.29994 m .56692 1.29558 L p .59556 1.31198 L 0 .289 .78 r
F P
0 g
s
.58412 1.29994 m .597 1.32532 L .60357 1.32042 L .69 .689 .843 r
F
.63099 1.29994 m .58412 1.29994 L p .60357 1.32042 L F P
0 g
s
.63088 1.30002 m .63099 1.29994 L p .63091 1.30043 L 0 0 .059 r
F P
0 g
s
.63096 1.3011 m .63099 1.29994 L p .597 1.32532 L .69 .689 .843 r
F P
0 g
s
.61632 1.32387 m .59685 1.30317 L .58412 1.29994 L p 0 .289 .78 r
F P
0 g
s
.59556 1.31198 m .61632 1.32387 L .58412 1.29994 L 0 .289 .78 r
F
.60519 1.2932 m .58611 1.27286 L .56692 1.29558 L p .855 .698 .687 r
F P
0 g
s
.46974 1.09988 m .46771 1.09965 L .484 1.09787 L .09 0 0 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L .063 .051 .53 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L .09 0 0 r
F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.45793 1.29994 m .58412 1.29994 L p .43102 1.27533 L .693 .453 .555 r
F P
0 g
s
.42955 1.27701 m .45793 1.29994 L .43102 1.27533 L .693 .453 .555 r
F
.39417 1.29558 m .41389 1.31592 L .43349 1.2932 L p .851 .695 .688 r
F P
0 g
s
.44611 1.30853 m .42955 1.32055 L .63045 1.32905 L .69 .689 .843 r
F
.41785 1.32905 m .43784 1.32905 L p .42955 1.32055 L F P
0 g
s
.43784 1.32905 m .63045 1.32905 L p .42955 1.32055 L .69 .689 .843 r
F P
0 g
s
.42955 1.32055 m .41389 1.31592 L p .45381 1.30294 L .076 0 .035 r
F P
0 g
s
.39417 1.29558 m .41389 1.31592 L .42955 1.32055 L p 0 .258 .754 r
F P
0 g
s
.46069 1.3007 m .4408 1.32387 L .42955 1.32055 L p .076 0 .035 r
F P
0 g
s
.45381 1.30294 m .46069 1.3007 L .42955 1.32055 L .076 0 .035 r
F
.39417 1.29558 m .42955 1.32055 L .42121 1.31198 L 0 .258 .754 r
F
.36901 1.29994 m .41785 1.32905 L .42955 1.32055 L .69 .689 .843 r
F
.4144 1.305 m .42955 1.32055 L .44611 1.30853 L F
.40947 1.29994 m .39417 1.29558 L p .42121 1.31198 L 0 .258 .754 r
F P
0 g
s
.36901 1.29994 m .42955 1.32055 L .4144 1.305 L .69 .689 .843 r
F
.40412 1.30385 m .44611 1.30853 L .40947 1.29994 L F
.4408 1.32387 m .42079 1.30317 L .40947 1.29994 L p 0 .258 .754 r
F P
0 g
s
.42121 1.31198 m .4408 1.32387 L .40947 1.29994 L 0 .258 .754 r
F
.42955 1.32055 m .4408 1.32387 L p .42121 1.31198 L F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .41785 1.32905 L p .69 .689 .843 r
F P
0 g
s
.45793 1.29994 m .40947 1.29994 L p .44611 1.30853 L .69 .689 .843 r
F P
0 g
s
.40947 1.29994 m .36901 1.29994 L p .40412 1.30385 L .69 .689 .843 r
F P
0 g
s
.43349 1.2932 m .41389 1.27286 L .39417 1.29558 L p .851 .695 .688 r
F P
0 g
s
.42955 1.27701 m .41389 1.27286 L p .41787 1.29035 L .065 0 .024 r
F P
0 g
s
.41389 1.27286 m .39417 1.29558 L .40947 1.29994 L p .065 0 .024 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .40947 1.29994 L p .693 .453 .555 r
F P
0 g
s
.40947 1.29994 m .45793 1.29994 L p .42125 1.2865 L .693 .453 .555 r
F P
0 g
s
.41389 1.27286 m .40947 1.29994 L .41787 1.29035 L .065 0 .024 r
F
.36955 1.26755 m .40947 1.29994 L .42125 1.2865 L .693 .453 .555 r
F
.40947 1.29994 m .42079 1.30317 L p .41787 1.29035 L .065 0 .024 r
F P
0 g
s
.36955 1.26755 m .45793 1.29994 L .42659 1.27462 L .693 .453 .555 r
F
.42955 1.27701 m .4408 1.27999 L p .43846 1.28421 L 0 .267 .761 r
F P
0 g
s
.42079 1.30317 m .4408 1.27999 L .43788 1.27922 L p .065 0 .024 r
F P
0 g
s
.43788 1.27922 m .42955 1.27701 L p .42588 1.28797 L .065 0 .024 r
F P
0 g
s
.42588 1.28797 m .42079 1.30317 L .43788 1.27922 L .065 0 .024 r
F
.41787 1.29035 m .42079 1.30317 L .42955 1.27701 L F
.42659 1.27462 m .42955 1.27701 L .43102 1.27533 L .693 .453 .555 r
F
.58412 1.29994 m .63099 1.29994 L p .5886 1.29469 L F P
0 g
s
.58611 1.27286 m .56692 1.29558 L .58412 1.29994 L p .102 0 .063 r
F P
0 g
s
.58611 1.27286 m .58412 1.29994 L .59231 1.29035 L .102 0 .063 r
F
.42659 1.27462 m .58412 1.29994 L .5886 1.29469 L .693 .453 .555 r
F
.63099 1.29994 m .63096 1.29866 L p .42619 1.27429 L F P
0 g
s
.42659 1.27462 m .63099 1.29994 L .42619 1.27429 L .693 .453 .555 r
F
.60519 1.2932 m .58611 1.27286 L .61632 1.27999 L p 0 .297 .787 r
F P
0 g
s
.60369 1.27701 m .58611 1.27286 L p .59231 1.29035 L .102 0 .063 r
F P
0 g
s
.61632 1.27999 m .63132 1.29606 L p .60519 1.2932 L 0 .297 .787 r
F P
0 g
s
.59178 1.26755 m .36955 1.26755 L p .63096 1.29866 L .693 .453 .555 r
F P
0 g
s
.58412 1.29994 m .59685 1.30317 L p .59231 1.29035 L .102 0 .063 r
F P
0 g
s
.59685 1.30317 m .61632 1.27999 L .61303 1.27922 L p .102 0 .063 r
F P
0 g
s
.61303 1.27922 m .60369 1.27701 L p .60083 1.28797 L .102 0 .063 r
F P
0 g
s
.60083 1.28797 m .59685 1.30317 L .61303 1.27922 L .102 0 .063 r
F
.58412 1.29994 m .45793 1.29994 L p .55851 1.3183 L .69 .689 .843 r
F P
0 g
s
.55851 1.3183 m .597 1.32532 L .58412 1.29994 L .69 .689 .843 r
F
.4408 1.27999 m .46069 1.3007 L .45793 1.29994 L p 0 .267 .761 r
F P
0 g
s
.43846 1.28421 m .4408 1.27999 L .45793 1.29994 L 0 .267 .761 r
F
.36955 1.26755 m .42659 1.27462 L .42619 1.27429 L .693 .453 .555 r
F
.59231 1.29035 m .59685 1.30317 L .60369 1.27701 L .102 0 .063 r
F
.60369 1.32055 m .61632 1.32387 L p .59556 1.31198 L 0 .289 .78 r
F P
0 g
s
.63567 1.3007 m .63132 1.3059 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.63132 1.3059 m .61632 1.32387 L p .63104 1.30212 L .112 0 .073 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46974 1.09988 m .46368 1.10009 L .46771 1.09965 L F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .66674 1.01586 L .64101 1.04449 L .333 .272 .638 r
F
.66674 1.01586 m .69838 .9119 L .65042 1.02274 L F
.66674 1.01586 m .65042 1.02274 L .64101 1.04449 L F
.68501 1.00816 m .70698 1.0175 L p .70923 1.00251 L .468 .815 .998 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 1.03682 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70186 .99895 m .70923 1.00251 L p .70227 1.00088 L .872 .62 .556 r
F P
0 g
s
.71431 1.00257 m .71493 .99856 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70923 1.00251 m .71431 1.00257 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70996 .99764 m .70963 .99983 L .71493 .99856 L .593 .916 .975 r
F
.71084 1.00289 m .71172 1.01571 L .71247 1.01268 L .468 .815 .998 r
F
.70996 .99764 m .71047 1.0028 L .71084 1.00289 L F
.71047 1.0028 m .71172 1.01571 L .71084 1.00289 L F
.70698 1.0175 m .71172 1.01571 L p .70996 .99764 L F P
0 g
s
.71431 1.00257 m .71524 1.00018 L .7147 1.00367 L 0 0 .367 r
F
.71797 1.01454 m .71431 1.00257 L p .7173 1.011 L F P
0 g
s
.70996 .99764 m .71291 1.01526 L .71524 1.00018 L .468 .815 .998 r
F
.70923 1.00251 m .71468 1.00379 L .71441 1.00485 L .855 .518 .414 r
F
.70923 1.00251 m .71439 1.005 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.7147 1.00367 m .71524 1.00018 L .7173 1.011 L 0 0 .367 r
F
.73321 1.01578 m .73666 1.00258 L .70996 .99764 L .96 .784 .62 r
F
.75797 .92105 m .74849 .91876 L .70996 .99764 L F
.70881 .87398 m .70996 .90945 L p .74865 .87438 L .948 .647 .432 r
F P
0 g
s
.70996 .99764 m .74849 .91876 L .7394 .91657 L .96 .784 .62 r
F
.71004 .99631 m .7394 .91657 L .71465 .91059 L F
.70996 .99764 m .7394 .91657 L .71004 .99631 L F
.70227 1.00088 m .68501 1.00816 L .70923 1.00251 L .468 .815 .998 r
F
.6578 1.04524 m .70996 1.03682 L .70265 1.00262 L .333 .272 .638 r
F
.71493 .99856 m .71547 .99502 L p .71 .99738 L .593 .916 .975 r
F P
0 g
s
.71547 .99502 m .7155 .99487 L .71 .99738 L p .593 .916 .975 r
F P
0 g
s
.71 .99738 m .70996 .99764 L .71493 .99856 L .593 .916 .975 r
F
.73666 1.00258 m .71931 .98274 L .71559 .99868 L .96 .784 .62 r
F
.73666 1.00258 m .75797 .92105 L .71931 .98274 L F
.75352 .99995 m .73515 .99192 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.75352 .99995 m .73175 1.00816 L p .73369 .9989 L .302 .134 .481 r
F P
0 g
s
.75352 .99995 m .73505 .99188 L p .71558 .99794 L .468 .815 .998 r
F P
0 g
s
.71587 .99609 m .71558 .99794 L .73505 .99188 L .468 .815 .998 r
F
.71493 .99856 m .7155 .99487 L p .71573 .99699 L 0 0 .367 r
F P
0 g
s
.71493 .99856 m .71573 .99699 L .71543 .99894 L 0 0 .367 r
F
.73175 1.00816 m .75352 .99995 L p .71558 .99794 L .468 .815 .998 r
F P
0 g
s
.71493 .99856 m .71543 .99894 L .71524 1.00018 L 0 0 .367 r
F
.70996 .99764 m .71524 1.00018 L .71558 .99794 L .468 .815 .998 r
F
.71524 1.00018 m .73175 1.00816 L .71558 .99794 L F
.71524 1.00018 m .716 .99938 L .71559 1.00203 L 0 0 .367 r
F
.71543 .99894 m .716 .99938 L .71524 1.00018 L F
.71543 .99894 m .71573 .99699 L .716 .99938 L F
.7155 .99487 m .71 .99738 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.71233 .98195 m .70996 .99764 L .71558 .99794 L .468 .815 .998 r
F
.7155 .99487 m .71587 .99609 L p .71573 .99699 L 0 0 .367 r
F P
0 g
s
.71769 .98429 m .71233 .98195 L p .71524 .99623 L .468 .815 .998 r
F P
0 g
s
.71524 .99623 m .71558 .99794 L .71587 .99609 L .468 .815 .998 r
F
.71587 .99609 m .7155 .99487 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.71524 .99623 m .71587 .99609 L .71769 .98429 L .468 .815 .998 r
F
.728 1.03569 m .73321 1.01578 L .71835 1.00418 L .96 .784 .62 r
F
.71555 .99746 m .71171 .99741 L .71439 1.005 L .327 .684 .979 r
F
.66243 1.03003 m .70265 1.00262 L .70227 1.00088 L .333 .272 .638 r
F
.66243 1.03003 m .70227 1.00088 L .6843 .95815 L F
.6578 1.04524 m .70265 1.00262 L .66243 1.03003 L F
.6843 .95815 m .70227 1.00088 L .68949 .94112 L F
.74865 .87438 m .70996 .90945 L .73478 .91545 L .948 .647 .432 r
F
.70996 .90945 m .70996 .99557 L p .71632 .87956 L .96 .784 .62 r
F P
0 g
s
.70996 .99557 m .70996 .99764 L p .71012 .99473 L .96 .784 .62 r
F P
0 g
s
.71012 .99473 m .71632 .87956 L .70996 .99557 L .96 .784 .62 r
F
.70996 .90945 m .70881 .87398 L p .69564 .91248 L .29 .123 .473 r
F P
0 g
s
.70996 .99764 m .70996 .90945 L p .70186 .99895 L .333 .272 .638 r
F P
0 g
s
.70996 .90945 m .70996 .87384 L p .70763 .90995 L .333 .272 .638 r
F P
0 g
s
.70186 .99895 m .70996 .90945 L .70763 .90995 L .333 .272 .638 r
F
.71 .99738 m .70959 .99757 L p .71561 .99615 L .482 .308 .568 r
F P
0 g
s
.68949 .94112 m .70186 .99895 L .70996 .87384 L .333 .272 .638 r
F
.6989 .99752 m .70186 .99895 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.71 .99738 m .6989 .99752 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.70186 .99895 m .70923 1.00251 L p .70996 .99764 L .327 .684 .979 r
F P
0 g
s
.70186 .99895 m .70227 1.00088 L .70996 .99764 L .333 .272 .638 r
F
.70202 1.00082 m .68501 1.00816 L .70227 1.00088 L .468 .815 .998 r
F
.6989 .99752 m .70186 .99895 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.70186 .99895 m .70227 1.00088 L .69878 1.00006 L .872 .62 .556 r
F
.69216 1.0013 m .68501 1.00816 L .70202 1.00082 L .468 .815 .998 r
F
.6983 .99995 m .6989 .99752 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.6983 .99995 m .70202 1.00082 L .71 .99738 L .468 .815 .998 r
F
.69216 1.0013 m .70202 1.00082 L .6983 .99995 L F
.68565 1.08458 m .70996 1.10469 L .69803 1.08458 L .68 .398 .487 r
F
.68565 1.08458 m .69803 1.08458 L .67512 1.04601 L F
.68665 1.06543 m .70345 1.05256 L .67644 1.04823 L .333 .272 .638 r
F
.69488 1.08618 m .67916 1.07879 L .6983 .99995 L p .872 .62 .556 r
F P
0 g
s
.69878 1.00006 m .69488 1.08618 L .6983 .99995 L .872 .62 .556 r
F
.71439 1.005 m .70503 1.04397 L p .69878 1.00006 L F P
0 g
s
.70923 1.00251 m .71439 1.005 L p .69878 1.00006 L .872 .62 .556 r
F P
0 g
s
.71439 1.005 m .71441 1.00485 L p .71013 1.02208 L .731 .724 .198 r
F P
0 g
s
.70996 1.10469 m .728 1.03569 L .71798 1.01454 L .96 .784 .62 r
F
.71441 1.00485 m .71094 1.0186 L .71013 1.02208 L .731 .724 .198 r
F
.70845 1.02973 m .71439 1.005 L p .71013 1.02208 L F P
0 g
s
.71013 1.02208 m .70996 1.02279 L .70845 1.02973 L .731 .724 .198 r
F
.70996 1.10469 m .71798 1.01454 L .71094 1.0186 L .96 .784 .62 r
F
.70996 1.01917 m .70996 1.02279 L p .71094 1.0186 L F P
0 g
s
.70996 1.02279 m .70996 1.10469 L p .71094 1.0186 L .96 .784 .62 r
F P
0 g
s
.71238 1.01291 m .70923 1.00251 L .71266 1.01181 L .855 .518 .414 r
F
.70293 1.00243 m .70923 1.00251 L p .71238 1.01291 L F P
0 g
s
.70293 1.00243 m .71238 1.01291 L .71049 1.02041 L .855 .518 .414 r
F
.71013 1.02208 m .71056 1.02012 L .71005 1.02242 L .731 .724 .198 r
F
.71432 1.00481 m .71426 1.00478 L .71439 1.005 L .327 .684 .979 r
F
.70923 1.00251 m .71441 1.00485 L .71266 1.01181 L .855 .518 .414 r
F
.71088 1.01864 m .71094 1.0186 L .71093 1.01841 L .96 .784 .62 r
F
.71088 1.01864 m .71093 1.01841 L .70996 .99764 L F
.70996 .99764 m .70996 1.01917 L p .71088 1.01864 L F P
0 g
s
.71094 1.0186 m .7139 1.00593 L .70996 .99764 L .96 .784 .62 r
F
.7151 1.00516 m .71797 1.01454 L p .71266 1.01181 L .855 .518 .414 r
F P
0 g
s
.71441 1.00485 m .7151 1.00516 L .71266 1.01181 L .855 .518 .414 r
F
.71248 .9996 m .70996 .99764 L .71426 1.00478 L .327 .684 .979 r
F
.71248 .9996 m .71426 1.00478 L .71432 1.00481 L F
.71441 1.00485 m .71493 1.00151 L p .71094 1.0186 L .731 .724 .198 r
F P
0 g
s
.71468 1.00379 m .7151 1.00516 L p .71441 1.00485 L .855 .518 .414 r
F P
0 g
s
.71798 1.01454 m .71835 1.00418 L .70996 .99764 L .96 .784 .62 r
F
.72098 1.02088 m .71981 1.01348 L .71798 1.01454 L F
.71981 1.01348 m .71835 1.00418 L .71798 1.01454 L F
.71783 1.0746 m .77017 1.02671 L .73961 1.01195 L F
.71797 1.01454 m .73912 1.08369 L p .71442 1.01659 L .855 .518 .414 r
F P
0 g
s
.71266 1.01181 m .71797 1.01454 L .71442 1.01659 L .855 .518 .414 r
F
.70996 .99764 m .70227 1.00088 L .70923 1.00251 L .468 .815 .998 r
F
.7096 .99789 m .70516 1.00091 L .70963 .99983 L .593 .916 .975 r
F
.71 .99738 m .70202 1.00082 L .70996 .99764 L .468 .815 .998 r
F
.70959 .99757 m .7096 .99789 L .70996 .99764 L .593 .916 .975 r
F
.7096 .99789 m .70963 .99983 L .70996 .99764 L F
.70227 1.00088 m .70265 1.00262 L .70996 .99764 L .333 .272 .638 r
F
.69878 1.00006 m .70503 1.04397 L .69622 1.05672 L .872 .62 .556 r
F
.69904 1.00239 m .70923 1.00251 L p .70963 .99983 L .593 .916 .975 r
F P
0 g
s
.70996 1.03682 m .70996 1.01917 L p .70265 1.00262 L .333 .272 .638 r
F P
0 g
s
.70503 1.04397 m .69488 1.08618 L p .69622 1.05672 L .872 .62 .556 r
F P
0 g
s
.71005 1.02242 m .69598 1.07885 L .70721 1.03459 L .731 .724 .198 r
F
.70996 1.02279 m .70721 1.03459 L .70845 1.02973 L F
.71005 1.02242 m .70721 1.03459 L .70996 1.02279 L F
.69598 1.07885 m .69488 1.08618 L .70845 1.02973 L p F P
0 g
s
.71005 1.02242 m .71049 1.02041 L .69598 1.07885 L .731 .724 .198 r
F
.70778 1.03115 m .69904 1.00239 L p .70962 1.02384 L .855 .518 .414 r
F P
0 g
s
.70996 1.01917 m .70996 .99764 L p .70293 1.00243 L .333 .272 .638 r
F P
0 g
s
.70265 1.00262 m .70996 1.01917 L .70293 1.00243 L .333 .272 .638 r
F
.70077 1.05893 m .69598 1.07885 L p .71049 1.02041 L .731 .724 .198 r
F P
0 g
s
.71554 .99753 m .71229 .99848 L .71464 1.00142 L .482 .308 .568 r
F
.71561 .99615 m .71225 .99741 L .71555 .99746 L F
.71 .99738 m .70959 .99757 L p .70996 .99764 L .593 .916 .975 r
F P
0 g
s
.71169 .99736 m .70996 .99764 L .71248 .9996 L .327 .684 .979 r
F
.70959 .99757 m .70942 .99848 L .71225 .99741 L .482 .308 .568 r
F
.71037 .99739 m .71225 .99741 L .71561 .99615 L F
.71143 .9974 m .71 .99738 L .70996 .99764 L .327 .684 .979 r
F
.70959 .99757 m .71225 .99741 L .71037 .99739 L .482 .308 .568 r
F
.71169 .99736 m .71 .99738 L p .71143 .9974 L .327 .684 .979 r
F P
0 g
s
.71558 .99731 m .71171 .99741 L .71555 .99746 L .327 .684 .979 r
F
.70202 1.00082 m .70227 1.00088 L .70996 .99764 L .468 .815 .998 r
F
.70959 .99757 m .69904 1.00239 L p .70516 1.00091 L .593 .916 .975 r
F P
0 g
s
.70959 .99757 m .70516 1.00091 L .7096 .99789 L .593 .916 .975 r
F
.71225 .99741 m .69904 1.00239 L .71554 .99753 L .482 .308 .568 r
F
.71555 .99746 m .71554 .99753 L .71574 .99747 L F
.71225 .99741 m .71554 .99753 L .71555 .99746 L F
.71493 1.00151 m .71555 .99746 L p .71058 1.02003 L .731 .724 .198 r
F P
0 g
s
.71555 .99746 m .71558 .99731 L p .71534 .99836 L .731 .724 .198 r
F P
0 g
s
.71555 .99746 m .71534 .99836 L .71058 1.02003 L .731 .724 .198 r
F
.71094 1.0186 m .71058 1.02003 L .71013 1.02208 L F
.71493 1.00151 m .71058 1.02003 L .71094 1.0186 L F
.69904 1.00239 m .70293 1.00243 L p .71049 1.02041 L .855 .518 .414 r
F P
0 g
s
.71056 1.02012 m .71049 1.02041 L .71005 1.02242 L .731 .724 .198 r
F
.71013 1.02208 m .71058 1.02003 L .71056 1.02012 L F
.71013 1.02208 m .71005 1.02242 L .70996 1.02279 L F
.70962 1.02384 m .71049 1.02041 L .72536 1.05577 L .855 .518 .414 r
F
.69904 1.00239 m .71049 1.02041 L .70962 1.02384 L F
.69904 1.00239 m .70778 1.03115 L p .71464 1.00142 L .482 .308 .568 r
F P
0 g
s
.71229 .99848 m .69904 1.00239 L .71464 1.00142 L .482 .308 .568 r
F
.71515 .99908 m .70077 1.05893 L p .71049 1.02041 L .731 .724 .198 r
F P
0 g
s
.71155 1.10458 m .77017 1.10042 L p .71783 1.0746 L .96 .784 .62 r
F P
0 g
s
.72375 1.08378 m .70778 1.03115 L p .72536 1.05577 L .855 .518 .414 r
F P
0 g
s
.70962 1.02384 m .72536 1.05577 L .70778 1.03115 L .855 .518 .414 r
F
.73912 1.08369 m .73711 1.0837 L p .72536 1.05577 L F P
0 g
s
.73711 1.0837 m .72375 1.08378 L p .72536 1.05577 L .855 .518 .414 r
F P
0 g
s
.71049 1.02041 m .71238 1.01291 L .72536 1.05577 L .855 .518 .414 r
F
.71363 1.01705 m .71238 1.01291 L .71389 1.0169 L F
.71238 1.01291 m .71266 1.01181 L .73912 1.08369 L F
.71094 1.0186 m .71798 1.01454 L .7139 1.00593 L .96 .784 .62 r
F
.72536 1.05577 m .71363 1.01705 L .73912 1.08369 L .855 .518 .414 r
F
.71363 1.01705 m .71389 1.0169 L .73912 1.08369 L F
.71559 1.00203 m .71582 1.00051 L .71635 1.00602 L 0 0 .367 r
F
.71582 1.00051 m .716 .99938 L .71635 1.00602 L F
.71635 1.00602 m .716 .99938 L .7173 1.011 L F
.71574 .99747 m .71554 .99753 L .72375 1.08378 L .482 .308 .568 r
F
.71056 1.02012 m .71466 1.00133 L .71049 1.02041 L .731 .724 .198 r
F
.71466 1.00133 m .71464 1.00142 L .71049 1.02041 L F
.71056 1.02012 m .71534 .99836 L .71466 1.00133 L F
.71058 1.02003 m .71534 .99836 L .71056 1.02012 L F
.70778 1.03115 m .72375 1.08378 L p .71554 .99753 L .482 .308 .568 r
F P
0 g
s
.71466 1.00133 m .71515 .99908 L .71464 1.00142 L .731 .724 .198 r
F
.70959 .99757 m .69904 1.00239 L p .70942 .99848 L .482 .308 .568 r
F P
0 g
s
.71 .99738 m .70964 .99738 L p .70961 .99747 L .439 .19 .439 r
F P
0 g
s
.6989 .99752 m .67916 1.07879 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.70964 .99738 m .6989 .99752 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.71233 .98195 m .69216 1.0013 L .71 .99738 L .468 .815 .998 r
F
.71 .99738 m .70961 .99747 L .70957 .99757 L .439 .19 .439 r
F
.728 1.03569 m .7227 1.01839 L .72098 1.02088 L .96 .784 .62 r
F
.7227 1.01839 m .71835 1.00418 L .72098 1.02088 L F
.7173 1.011 m .71573 .99699 L .74046 1.07635 L 0 0 .367 r
F
.71587 .99609 m .74046 1.07635 L p .71573 .99699 L F P
0 g
s
.74046 1.07635 m .73912 1.08369 L .71797 1.01454 L p 0 0 .367 r
F P
0 g
s
.7173 1.011 m .74046 1.07635 L .71797 1.01454 L 0 0 .367 r
F
.72375 1.08378 m .74046 1.07635 L .71587 .99609 L p .482 .308 .568 r
F P
0 g
s
.71561 .99615 m .72375 1.08378 L .71587 .99609 L .482 .308 .568 r
F
.71568 .9969 m .71555 .99746 L .71574 .99747 L F
.71561 .99615 m .71555 .99746 L .71568 .9969 L F
.71558 .99731 m .71515 .99908 L p .71466 1.00133 L .731 .724 .198 r
F P
0 g
s
.71534 .99836 m .71558 .99731 L .71466 1.00133 L .731 .724 .198 r
F
.71558 .99731 m .71169 .99736 L p .71171 .99741 L .327 .684 .979 r
F P
0 g
s
.73505 .99188 m .71769 .98429 L p .71587 .99609 L .468 .815 .998 r
F P
0 g
s
.71558 .99731 m .71 .99738 L p .68203 1.07235 L .439 .19 .439 r
F P
0 g
s
.71 .99738 m .70957 .99757 L .68203 1.07235 L .439 .19 .439 r
F
.70996 .90945 m .71233 .98195 L p .73478 .91545 L .948 .647 .432 r
F P
0 g
s
.71465 .91059 m .75197 .91164 L .71632 .87956 L .96 .784 .62 r
F
.74849 .91876 m .75197 .91164 L .71465 .91059 L F
.70996 .87384 m .70996 .90945 L p .71632 .87956 L F P
0 g
s
.69838 .9119 m .69423 .91277 L .64101 1.04449 L .333 .272 .638 r
F
.68501 1.00816 m .66572 .99995 L .66367 .91922 L p .946 .648 .442 r
F P
0 g
s
.66572 .99995 m .69296 .98943 L p .70996 .90945 L .29 .123 .473 r
F P
0 g
s
.69296 .98943 m .71233 .98195 L .70996 .90945 L p .29 .123 .473 r
F P
0 g
s
.71233 .98195 m .66572 .99995 L .68501 1.00816 L p .468 .815 .998 r
F P
0 g
s
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70345 1.05256 m .70996 1.04757 L .7046 1.04733 L .333 .272 .638 r
F
.70265 .87403 m .66572 .99995 L .70881 .87398 L .29 .123 .473 r
F
.69838 .9119 m .70996 .87384 L .69423 .91277 L .333 .272 .638 r
F
.66253 .87438 m .66367 .91922 L p .70265 .87403 L .29 .123 .473 r
F P
0 g
s
.66367 .91922 m .66572 .99995 L p .6911 .91343 L .29 .123 .473 r
F P
0 g
s
.70265 .87403 m .66367 .91922 L .6911 .91343 L .29 .123 .473 r
F
.7082 .85514 m .66253 .87438 L p .70265 .87403 L F P
0 g
s
.65178 .87448 m .64101 .87438 L p .66253 .87438 L .012 .587 .719 r
F P
0 g
s
.64101 .87438 m .70996 .87384 L p .70881 .87398 L .012 .587 .719 r
F P
0 g
s
.66253 .87438 m .64101 .87438 L .70881 .87398 L .012 .587 .719 r
F
.75797 .92105 m .77017 .87438 L .74849 .91876 L .96 .784 .62 r
F
.75038 .91922 m .75352 .99995 L p .73963 .97056 L .302 .134 .481 r
F P
0 g
s
.77017 .87438 m .75791 .87448 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .7598 .87429 L p .75197 .91164 L .96 .784 .62 r
F P
0 g
s
.7598 .87429 m .70996 .87384 L p .75197 .91164 L .96 .784 .62 r
F P
0 g
s
.77017 .924 m .77017 .87438 L p .75797 .92105 L .96 .784 .62 r
F P
0 g
s
.71233 .98195 m .75352 .99995 L .75038 .91922 L p .948 .647 .432 r
F P
0 g
s
.73478 .91545 m .71233 .98195 L .75038 .91922 L .948 .647 .432 r
F
.70996 1.10469 m .71155 1.10458 L p .71783 1.0746 L .96 .784 .62 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 .924 L p .333 .272 .638 r
F P
0 g
s
.69423 .91277 m .70996 .87384 L .64101 .924 L .333 .272 .638 r
F
.69564 .91248 m .66572 .99995 L .70996 .90945 L .29 .123 .473 r
F
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.45263 .38705 m .22102 .37893 L .46245 .39084 L .222 .729 .893 r
F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.22102 .37893 m .22014 .38872 L p .45622 .39277 L .222 .729 .893 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5186 .39814 m .47807 .39686 L .4814 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .22014 .38872 L .5186 .39814 L .222 .729 .893 r
F
.45622 .39277 m .22014 .38872 L .52117 .39715 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.52928 .39402 m .45622 .39277 L .52117 .39715 L .222 .729 .893 r
F
.526 .39397 m .33234 .38442 L .45622 .39277 L F
.33234 .38442 m .22102 .37893 L .45622 .39277 L F
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.46985 .39369 m .46985 .77742 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.34707 .23379 m .3466 .22046 L .32817 .22245 L p .525 .452 .716 r
F P
0 g
s
.33879 .36823 m .33879 .18543 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.38103 .36782 m .36908 .36794 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.36908 .36794 m .33879 .36823 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.37555 .2036 m .36908 .20184 L .36908 .20039 L 1 .816 .504 r
F
.37594 .17624 m .37643 .19026 L .37555 .2036 L p F P
0 g
s
.37555 .2036 m .37643 .19026 L .39599 .18806 L p .504 .366 .627 r
F P
0 g
s
.37643 .19026 m .37594 .17624 L .39551 .17399 L p .517 .446 .715 r
F P
0 g
s
.39551 .17399 m .39599 .18806 L .37643 .19026 L p .517 .446 .715 r
F P
0 g
s
.37411 .16211 m .37594 .17624 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.37102 .14847 m .37411 .16211 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.39599 .18806 m .39512 .20144 L .37555 .2036 L p .504 .366 .627 r
F P
0 g
s
.37335 .2157 m .37555 .2036 L .39512 .20144 L p .481 .268 .513 r
F P
0 g
s
.38103 .36782 m .38103 .22264 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.38103 .22264 m .38103 .22103 L p .38136 .22276 L .241 .197 .606 r
F P
0 g
s
.38136 .22276 m .3887 .2607 L .38103 .22264 L .241 .197 .606 r
F
.38729 .2255 m .3887 .23471 L .38217 .22306 L F
.38729 .2255 m .38217 .22306 L .38572 .22438 L F
.3887 .23471 m .3887 .2607 L .38103 .22103 L F
.38572 .22438 m .38954 .22398 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.37355 .21568 m .39275 .2136 L p .38022 .22045 L .44 .142 .361 r
F P
0 g
s
.3918 .2142 m .38025 .22047 L .39275 .2136 L .44 .142 .361 r
F
.38025 .22047 m .36992 .22607 L .38022 .22045 L F
.38025 .22047 m .38022 .22045 L .39275 .2136 L F
.39512 .20144 m .39299 .21334 L p .37335 .2157 L .481 .268 .513 r
F P
0 g
s
.39299 .21334 m .39294 .21358 L .39275 .2136 L p .481 .268 .513 r
F P
0 g
s
.39275 .2136 m .37335 .2157 L p .39299 .21334 L .481 .268 .513 r
F P
0 g
s
.37582 .22479 m .37746 .22412 L .37685 .23084 L .686 .56 .707 r
F
.36908 .22759 m .36992 .22607 L .37371 .22567 L p .369 0 .15 r
F P
0 g
s
.36992 .22607 m .37335 .2157 L .37355 .21568 L p .44 .142 .361 r
F P
0 g
s
.38022 .22045 m .36992 .22607 L .37355 .21568 L .44 .142 .361 r
F
.33879 .18543 m .36908 .18504 L p .36908 .3162 L .686 .56 .707 r
F P
0 g
s
.33561 .10515 m .34231 .10584 L p .36927 .18512 L 1 .816 .504 r
F P
0 g
s
.33879 .18543 m .36908 .18504 L p .30025 .16878 L .289 .763 .934 r
F P
0 g
s
.30025 .16878 m .36908 .18504 L .35855 .1804 L .289 .763 .934 r
F
.37555 .2036 m .3678 .18447 L .36927 .18512 L 1 .816 .504 r
F
.3678 .18447 m .33561 .10515 L .36927 .18512 L F
.37555 .2036 m .36908 .15364 L .37102 .14847 L F
.36155 .12489 m .36677 .13589 L p .37339 .18694 L F P
0 g
s
.37555 .2036 m .37252 .18656 L .37339 .18694 L 1 .816 .504 r
F
.37252 .18656 m .36155 .12489 L .37339 .18694 L F
.37594 .17624 m .37411 .16211 L .3937 .15982 L p .522 .513 .788 r
F P
0 g
s
.3937 .15982 m .39551 .17399 L .37594 .17624 L p .522 .513 .788 r
F P
0 g
s
.35556 .11596 m .36155 .12489 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34906 .10951 m .35556 .11596 L p .37157 .18614 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .3705 .18567 L .37157 .18614 L 1 .816 .504 r
F
.3705 .18567 m .34906 .10951 L .37157 .18614 L F
.34231 .10584 m .34906 .10951 L p .37555 .2036 L F P
0 g
s
.32926 .10751 m .33561 .10515 L p .3678 .18447 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .36595 .18366 L .3678 .18447 L 1 .816 .504 r
F
.36595 .18366 m .32926 .10751 L .3678 .18447 L F
.32355 .11284 m .32926 .10751 L p .36595 .18366 L F P
0 g
s
.37555 .2036 m .36352 .18259 L .36595 .18366 L 1 .816 .504 r
F
.36352 .18259 m .32355 .11284 L .36595 .18366 L F
.31874 .12093 m .32355 .11284 L p .37555 .2036 L F P
0 g
s
.30025 .16878 m .35855 .1804 L .33932 .17194 L .289 .763 .934 r
F
.31507 .13144 m .31874 .12093 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.3127 .1439 m .31507 .13144 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.30025 .16878 m .33122 .16837 L .32545 .16583 L .289 .763 .934 r
F
.31964 .16327 m .30025 .16878 L p .32545 .16583 L F P
0 g
s
.30025 .16878 m .33932 .17194 L .33122 .16837 L .289 .763 .934 r
F
.31176 .15774 m .3127 .1439 L p .31964 .15049 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .31964 .1634 L .31964 .15049 L 1 .816 .504 r
F
.37411 .16211 m .37102 .14847 L .39063 .14614 L p .52 .574 .849 r
F P
0 g
s
.39063 .14614 m .3937 .15982 L .37411 .16211 L p .52 .574 .849 r
F P
0 g
s
.3937 .15982 m .39551 .17399 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.39063 .14614 m .3937 .15982 L p .39457 .18544 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39379 .18509 L .39457 .18544 L 1 .816 .5 r
F
.39379 .18509 m .39063 .14614 L .39457 .18544 L F
.38103 .18488 m .3887 .18281 L p .33932 .17194 L .289 .763 .934 r
F P
0 g
s
.39551 .17399 m .39599 .18806 L .39512 .20144 L p 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .15132 L .39063 .14614 L 1 .816 .5 r
F
.38642 .1335 m .39063 .14614 L .37102 .14847 L p .513 .629 .903 r
F P
0 g
s
.38642 .1335 m .3887 .14036 L p .3887 .15132 L 1 .816 .5 r
F P
0 g
s
.3887 .14036 m .39063 .14614 L p .3887 .15132 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39235 .20795 L .39197 .20717 L 1 .816 .5 r
F
.36908 .2286 m .37685 .23084 L .36908 .23926 L .686 .56 .707 r
F
.37371 .22567 m .36992 .22607 L p .3918 .2142 L .44 .142 .361 r
F P
0 g
s
.33879 .36823 m .30541 .36334 L .30541 .17886 L p .932 .761 .647 r
F P
0 g
s
.30541 .17886 m .33879 .18543 L .33879 .36823 L p .932 .761 .647 r
F P
0 g
s
.30541 .36334 m .30025 .35584 L .30025 .16878 L p .847 .692 .158 r
F P
0 g
s
.30025 .16878 m .30541 .17886 L .30541 .36334 L p .847 .692 .158 r
F P
0 g
s
.30025 .16878 m .30025 .35584 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.37555 .2036 m .31964 .17596 L .31964 .1634 L 1 .816 .504 r
F
.32545 .16583 m .3267 .16585 L .32672 .16568 L .289 .763 .934 r
F
.37102 .14847 m .36677 .13589 L .38642 .1335 L p .513 .629 .903 r
F P
0 g
s
.38125 .12246 m .38642 .1335 L .36677 .13589 L p .497 .682 .949 r
F P
0 g
s
.38125 .12246 m .38642 .1335 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36677 .13589 m .36155 .12489 L .38125 .12246 L p .497 .682 .949 r
F P
0 g
s
.37531 .1135 m .38125 .12246 L .36155 .12489 L p .467 .73 .983 r
F P
0 g
s
.37531 .1135 m .38125 .12246 L p .39212 .18434 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39118 .18392 L .39212 .18434 L 1 .816 .5 r
F
.39118 .18392 m .37531 .1135 L .39212 .18434 L F
.36155 .12489 m .35556 .11596 L .37531 .1135 L p .467 .73 .983 r
F P
0 g
s
.36886 .10701 m .37531 .1135 L .35556 .11596 L p .416 .768 .996 r
F P
0 g
s
.36886 .10701 m .37531 .1135 L p .39118 .18392 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .39012 .18345 L .39118 .18392 L 1 .816 .5 r
F
.39012 .18345 m .36886 .10701 L .39118 .18392 L F
.33932 .17194 m .3699 .17441 L .33122 .16837 L .289 .763 .934 r
F
.35556 .11596 m .34906 .10951 L .36886 .10701 L p .416 .768 .996 r
F P
0 g
s
.36218 .10332 m .36886 .10701 L .34906 .10951 L p .328 .776 .958 r
F P
0 g
s
.36218 .10332 m .36886 .10701 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.38103 .18488 m .3887 .18281 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.33932 .17194 m .3887 .18281 L .3699 .17441 L .289 .763 .934 r
F
.34906 .10951 m .34231 .10584 L .36218 .10332 L p .328 .776 .958 r
F P
0 g
s
.35554 .10262 m .36218 .10332 L .34231 .10584 L p .183 .715 .821 r
F P
0 g
s
.35554 .10262 m .36218 .10332 L p .3889 .1829 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .38744 .18225 L .3889 .1829 L 1 .816 .5 r
F
.38744 .18225 m .35554 .10262 L .3889 .1829 L F
.33122 .16837 m .35568 .16805 L .32545 .16583 L .289 .763 .934 r
F
.36677 .13589 m .36908 .14271 L p .36908 .15364 L 1 .816 .504 r
F P
0 g
s
.36908 .14271 m .37102 .14847 L p .36908 .15364 L 1 .816 .504 r
F P
0 g
s
.34924 .10498 m .35554 .10262 L p .38744 .18225 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .38561 .18143 L .38744 .18225 L 1 .816 .5 r
F
.38561 .18143 m .34924 .10498 L .38744 .18225 L F
.3267 .16585 m .35189 .16635 L .32672 .16568 L .289 .763 .934 r
F
.34358 .11032 m .34924 .10498 L p .38561 .18143 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3832 .18035 L .38561 .18143 L 1 .816 .5 r
F
.3832 .18035 m .34358 .11032 L .38561 .18143 L F
.3832 .18035 m .33971 .11967 L .34358 .11032 L F
.37979 .17883 m .33971 .11974 L .3832 .18035 L F
.33971 .11974 m .33882 .11843 L .33971 .11967 L F
.33971 .11974 m .33971 .11967 L .3832 .18035 L F
.32736 .16107 m .31964 .16327 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.32672 .16568 m .35161 .16623 L .34547 .16348 L .289 .763 .934 r
F
.35189 .16635 m .35161 .16623 L .32672 .16568 L F
.35568 .16805 m .35189 .16635 L .32545 .16583 L F
.32545 .16583 m .34547 .16348 L .31964 .16327 L F
.33518 .12897 m .33882 .11843 L p .37979 .17883 L 1 .816 .5 r
F P
0 g
s
.37444 .17644 m .33518 .12897 L .37979 .17883 L 1 .816 .5 r
F
.3699 .17441 m .36548 .17243 L .33122 .16837 L .289 .763 .934 r
F
.33122 .16837 m .36548 .17243 L .35568 .16805 L F
.35855 .1804 m .38103 .18488 L .33932 .17194 L F
.36908 .18504 m .38103 .18488 L p .35855 .1804 L F P
0 g
s
.30025 .16878 m .30541 .17886 L .33879 .18543 L p .289 .763 .934 r
F P
0 g
s
.31964 .16327 m .30025 .16878 L p .31683 .20967 L .218 .178 .597 r
F P
0 g
s
.31964 .20688 m .31683 .20967 L .31964 .21658 L .218 .178 .597 r
F
.31964 .16327 m .31683 .20967 L .31964 .20688 L F
.32207 .21381 m .31757 .20101 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.32755 .22478 m .32207 .21381 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.32207 .21381 m .34212 .21161 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31964 .20688 m .32207 .21381 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31757 .20101 m .31425 .18697 L p .31964 .18843 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .31964 .20111 L .31964 .18843 L 1 .816 .504 r
F
.31964 .20111 m .31757 .20101 L .31964 .18843 L F
.34547 .16348 m .34225 .16205 L .31964 .16327 L .289 .763 .934 r
F
.31425 .18697 m .31228 .17232 L p .36908 .20039 L 1 .816 .504 r
F P
0 g
s
.36908 .20184 m .31425 .18697 L .36908 .20039 L 1 .816 .504 r
F
.32736 .16107 m .31964 .16327 L p .31964 .20688 L .218 .178 .597 r
F P
0 g
s
.32018 .20635 m .31964 .20688 L .31964 .20977 L .218 .178 .597 r
F
.32736 .16107 m .31964 .20688 L .32018 .20635 L F
.34212 .21161 m .33971 .20466 L p .32657 .20001 L .501 .629 .909 r
F P
0 g
s
.32863 .19978 m .32657 .20001 L p .33971 .20466 L .501 .629 .909 r
F P
0 g
s
.34212 .21161 m .32657 .20001 L .32313 .20341 L .501 .629 .909 r
F
.33375 .23346 m .32755 .22478 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34037 .23947 m .33375 .23346 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.34714 .2426 m .34037 .23947 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.35375 .24273 m .34714 .2426 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.35991 .2399 m .35375 .24273 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.33375 .23346 m .34037 .23947 L .36026 .23738 L p .388 .762 .992 r
F P
0 g
s
.36026 .23738 m .35369 .23134 L .33375 .23346 L p .388 .762 .992 r
F P
0 g
s
.32755 .22478 m .33375 .23346 L .35369 .23134 L p .447 .73 .987 r
F P
0 g
s
.35369 .23134 m .34755 .22262 L .32755 .22478 L p .447 .73 .987 r
F P
0 g
s
.32207 .21381 m .32755 .22478 L .34755 .22262 L p .482 .682 .954 r
F P
0 g
s
.34755 .22262 m .34212 .21161 L .32207 .21381 L p .482 .682 .954 r
F P
0 g
s
.33971 .2965 m .33098 .20082 L .32736 .3501 L .686 .56 .707 r
F
.32736 .16107 m .32736 .19889 L p .33098 .20082 L F P
0 g
s
.33971 .16091 m .32736 .16107 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.33971 .16091 m .32736 .16107 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33766 .19877 m .33014 .19498 L .32736 .19889 L .51 .572 .854 r
F
.32657 .20001 m .32863 .19978 L p .32736 .19889 L F P
0 g
s
.33098 .20082 m .32736 .19889 L .32863 .19978 L .686 .56 .707 r
F
.32863 .19978 m .33766 .19877 L p .32736 .19889 L .51 .572 .854 r
F P
0 g
s
.32736 .19889 m .32736 .19922 L p .32863 .19978 L .686 .56 .707 r
F P
0 g
s
.32736 .19922 m .32736 .3501 L p .33098 .20082 L .686 .56 .707 r
F P
0 g
s
.33971 .20466 m .33766 .19877 L .32863 .19978 L p .501 .629 .909 r
F P
0 g
s
.32736 .16107 m .31964 .20977 L .32082 .2081 L .218 .178 .597 r
F
.32736 .3501 m .32736 .16107 L p .31964 .21658 L F P
0 g
s
.32657 .20001 m .31757 .20101 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.31425 .18697 m .31757 .20101 L .32657 .20001 L p .51 .572 .854 r
F P
0 g
s
.33014 .19498 m .31425 .18697 L .32657 .20001 L .51 .572 .854 r
F
.32082 .2081 m .31964 .20977 L .31964 .21658 L .218 .178 .597 r
F
.31757 .20101 m .31964 .20688 L p .32313 .20341 L .501 .629 .909 r
F P
0 g
s
.36537 .23426 m .35991 .2399 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.36992 .22607 m .36537 .23426 L p .37555 .2036 L 1 .816 .504 r
F P
0 g
s
.37555 .2036 m .37335 .2157 L .36992 .22607 L p 1 .816 .504 r
F P
0 g
s
.36908 .18504 m .38103 .18488 L p .37746 .22412 L .686 .56 .707 r
F P
0 g
s
.37575 .22437 m .37685 .23084 L .36908 .2286 L .686 .56 .707 r
F
.36908 .18504 m .37746 .22412 L .37582 .22479 L F
.38572 .22438 m .38217 .22306 L .38103 .22103 L .241 .197 .606 r
F
.36908 .3162 m .37754 .22324 L .38103 .36782 L .686 .56 .707 r
F
.38103 .22103 m .38103 .36782 L p .37754 .22324 L F P
0 g
s
.39294 .21358 m .38954 .22398 L .37371 .22567 L p .44 .142 .361 r
F P
0 g
s
.39294 .21358 m .37371 .22567 L .3918 .2142 L .44 .142 .361 r
F
.38954 .22398 m .3887 .22549 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.38103 .18488 m .3887 .20052 L .38729 .2255 L .241 .197 .606 r
F
.38103 .1865 m .38103 .18488 L p .38132 .18678 L F P
0 g
s
.38132 .18678 m .38729 .2255 L .38103 .1865 L .241 .197 .606 r
F
.38103 .22103 m .38103 .1865 L p .38729 .2255 L F P
0 g
s
.38103 .18488 m .38103 .22103 L p .37754 .22324 L .686 .56 .707 r
F P
0 g
s
.33283 .14147 m .33518 .12897 L p .3887 .19368 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .19526 L .3887 .19368 L 1 .816 .5 r
F
.3887 .19526 m .33283 .14147 L .3887 .19368 L F
.39235 .20795 m .3887 .21651 L .39197 .20717 L F
.39197 .20717 m .3887 .21651 L .3887 .21309 L F
.39512 .20144 m .3887 .21309 L .3887 .21035 L F
.39275 .2136 m .39294 .21358 L p .3918 .2142 L .44 .142 .361 r
F P
0 g
s
.3887 .20052 m .3887 .22652 L .38729 .2255 L .241 .197 .606 r
F
.36908 .18504 m .37575 .22437 L .36908 .2286 L .686 .56 .707 r
F
.33766 .19877 m .33437 .18468 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34212 .21161 m .33766 .19877 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34755 .22262 m .34212 .21161 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.35369 .23134 m .34755 .22262 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36537 .23426 m .36908 .22759 L p .38572 .22438 L .369 0 .15 r
F P
0 g
s
.37371 .22567 m .38572 .22438 L p .36908 .22759 L .369 0 .15 r
F P
0 g
s
.36026 .23738 m .35369 .23134 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.36908 .23926 m .37685 .23084 L .36908 .3162 L .686 .56 .707 r
F
.38504 .23218 m .36537 .23426 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.38725 .22495 m .36537 .23426 L .38572 .22438 L .369 0 .15 r
F
.35991 .2399 m .36537 .23426 L .38504 .23218 L p .25 0 0 r
F P
0 g
s
.38504 .23218 m .37962 .23783 L .35991 .2399 L p .25 0 0 r
F P
0 g
s
.35375 .24273 m .35991 .2399 L .37962 .23783 L p .073 0 0 r
F P
0 g
s
.37962 .23783 m .37351 .24067 L .35375 .24273 L p .073 0 0 r
F P
0 g
s
.36697 .24052 m .36026 .23738 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.40837 .24057 m .40837 .36233 L p .3887 .23471 L .241 .197 .606 r
F P
0 g
s
.38729 .2255 m .3887 .22652 L .3887 .23471 L .241 .197 .606 r
F
.3887 .22652 m .40837 .24057 L .3887 .23471 L F
.38954 .22398 m .3887 .22549 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.38739 .225 m .38504 .23218 L p .38725 .22495 L .369 0 .15 r
F P
0 g
s
.3887 .22549 m .38504 .23218 L p .3887 .221 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .3887 .22549 L .3887 .221 L 1 .816 .5 r
F
.38504 .23218 m .37962 .23783 L p .39512 .20144 L F P
0 g
s
.39512 .20144 m .39294 .21358 L .38954 .22398 L p 1 .816 .5 r
F P
0 g
s
.3887 .20052 m .40837 .24057 L .3887 .22652 L .241 .197 .606 r
F
.3319 .15535 m .33283 .14147 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34547 .16348 m .37103 .16049 L .34225 .16205 L .289 .763 .934 r
F
.39512 .20144 m .37444 .17644 L .37979 .17883 L 1 .816 .5 r
F
.37103 .16049 m .33971 .16091 L p .34225 .16205 L .289 .763 .934 r
F P
0 g
s
.40465 .1674 m .37103 .16049 L p .34547 .16348 L .289 .763 .934 r
F P
0 g
s
.35161 .16623 m .40465 .1674 L .34547 .16348 L .289 .763 .934 r
F
.35189 .16635 m .40465 .1674 L .35161 .16623 L F
.35568 .16805 m .40465 .1674 L .35189 .16635 L F
.3699 .17441 m .40837 .17751 L .36548 .17243 L F
.40837 .17751 m .40465 .1674 L p .35568 .16805 L F P
0 g
s
.36548 .17243 m .40837 .17751 L .35568 .16805 L .289 .763 .934 r
F
.33242 .16998 m .3319 .15535 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.33437 .18468 m .33242 .16998 L p .39512 .20144 L 1 .816 .5 r
F P
0 g
s
.34714 .2426 m .35375 .24273 L .37351 .24067 L p .126 .675 .772 r
F P
0 g
s
.37351 .24067 m .36697 .24052 L .34714 .2426 L p .126 .675 .772 r
F P
0 g
s
.34037 .23947 m .34714 .2426 L .36697 .24052 L p .285 .758 .937 r
F P
0 g
s
.36697 .24052 m .36026 .23738 L .34037 .23947 L p .285 .758 .937 r
F P
0 g
s
.37103 .16049 m .33971 .16091 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.3887 .18281 m .40837 .17751 L p .3699 .17441 L .289 .763 .934 r
F P
0 g
s
.37351 .24067 m .36697 .24052 L p .3887 .21035 L 1 .816 .5 r
F P
0 g
s
.37103 .34966 m .37103 .16049 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.32736 .3501 m .33971 .34998 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33971 .34998 m .37103 .34966 L p .33971 .2965 L .686 .56 .707 r
F P
0 g
s
.33882 .11843 m .33971 .11692 L p .33971 .11967 L 1 .816 .5 r
F P
0 g
s
.33971 .11692 m .34358 .11032 L p .33971 .11967 L 1 .816 .5 r
F P
0 g
s
.39512 .20144 m .37979 .17883 L .3832 .18035 L 1 .816 .5 r
F
.31228 .17232 m .31176 .15774 L p .31964 .1634 L 1 .816 .504 r
F P
0 g
s
.31964 .17596 m .31228 .17232 L .31964 .1634 L 1 .816 .504 r
F
.40837 .17751 m .40837 .24057 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.3887 .18281 m .40837 .17751 L p .3887 .20052 L .241 .197 .606 r
F P
0 g
s
.31964 .1634 m .31176 .15774 L .31964 .15049 L 1 .816 .504 r
F
.30025 .35584 m .31964 .35174 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.31964 .35174 m .32736 .3501 L p .31964 .21658 L .218 .178 .597 r
F P
0 g
s
.3887 .23471 m .40837 .36233 L .3887 .2607 L .241 .197 .606 r
F
.37962 .23783 m .37351 .24067 L p .3887 .21309 L 1 .816 .5 r
F P
0 g
s
.3887 .21651 m .37962 .23783 L .3887 .21309 L 1 .816 .5 r
F
.3887 .21309 m .37351 .24067 L .3887 .21035 L F
.40837 .36233 m .3887 .36628 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.3887 .36628 m .38103 .36782 L p .3887 .2607 L .241 .197 .606 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.33879 .36823 m .38103 .36782 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.30025 .35584 m .30541 .36334 L .33879 .36823 L p .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.61805 .23379 m .61766 .22046 L .59844 .22245 L p .533 .457 .716 r
F P
0 g
s
.40465 .35481 m .40837 .36233 L .40837 .17751 L p .813 .664 .115 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.38103 .36782 m .40837 .36233 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.40837 .36233 m .40465 .35481 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.37103 .34966 m .32736 .3501 L .30025 .35584 L p .224 .73 .894 r
F P
0 g
s
.40465 .35481 m .37103 .34966 L p .30025 .35584 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40837 .17751 m .40465 .1674 L .40465 .35481 L p .813 .664 .115 r
F P
0 g
s
.37103 .34966 m .40465 .35481 L .40465 .1674 L p .938 .766 .643 r
F P
0 g
s
.40465 .1674 m .37103 .16049 L .37103 .34966 L p .938 .766 .643 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.62462 .36823 m .62462 .18543 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.66708 .36782 m .65506 .36794 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.65506 .36794 m .62462 .36823 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.6604 .2036 m .65506 .20184 L .65506 .20039 L .996 .813 .454 r
F
.66072 .17624 m .66112 .19026 L .6604 .2036 L p F P
0 g
s
.6604 .2036 m .66112 .19026 L .68156 .18806 L p .514 .376 .631 r
F P
0 g
s
.66112 .19026 m .66072 .17624 L .68117 .17399 L p .525 .452 .716 r
F P
0 g
s
.68117 .17399 m .68156 .18806 L .66112 .19026 L p .525 .452 .716 r
F P
0 g
s
.65921 .16211 m .66072 .17624 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65666 .14847 m .65921 .16211 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.68156 .18806 m .68085 .20144 L .6604 .2036 L p .514 .376 .631 r
F P
0 g
s
.65859 .2157 m .6604 .2036 L .68085 .20144 L p .492 .283 .523 r
F P
0 g
s
.66708 .36782 m .66708 .22264 L p .67558 .2607 L .284 .232 .621 r
F P
0 g
s
.66708 .22264 m .66708 .22103 L p .66745 .22276 L .284 .232 .621 r
F P
0 g
s
.66745 .22276 m .67558 .2607 L .66708 .22264 L .284 .232 .621 r
F
.67401 .2255 m .67558 .23471 L .66834 .22306 L F
.67401 .2255 m .66834 .22306 L .67228 .22438 L F
.67558 .23471 m .67558 .2607 L .66708 .22103 L F
.67228 .22438 m .67626 .22398 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.65879 .21568 m .67885 .2136 L p .66617 .22045 L .455 .162 .378 r
F P
0 g
s
.6779 .2142 m .66621 .22047 L .67885 .2136 L .455 .162 .378 r
F
.66621 .22047 m .65575 .22607 L .66617 .22045 L F
.66621 .22047 m .66617 .22045 L .67885 .2136 L F
.68085 .20144 m .6791 .21334 L p .65859 .2157 L .492 .283 .523 r
F P
0 g
s
.6791 .21334 m .67906 .21358 L .67885 .2136 L p .492 .283 .523 r
F P
0 g
s
.67885 .2136 m .65859 .2157 L p .6791 .21334 L .492 .283 .523 r
F P
0 g
s
.66184 .22479 m .66349 .22412 L .66287 .23084 L .686 .56 .707 r
F
.65506 .22759 m .65575 .22607 L .65972 .22567 L p .388 0 .176 r
F P
0 g
s
.65575 .22607 m .65859 .2157 L .65879 .21568 L p .455 .162 .378 r
F P
0 g
s
.66617 .22045 m .65575 .22607 L .65879 .21568 L .455 .162 .378 r
F
.62462 .18543 m .65506 .18504 L p .65506 .3162 L .686 .56 .707 r
F P
0 g
s
.62749 .10515 m .63301 .10584 L p .65522 .18512 L .996 .813 .454 r
F P
0 g
s
.62462 .18543 m .65506 .18504 L p .59274 .16878 L .289 .763 .934 r
F P
0 g
s
.59274 .16878 m .65506 .18504 L .64638 .1804 L .289 .763 .934 r
F
.6604 .2036 m .65401 .18447 L .65522 .18512 L .996 .813 .454 r
F
.65401 .18447 m .62749 .10515 L .65522 .18512 L F
.6604 .2036 m .65506 .15364 L .65666 .14847 L F
.64886 .12489 m .65316 .13589 L p .65862 .18694 L F P
0 g
s
.6604 .2036 m .6579 .18656 L .65862 .18694 L .996 .813 .454 r
F
.6579 .18656 m .64886 .12489 L .65862 .18694 L F
.66072 .17624 m .65921 .16211 L .67968 .15982 L p .529 .516 .786 r
F P
0 g
s
.67968 .15982 m .68117 .17399 L .66072 .17624 L p .529 .516 .786 r
F P
0 g
s
.64393 .11596 m .64886 .12489 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63857 .10951 m .64393 .11596 L p .65712 .18614 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65624 .18567 L .65712 .18614 L .996 .813 .454 r
F
.65624 .18567 m .63857 .10951 L .65712 .18614 L F
.63301 .10584 m .63857 .10951 L p .6604 .2036 L F P
0 g
s
.62226 .10751 m .62749 .10515 L p .65401 .18447 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65249 .18366 L .65401 .18447 L .996 .813 .454 r
F
.65249 .18366 m .62226 .10751 L .65401 .18447 L F
.61755 .11284 m .62226 .10751 L p .65249 .18366 L F P
0 g
s
.6604 .2036 m .65048 .18259 L .65249 .18366 L .996 .813 .454 r
F
.65048 .18259 m .61755 .11284 L .65249 .18366 L F
.61359 .12093 m .61755 .11284 L p .6604 .2036 L F P
0 g
s
.59274 .16878 m .64638 .1804 L .63055 .17194 L .289 .763 .934 r
F
.61057 .13144 m .61359 .12093 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.60862 .1439 m .61057 .13144 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.59274 .16878 m .62387 .16837 L .61912 .16583 L .289 .763 .934 r
F
.61433 .16327 m .59274 .16878 L p .61912 .16583 L F P
0 g
s
.59274 .16878 m .63055 .17194 L .62387 .16837 L .289 .763 .934 r
F
.60784 .15774 m .60862 .1439 L p .61433 .15049 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .61433 .1634 L .61433 .15049 L .996 .813 .454 r
F
.65921 .16211 m .65666 .14847 L .67716 .14614 L p .528 .575 .846 r
F P
0 g
s
.67716 .14614 m .67968 .15982 L .65921 .16211 L p .528 .575 .846 r
F P
0 g
s
.67968 .15982 m .68117 .17399 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.67716 .14614 m .67968 .15982 L p .6804 .18544 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67976 .18509 L .6804 .18544 L .995 .813 .449 r
F
.67976 .18509 m .67716 .14614 L .6804 .18544 L F
.66708 .18488 m .67558 .18281 L p .63055 .17194 L .289 .763 .934 r
F P
0 g
s
.68117 .17399 m .68156 .18806 L .68085 .20144 L p .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .15132 L .67716 .14614 L .995 .813 .449 r
F
.67371 .1335 m .67716 .14614 L .65666 .14847 L p .52 .629 .899 r
F P
0 g
s
.67371 .1335 m .67558 .14036 L p .67558 .15132 L .995 .813 .449 r
F P
0 g
s
.67558 .14036 m .67716 .14614 L p .67558 .15132 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67868 .20623 L .67836 .20564 L .995 .813 .449 r
F
.67868 .20623 m .67558 .21309 L .67836 .20564 L F
.67836 .20564 m .67558 .21309 L .67558 .21035 L F
.68085 .20144 m .67558 .21035 L .67558 .20805 L F
.65666 .14847 m .65316 .13589 L .67371 .1335 L p .52 .629 .899 r
F P
0 g
s
.66946 .12246 m .67371 .1335 L .65316 .13589 L p .504 .682 .946 r
F P
0 g
s
.66946 .12246 m .67371 .1335 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65316 .13589 m .64886 .12489 L .66946 .12246 L p .504 .682 .946 r
F P
0 g
s
.66458 .1135 m .66946 .12246 L .64886 .12489 L p .475 .73 .982 r
F P
0 g
s
.66458 .1135 m .66946 .12246 L p .67838 .18434 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67761 .18392 L .67838 .18434 L .995 .813 .449 r
F
.67761 .18392 m .66458 .1135 L .67838 .18434 L F
.64886 .12489 m .64393 .11596 L .66458 .1135 L p .475 .73 .982 r
F P
0 g
s
.65929 .10701 m .66458 .1135 L .64393 .11596 L p .422 .768 .996 r
F P
0 g
s
.65929 .10701 m .66458 .1135 L p .67761 .18392 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67674 .18345 L .67761 .18392 L .995 .813 .449 r
F
.67674 .18345 m .65929 .10701 L .67761 .18392 L F
.63055 .17194 m .66014 .17441 L .62387 .16837 L .289 .763 .934 r
F
.64393 .11596 m .63857 .10951 L .65929 .10701 L p .422 .768 .996 r
F P
0 g
s
.65379 .10332 m .65929 .10701 L .63857 .10951 L p .329 .776 .959 r
F P
0 g
s
.65379 .10332 m .65929 .10701 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.66708 .18488 m .67558 .18281 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.63055 .17194 m .67558 .18281 L .66014 .17441 L .289 .763 .934 r
F
.63857 .10951 m .63301 .10584 L .65379 .10332 L p .329 .776 .959 r
F P
0 g
s
.64834 .10262 m .65379 .10332 L .63301 .10584 L p .173 .709 .814 r
F P
0 g
s
.64834 .10262 m .65379 .10332 L p .67574 .1829 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67454 .18225 L .67574 .1829 L .995 .813 .449 r
F
.67454 .18225 m .64834 .10262 L .67574 .1829 L F
.62387 .16837 m .64846 .16805 L .61912 .16583 L .289 .763 .934 r
F
.64318 .10498 m .64834 .10262 L p .67454 .18225 L .995 .813 .449 r
F P
0 g
s
.67304 .18143 m .64318 .10498 L .67454 .18225 L .995 .813 .449 r
F
.65316 .13589 m .65506 .14271 L p .65506 .15364 L .996 .813 .454 r
F P
0 g
s
.65506 .14271 m .65666 .14847 L p .65506 .15364 L .996 .813 .454 r
F P
0 g
s
.63853 .11032 m .64318 .10498 L p .67304 .18143 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67106 .18035 L .67304 .18143 L .995 .813 .449 r
F
.67106 .18035 m .63853 .11032 L .67304 .18143 L F
.62293 .16107 m .61433 .16327 L p .63743 .16205 L .289 .763 .934 r
F P
0 g
s
.67106 .18035 m .63534 .11967 L .63853 .11032 L .995 .813 .449 r
F
.66826 .17883 m .63534 .11974 L .67106 .18035 L F
.63534 .11974 m .63462 .11843 L .63534 .11967 L F
.63534 .11974 m .63534 .11967 L .67106 .18035 L F
.61912 .16583 m .64007 .16348 L .61433 .16327 L .289 .763 .934 r
F
.64007 .16348 m .63743 .16205 L .61433 .16327 L F
.61912 .16583 m .64535 .16635 L .64007 .16348 L F
.64846 .16805 m .64535 .16635 L .61912 .16583 L F
.62462 .36823 m .59386 .36334 L .59386 .17886 L p .943 .77 .638 r
F P
0 g
s
.59386 .17886 m .62462 .18543 L .62462 .36823 L p .943 .77 .638 r
F P
0 g
s
.59274 .16878 m .59386 .17886 L .62462 .18543 L p .289 .763 .934 r
F P
0 g
s
.59386 .36334 m .59274 .35584 L .59274 .16878 L p .741 .605 .035 r
F P
0 g
s
.59274 .16878 m .59386 .17886 L .59386 .36334 L p .741 .605 .035 r
F P
0 g
s
.59274 .16878 m .59274 .35584 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.65506 .20039 m .61433 .18829 L .61433 .17596 L .996 .813 .454 r
F
.61433 .16327 m .59274 .16878 L p .61121 .20967 L .264 .216 .614 r
F P
0 g
s
.61433 .20688 m .61121 .20967 L .61433 .21658 L .264 .216 .614 r
F
.61433 .16327 m .61121 .20967 L .61433 .20688 L F
.61634 .21381 m .61263 .20101 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.62085 .22478 m .61634 .21381 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.61634 .21381 m .63733 .21161 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.61433 .20688 m .61634 .21381 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.65506 .20184 m .61433 .18843 L .65506 .20039 L .996 .813 .454 r
F
.61433 .18843 m .60989 .18697 L .61433 .18829 L F
.61433 .18843 m .61433 .18829 L .65506 .20039 L F
.60827 .17232 m .60784 .15774 L p .6604 .2036 L F P
0 g
s
.61263 .20101 m .60989 .18697 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.62293 .16107 m .61433 .16327 L p .61433 .20688 L .264 .216 .614 r
F P
0 g
s
.61493 .20635 m .61433 .20688 L .61433 .20977 L .264 .216 .614 r
F
.62293 .16107 m .61433 .20688 L .61493 .20635 L F
.63733 .21161 m .63534 .20466 L p .62205 .20001 L .509 .629 .905 r
F P
0 g
s
.62421 .19978 m .62205 .20001 L p .63534 .20466 L .509 .629 .905 r
F P
0 g
s
.63733 .21161 m .62205 .20001 L .61822 .20341 L .509 .629 .905 r
F
.62595 .23346 m .62085 .22478 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63141 .23947 m .62595 .23346 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.63699 .2426 m .63141 .23947 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.64243 .24273 m .63699 .2426 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.64751 .2399 m .64243 .24273 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65201 .23426 m .64751 .2399 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.65506 .23044 m .66287 .23084 L .65506 .23926 L .686 .56 .707 r
F
.65575 .22607 m .65201 .23426 L p .6604 .2036 L .996 .813 .454 r
F P
0 g
s
.6604 .2036 m .65859 .2157 L .65575 .22607 L p .996 .813 .454 r
F P
0 g
s
.66177 .22437 m .66246 .22842 L .65506 .2286 L .686 .56 .707 r
F
.65972 .22567 m .65575 .22607 L p .6779 .2142 L .455 .162 .378 r
F P
0 g
s
.65506 .18504 m .66708 .18488 L p .66349 .22412 L .686 .56 .707 r
F P
0 g
s
.65506 .18504 m .66349 .22412 L .66184 .22479 L .686 .56 .707 r
F
.67228 .22438 m .66834 .22306 L .66708 .22103 L .284 .232 .621 r
F
.65506 .3162 m .66357 .22324 L .66708 .36782 L .686 .56 .707 r
F
.66708 .22103 m .66708 .36782 L p .66357 .22324 L F P
0 g
s
.67906 .21358 m .67626 .22398 L .65972 .22567 L p .455 .162 .378 r
F P
0 g
s
.67906 .21358 m .65972 .22567 L .6779 .2142 L .455 .162 .378 r
F
.65506 .2286 m .66246 .22842 L .65506 .23044 L .686 .56 .707 r
F
.65506 .18504 m .66177 .22437 L .65506 .2286 L F
.66246 .22842 m .66287 .23084 L .65506 .23044 L F
.65506 .23926 m .66287 .23084 L .65506 .3162 L F
.64751 .2399 m .65201 .23426 L .67257 .23218 L p .272 0 0 r
F P
0 g
s
.62595 .23346 m .63141 .23947 L .65222 .23738 L p .394 .764 .993 r
F P
0 g
s
.65222 .23738 m .64683 .23134 L .62595 .23346 L p .394 .764 .993 r
F P
0 g
s
.62085 .22478 m .62595 .23346 L .64683 .23134 L p .456 .73 .986 r
F P
0 g
s
.64683 .23134 m .64178 .22262 L .62085 .22478 L p .456 .73 .986 r
F P
0 g
s
.61634 .21381 m .62085 .22478 L .64178 .22262 L p .49 .682 .951 r
F P
0 g
s
.64178 .22262 m .63733 .21161 L .61634 .21381 L p .49 .682 .951 r
F P
0 g
s
.63534 .2965 m .62657 .20082 L .62293 .3501 L .686 .56 .707 r
F
.62293 .16107 m .62293 .19889 L p .62657 .20082 L F P
0 g
s
.63534 .16091 m .62293 .16107 L p .63743 .16205 L .289 .763 .934 r
F P
0 g
s
.66014 .17441 m .65651 .17243 L .62387 .16837 L .289 .763 .934 r
F
.62387 .16837 m .65651 .17243 L .64846 .16805 L F
.64638 .1804 m .66708 .18488 L .63055 .17194 L F
.64243 .24273 m .64751 .2399 L .66812 .23783 L p .093 0 0 r
F P
0 g
s
.66812 .23783 m .6631 .24067 L .64243 .24273 L p .093 0 0 r
F P
0 g
s
.63141 .23947 m .63699 .2426 L .65773 .24052 L p .287 .759 .938 r
F P
0 g
s
.67257 .23218 m .66812 .23783 L .64751 .2399 L p .272 0 0 r
F P
0 g
s
.65773 .24052 m .65222 .23738 L .63141 .23947 L p .287 .759 .938 r
F P
0 g
s
.63534 .16091 m .62293 .16107 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63366 .19877 m .62602 .19498 L .62293 .19889 L .519 .573 .85 r
F
.62205 .20001 m .62421 .19978 L p .62293 .19889 L F P
0 g
s
.62657 .20082 m .62293 .19889 L .62421 .19978 L .686 .56 .707 r
F
.62421 .19978 m .63366 .19877 L p .62293 .19889 L .519 .573 .85 r
F P
0 g
s
.62293 .19889 m .62293 .19922 L p .62421 .19978 L .686 .56 .707 r
F P
0 g
s
.62293 .19922 m .62293 .3501 L p .62657 .20082 L .686 .56 .707 r
F P
0 g
s
.63534 .20466 m .63366 .19877 L .62421 .19978 L p .509 .629 .905 r
F P
0 g
s
.62293 .16107 m .61433 .20977 L .61564 .2081 L .264 .216 .614 r
F
.62293 .3501 m .62293 .16107 L p .61433 .21658 L F P
0 g
s
.62205 .20001 m .61263 .20101 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.60989 .18697 m .61263 .20101 L .62205 .20001 L p .519 .573 .85 r
F P
0 g
s
.62602 .19498 m .60989 .18697 L .62205 .20001 L .519 .573 .85 r
F
.61564 .2081 m .61433 .20977 L .61433 .21658 L .264 .216 .614 r
F
.61263 .20101 m .61433 .20688 L p .61822 .20341 L .509 .629 .905 r
F P
0 g
s
.60989 .18697 m .60827 .17232 L p .61433 .17596 L .996 .813 .454 r
F P
0 g
s
.61433 .18829 m .60989 .18697 L .61433 .17596 L .996 .813 .454 r
F
.63163 .12897 m .63462 .11843 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65506 .18504 m .66708 .18488 L p .64638 .1804 L .289 .763 .934 r
F P
0 g
s
.6297 .14147 m .63163 .12897 L p .67558 .19368 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .19526 L .67558 .19368 L .995 .813 .449 r
F
.67626 .22398 m .67558 .22549 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.66708 .18488 m .67558 .20052 L .67401 .2255 L .284 .232 .621 r
F
.66708 .18529 m .66708 .18488 L p .66716 .18539 L F P
0 g
s
.66716 .18539 m .67401 .2255 L .66708 .18529 L .284 .232 .621 r
F
.66708 .22103 m .66708 .18529 L p .67401 .2255 L F P
0 g
s
.66708 .18488 m .66708 .22103 L p .66357 .22324 L .686 .56 .707 r
F P
0 g
s
.67558 .19526 m .6297 .14147 L .67558 .19368 L .995 .813 .449 r
F
.67885 .2136 m .67906 .21358 L p .6779 .2142 L .455 .162 .378 r
F P
0 g
s
.67558 .20052 m .67558 .22652 L .67401 .2255 L .284 .232 .621 r
F
.63366 .19877 m .63096 .18468 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63733 .21161 m .63366 .19877 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64178 .22262 m .63733 .21161 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64683 .23134 m .64178 .22262 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.65201 .23426 m .65506 .22759 L p .67228 .22438 L .388 0 .176 r
F P
0 g
s
.65972 .22567 m .67228 .22438 L p .65506 .22759 L .388 0 .176 r
F P
0 g
s
.67257 .23218 m .65201 .23426 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.67396 .22495 m .65201 .23426 L .67228 .22438 L .388 0 .176 r
F
.65222 .23738 m .64683 .23134 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.66812 .23783 m .6631 .24067 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.67257 .23218 m .66812 .23783 L p .67558 .21651 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67558 .221 L .67558 .21651 L .995 .813 .449 r
F
.67401 .2255 m .67558 .22652 L .67558 .23471 L .284 .232 .621 r
F
.67558 .22549 m .67257 .23218 L p .67396 .22495 L .388 0 .176 r
F P
0 g
s
.67558 .221 m .67257 .23218 L .67558 .21651 L .995 .813 .449 r
F
.69736 .24057 m .69736 .36233 L p .67558 .23471 L .284 .232 .621 r
F P
0 g
s
.67558 .22652 m .69736 .24057 L .67558 .23471 L .284 .232 .621 r
F
.67626 .22398 m .67257 .23218 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .67906 .21358 L .67626 .22398 L p .995 .813 .449 r
F P
0 g
s
.67558 .20052 m .69736 .24057 L .67558 .22652 L .284 .232 .621 r
F
.62893 .15535 m .6297 .14147 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.64007 .16348 m .66684 .16049 L .63743 .16205 L .289 .763 .934 r
F
.66684 .16049 m .63534 .16091 L p .63743 .16205 L F P
0 g
s
.69769 .1674 m .66684 .16049 L p .64007 .16348 L .289 .763 .934 r
F P
0 g
s
.64535 .16635 m .69769 .1674 L .64007 .16348 L .289 .763 .934 r
F
.64846 .16805 m .69769 .1674 L .64535 .16635 L F
.66014 .17441 m .69736 .17751 L .65651 .17243 L F
.69736 .17751 m .69769 .1674 L p .64846 .16805 L F P
0 g
s
.65651 .17243 m .69736 .17751 L .64846 .16805 L .289 .763 .934 r
F
.67558 .18281 m .69736 .17751 L p .66014 .17441 L F P
0 g
s
.62936 .16998 m .62893 .15535 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63096 .18468 m .62936 .16998 L p .68085 .20144 L .995 .813 .449 r
F P
0 g
s
.63699 .2426 m .64243 .24273 L .6631 .24067 L p .116 .668 .763 r
F P
0 g
s
.6631 .24067 m .65773 .24052 L .63699 .2426 L p .116 .668 .763 r
F P
0 g
s
.66684 .16049 m .63534 .16091 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.6631 .24067 m .65773 .24052 L p .67558 .21035 L .995 .813 .449 r
F P
0 g
s
.67558 .21309 m .6631 .24067 L .67558 .21035 L .995 .813 .449 r
F
.65773 .24052 m .65222 .23738 L p .67558 .20805 L F P
0 g
s
.67558 .21035 m .65773 .24052 L .67558 .20805 L .995 .813 .449 r
F
.66684 .34966 m .66684 .16049 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.62293 .3501 m .63534 .34998 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63534 .34998 m .66684 .34966 L p .63534 .2965 L .686 .56 .707 r
F P
0 g
s
.63462 .11843 m .63534 .11692 L p .63534 .11967 L .995 .813 .449 r
F P
0 g
s
.63534 .11692 m .63853 .11032 L p .63534 .11967 L .995 .813 .449 r
F P
0 g
s
.68085 .20144 m .66826 .17883 L .67106 .18035 L .995 .813 .449 r
F
.68085 .20144 m .67304 .18143 L .67454 .18225 L F
.69736 .17751 m .69736 .24057 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.67558 .18281 m .69736 .17751 L p .67558 .20052 L .284 .232 .621 r
F P
0 g
s
.61433 .1634 m .60784 .15774 L .61433 .15049 L .996 .813 .454 r
F
.59274 .35584 m .61433 .35174 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.61433 .35174 m .62293 .3501 L p .61433 .21658 L .264 .216 .614 r
F P
0 g
s
.67558 .23471 m .69736 .36233 L .67558 .2607 L .284 .232 .621 r
F
.69736 .36233 m .67558 .36628 L p .67558 .2607 L F P
0 g
s
.67558 .36628 m .66708 .36782 L p .67558 .2607 L .284 .232 .621 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62462 .36823 m .66708 .36782 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.59274 .35584 m .59386 .36334 L .62462 .36823 L p .224 .73 .894 r
F P
0 g
s
.66708 .36782 m .69736 .36233 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.69769 .35481 m .69736 .36233 L .69736 .17751 L p 0 0 .01 r
F P
0 g
s
.69736 .36233 m .69769 .35481 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.66684 .34966 m .62293 .3501 L .59274 .35584 L p .224 .73 .894 r
F P
0 g
s
.69769 .35481 m .66684 .34966 L p .59274 .35584 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.69736 .17751 m .69769 .1674 L .69769 .35481 L p 0 0 .01 r
F P
0 g
s
.66684 .34966 m .69769 .35481 L .69769 .1674 L p .949 .775 .632 r
F P
0 g
s
.69769 .1674 m .66684 .16049 L .66684 .34966 L p .949 .775 .632 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.46069 1.3007 m .4408 1.27999 L .42079 1.30317 L p .854 .697 .687 r
F P
0 g
s
.42079 1.30317 m .4408 1.32387 L .46069 1.3007 L p .854 .697 .687 r
F P
0 g
s
.63567 1.3007 m .61632 1.27999 L .59685 1.30317 L p .857 .7 .686 r
F P
0 g
s
.59685 1.30317 m .61632 1.32387 L .63567 1.3007 L p .857 .7 .686 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.67916 1.07879 m .69598 1.07885 L .71558 .99731 L p .439 .19 .439 r
F P
0 g
s
.74046 1.07635 m .72375 1.08378 L .73912 1.08369 L closepath p .576 .915 .969 \
r
F P
0 g
s
.69598 1.07885 m .67916 1.07879 L .69488 1.08618 L closepath p .303 .677 .975 \
r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.34231 .10584 m .33561 .10515 L .35554 .10262 L p .183 .715 .821 r
F P
0 g
s
.63301 .10584 m .62749 .10515 L .64834 .10262 L p .173 .709 .814 r
F P
0 g
s
.33561 .10515 m .32926 .10751 L .34924 .10498 L p .013 0 0 r
F P
0 g
s
.34924 .10498 m .35554 .10262 L .33561 .10515 L p .013 0 0 r
F P
0 g
s
.62749 .10515 m .62226 .10751 L .64318 .10498 L p .035 0 0 r
F P
0 g
s
.64318 .10498 m .64834 .10262 L .62749 .10515 L p .035 0 0 r
F P
0 g
s
.32926 .10751 m .32355 .11284 L .34358 .11032 L p .203 0 0 r
F P
0 g
s
.34358 .11032 m .34924 .10498 L .32926 .10751 L p .203 0 0 r
F P
0 g
s
.62226 .10751 m .61755 .11284 L .63853 .11032 L p .228 0 0 r
F P
0 g
s
.63853 .11032 m .64318 .10498 L .62226 .10751 L p .228 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.32355 .11284 m .31874 .12093 L .33882 .11843 L p .339 0 .107 r
F P
0 g
s
.33882 .11843 m .34358 .11032 L .32355 .11284 L p .339 0 .107 r
F P
0 g
s
.61755 .11284 m .61359 .12093 L .63462 .11843 L p .36 0 .136 r
F P
0 g
s
.63462 .11843 m .63853 .11032 L .61755 .11284 L p .36 0 .136 r
F P
0 g
s
.31874 .12093 m .31507 .13144 L .33518 .12897 L p .42 .113 .336 r
F P
0 g
s
.33518 .12897 m .33882 .11843 L .31874 .12093 L p .42 .113 .336 r
F P
0 g
s
.61359 .12093 m .61057 .13144 L .63163 .12897 L p .436 .136 .356 r
F P
0 g
s
.63163 .12897 m .63462 .11843 L .61359 .12093 L p .436 .136 .356 r
F P
0 g
s
.31507 .13144 m .3127 .1439 L .33283 .14147 L p .467 .25 .501 r
F P
0 g
s
.33283 .14147 m .33518 .12897 L .31507 .13144 L p .467 .25 .501 r
F P
0 g
s
.61057 .13144 m .60862 .1439 L .6297 .14147 L p .479 .266 .512 r
F P
0 g
s
.6297 .14147 m .63163 .12897 L .61057 .13144 L p .479 .266 .512 r
F P
0 g
s
.31228 .17232 m .31425 .18697 L .33437 .18468 L p .512 .509 .79 r
F P
0 g
s
.33766 .19877 m .33437 .18468 L .31425 .18697 L p .51 .572 .854 r
F P
0 g
s
.60827 .17232 m .60989 .18697 L .63096 .18468 L p .521 .513 .788 r
F P
0 g
s
.63366 .19877 m .63096 .18468 L .60989 .18697 L p .519 .573 .85 r
F P
0 g
s
.3127 .1439 m .31176 .15774 L .3319 .15535 L p .493 .355 .621 r
F P
0 g
s
.3319 .15535 m .33283 .14147 L .3127 .1439 L p .493 .355 .621 r
F P
0 g
s
.60862 .1439 m .60784 .15774 L .62893 .15535 L p .503 .366 .626 r
F P
0 g
s
.62893 .15535 m .6297 .14147 L .60862 .1439 L p .503 .366 .626 r
F P
0 g
s
.31176 .15774 m .31228 .17232 L .33242 .16998 L p .507 .439 .714 r
F P
0 g
s
.33437 .18468 m .33242 .16998 L .31228 .17232 L p .512 .509 .79 r
F P
0 g
s
.60784 .15774 m .60827 .17232 L .62936 .16998 L p .516 .445 .715 r
F P
0 g
s
.63096 .18468 m .62936 .16998 L .60827 .17232 L p .521 .513 .788 r
F P
0 g
s
.33242 .16998 m .3319 .15535 L .31176 .15774 L p .507 .439 .714 r
F P
0 g
s
.62936 .16998 m .62893 .15535 L .60784 .15774 L p .516 .445 .715 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00h03oool800000;<0oooo2000003M0?oo
o`00fP3oool8000000H0om1o0P00002[0?ooo`P000001P3nd7800`000000oooo0?ooo`3J0?ooo`00
e@3oool700000080<`0000<000000?o@O`3od7l02@3od7l200000:@0oooo2000000203X000030000
003nd780o]1b00L0o]1b00<000000?ooo`3oool0f@3oool00=80oooo1000000703<000030000003o
d7l0om1o00`0om1o00<000000?ooo`3oool0W`3oool4000000L0>P0000<000000?k@LP3nd7802@3n
d7800`000000oooo0?ooo`3H0?ooo`00d@3oool00`000000<`0003<0000803<000030000003od7l0
om1o00h0om1o00<000000?ooo`3oool0W@3oool00`000000>P0003X0000903X000030000003nd780
o]1b00X0o]1b00<000000?ooo`3oool0e`3oool00=00oooo00<0000003<0000c00000`0c00060000
0180om1o00<000000?ooo`3oool0V`3oool00`000000>P0003X0000303X000L000003P3nd7800`00
0000oooo0?ooo`3F0?ooo`00c`3oool7000000@0EP0K00<000000?o@O`3od7l04P3od7l00`000000
oooo0?ooo`2I0?ooo`L000001P1L02800`000000o]1b0?k@LP0=0?k@LP030000003oool0oooo0=D0
oooo003>0?ooo`030000001F01/0EP0K00T0EP0K00<000000?o@O`3od7l04`3od7l00`000000oooo
0?ooo`2G0?ooo`030000001L0280G00R00X0G00R00<000000?k@LP3nd7803`3nd7800`000000oooo
0?ooo`3D0?ooo`00cP3oool00`000000EP0K05H06`0805H06`030000003od7l0om1o01D0om1oV@3o
ool00`000000G00R05`08P0:05`08P030000003nd780o]1b0100o]1beP3oool00<d0oooo00<00000
05H06`1F01/02@1F01/00`000000om1o0?o@O`0E0?o@O`030000003oool0oooo09D0oooo00<00000
05`08P1L02802P1L02800`000000o]1b0?k@LP0A0?k@LP030000003oool0oooo0=<0oooo003<0?oo
o`030000001F01/0EP0K00H0EP0K1000000H0?o@O`030000003oool0oooo09D0oooo00<0000005`0
8P1L02801`1L0284000001<0o]1b00<000000?ooo`3oool0d`3oool00<`0oooo00<0000005H06`1F
01/01P00000306/LEP030000003od7l0om1o01L0om1o00<000000?ooo`3oool0T`3oool010000000
G00R05`08P1L0287000000<0Kb9K00<000000?k@LP3nd7804P3nd7800`000000oooo0?ooo`3B0?oo
o`00b`3oool4000000P0JaaF00<000000?o@O`3od7l0603od7l00`000000oooo0?ooo`2C0?ooo`@0
00002@1_8U/00`000000o]1b0?k@LP0C0?k@LP030000003oool0oooo0=80oooo003;0?ooo`030000
001[75H0JaaF00T0JaaF00<000000?o@O`3od7l06@3od7l00`000000oooo0?ooo`2B0?ooo`030000
001_8U/0Kb9K00X0Kb9K00<000000?k@LP3nd780503nd7800`000000oooo0?ooo`3A0?ooo`00bP3o
ool00`000000JaaF06/LEP0:06/LEP050000003od7l0om1o0?o@O`3od840603od7l00`000000oooo
0?ooo`2@0?ooo`030000001_8U/0Kb9K00/0Kb9K00<000000?k@LP3nd7805@3nd7;C0?ooo`00bP3o
ool00`000000JaaF06/LEP0:06/LEP030000003od7l0om1o01X0om1o00<000000?ooo`3oool0T03o
ool00`000000Kb9K06lRF`0;06lRF`030000003nd780o]1b01D0o]1b00<000000?ooo`3oool0d03o
ool00<X0oooo00<0000006/LEP1[75H02@1[75H00`000000om1o0?o@O`0L0?o@O`030000003oool0
oooo08l0oooo00<0000006lRF`1_8U/02P1_8U/00`000000o]1b0?k@LP0F0?k@LP030000003oool0
oooo0=00oooo00390?ooo`030000001[75H0JaaF00@0JaaF1`0000060?o@O`030?o@P@3od7l0om1o
01D0om1o00<000000?ooo`3oool0SP3oool00`000000Kb9K06lRF`0506lRF`L000006@3nd7800`00
0000oooo0?ooo`3?0?ooo`00b@3oool7000000H0Mcn000<000000?o@O`3od7l07@3od7l00`000000
oooo0?ooo`2=0?ooo`P000001P1jA8<00`000000o]1b0?k@LP0G0?k@LP030000003oool0oooo0<l0
oooo00390?ooo`030000001g?h00Mcn000T0Mcn000<000000?o@O`3od7l07P3od7l00`000000oooo
0?ooo`2=0?ooo`030000001jA8<0NTB300X0NTB300<000000?k@LP3nd7806@3nd7800`000000oooo
0?ooo`3>0?ooo`00b@3oool00`000000Mcn007LoP00907LoP0030000003od7l0om1o00L0om1o00<0
om210?o@O`3od7l05@3od7l00`000000oooo0?ooo`2<0?ooo`030000001jA8<0NTB300X0NTB300<0
00000?k@LP3nd7804`3nd7800`000000o]1b0?k@LP030?k@LP030000003oool0oooo0<h0oooo0039
0?ooo`030000001g?h00Mcn000T0Mcn000<000000?o@O`3od7l0803od7n>0?ooo`030000001jA8<0
NTB300X0NTB300<000000?k@LP3nd7806P3nd7;@0?ooo`00b03oool00`000000Mcn007LoP00:07Lo
P0030000003od7l0om1o0200om1oS@3oool00`000000NTB307Y4P`0;07Y4P`030000003nd780o]1b
01X0o]1bd03oool00<P0oooo00<0000007LoP01g?h002@1g?h000`000000om1o0?o@O`0:0?o@O`03
0?o@P@3od7l0om1o01@0om1o00<000000?ooo`3oool0RP3oool00`000000NTB307Y4P`0:07Y4P`03
0000003nd780o]1b01/0o]1b00<000000?ooo`3oool0c@3oool00<P0oooo00<0000007LoP01g?h00
2@1g?h000`000000om1o0?o@O`0Q0?o@O`030000003oool0oooo08X0oooo00<0000007Y4P`1jA8<0
2P1jA8<00`000000o]1b0?k@LP0E0?k@LP0308FQiP3nd780o]1b00<0o]1b00<000000?ooo`3oool0
c@3oool00<P0oooo00<0000007LoP01g?h00101g?h06000002<0om1o00<000000?ooo`3oool0RP3o
ool00`000000NTB307Y4P`0407Y4P`L000007@3nd7800`000000oooo0?ooo`3=0?ooo`00b03oool7
000000D0OUZN00<000000?o@O`3od7l08@3od7l00`000000oooo0?ooo`2:0?ooo`L000001P20GJ00
0`000000o]1b0?k@LP0K0?k@LP030000003oool0oooo0<d0oooo00380?ooo`030000001nFYh0OUZN
00T0OUZN00<000000?o@O`3od7l08P3od7l00`000000oooo0?ooo`290?ooo`0300000020GJ00P5fP
00X0P5fP00<000000?k@LP3nd780703nd7800`000000oooo0?ooo`3<0?ooo`00b03oool00`000000
OUZN07iJWP0907iJWP030000003od7l0om1o0280om1o00<000000?ooo`3oool0R@3oool00`000000
P5fP081MX00:081MX0030000003nd780o]1b01H0o]1b00<000000?k@LP3nd7800`3nd7800`000000
oooo0?ooo`3<0?ooo`00b03oool00`000000OUZN07iJWP0907iJWP030000003od7l0om1o02<0om1o
R`3oool00`000000P5fP081MX00:081MX0030000003nd780o]1b01d0o]1bcP3oool00<P0oooo00<0
000007iJWP1nFYh02@1nFYh00`000000om1o0?o@O`0S0?o@Oh/0oooo00<00000081MX020GJ002P20
GJ000`000000o]1b0?k@LP0M0?k@L/h0oooo00370?ooo`030000001nFYh0OUZN00X0OUZN00<00000
0?o@O`3od7l08`3od7l00`000000oooo0?ooo`270?ooo`0300000020GJ00P5fP00/0P5fP00<00000
0?k@LP3nd7807@3nd7;>0?ooo`00a`3oool00`000000OUZN07iJWP0:07iJWP030000003od7l0om1o
02<0om1o00<000000?ooo`3oool0Q`3oool00`000000P5fP081MX00;081MX0030000003nd780o]1b
01L0o]1b00<0Qi?H0?k@LP3nd7800`3nd7;>0?ooo`00a`3oool00`000000OUZN07iJWP0:07iJWP03
0000003od7l0om1o0140om1o00<0om210?o@O`3od7l03`3od7l00`000000oooo0?ooo`270?ooo`03
00000020GJ00P5fP00/0P5fP00<000000?k@LP3nd780103nd7800`3nd7@0o]1b0?k@LP0@0?k@LP03
08NCf03nd780o]1b00<0o]1b00<000000?ooo`3oool0b`3oool00<L0oooo00<0000007iJWP1nFYh0
101nFYh7000002D0om1o00<000000?ooo`3oool0Q`3oool00`000000P5fP081MX005081MX0L00000
7`3nd7800`000000oooo0?ooo`3;0?ooo`00a`3oool7000000H0PG2f00<000000?o@O`3od7l0903o
d7l00`000000oooo0?ooo`260?ooo`P000001P24LKL00`000000o]1b0?k@LP0M0?k@LP030000003o
ool0oooo0</0oooo00370?ooo`0300000021L;H0PG2f00X0PG2f00<000000?o@O`3od7l04`3od7l0
0`3od840om1o0?o@O`0>0?o@O`030000003oool0oooo08H0oooo00<0000008Aa]`24LKL02`24LKL0
0`000000o]1b0?k@LP0H0?k@LP0308NCf03nd780o]1b0080o]1b00<000000?ooo`3oool0b`3oool0
0<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@OaL000002P3od7l20000
08P0oooo00<0000008Aa]`24LKL02`24LKL010000000o]1b0?k@LP3nd78H000000@0o]1b00<00000
0?ooo`3oool0b`3oool00<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@01@0000050?o@O`0308F3b@3od7l0oooo08L0oooo00<0000008Aa
]`24LKL02`24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00D0000000<0o]1b
0?ooo`3oool0b`3oool00<L0oooo00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@01@3`a:@6000000030?o@O`3oool0oooo08H0oooo00<0000008Aa
]`24LKL02`24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00D0l/JQ1@000039
0?ooo`00a`3oool00`000000PG2f085`]P0:085`]P030000003od7l0om1o0080om1o502_Sk@00`00
0000l<BT0?34Y00;0?34Y0D00000P`3oool2000000d0Q76g00@000000?k@LP3nd780o]1b502_Sk@0
0`000000l/JQ0?;6X@0:0?;6X@D00000a03oool00<<0oooo1@00000<085`]P030000003od7l0om1o
0080om1o502_Sk@00`000000l<BT0?34Y00@0?34Y0<00000N`3oool500000080@cNM00<0000008Aa
]`24LKL02P24LKL010000000o]1b0?k@LP3nd78D0:n?]0030000003baZ40l/JQ00l0l/JQ0`000031
0?ooo`00`03oool3000000@0=bfH00<00000085`]P21L;H02P21L;H00`000000om1o0?o@O`020?o@
Oa@0[hnd00<000000?34Y03`a:@04P3`a:@00`000000oooo0?ooo`1f0?ooo`<000001`13=id00`00
0000Q76g08Aa]`0:08Aa]`040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ404@3baZ40
0`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00403L]V00300000021L;H0PG2f
00L0PG2f100000040?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@2000007L0oooo00<0000004<g
W@13=id01`13=id00`000000Q76g08Aa]`0708Aa]`@000000`3nd78D0:n?]0030000003baZ40l/JQ
0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0100g;IP010000000
PG2f085`]P21L;H6000000<0Ph;:00<000000?o@O`3od7l00P3od7lD0:n?]0030000003`a:@0l<BT
0180l<BT0P00001g0?ooo`0300000013=id0@cNM00L0@cNM00@0000008Aa]`24LKL0Q76g1P000003
08F3b@040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?oo
o`2o0?ooo`00`03oool2000000D0=bfH1000000908>2bP030000003od7l0om1o0080om1o502_Sk@0
0`000000l<BT0?34Y00B0?34Y0030000003@ZAd0000007H0oooo00<0000004<gW@13=id01`13=id4
000000T0QH?900@000000?k@LP3nd780o]1b502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003o
ool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00@0=bfH00<0000008>2bP23P/X02P23P/X0
0`000000om1o0?o@O`020?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@00`000000d:TM0000001f
0?ooo`0300000013=id0@cNM00L0@cNM00<0000008F3b@25PlT02P25PlT010000000o]1b0?k@LP3n
d78D0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<00000
03L]V00g;IP0100g;IP00`000000Ph;:08>2bP0:08>2bP030000003od7l0om1o0080om1o502_Sk@0
0`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id01`13
=id00`000000QH?908F3b@0:08F3b@040000003nd780o]1b0?k@LQ@0[hnd00<000000?;6X@3baZ40
4@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00503L]V00300000023
P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id01`13=id00`000000QH?908F3b@0;08F3b@03
0000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00503L]V00300000023P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0
om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<g
W@13=id01`13=id00`000000QH?908F3b@0;08F3b@030000003nd780o]1b01@0[hnd00<000000?;6
X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00503L]V003
00000023P/X0Ph;:00X0Ph;:00@000000?o@O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34
Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02013=id00`000000QH?908F3b@0:
08F3b@030000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00503L]V00300000023P/X0Ph;:00X0Ph;:00@000000?o@
O`3od7l0om1o502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0
000004<gW@13=id02013=id00`000000QH?908F3b@0:08F3b@030000003nd780o]1b01@0[hnd00<0
00000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V006
03L]V00300000023P/X0Ph;:00L0Ph;:0`0000030?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@0
10000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM00P0@cNM00<0000008F3b@25PlT01`25
PlT400000080o]1b502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo0030
0?ooo`030000000g;IP0=bfH00H0=bfH00@0000008>2bP23P/X0Ph;:1P00000208:BfP040000003o
d7l0om1o0?o@Oa@0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`03
00000013=id0@cNM0080@cNM00<0lLFS04<gW@13=id00`13=id010000000QH?908F3b@25PlT60000
00<0Q9;I00<000000?k@LP3nd780502_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo
0;l0oooo00300?ooo`030000000g;IP0=bfH00H0=bfH1000000908:BfP030000003od7l0om1o01@0
[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM
00P0@cNM1000000908BBf@030000003nd780o]1b01@0[hnd00<000000?;6X@3baZ404@3baZ400`00
0000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00603L]V00300000022T]X0om2100X0
PY;J00<000000?o@O`3od7l0502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM0000
07D0oooo00<0000004<gW@13=id02013=id00`000000Q9;I0?k@M00;08BBf@030000003nd780[hnd
01<0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000
=bfH03L]V00603L]V00500000022T]X0PY;J08:BfP0g;IP02022T]X00`000000om1o0?o@O`0D0:n?
]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@08
04<gW@0500000024T]T0Q9;I08BBf@13=id02@24T]T00`000000o]1b0:n?]00C0:n?]0030000003b
aZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP01`0g;IP0
0`000000PY;J08:BfP0208:BfP0303L]V022T]X0PY;J00D0PY;J00<000000?o@O`2_Sk@04`2_Sk@0
0`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02@13
=id00`000000Q9;I08BBf@0208BBf@0304<gW@24T]T0Q9;I00D0Q9;I00<000000?k@LP2_Sk@04`2_
Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0
=bfH00L0=bfH00<0000008:BfP22T]X01022T]X00`000000PY;J08:BfP0308:BfP030000003od7l0
[hnd01<0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013
=id0@cNM00T0@cNM00<0000008BBf@24T]T01024T]T00`000000Q9;I08BBf@0308BBf@030000003n
d780[hnd01<0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool0
0`000000=bfH03L]V00703L]V00300000022T]X0PY;J00H0PY;J00H0om2108:BfP22T]X0PY;J0000
003od7lD0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000
@cNM04<gW@0904<gW@0300000024T]T0Q9;I00H0Q9;I00<0o]1d08BBf@24T]T00P24T]T00`000000
[hnd0:n?]00B0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo
00<0000003L]V00g;IP01`0g;IP00`000000PY;J08:BfP0508:BfP030:n?]022T]X0PY;J00<0PY;J
00<000000:n?]02_Sk@04P2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0
oooo00<0000004<gW@13=id02@13=id00`000000Q9;I08BBf@0;08BBf@030000002_Sk@0[hnd0180
[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH
03L]V00803L]V00300000022T]X0PY;J00<0PY;J00<0000008:BfP22T]X00P22T]X3000001@0[hnd
00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM00X0
@cNM00<0000008BBf@24T]T02024T]T3000001@0[hnd00<000000?;6X@3baZ404@3baZ400`000000
oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00803L]V00300000022T]X0PY;J00P00000
0P20XNP00`000000[hnd0:n?]00B0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
0000M@3oool00`000000@cNM04<gW@0:04<gW@0400000024T]T0Q9;I08BBf@L000000P22XNL00`00
0000[hnd0:n?]00B0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00
oooo00<0000003L]V00g;IP0200g;IP300000007082Qj00g;IP0=bfH0000002_Sk@0P:7X0:n?]003
082Qj0030000002_Sk@0[hnd0180[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00
001e0?ooo`0300000013=id0@cNM00X0@cNM100000001P22XNL0@cNM0000002_Sk@0PZ7W0:n?]0<0
PZ7W00<000000:n?]02_Sk@04P2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0
oooo00300?ooo`030000000g;IP0=bfH00P0=bfH00<00000082Qj020XNP00`0g;IP00`000000[hnd
0:n?]0030:n?]080P:7X502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0
oooo00<0000004<gW@13=id01`13=id0103aaJ<0@cNM04<gW@00000208:Qi`<0@cNM00<000000:n?
]02_Sk@00`2_Sk@208:Qia@0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?oo
o`00`03oool00`000000=bfH03L]V00803L]V00300000020XNP0P:7X00<0=bfH00<000000:n?]02_
Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<g
W@13=id02P13=id00`000000PZ7W08:Qi`0304<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6
X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00903L]V003
0000000g;IP0=bfH0080=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y004
0000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id02013=id0103aaJ<0@cNM04<gW@000004
04<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00903L]V0030000000g;IP0=bfH0080=bfH00<000000:n?
]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<00000
04<gW@13=id02`13=id00`000000@cNM04<gW@0204<gW@030000002_Sk@0[hnd01T0[hnd00<00000
0?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]
V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e
0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A
0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?
]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<00000
04<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<00000
0?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP010000000[hnd0:n?]020XNPH
0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<g
W@0@04<gW@040000002_Sk@0[hnd000001P0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo
0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0040000002_Sk@0[hnd000001P0[hnd
00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100
@cNM00@000000:n?]02_Sk@0OJkc602_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo
0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00@000000:n?]02_Sk@0Njkd602_Sk@00`00
0000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id04013=id0
10000000[hnd0:n?]01m[_<H0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3o
ool00<00oooo00<0000003L]V00g;IP03P0g;IP010000000[hnd0:n?]01k[_@H0:n?]0030000003`
a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@040000
002_Sk@0[hnd07f^laP0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@0
4P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM000007D0oooo00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
0000M@3oool00`000000@cNM04<gW@0@04<gW@030000002_Sk@0[hnd01T0[hnd00<000000?;6X@3b
aZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000
002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@00001e0?ooo`03
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM000007D0oooo00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@03
0000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@0
4P3`a:@010000000d:TM0=2Y7@00001e0?ooo`0300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00D000000:n?]02_Sk@0[hnd07:jo00G0:n?]0030000003`a:@0l<BT0180
l<BT00@000000=2Y7@3@ZAd00000M@3oool00`000000@cNM04<gW@0@04<gW@050000002_Sk@0[hnd
0:n?]01d^_`05`2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?oo
o`030000000g;IP0=bfH00h0=bfH00D000000:n?]02_Sk@0[hnd07:jo00G0:n?]0030000003`a:@0
l<BT0180l<BT00<000000=2Y7@3@ZAd01000001`0?ooo`<000004P13=id01@000000[hnd0:n?]02_
Sk@0M;[l01L0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool0
0`000000=bfH03L]V00>03L]V0050000002_Sk@0[hnd0:n?]01b^_`05`2_Sk@00`000000l<BT0?34
Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000?ooo`3oool0J`3oool300000080C3jP
00<0000004<gW@13=id04013=id01@000000[hnd0:n?]02_Sk@0M;[l01L0[hnd00<000000?;6X@3b
aZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000
002_Sk@0[hnd01T0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@0000020>g1YP80
0000K03oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V0P00001/0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]0020:n?]0030>k2
Y@2_Sk@0[hnd01@0[hnd00<000000?34Y03`a:@04P3`a:@010000000d:TM0=2Y7@0000020>g1YP03
0000003AZal0000006/0oooo00<0000004`nX01<?Z000P1<?Z000`000000@cNM04<gW@0@04<gW@03
0000002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00
`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd0080[hnd00<0k/:U0:n?]02_Sk@0
502_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
0000J`3oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000
003@ZAd0d:TM00000080kL6V00<000000=6[7`000000J`3oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
0`2_Sk@00`3^`ZD0[hnd0:n?]00C0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000001[0?ooo`030000001<?Z00C3jP0080C3jP00<0000004<gW@13
=id04013=id00`000000[hnd0:n?]00I0:n?]0030000003baZ40l/JQ0140l/JQ00<000000?ooo`3o
ool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?]00I0:n?]0030000
003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd000000P3]`JH00`000000dJ/O0000001[0?ooo`03
0000001<?Z00C3jP0080C3jP00<0000004<gW@13=id04013=id00`000000[hnd0:n?]00I0:n?]003
0000003baZ40l/JQ0140l/JQ00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP0
3P0g;IP00`000000[hnd0:n?]00I0:n?]0030000003`a:@0l<BT0180l<BT00@000000=2Y7@3@ZAd0
00000P3]`JH00`000000dJ/O0000000G0?oooc`00000603oool00`000000C3jP04`nX00204`nX003
00000013=id0@cNM0100@cNM00<000000:n?]02_Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@03
0000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@0
6@2_Sk@00`000000l<BT0?34Y00B0?34Y0040000003@ZAd0d:TM00000080kL6V00<000000=6[7`00
00000`3ooolD000000T0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@0
0000103oool00`000000C3jP04`nX00204`nX00300000013=id0@cNM0100@cNM00<000000:n?]02_
Sk@06@2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000
000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@06@2_Sk@00`000000l<BT0?34Y00=0?34Y1400000
7@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0b:Bc01/0b:Bc4@00000;04<gW@030000
002_Sk@0[hnd01T0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o0?ooo`00`03o
ool00`000000=bfH03L]V00>03L]V0030000002_Sk@0[hnd01T0[hnd00@000000?34Y03`a:@0l<BT
3000000608A/[`030000002NPK<0WX6c02D0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc
0<RT/`0U0<RT/`030000003K/Zl0fk:_00@0fk:_3000000K0:n?]0030000003baZ40l/JQ0140l/JQ
00<000000?ooo`3oool0_`3oool00<00oooo00<0000003L]V00g;IP03P0g;IP00`000000[hnd0:n?
]00A0:n?]0`000004P24K:l00`000000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b
[`0@0=^b[``000003`2_Sk@00`000000l/JQ0?;6X@0A0?;6X@030000003oool0oooo0;l0oooo0030
0?ooo`030000000g;IP0=bfH00h0=bfH00<000000:n?]02_Sk@01`2_Sk@:000001P0Q6b_6`00001@
03Rji1D000007P3K/Zl:000000D0[hnd00<000000?;6X@3baZ404@3baZ400`000000oooo0?ooo`2o
0?ooo`00`03oool00`000000=bfH03L]V00>03L]V0030000002_Sk@0000000L000000`1SD:L00`00
0000Q6b_08A/[`0@08A/[``00000QP0h^^@<00000180fk:_00@000000>c0Y`3/`:L0k<2W2000000A
0?;6X@030000003oool0oooo0;l0oooo00300?ooo`030000000g;IP0=bfH00P0=bfH2000000;06=@
Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`000001P3K/Zl00`000000k<2W0>c0Y`090>c0
Y`P000002@3baZ400`000000oooo0?ooo`2o0?ooo`00`03oool00`000000=bfH03L]V00800000100
He2W2P00002f03Rji0L000004`3/`:L8000000030?;6X@000000oooo0<00oooo002m0?ooo`H00000
401SD:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001S
D:L0He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c
0?ooo`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<00000
0?[<V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<
V0D00000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0
oooo002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3o
ool2000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003o
d7`0000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o
03Rji1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool30000
00H0001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l
00D0om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<0
0000V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo
002F0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3
000000H0001l0`00003P03Rji0030000000h^^@0>;[T05d0>;[T0P0000070?o@O0<00000U03oool0
09<0oooo00@000000000B`0004/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@00000
0?34B`3`a4/00000T`3oool00940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;
03Rji0<0000000<0om1l0000003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;
00<0001;0P00003o03Rji540>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`80
0000100004/200000?l0>;[TE@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;
0000B`030000B`030000000h^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000
003oool0oooo08/0oooo002=0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji0800000
0`3`a4/00`000000oooo0?ooo`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T
00@000000?34B`3`a4/00000S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03o
ool200000?l0>;[TI@0h^^@2000008`0oooo002<0?ooo`8000007@0h^^@403Vji900>;[T00<00000
03Rji00h^^@0/00h^^@2000008`0oooo002<0?ooo`800000>`0h^^@703Vji6H0>;[T2@2<L[400`00
0000eZna0=J_/@0=0=J_/J<0>;[T0P00002<0?ooo`00S03oool00`000000>;[T03Rji01G03Rji0`0
>K[T>P0h^^@00`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h
^^@0W00h^^@2000008`0oooo002<0?ooo`030000000h^^@0>;[T07D0>;[T3`0i^^@G03Rji080001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<0000003Rji00h^^@0U@0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T03Rj
i02B03Rji0<0>K[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg400`3ncg4@03Rji0L0>K[TP`0h^^@00`000000oooo0?oo
o`2:0?ooo`00S03oool00`000000>;[T03Rji02E03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@07P0h^^@803Vji6l0>;[T00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rj
i00h^^@0U00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T0300>;[T2@0i^^AK03Rj
i0030000003oool0oooo08/0oooo002>0?ooo`800000U00h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000000h^^@0>;[T00d0>;[T400i^^@V03Rji0L0>K[TB00h^^@2000008h0oooo002@0?ooo`030000
000h^^@0>;[T0940>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[T
7@0h^^@503Vji3H0>;[T00<000000?ooo`3oool0SP3oool00940oooo00<0000003Rji00h^^@0T00h
^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04d0>;[T200i^^@C03Rji0@0>K[T900h
^^@00`000000oooo0?ooo`2?0?ooo`00TP3oool200000900>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji01]03Rji0@0>K[T2P0h^^@203Vji140>;[T0P00002B0?ooo`00U03oool00`00
0000>;[T03Rji02=03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0S@0h^^@00`00
0000oooo0?ooo`2B0?ooo`00UP3oool2000008`0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000
>;[T03Rji02:03Rji0800000UP3oool009P0oooo0P00002:03Rji003000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma
00<0000003Rji00h^^@0R00h^^@2000009P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?
L@060?k?L@030000000h^^@0>;[T08D0>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000>;[T03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rj
i003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@0
0000O`0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00
Y@3oool5000007X0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000
Y@3oool00:X0oooo1@00001e03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0L`0h
^^@500000:X0oooo002_0?ooo`D00000L00h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T06h0>;[T1@00002_0?ooo`00]03oool5000006/0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji01Y03Rji0D00000]03oool00;T0oooo1@00001V03Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0I00h^^@500000;T0oooo002n0?ooo`D00000H@0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T05l0>;[T1@00002n0?ooo`00``3oool5000005`0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00l0eZna00<0
SG>a0=J_/@0000001`3ncg400`000000>;[T03Rji01J03Rji0D00000``3oool00<P0oooo1@00001G
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0?
0=J_/@0308ec/@3F[k40000000L0o/ma00<0000003Rji00h^^@0E@0h^^@500000<P0oooo003=0?oo
o`L00000D00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k403`3F[k400`2=Lk40eZna000000070?k?L@030000000h^^@0>;[T04h0>;[T1`00003=0?oo
o`00e03oool:000004H0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01403Rji0X0
0000e03oool00=h0oooo2P00000l03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
>P0h^^@:00000=h0oooo003X0?ooo`d00000;`0h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T02d0>;[T3@00003X0?ooo`00m@3oool@000001l0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji00M03Rji1000000m@3oool00?l0oooo1P3ooolI000000H0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji00403Rji1T00000o`3oool60?ooo`00o`3ooolO0?ooo`L0
00001`0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg4700000?l0oooo7`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k403P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k403P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k403P3F[k40102=Lk40eZna0=J_/@0000070?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403@3F[k401@2=
Lk40eZna0=J_/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_
/@0508ec/@3F[k40eZna0=J_/@0000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
00d0eZna00D0SG>a0=J_/@3F[k40eZna000000070?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40303F[k400`2=Lk40eZna0=J_/@020=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0<0=J_/@03
08ec/@3F[k40eZna0080eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna00`0eZna00<0SG>a0=J_/@3F[k400P3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k402`3F
[k400`2=Lk40eZna0=J_/@030=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0;0=J_/@0308ec/@3F[k40eZna00<0eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
00X0eZna00<0SG>a0=J_/@3F[k40103F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k402P3F[k400`2=Lk40eZna0=J_/@040=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0:0=J_/@0308ec/@3F[k40eZna00@0eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna00T0eZna00<0SG>a0=J_/@3F[k401@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k402@3F[k400`2=Lk40eZna0=J_/@05
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@080=J_/@0308ec/@3F[k40eZna00H0eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00P0eZna00<0SG>a0=J_/@3F[k40
1P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k401`3F[k400`2=Lk40eZna0=J_/@070=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@070=J_/@0308ec/@3F[k40
eZna00L0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna00H0eZna00<0SG>a0=J_/@3F[k40203F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k401P3F[k400`2=Lk40eZna
0=J_/@080=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@050=J_/@0308ec/@3F[k40eZna00T0eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna00@0eZna00<0SG>a0=J_/@3F[k402P3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00<<0oooo0`00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/03oool200000140oooo00<0000007YIX01jFJ001@00001I0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool30000000307]^^P000000000000l0
oooo00<0000007YIX01jFJ001P1jFJ03000005H0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`@000001@1kK[X00`000000oooo0?ooo`0=0?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E03oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:L0oooo0P00000907]^^P8000003P3oool00`000000NUVP07YI
X00707YIX0800000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:L0oooo00<0000007]^^P1kK[X0201kK[X2000000h0oooo00<0000007YIX01jFJ001`1jFJ02
000005H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna00<0eZna00<0SG>a0=J_/@3F[k402`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X01`1kK[X2000000d0oooo00<0000007YI
X01jFJ00201jFJ000`000000oooo0?ooo`1E0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0807]^^P030<1i003oool0oooo00/0
oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1E0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0807]^^P030<1i
00000000oooo00/0oooo00<0000007YIX01jFJ001`1jFJ02000005L0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj0P00
000<0?ooo`030000001jFJ00NUVP00L0NUVP0P00001G0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^^P0707]^^P8000002`3oool0
0`000000NUVP07YIX00807YIX0030000003oool0oooo05H0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?oo
o`3oool02@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05H0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00P0
Nfjj00<0`7T00000003oool02@3oool00`000000NUVP07YIX00707YIX0800000F03oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^
^P0707]^^P030<1i00000000oooo00P0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?oo
o`1G0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00ZP3oool0
0`000000Nfjj07]^^P0707]^^P8000002@3oool00`000000NUVP07YIX00807YIX0030000003oool0
oooo05L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?oo
o`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX00707YI
X0800000F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0
oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0
NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool00`000000NUVP07YIX00707YIX0030=fn
^P000000oooo05T0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0080eZna00<0SG>a0=J_/@3F[k40303F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X01`1kK[X2000000L0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1H0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000
oooo00D0oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000
003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0
oooo00<0000007YIX01jFJ00201jFJ02000005X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000
001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0F@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X0201kK[X2000000@0oooo00<0
000007YIX01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002/0?ooo`8000002@1kK[X00`30N@0000000?ooo`030?ooo`030000001jFJ00
NUVP00L0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YI
X0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0
oooo00<0000007]^^P1kK[X01`1kK[X2000000<0oooo00<0000007YIX01jFJ00201jFJ000`000000
oooo0?ooo`1J0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[@3oool00`000000Nfjj07]^^P0807]^^P8000000P3oool00`000000NUVP07YIX00707YIX0800000
G03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:d0oooo0P00
000907]^^P050<1i00000000oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00
00000`3oool0000007YIX00907YIX0800000G03oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X4000000P0NUVP00<0gKjj
000000000000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:h0oooo00<0000007]^^P1kK[X0201kK[X3000000T0NUVP0P00001M0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool2000000T0Nfjj0`00000907YIX080
0000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo
00<0000007]^^P1kK[X01`1kK[X2000000P0NUVP00@0gKjj07YIX038adH00000G@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1kK[X0
1`1kK[X2000000T0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00L0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool2
000000T0Nfjj00<0000007YIX01jFJ001`1jFJ02000005h0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YI
X01jFJ001`1jFJ000`38adH000000?ooo`1M0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00/03oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00D0
NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
/03oool2000000T0Nfjj00<0000007YIX01jFJ001@1jFJ02000005l0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`8000002@1kK[X00`000000NUVP07YI
X00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;40oooo00<0000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7AP000000
oooo05h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?oo
o`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ000`1jFJ03000005l0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@040000003F[k40eZna08ec/A00eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X01P00
0000NUVP07YIX01jFJ00gKjj07YIX0800000H03oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00001P
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool00`00
0000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00<0NUVP00<0b<M60000003oool0G`3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo00<0000007]^^P1k
K[X0201kK[X010000000NUVP0=fn^P1jFJ0300000600oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`8000002@1kK[X010000000NUVP07YIX01jFJ020000
0640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`80
00002@1kK[X010000000NUVP07YIX01jFJ0200000640oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`030000001kK[X0Nfjj00L0Nfjj00H000000=fn^P1j
FJ00NUVP0<S7AP00001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/`3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00000000800000H@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;<0oooo0P00000907]^^P04
0000001jFJ00000000000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00]03oool00`000000Nfjj07]^^P0707]^^P04
0000001jFJ00b<M600000680oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002d0?ooo`030000001kK[X0Nfjj00P0Nfjj0`00001R0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3ooolS000005<0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`h000003018>ih00`000000lLBS0?74
X`0<0?74X`l00000C03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?oo
o`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
A`3oooln00000?l0oooo8P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo2`00000900d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H01`3od8H;00000?l0oooo5`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0
oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`1H0?ooo`800000^P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0EP3oool20000000404XON@000000
000000000;P0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo05@0oooo0P00000304XON@030000003bYFh0
lZE^00800000]P3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0D@3oool3000000D0BQmi00<000000?:U
KP3bYFh00P3bYFh200000;@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04l0oooo0P00000804XON@03
0000003bYFh0lZE^00@0lZE^0P00002b0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000
003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`1=0?ooo`800000
2P1:7gT00`000000lZE^0?:UKP060?:UKP800000/03oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0B`3o
ool2000000`0BQmi00<000000?:UKP3bYFh0203bYFh200000:h0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo04P0oooo0`00000>04XON@030000003bYFh0lZE^00X0lZE^0P00002/0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`160?ooo`8000004@1:7gT00`000000lZE^0?:UKP0<0?:UKP800000ZP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0A03oool2000001<0BQmi00<000000?:UKP3bYFh03P3bYFh200000:P0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo0440oooo0`00000E04XON@030000003bYFh0lZE^0100lZE^
0P00002V0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`800000601:7gT00`000000lZE^0?:U
KP0B0?:UKP800000Y03oool00:00oooo00<0000004PkWP18>ih01018>ihX000000P0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`8000001P1:7gT]00000:80oooo002C0?oo
oa@000004P17>Yh00`000000lLFS0?75X`0C0?75XaL00000<03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
oaL000005@1EAJ<2000000h0mLRN5`00002C0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3bYFh08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0
;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00@000000?G8WP3eb9h0
lZE^8P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00D000000?G8WP3eb9h0mLRN0?:UKP0Q0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<09@1EAJ<01@1:7gT0EDFS05E5X`1EAJ<0000000d0mLRN00<0lZE^
0?G8WP3eb9h05@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0303eb9h00`3bYFh0mLRN0?G8WP0D0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<00`1:7gT0EDFS05E5X`0205E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0S05E5X`0304XON@1EAJ<0EDFS00<0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS0280EDFS00<0
BQmi05E5X`1EAJ<0101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<08P1EAJ<00`1:7gT0EDFS05E5X`04
05E5X`040000003eb9h0mLRN0?:UKR80mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0U05E5X`@0BQmi00<000000?:UKP3bYFh08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS
0200EDFS2@1:7gT00`000000lZE^0?:UKP050?:UKQh0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0K05E5X`h0BQmi00<000000?:UKP3b
YFh02@3bYFhJ0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo
00<0000005E5X`1EAJ<05`1EAJ<B04XON@030000003bYFh0lZE^00d0lZE^5P3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01<0EDFS5P1:
7gT00`000000lZE^0?:UKP0B0?:UKQ40mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0>05E5Xa/0BQmi00<000000?:UKP3bYFh05`3bYFh0
0`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^
01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT06`1:7gT00`000000
lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0;05E5X`030000001:7gT0BQmi01/0BQmi
00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XO
N@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0EDFS00<00000
04XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0;05E5
X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<02`1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3e
b9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000
003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0;05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3b
YFh00`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0
lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00/0EDFS00<0000004XON@1:7gT06`1:7gT00`00
0000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0;05E5X`030000001:7gT0BQmi01/0
BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP090?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<02`1EAJ<00`000000BQmi
04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8WP3eb9h02@3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00`0EDFS00<0
000004XON@1:7gT06P1:7gT00`000000lZE^0?:UKP0H0?:UKP030000003eb9h0mLRN00P0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0<
05E5X`030000001:7gT0BQmi01X0BQmi00<000000?:UKP3bYFh0603bYFh00`000000mLRN0?G8WP08
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<0301EAJ<00`000000BQmi04XON@0J04XON@030000003bYFh0lZE^01P0lZE^00<000000?G8
WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS00`0EDFS00<0000004XON@1:7gT06P1:7gT00`000000lZE^0?:UKP0H0?:UKP03
0000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0<05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh0
5`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<00`000000BQmi04XON@0K04XON@030000003b
YFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;`00000C
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H_00000080oooo00<00000
05E5X`1EAJ<0301EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<00000
0?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS=000000A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H9000000P01@008@00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:U
KP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000
]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000>05E5X`030000001:7gT0BQmi
01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400
[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000>05E5
X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0040000003od8H0om260?o@
QT00[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`00
0000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260440[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3b
YFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi
00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000>05E5X`030000001:
7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2
00000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000>
05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh05`3bYFh00`000000mLRN0?G8WP08
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000om260:eTN`110:eT
N`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0lZE^00<000000?G8
WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]
I7/0@@2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP03
0000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000
002]I7/0[FAk0440[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:UKP3bYFh0
5`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2d
Tk@00`000000[FAk0:eTN`110:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003b
YFh0lZE^01L0lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000130:eTN`030000002dTk@0
]9>d02P0]9>d00<000000:eTN`2]I7/0@@2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT0
0`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`00
0000]9>d0;BC]00X0;BC]4@0[FAk0P00000>05E5X`030000001:7gT0BQmi01/0BQmi00<000000?:U
KP3bYFh05`3bYFh00`000000mLRN0?G8WP080?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<2000004<0[FAk00<000000;BC]02d
Tk@0:02dTkA40:eTN`8000003P1EAJ<00`000000BQmi04XON@0K04XON@030000003bYFh0lZE^01L0
lZE^00<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000130:eTN`030000002dTk@0]9>d02P0]9>d
A02]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000
003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:
7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2
000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`000000lZE^0?:UKP0G0?:UKP030000003eb9h0
mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000h0EDFS00<0000004XON@1:7gT06`1:7gT00`00
0000lZE^0?:UKP0G0?:UKP030000003eb9h0mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000000l0
EDFS00<0000004XON@1:7gT06P1:7gT00`000000lZE^0?:UKP0H0?:UKP030000003eb9h0mLRN00L0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`800000/P2]I7/2000000l0EDFS00<0000004XON@1:7gT06@1:7gT3000001T0lZE^
00<000000?G8WP3eb9h01`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`8000003`1EAJ<00`000000BQmi04XO
N@0F04XON@<000000`1gd?l2000001L0lZE^00<000000?G8WP3eb9h01`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b
0:eTN`8000003`1EAJ<00`000000BQmi04XON@0C04XON@@000001`1gd?l3000001@0lZE^00<00000
0?G8WP3eb9h01`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`8000003`1EAJ<00`000000BQmi04XON@0@04XO
N@@000003@1gd?l200000180lZE^00<000000?G8WP3eb9h01`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`80
00003`1EAJ<00`000000BQmi04XON@0=04XON@@000004P1gd?l3000000l0lZE^00<000000?G8WP3e
b9h01`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/@2]I7/2000000l0EDFS00<0000004XON@1:7gT0
2`1:7gT4000000`0Mm3o00<0mLRN07O@o`1gd?l0201gd?l2000000d0lZE^00<000000?G8WP3eb9h0
1`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0G@2]I7/00`2^]]l0[FAk0:eTN`1B0:eTN`030000001E
AJ<0EDFS00d0EDFS00<0000004XON@1:7gT0201:7gT4000001`0Mm3o0P00000;0?:UKP030000003e
b9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<02`1EAJ<0
0`3daj00EDFS0000000804XON@<000008@1gd?l3000000P0lZE^00<000000?G8WP3eb9h01`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0I02]I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0EDFS
00d0EDFS00<0000004XON@1:7gT0101:7gT3000001D0Mm3o00<0000007O@o`1gd?l03P1gd?l20000
00H0lZE^00<000000?G8WP3eb9h01`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000
EDFS05E5X`0=05E5X`040000001:7gT0BQmi04XON@<000005P1gd?l400000140Mm3o0`0000030?:U
KP030000003eb9h0mLRN00L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<03@1EAJ<010000000BQmi00000000000H07O@o`80000000<0L31`0000001kCY40501gd?l20000
00030?:UKP000000mLRN00P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk06l0[FAk00<0[[KO0:eTN`2]
I7/0@02]I7/00`000000EDFS05E5X`0=05E5X`800000501gd?l9070`L0030000001kCY40000001D0
Mm3o0P0000090?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00l0EDFS
0P00000@07O@o`030000001`<700L31`00L0L31`00@000000;^i<P1kCY4000004P1gd?l3000000/0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk07H0[FAk00<0[[KO0:eTN`2]I7/0>@2]I7/00`000000EDFS
05E5X`0A05E5X`8000003P1gd?l00`000000L31`070`L007070`L0040000001kCY40NdjA00000080
mLRN3P1gd?l2000000h0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0
4`1EAJ<3000000T0Mm3o00<0EDFS0000000000002@1`<70010000000NdjA07]>T@0000040?G8WPT0
Mm3o0`00000@0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1m0:eTN`030:jfg`2]I7/0[FAk0380[FAk
00<0000005E5X`1EAJ<05P1EAJ<2000000@0Mm3o101EAJ<00`000000L31`070`L008070`L0050000
001kCY40NdjA07]>T@0000001@3eb9h407O@o`<000004`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0
/P2]I7/00`000000EDFS05E5X`0H05E5X`8000001P1EAJ<00`000000L31`070`L007070`L0030000
001kCY40NdjA0080NdjA00<000000?G8WP1gd?l01@3eb9h2000000@0mLRN00<0F4RT0?G8WP3eb9h0
3`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0Q02]I7/00`2^]]l0[FAk0:eTN`0[0:eTN`030000001E
AJ<0EDFS0200EDFS00<00000070`L01`<7001`1`<7000`000000NdjA07]>T@0207]>T@030000003e
b9h0mLRN01d0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07`1EAJ<2
000000T0L31`00<0000007]>T@1kCY400`1kCY400`000000mLRN0?G8WP0L0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0000005E5X`1EAJ<07`1EAJ<00`00
0000L31`070`L008070`L0030000001kCY40NdjA00<0NdjA00<000000?G8WP3eb9h0703eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0O05E5X`030000001`<700L31`00P0
L31`00<0000007]>T@1kCY400`1kCY400`000000mLRN0?G8WP0L0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`2b0:eTN`030000001EAJ<0EDFS01l0EDFS00<00000070`L01`<7001`1`<7000`000000NdjA
07]>T@0507]>T@030000003eb9h0mLRN01/0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0
000005E5X`1EAJ<07P1EAJ<2000000T0L31`00<0000007]>T@1kCY401@1kCY400`000000mLRN0?G8
WP0K0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS01h0EDFS00<00000
070`L01`<700201`<7000`000000NdjA07]>T@0507]>T@030000003eb9h0mLRN01/0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07P1EAJ<00`000000L31`070`L008070`
L0030000001kCY40NdjA00D0NdjA00<000000?G8WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0/P2]I7/00`000000EDFS05E5X`0N05E5X`030000001`<700L31`00@0L31`00@00000070`L01`
<70000002@1kCY400`000000mLRN0?G8WP0J0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`03
0000001EAJ<0EDFS01d0EDFS0P000009070`L0030000001kCY40NdjA00L0NdjA00<000000?G8WP3e
b9h06P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0M05E5X`800000
2@1`<7000`000000NdjA07]>T@0707]>T@030000003eb9h0mLRN01X0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]
I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<07@1EAJ<00`000000L31`070`L008070`L0030000001k
CY40NdjA00P0NdjA00@000000?G8WP3eb9h0F4RT603eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0M05E5X`030000001`<700L31`00L0L31`00<0000007]>T@1kCY402@1k
CY400`000000mLRN0?G8WP0I0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ>f000001l0EDFS00<00000070`L01`<7001`1`<700
0`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN01T0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ
0;80[KSQ00<0000005E5X`1EAJ<0701EAJ<2000000T0L31`00<0000007]>T@1kCY402@1kCY400`00
0000mLRN05Q8Y00I0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS01`0
EDFS00<00000070`L01`<7000`1`<7000`3OWXh0L31`070`L002070`L0030000001kCY40NdjA00X0
NdjA00<000000?G8WP3eb9h0603eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS
05E5X`0L05E5X`030000001`<700L31`00P0L31`0P00000;07]>T@030000003eb9h0mLRN01P0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0701EAJ<00`000000L31`070`
L007070`L0<000002`1kCY400`000000mLRN0?G8WP0H0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b
0:fhh@030000001EAJ<0EDFS01/0EDFS0P000009070`L0<00000301kCY400`000000mLRN0?G8WP0G
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS01/0EDFS00<00000070`
L01`<700201`<7020000000305E5X`000000NdjA00X0NdjA00<000000?G8WP3eb9h05`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0K05E5X`030000001`<700L31`00P0
L31`00@0000005E5X`1EAJ<000002`1kCY400`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS01/0EDFS00<00000070`L01`<7001`1`<70200000080
EDFS00<0000007]>T@1kCY402P1kCY400`000000mLRN0?G8WP0F0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ
0:fhh@2b0:fhh@030000001EAJ<0EDFS01X0EDFS0P000009070`L08000000P1EAJ<2000000/0NdjA
00<000000?G8WP3eb9h05P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5
X`0J05E5X`030000001`<700L31`00P0L31`0P00000205E5X`8000002`1kCY400`000000mLRN0?G8
WP0F0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<04`3aaJ<G00000;@0[KSQ6`00000205E5X`050000001`<700L31`070`L03OWXh01P1`
<70010000000EDFS05E5X`1EAJ<2000000/0NdjA00<000000?G8WP3eb9h05P3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS01<0lLFS5P2^
IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01@0[VEl1P1EAJ<00`000000L31`070`
L008070`L0070000001EAJ<0EDFS05E5X`000000mLRN0000000;07]>T@030000003eb9h0mLRN01D0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0B0?75XaL0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO0D0EDFS
0P000009070`L0030000001EAJ<0EDFS0080EDFS00<000000?G8WP0000002`1kCY400`000000mLRN
0?G8WP0E0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^
IG`405E5X`030000001`<700L31`00P0L31`00<0000005E5X`1EAJ<00P1EAJ<00`000000mLRN0000
000;07]>T@030000003eb9h0mLRN01D0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40/P2]^>40
0`000000[VEl0:iUO00E0:iUO0@0EDFS00<00000070`L01`<700201`<7000`000000EDFS05E5X`02
05E5X`040000003eb9h0mLRN000000/0NdjA00<000000?G8WP3eb9h0503eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^IG`0
0`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl0`1EAJ<00`000000L31`070`L008
070`L0030000001EAJ<0EDFS0080EDFS00@000000?G8WP3eb9h000002`1kCY400`000000mLRN0?G8
WP0D0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0403aaJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05`2^IG`2
05E5X`030000001`<700L31`00L0L31`0P00000405E5X`040000003eb9h0mLRN000000/0NdjA00<0
00000?G8WP3eb9h0503eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006@2^IG`0
1@1EAJ<00000070`L01`<700gij>00L0L31`0P00000405E5X`040000003eb9h0mLRN000000/0NdjA
00<000000?G8WP3eb9h0503eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006P2^
IG`00`000000L31`070`L008070`L0030000001EAJ<0EDFS00<0EDFS00D000000?G8WP3eb9h0mLRN
0000000;07]>T@030000003eb9h0mLRN01<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75XaD0[VEl00<0lLFS0:iUO02^IG`0102^
IG`00`000000[KSQ0:fhh@2`0:fhh@8000006P2^IG`00`000000L31`070`L008070`L0030000001E
AJ<0EDFS00<0EDFS00D000000?G8WP3eb9h0mLRN0000000;07]>T@030000003eb9h0mLRN01<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0>0?75Xa`0[VEl00<000000:fhh@2]^>40/02]^>42000001X0[VEl00<00000070`L01`<7001`1`
<702000000D0EDFS00D000000?G8WP3eb9h0mLRN0000000;07]>T@030000003eb9h0mLRN01<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0=0?75Xad0[VEl00<000000:fhh@2]^>40/02]^>42000001T0[VEl00<00000070`L01`<700201`
<702000000D0EDFS00<000000?G8WP3eb9h00P3eb9h00`000000NdjA07]>T@0907]>T@030000003e
b9h0mLRN0180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0<0?75Xah0[VEl00<000000:fhh@2]^>40/02]^>42000001T0[VEl00<00000
070`L01`<700201`<7000`000000EDFS05E5X`0405E5X`030000003eb9h0mLRN0080mLRN00<00000
07]>T@1kCY402@1kCY400`000000mLRN0?G8WP0B0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0303aaJ<N0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0602^IG`00`000000L31`070`L008070`L0030000001EAJ<0EDFS
00@0EDFS00<000000?G8WP3eb9h00P3eb9h00`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN
0180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0;0?75Xal0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00H0:iUO003
0000003OWXh0L31`00P0L31`00<0000005E5X`1EAJ<0101EAJ<00`000000mLRN0?G8WP030?G8WP03
0000001kCY40NdjA00T0NdjA00<000000?G8WP3eb9h04@3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0lLFS7`2^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl01L0[VEl00<00000070`L01`<700201`<702000000H0EDFS
00<000000?G8WP3eb9h00`3eb9h00`000000NdjA07]>T@0907]>T@030000003eb9h0mLRN0140mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0:0?75Xb00[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00G0:iUO0030000003O
WXh0L31`00P0L31`00<0000005E5X`1EAJ<01@1EAJ<00`000000mLRN0?G8WP030?G8WP030000001k
CY40NdjA00T0NdjA00<000000?G8WP3eb9h04@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`
0:fhh@030000002^IG`0[VEl01L0[VEl00<00000070`L01`<700201`<7000`000000EDFS05E5X`05
05E5X`030000003eb9h0mLRN0080mLRN00<0F4RT0?G8WP0000002P1kCY400`000000mLRN0?G8WP0A
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`05`2^IG`00`00
0000L31`070`L008070`L0030000001EAJ<0EDFS00D0EDFS00<000000?G8WP3eb9h0103eb9h00`00
0000NdjA07]>T@0907]>T@030000003eb9h0mLRN0100mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75Xb80[VEl00<000000:fhh@2]
^>40/02]^>400`000000[VEl0:iUO00F0:iUO0030000001`<700L31`00P0L31`0P00000705E5X`03
0000003eb9h0mLRN00@0mLRN00<0000007]>T@1kCY402@1kCY400`000000mLRN0?G8WP0@0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
203aaJ<R0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`05P2^IG`00`000000L31`
070`L008070`L0030000001EAJ<0EDFS00H0EDFS00<000000?G8WP3eb9h01@3eb9h00`000000NdjA
07]>T@0607]>T@<000004P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00L0lLFS8`2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^
IG`0[VEl01H0[VEl3000000805E5X`050000003eb9h0mLRN0?G8WP1HB:@00`3eb9h00`000000NdjA
07]>T@0407]>T@8000000P2Cj_P00`000000mLRN0?G8WP0@0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3aaJ<T0:iUO0030000002]
^>40[KSQ0;00[KSQ00<000000:iUO02^IG`0602^IG`2000000L0CJgi00<0000005E5X`1EAJ<01P1E
AJ<00`000000mLRN0?G8WP050?G8WP030000001kCY40NdjA0080NdjA0P00000309?Zn0030000003e
b9h0mLRN0140mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`060?75Xb@0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00J
0:iUO0<000000`1=[OT2000000P0EDFS00<000000?G8WP3eb9h01P3eb9h207]>T@8000001@2Cj_P0
0`000000mLRN0?G8WP0A0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<01@3aaJ<U0:iUO0030000002]^>40[KSQ0380[KSQ00<0^iT60:fh
h@2]^>40AP2]^>400`000000[KSQ0:fhh@0b0:fhh@030000002^IG`0[VEl01d0[VEl0P0000000`1=
[OT000000:iUO00805E5X`030000003eb9h0mLRN00H0mLRN2P00000C0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01@3aaJ=J0:iUO003
0;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00O0:iUO080
00000P2^IG`705E5X`040000003eb9h0mLRN05Q8Y280mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`040?75Xcl0[VEl00<0[KSQ0:iUO02^
IG`06@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^
IG`0902^IG`605E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`030?75Xdh0[VEl00<0[KSQ0:iUO02^IG`0
2`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0
902^IG`605E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`030?75XdD0[VEl00<0[KSQ0:iUO02^IG`0502^
IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09@2^
IG`505E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`020?75Xed0[VEl00<0^iT60:fhh@2]^>40AP2]^>40
0`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN05Q8Y00S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<00P3aaJ=;0:iUO0030:fhh@2^IG`0[VEl00l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`00
0000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02H0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00@000000?75X`3a
aJ<0lLFSGP2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iU
O02^IG`09`2^IG`305E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`1H0:iUO0030:fhh@2^IG`0[VEl00@0
[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0
[VEl0`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000
002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^IG`205E5X`030000000G0000mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0
^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0
EDFS0000003eb9h07P3eb9h7000009<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O
0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y
0:iUO00305E5X`000000mLRN0180mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iU
O02^IG`0G`2^IG`00`2kV@H0000000000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`00
0000mLRN0?G8WP050?G8WP`00000YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<00006000000000000J000002b0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0
]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80
[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>80
0`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0
oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo
0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<00000
0:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P
0:fhhP030000003oool0oooo0;L0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?oo
o`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo
0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?oo
o`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fh
hP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00
^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3o
ool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2
000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`0=0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`2i0?ooo`00^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL00`0@3HL01@3od8T040f7010=Q`0@3HL0000001@0]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
1000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d2P3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`06010=Q`030?o@R@000000]9>d01<0]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00k@3ooolo000000T040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Qcl00000k@3oool00>d0oooo00<0000008<51P231@H010231@H00`1Mb_P0P`D608<5
1P0e08<51PL040f700<0P`D6010=Q`000000502dTk@00`000000om270?o@Q`060?o@Qcl0P`D600<0
00000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H02`231@H00`1Mb_P0P`D608<51P0_
08<51PP040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`050?o@Qd00P`D600<00000
0?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H04P231@H00`1Mb_P0P`D608<51P0Y08<5
1PL040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`040?o@Qd40P`D600<000000?oo
o`3oool0j`3oool00>d0oooo00<0000008<51P231@H060231@H305g:n2@0P`D60`0@3HL010231@H0
40f7010=Q`00000D0;BC]0030000003od8L0om2700<0om27@P231@H00`000000oooo0?ooo`3[0?oo
o`00k03oool00`000000P`D608<51P0P08<51P<0GL[h7`231@H4010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L00P3od8M308<51P030000003oool0oooo0>/0oooo003/0?ooo`030000
00231@H0P`D602L0P`D60`00000I08<51P<040f700<000000;BC]02dTk@04P2dTk@010000000om27
0?o@Q`3od8M508<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D602d0P`D6
1@2`[mLB08<51P8040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`1608<51P030000
003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D603@0P`D61@2`[mL<08<51P03010=Q`00
0000]9>d01<0]9>d00<000000?o@Q`231@H07@231@H50;2_eb@0P`D600<000000?ooo`3oool0jP3o
ool00>`0oooo00<0000008<51P231@H0>`231@H00`2`[mL00000010=Q`02010=Q`H0P`D600<00000
0;BC]02dTk@04P2dTk@00`000000P`D608<51P0[08<51PT0/:oG4P231@H00`000000oooo0?ooo`3Z
0?ooo`00k03ooom900000540P`D63P00003/0?ooo`00k03oool00`000000/G>>0;5cSP050;5cSP03
0;2_e`2aLhh0/G>>09`0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0
302aLhh20;2_eiH0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh01@2a
Lhh00`2`[mL0/G>>0;5cSP0;0;5cSP@0/:oGS@2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool0
0`000000/G>>0;5cSP0J0;5cSP8000000`2`[mMa0;5cSP030;2_e`2aLhh0/G>>0140/G>>00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh02P2aLhh00`2`[mL0/G>>0;5cSP0D0;5c
SPH0/:oGO@2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0=0;5cSP03
0;2_e`2aLhh0/G>>01<0/G>>0P0000060;5cSPD0/:oGH`2aLhh2000000l0/G>>00<000000?ooo`3o
ool0jP3oool00>`0oooo00<000000;5cSP2aLhh03`2aLhh00`2`[mL0/G>>0;5cSP0A0;5cSP804006
100000080;5cSP030;2_e`2aLhh0/:oG00@0/:oGF`2aLhh201X040@000002`2aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0B0;5cSP030;2_e`2aLhh0/G>>00d0/G>>1P0@
00H4000000d0/G>>00@0/:oG0;5cSP2aLhh000000P0@3HL00`3od8T0/G>>0;5cSP1@0;5cSPH06P0@
100000080;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>01@0/G>>00<0
/:oG0000002aLhh02P2aLhh901001P030000003J/Zl0000001@0/G>>00<040f70;5cSP2aLhh00P0@
3HL00`000000]9>d0;BC]0180;5cSPT06P0@00<000000=^c[`0000001`2aLhh00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0G0;5cSP8040061`2aLhh901001P050000003J/Zl0
f[:_0=Zb[`0000006`2aLhh0102dTk@0/G>>0;5cSP2aLhh40;BC]3l0/G>>2@0J01001@000000fk>_
0=^c[`3K/jl0000000H0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0
6@2aLhh201001PD0/G>>200@00H00`000000f[:_0=Zb[`030=Zb[`030000002aLhh0/G>>0200/G>>
0P2dTk@30;5cSP<0]9>d=`2aLhh801X040030000003K/jl0fk>_00<0fk>_00<000000;5cSP2aLhh0
0`2aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP0L0;5cSP80400600<0
/G>>01001P0@00H01`0@00H00`000000f[:_0=Zb[`030=Zb[`030000002aLhh0/G>>02P0/G>>0P2d
Tk@40;5cSP<0om27;@2aLhh901X040030000003K/jl0fk>_00<0fk>_0P0000040;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>01h0/G>>2@0@00H00`000000f[:_0=Zb[`05
0=Zb[`030000002aLhh0/G>>02l0/G>>0P3od8L40;5cSP<0/:oG902aLhh901X040030000003K/jl0
fk>_00D0fk>_0P0000030;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>
01d0/G>>2@0@00H00`000000f[:_0=Zb[`070=Zb[`030000002aLhh0/G>>03H0/G>>0P0000050;5c
SP8000006`2aLhh901X040030000003K/jl0fk>_00L0fk>_00D000000;5cSP2aLhh0/G>>0000003/
0?ooo`00k03oool00`000000/G>>0;5cSP0L0;5cSPT0400600<000000=Zb[`3J/Zl02@3J/Zl00`00
0000/G>>0;5cSP0m0;5cSP80/GB?1P2aLhh20;5dSa40/G>>2@0J01000`000000fk>_0=^c[`090=^c
[`040000002aLhh0/G>>00000>`0oooo003/0?ooo`030000002aLhh0/G>>01`0/G>>200@00H00`00
0000f[:_0=Zb[`0;0=Zb[`030000002aLhh0/G>>04@0/G>>0`2aM8l60;5cSP0301X0402aLhh0/G>>
00H0/G>>2@0J01000`000000fk>_0=^c[`0;0=^c[`030000002aLhh000000>`0oooo003/0?ooo`03
0000002aLhh0/G>>01/0/G>>200@00H00`000000f[:_0=Zb[`0=0=Zb[`030000002aLhh0/G>>04/0
/G>>0`0J01060;5cSPT06P0@00<000000=^c[`3K/jl03@3K/jl200000>`0oooo003/0?ooo`030000
002aLhh0/G>>01X0/G>>200@00H00`000000f[:_0=Zb[`0?0=Zb[`030000002aLhh0/G>>0580/G>>
2@0J01000`000000fk>_0=^c[`0?0=^c[`030000003oool0oooo0>X0oooo003/0?ooo`030000002a
Lhh0/G>>01T0/G>>200@00H00`000000f[:_0=Zb[`0@0=Zb[`030000002aLhh0/G>>0540/G>>2@0J
01000`000000fk>_0=^c[`0@0=^c[`800000j`3oool00>`0oooo00<000000;5cSP2aLhh0602aLhh9
01001P030000003J/Zl0f[:_0140f[:_00<000000;5cSP2aLhh0C`2aLhh:01X040030000003K/jl0
fk>_0140fk>_0P00003Z0?ooo`00k03ooolL000000L0400600<000000=Zb[`3J/Zl04`3J/ZmB0000
00P06P0@00<000000=^c[`3K/jl04`3K/jl00`000000oooo0?ooo`3X0?ooo`00k03oool00`000000
/;3G0;2`e`0H0;2`e`030012`@0000000000008000000P0@00H00`000000f[:_0=Zb[`0E0=Zb[`03
0000002`/=L0/;3G04d0/;3G00<004W70000000000000P00000301X040030000003K/jl0fk>_01D0
fk>_00<000000?ooo`3oool0i`3oool00>`0oooo00<000000;2`e`2`/=L06@2`/=L40012`@800000
5`3J/Zl00`000000/;3G0;2`e`1?0;2`e`@004W70`00000G0=^c[`030000003oool0oooo0>P0oooo
003/0?ooo`030000002`/=L0/;3G01X0/;3G1@00@/400`000000f[:_0=Zb[`0C0=Zb[`030000002`
/=L0/;3G0540/;3G1P00BLL00`000000fk>_0=^c[`0C0=^c[`800000jP3oool00>`0oooo00<00000
0;2`e`2`/=L06`2`/=L50012`@030000003J/Zl0f[:_0140f[:_00<000000;2`e`2`/=L0D`2`/=L6
0019a`030000003K/jl0fk>_0140fk>_0P00003[0?ooo`00k03oool00`000000/;3G0;2`e`0L0;2`
e`D004;100<000000=Zb[`3J/Zl0403J/Zl00`000000/;3G0;2`e`1D0;2`e`H004W700<000000=^c
[`3K/jl0403K/jl00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`0M0;2`e`D0
04;100<000000=Zb[`3J/Zl03P3J/Zl00`000000/;3G0;2`e`1F0;2`e`H004W700<000000=^c[`3K
/jl03P3K/jl200000>`0oooo003/0?ooo`030000002`/=L0/;3G01h0/;3G1@00@/400`000000f[:_
0=Zb[`0<0=Zb[`030000002`/=L0/;3G05P0/;3G1P00BLL00`000000fk>_0=^c[`0<0=^c[`030000
002`/=L000000>`0oooo003/0?ooo`030000002`/=L0/;3G01h0/;3G1P00@/400`000000f[:_0=Zb
[`0:0=Zb[`030000002`/=L0/;3G00d0/;3G00<0/GB?0;2`e`2`/=L0BP2`/=L60019a`030000003K
/jl0fk>_00X0fk>_00@000000;2`e`2`/=L00000k03oool00>`0oooo00<000000;2`e`2`/=L07`2`
/=L60012`@030000003J/Zl0f[:_00P0f[:_00<000000;2`e`2`/=L05`2`/=L20;5dSd<0/;3G1P00
BLL00`000000fk>_0=^c[`080=^c[`050000002`/=L0/;3G0;2`e`000000k03oool00>`0oooo00<0
00000;2`e`2`/=L0802`/=L60012`@030000003J/Zl0f[:_00H0f[:_00<000000;2`e`2`/=L08@2`
/=L20;5dSc/0/;3G1P00BLL00`000000fk>_0=^c[`060=^c[`8000000`2`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/;3G0;2`e`0Q0;2`e`H004;100<000000=Zb[`3J/Zl0103J/Zl0
0`000000/;3G0;2`e`0[0;2`e`<0/GB?<P2`/=L60019a`030000003K/jl0fk>_00@0fk>_0P000004
0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0280/;3G1P00@/400`00
0000f[:_0=Zb[`030=Zb[`030000002`/=L0/;3G03@0/;3G102aM8lY0;2`e`H004W700<000000=^c
[`3K/jl00`3K/jl00`000000/;3G0;2`e`030;2`e`030000003oool0oooo0>X0oooo003/0?ooo`03
0000002`/=L0/;3G02<0/;3G0P0000040012`@050000003J/Zl0f[:_0=Zb[`000000@02`/=L40000
0240/;3G0P0000040019a`050000003K/jl0fk>_0=^c[`0000001P2`/=L00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/;3G0;2`e`0U0;2`e`@0000000@004;10000003J/Zl00000BP2`/=L5
08H;3AT0/;3G100000001000BLL000000=^c[`0000070;2`e`030000003oool0oooo0>X0oooo003/
0?ooo`030000002`/=L0/;3G02T0/;3G0`00001D0;2`e`H0QP/=4`2`/=L3000000P0/;3G00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0R@2`/=L608H;3AD0/;3G00<000000?oo
o`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0TP2`/=L508H;3@d0/;3G00<000000?ooo`3o
ool0jP3oool00>`0oooo00<000000;2`e`2`/=L0V`2`/=L308H;3@H0/;3G00<000000?ooo`3oool0
jP3oool00>`0ooooZ000003/0?ooo`00k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0
oooo0>X0oooo003/0?ooo`030000001Fb?D0E/Se0:@0E/Se00<000000?ooo`3oool0jP3oool00>d0
oooo00<0000005K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?ooo`00k@3oool00`000000E/Se
05K8m@2R05K8m@030000003oool0oooo0>/0oooo003]0?ooojH00000k@3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo0000\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.65808 .41234 m .6195 .41337 L .6195 .24609 L p .649 .53 .705 r
F P
0 g
s
.6195 .24609 m .65808 .24471 L .65808 .41234 L p .649 .53 .705 r
F P
0 g
s
.6195 .41337 m .5885 .40982 L .5885 .24132 L p .898 .734 .669 r
F P
0 g
s
.5885 .24132 m .6195 .24609 L .6195 .41337 L p .898 .734 .669 r
F P
0 g
s
.65808 .41234 m .65808 .24471 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.68245 .40731 m .67551 .40874 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.67551 .40874 m .65808 .41234 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.68918 .24604 m .6868 .25851 L p .67551 .27142 L .78 .637 .703 r
F P
0 g
s
.67551 .26559 m .68918 .24604 L .67551 .27142 L .78 .637 .703 r
F
.689 .23321 m .68918 .24604 L p .67551 .26559 L F P
0 g
s
.67551 .25771 m .689 .23321 L .67551 .26559 L .78 .637 .703 r
F
.65808 .24471 m .67551 .23987 L p .67551 .27929 L .228 .186 .601 r
F P
0 g
s
.66504 .29113 m .67551 .27929 L .67551 .36098 L .228 .186 .601 r
F
.65808 .24471 m .67551 .27929 L .66504 .29113 L F
.67551 .27929 m .68195 .27008 L .68315 .26923 L p 0 0 0 r
F P
0 g
s
.68315 .26923 m .6865 .26686 L p .68245 .27144 L 0 0 0 r
F P
0 g
s
.68245 .27144 m .67551 .27929 L .68315 .26923 L 0 0 0 r
F
.65808 .24471 m .67551 .23987 L p .5885 .24132 L .289 .763 .934 r
F P
0 g
s
.6806 .24012 m .68625 .22057 L .68507 .24034 L .78 .637 .703 r
F
.67551 .24618 m .6781 .24 L .67551 .25771 L F
.6781 .24 m .68625 .22057 L .6806 .24012 L F
.6781 .24 m .6806 .24012 L .67551 .25771 L F
.5885 .24132 m .67551 .23987 L .65578 .2389 L .289 .763 .934 r
F
.68107 .20866 m .68625 .22057 L p .6781 .24 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .67172 .23968 L .6781 .24 L .78 .637 .703 r
F
.67172 .23968 m .68107 .20866 L .6781 .24 L F
.67366 .19801 m .68107 .20866 L p .65515 .29467 L F P
0 g
s
.66435 .18907 m .67366 .19801 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .65578 .2389 L .62026 .23715 L .289 .763 .934 r
F
.5885 .24132 m .6195 .24609 L .65808 .24471 L p F P
0 g
s
.65353 .18223 m .66435 .18907 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.64167 .1778 m .65353 .18223 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.6293 .17598 m .64167 .1778 L p .64868 .23855 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .64286 .23826 L .64868 .23855 L .78 .637 .703 r
F
.64286 .23826 m .6293 .17598 L .64868 .23855 L F
.61694 .17686 m .6293 .17598 L p .65515 .29467 L F P
0 g
s
.60513 .18039 m .61694 .17686 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.59441 .18645 m .60513 .18039 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .62026 .23715 L .6055 .23642 L .289 .763 .934 r
F
.58523 .19475 m .59441 .18645 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.5885 .24132 m .6055 .23642 L .59504 .23591 L .289 .763 .934 r
F
.57802 .20495 m .58523 .19475 L p .61471 .23688 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .60506 .2364 L .61471 .23688 L .78 .637 .703 r
F
.60506 .2364 m .57802 .20495 L .61471 .23688 L F
.58456 .23539 m .5885 .24132 L p .59504 .23591 L .289 .763 .934 r
F P
0 g
s
.57309 .21659 m .57802 .20495 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.57067 .22916 m .57309 .21659 L p .58456 .2275 L .78 .637 .703 r
F P
0 g
s
.58456 .23993 m .57067 .22916 L .58456 .2275 L .78 .637 .703 r
F
.5885 .24132 m .5885 .29475 L p .58511 .27763 L .88 .718 .202 r
F P
0 g
s
.58456 .23539 m .5885 .24132 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58643 .27753 m .57892 .26684 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.57892 .26684 m .58456 .27487 L p .58344 .2692 L 0 .237 .754 r
F P
0 g
s
.57086 .24211 m .57067 .22916 L p .58456 .23993 L .78 .637 .703 r
F P
0 g
s
.58456 .25065 m .57086 .24211 L .58456 .23993 L .78 .637 .703 r
F
.57365 .25485 m .57086 .24211 L p .65515 .29467 L F P
0 g
s
.57892 .26684 m .57365 .25485 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.58299 .23303 m .58456 .23539 L p .58456 .27487 L .88 .718 .202 r
F P
0 g
s
.58299 .23303 m .58456 .27487 L .58437 .27388 L .88 .718 .202 r
F
.58299 .23303 m .58456 .27967 L .58441 .27855 L F
.58344 .2692 m .58299 .26693 L .57892 .26684 L 0 .237 .754 r
F
.58241 .26403 m .58054 .26553 L p .58299 .26693 L F P
0 g
s
.58054 .26553 m .57892 .26684 L p .58299 .26693 L 0 .237 .754 r
F P
0 g
s
.57875 .25064 m .57365 .25485 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.58299 .26821 m .58299 .23303 L p .58441 .27855 L .88 .718 .202 r
F P
0 g
s
.65515 .29467 m .58456 .25065 L .58456 .23993 L .78 .637 .703 r
F
.65515 .29467 m .58456 .23993 L .58456 .2275 L F
.58299 .23303 m .58456 .23539 L p .59438 .23129 L .289 .763 .934 r
F P
0 g
s
.58299 .23303 m .58299 .26693 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.61035 .23208 m .58973 .20807 L .62006 .23256 L .781 .637 .703 r
F
.57819 .21213 m .58315 .20041 L p .58973 .20807 L F P
0 g
s
.59504 .23591 m .60027 .23158 L .58456 .23539 L .289 .763 .934 r
F
.61035 .23208 m .58973 .22311 L .58973 .20807 L .781 .637 .703 r
F
.59853 .23149 m .58973 .22311 L .61035 .23208 L F
.60027 .23158 m .59438 .23129 L .58456 .23539 L .289 .763 .934 r
F
.58973 .23106 m .58299 .23303 L p .59438 .23129 L F P
0 g
s
.58973 .23106 m .58299 .23303 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.57575 .22478 m .57819 .21213 L p .59853 .23149 L .781 .637 .703 r
F P
0 g
s
.59504 .23591 m .61208 .23217 L .60027 .23158 L .289 .763 .934 r
F
.58973 .20807 m .58973 .20614 L .62006 .23256 L .781 .637 .703 r
F
.58315 .20041 m .59041 .19015 L p .62006 .23256 L F P
0 g
s
.6055 .23642 m .61908 .23251 L .59504 .23591 L .289 .763 .934 r
F
.64167 .1778 m .6293 .17598 L .63474 .17128 L p .28 .735 .955 r
F P
0 g
s
.64839 .23397 m .63474 .17128 L .65424 .23426 L .781 .637 .703 r
F
.6293 .17598 m .61694 .17686 L .6223 .17215 L p .35 .814 .921 r
F P
0 g
s
.6223 .17215 m .63474 .17128 L .6293 .17598 L p .35 .814 .921 r
F P
0 g
s
.6223 .17215 m .63474 .17128 L p .64839 .23397 L .781 .637 .703 r
F P
0 g
s
.64224 .23366 m .6223 .17215 L .64839 .23397 L .781 .637 .703 r
F
.65353 .18223 m .64167 .1778 L .64719 .17311 L p .206 .636 .95 r
F P
0 g
s
.63474 .17128 m .64719 .17311 L .64167 .1778 L p .28 .735 .955 r
F P
0 g
s
.63474 .17128 m .64719 .17311 L p .65424 .23426 L .781 .637 .703 r
F P
0 g
s
.62026 .23715 m .6456 .23383 L .6055 .23642 L .289 .763 .934 r
F
.68625 .22057 m .68107 .20866 L .68682 .20418 L p 0 .126 .666 r
F P
0 g
s
.68107 .20866 m .67366 .19801 L .67937 .19346 L p 0 .267 .772 r
F P
0 g
s
.67937 .19346 m .68682 .20418 L .68107 .20866 L p 0 .267 .772 r
F P
0 g
s
.67937 .19346 m .68123 .19613 L p .67742 .23541 L .781 .637 .703 r
F P
0 g
s
.68123 .19613 m .68682 .20418 L p .68123 .22276 L .781 .637 .703 r
F P
0 g
s
.67742 .23541 m .68123 .19613 L .68123 .22276 L .781 .637 .703 r
F
.6714 .23511 m .67937 .19346 L .67742 .23541 L F
.68245 .23794 m .68123 .23559 L p .62026 .23715 L .289 .763 .934 r
F P
0 g
s
.67742 .23541 m .68682 .20418 L .68384 .23572 L .781 .637 .703 r
F
.62026 .23715 m .68123 .23559 L .6456 .23383 L .289 .763 .934 r
F
.65578 .2389 m .68245 .23794 L .62026 .23715 L F
.67551 .23987 m .68245 .23794 L p .65578 .2389 L F P
0 g
s
.65515 .29467 m .67551 .24618 L .67551 .25771 L .78 .637 .703 r
F
.65515 .29467 m .67551 .25771 L .67551 .26559 L F
.65515 .29467 m .67551 .26559 L .67551 .27142 L F
.6868 .25851 m .68195 .27008 L p .65515 .29467 L F P
0 g
s
.68195 .27008 m .67484 .28024 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.67484 .28024 m .66578 .28856 L .65515 .29467 L p .78 .637 .703 r
F P
0 g
s
.67366 .19801 m .66435 .18907 L .67 .18446 L p .058 .399 .855 r
F P
0 g
s
.67 .18446 m .67937 .19346 L .67366 .19801 L p .058 .399 .855 r
F P
0 g
s
.67 .18446 m .67937 .19346 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.66435 .18907 m .65353 .18223 L .65912 .17757 L p .132 .522 .915 r
F P
0 g
s
.65912 .17757 m .67 .18446 L .66435 .18907 L p .132 .522 .915 r
F P
0 g
s
.65912 .17757 m .67 .18446 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.64719 .17311 m .65912 .17757 L .65353 .18223 L p .206 .636 .95 r
F P
0 g
s
.64719 .17311 m .65912 .17757 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68123 .23559 m .67809 .22957 L p .6456 .23383 L .289 .763 .934 r
F P
0 g
s
.68625 .22057 m .689 .23321 L p .68507 .24034 L .78 .637 .703 r
F P
0 g
s
.689 .23321 m .68625 .22057 L .69204 .21617 L p 0 0 .536 r
F P
0 g
s
.68682 .20418 m .69204 .21617 L .68625 .22057 L p 0 .126 .666 r
F P
0 g
s
.68682 .20418 m .69204 .21617 L p .68384 .23572 L .781 .637 .703 r
F P
0 g
s
.67551 .25771 m .6806 .24012 L .68507 .24034 L .78 .637 .703 r
F
.68195 .27008 m .6868 .25851 L .69259 .25436 L p 0 0 0 r
F P
0 g
s
.67551 .36098 m .68022 .27748 L .68245 .40731 L .228 .186 .601 r
F
.69259 .25436 m .68943 .2619 L p .68195 .27008 L 0 0 0 r
F P
0 g
s
.6865 .26686 m .68195 .27008 L p .68943 .2619 L 0 0 0 r
F P
0 g
s
.68245 .23794 m .68245 .27371 L p .68022 .27748 L .228 .186 .601 r
F P
0 g
s
.68245 .27371 m .68245 .40731 L p .68022 .27748 L .228 .186 .601 r
F P
0 g
s
.68943 .2619 m .68771 .266 L .6865 .26686 L p 0 0 0 r
F P
0 g
s
.67551 .23987 m .68245 .23794 L p .67551 .36098 L .228 .186 .601 r
F P
0 g
s
.67484 .28024 m .67551 .27929 L p .6823 .27189 L 0 0 0 r
F P
0 g
s
.68226 .27203 m .67484 .28024 L .6823 .27189 L 0 0 0 r
F
.68245 .40731 m .68245 .27144 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.67809 .40107 m .68123 .40556 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.68123 .40556 m .68245 .40731 L p .68123 .30778 L .849 .693 .16 r
F P
0 g
s
.68102 .27329 m .67551 .27929 L .68106 .27301 L 0 0 0 r
F
.68147 .2745 m .67809 .40107 L .68245 .27144 L .849 .693 .16 r
F
.68102 .27329 m .68106 .27301 L .6865 .26686 L 0 0 0 r
F
.6865 .26686 m .68771 .266 L p .68102 .27329 L F P
0 g
s
.66578 .28856 m .67484 .28024 L .68056 .27623 L p 0 0 0 r
F P
0 g
s
.68147 .2745 m .68123 .27527 L .68123 .28367 L .849 .693 .16 r
F
.68056 .27623 m .67484 .28024 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68771 .266 m .68123 .27527 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68123 .27527 m .68056 .27623 L p .68226 .27203 L 0 0 0 r
F P
0 g
s
.68123 .28367 m .68082 .27656 L .67809 .40107 L .849 .693 .16 r
F
.66075 .29074 m .68123 .27195 L .68056 .27623 L .781 .637 .703 r
F
.68123 .27527 m .68056 .27623 L p .68123 .27195 L F P
0 g
s
.68245 .23794 m .68123 .23559 L p .68123 .27527 L .849 .693 .16 r
F P
0 g
s
.68245 .23794 m .68123 .27527 L .68147 .2745 L .849 .693 .16 r
F
.68245 .27144 m .68245 .23794 L p .68147 .2745 L F P
0 g
s
.66075 .29074 m .67742 .23541 L .68384 .23572 L .781 .637 .703 r
F
.68056 .27623 m .67144 .2846 L .66578 .28856 L p 0 0 0 r
F P
0 g
s
.6868 .25851 m .68918 .24604 L .69499 .24181 L p 0 0 .196 r
F P
0 g
s
.69499 .24181 m .69259 .25436 L .6868 .25851 L p 0 0 .196 r
F P
0 g
s
.69499 .24181 m .69259 .25436 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68918 .24604 m .689 .23321 L .6948 .2289 L p 0 0 .38 r
F P
0 g
s
.6948 .2289 m .69499 .24181 L .68918 .24604 L p 0 0 .38 r
F P
0 g
s
.6948 .2289 m .69499 .24181 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.69204 .21617 m .6948 .2289 L .689 .23321 L p 0 0 .536 r
F P
0 g
s
.69204 .21617 m .6948 .2289 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.69259 .25436 m .68771 .266 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.68056 .27623 m .67144 .2846 L .66075 .29074 L p .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .67809 .28511 L p .68082 .27656 L .849 .693 .16 r
F P
0 g
s
.67809 .28511 m .67809 .40107 L p .68082 .27656 L .849 .693 .16 r
F P
0 g
s
.68771 .266 m .68226 .27203 L .6823 .27189 L 0 0 0 r
F
.68771 .266 m .68123 .27527 L p .68123 .27195 L .781 .637 .703 r
F P
0 g
s
.68123 .23559 m .67809 .22957 L p .68123 .28367 L .849 .693 .16 r
F P
0 g
s
.6456 .23383 m .63733 .23342 L .6055 .23642 L .289 .763 .934 r
F
.6055 .23642 m .63733 .23342 L .61908 .23251 L F
.61694 .17686 m .60513 .18039 L .61042 .17571 L p .41 .861 .84 r
F P
0 g
s
.61042 .17571 m .6223 .17215 L .61694 .17686 L p .41 .861 .84 r
F P
0 g
s
.61042 .17571 m .6223 .17215 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.6456 .23383 m .67809 .22957 L .63733 .23342 L .289 .763 .934 r
F
.66075 .29074 m .6714 .23511 L .67742 .23541 L .781 .637 .703 r
F
.66075 .29074 m .64224 .23366 L .64839 .23397 L F
.60513 .18039 m .59441 .18645 L .59963 .1818 L p .453 .864 .705 r
F P
0 g
s
.59963 .1818 m .61042 .17571 L .60513 .18039 L p .453 .864 .705 r
F P
0 g
s
.59963 .1818 m .61042 .17571 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.59041 .19015 m .59963 .1818 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .64674 .22455 L p .61908 .23251 L .289 .763 .934 r
F P
0 g
s
.63733 .23342 m .67809 .22957 L .61908 .23251 L .289 .763 .934 r
F
.61908 .23251 m .64674 .22455 L .61208 .23217 L F
.61908 .23251 m .61208 .23217 L .59504 .23591 L F
.66075 .29074 m .64839 .23397 L .65424 .23426 L .781 .637 .703 r
F
.66075 .29074 m .58973 .23563 L .59853 .23149 L F
.64674 .22455 m .607 .22601 L p .60027 .23158 L .289 .763 .934 r
F P
0 g
s
.61208 .23217 m .64674 .22455 L .60027 .23158 L .289 .763 .934 r
F
.66075 .29074 m .59853 .23149 L .61035 .23208 L .781 .637 .703 r
F
.59585 .28646 m .58643 .27753 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.60676 .29324 m .59585 .28646 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.61868 .29758 m .60676 .29324 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.60676 .29324 m .61868 .29758 L .62406 .29366 L p .163 .617 .934 r
F P
0 g
s
.59585 .28646 m .60676 .29324 L .61207 .28929 L p .087 .502 .901 r
F P
0 g
s
.62406 .29366 m .61207 .28929 L .60676 .29324 L p .163 .617 .934 r
F P
0 g
s
.58643 .27753 m .59585 .28646 L .60109 .28246 L p .011 .374 .84 r
F P
0 g
s
.61207 .28929 m .60109 .28246 L .59585 .28646 L p .087 .502 .901 r
F P
0 g
s
.60109 .28246 m .59161 .27347 L .58643 .27753 L p .011 .374 .84 r
F P
0 g
s
.57594 .23781 m .57575 .22478 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58973 .25544 m .58299 .26693 L .58973 .27079 L .206 .168 .592 r
F
.57875 .25064 m .57594 .23781 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58405 .26271 m .57875 .25064 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.59161 .27347 m .58973 .27079 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.58973 .27079 m .58405 .26271 L p .58973 .26478 L .781 .637 .703 r
F P
0 g
s
.66075 .29074 m .58973 .27079 L .58973 .26478 L .781 .637 .703 r
F
.58299 .40365 m .58299 .26821 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58441 .27855 m .58456 .28348 L .58299 .26821 L .88 .718 .202 r
F
.58456 .28348 m .58511 .27763 L .5885 .40982 L F
.5885 .29475 m .5885 .40982 L p .58511 .27763 L F P
0 g
s
.5885 .40982 m .58456 .40541 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58456 .40541 m .58299 .40365 L p .58456 .28348 L .88 .718 .202 r
F P
0 g
s
.58299 .26693 m .58299 .40365 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.59161 .27347 m .58405 .26271 L .58241 .26403 L p 0 .237 .754 r
F P
0 g
s
.59161 .27347 m .58241 .26403 L .58344 .2692 L 0 .237 .754 r
F
.58643 .27753 m .59161 .27347 L p .58344 .2692 L F P
0 g
s
.60109 .28246 m .59161 .27347 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.60014 .27675 m .58973 .27079 L .58973 .35378 L .206 .168 .592 r
F
.58437 .27388 m .58456 .27487 L .58456 .27967 L .88 .718 .202 r
F
.58441 .27855 m .58456 .27967 L .58456 .28348 L F
.58456 .27487 m .58643 .27753 L p .58344 .2692 L 0 .237 .754 r
F P
0 g
s
.58973 .27079 m .58299 .26693 L .58973 .35378 L .206 .168 .592 r
F
.61207 .28929 m .60109 .28246 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.607 .39843 m .607 .22601 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58299 .40365 m .58973 .40218 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58973 .40218 m .607 .39843 L p .58973 .35378 L .206 .168 .592 r
F P
0 g
s
.58973 .23563 m .58344 .23075 L .58973 .23106 L .781 .637 .703 r
F
.58973 .23563 m .58973 .23106 L .59853 .23149 L F
.58344 .23075 m .57575 .22478 L .59853 .23149 L F
.60027 .23158 m .607 .22601 L .59438 .23129 L .289 .763 .934 r
F
.58973 .22311 m .57819 .21213 L .58973 .20807 L .781 .637 .703 r
F
.607 .22601 m .58973 .25544 L .60014 .27675 L .206 .168 .592 r
F
.58973 .25544 m .58973 .27079 L .60014 .27675 L F
.607 .22601 m .58973 .23106 L p .59438 .23129 L .289 .763 .934 r
F P
0 g
s
.607 .22601 m .58973 .23106 L p .58973 .25544 L .206 .168 .592 r
F P
0 g
s
.58973 .20807 m .58315 .20041 L .58973 .20614 L .781 .637 .703 r
F
.66075 .29074 m .61035 .23208 L .62006 .23256 L F
.58405 .26271 m .5814 .25668 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.5814 .25668 m .57875 .25064 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.57365 .25485 m .57892 .26684 L .58241 .26403 L p 0 .09 .643 r
F P
0 g
s
.58241 .26403 m .58405 .26271 L p .58202 .26117 L 0 .09 .643 r
F P
0 g
s
.58202 .26117 m .57365 .25485 L .58241 .26403 L 0 .09 .643 r
F
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5885 .40982 m .6195 .41337 L .65808 .41234 L p .224 .73 .894 r
F P
0 g
s
.65808 .41234 m .68245 .40731 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.65515 .29467 m .66578 .28856 L .67144 .2846 L p .398 .823 .652 r
F P
0 g
s
.67144 .2846 m .66075 .29074 L .65515 .29467 L p .398 .823 .652 r
F P
0 g
s
.64674 .39734 m .67809 .40107 L .67809 .22957 L p .904 .738 .666 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.68245 .40731 m .67809 .40107 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.39597 .41234 m .35794 .41337 L .35794 .24609 L p .648 .529 .705 r
F P
0 g
s
.35794 .24609 m .39597 .24471 L .39597 .41234 L p .648 .529 .705 r
F P
0 g
s
.39597 .41234 m .39597 .24471 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41762 .40731 m .41145 .40874 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41145 .40874 m .39597 .41234 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.4254 .24604 m .42297 .25851 L p .41145 .27142 L .779 .636 .703 r
F P
0 g
s
.41145 .26559 m .4254 .24604 L .41145 .27142 L .779 .636 .703 r
F
.42521 .23321 m .4254 .24604 L p .41145 .26559 L F P
0 g
s
.41145 .25771 m .42521 .23321 L .41145 .26559 L .779 .636 .703 r
F
.39597 .24471 m .41145 .23987 L p .41145 .27929 L .175 .143 .58 r
F P
0 g
s
.40215 .29113 m .41145 .27929 L .41145 .36098 L .175 .143 .58 r
F
.39597 .24471 m .41145 .27929 L .40215 .29113 L F
.41145 .27929 m .41803 .27008 L .41887 .26923 L p 0 0 0 r
F P
0 g
s
.41887 .26923 m .42122 .26686 L p .41762 .27144 L 0 0 0 r
F P
0 g
s
.41762 .27144 m .41145 .27929 L .41887 .26923 L 0 0 0 r
F
.39597 .24471 m .41145 .23987 L p .32503 .24132 L .289 .763 .934 r
F P
0 g
s
.41664 .24012 m .42241 .22057 L .42121 .24034 L .779 .636 .703 r
F
.41145 .24618 m .4141 .24 L .41145 .25771 L F
.4141 .24 m .42241 .22057 L .41664 .24012 L F
.4141 .24 m .41664 .24012 L .41145 .25771 L F
.32503 .24132 m .41145 .23987 L .39134 .2389 L .289 .763 .934 r
F
.41712 .20866 m .42241 .22057 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.40957 .19801 m .41712 .20866 L p .40759 .23968 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .40149 .23939 L .40759 .23968 L .779 .636 .703 r
F
.40149 .23939 m .40957 .19801 L .40759 .23968 L F
.32503 .24132 m .35794 .24609 L .39597 .24471 L p .289 .763 .934 r
F P
0 g
s
.40007 .18907 m .40957 .19801 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .39134 .2389 L .35512 .23715 L .289 .763 .934 r
F
.38904 .18223 m .40007 .18907 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.37696 .1778 m .38904 .18223 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.36434 .17598 m .37696 .1778 L p .3841 .23855 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .37817 .23826 L .3841 .23855 L .779 .636 .703 r
F
.37817 .23826 m .36434 .17598 L .3841 .23855 L F
.35173 .17686 m .36434 .17598 L p .3907 .29467 L F P
0 g
s
.33969 .18039 m .35173 .17686 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32876 .18645 m .33969 .18039 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .35512 .23715 L .34007 .23642 L .289 .763 .934 r
F
.32503 .24132 m .35794 .24609 L .35794 .41337 L p .89 .727 .673 r
F P
0 g
s
.3194 .19475 m .32876 .18645 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.32503 .24132 m .34007 .23642 L .3294 .23591 L .289 .763 .934 r
F
.31205 .20495 m .3194 .19475 L p .34946 .23688 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .33962 .2364 L .34946 .23688 L .779 .636 .703 r
F
.33962 .2364 m .31205 .20495 L .34946 .23688 L F
.31872 .23539 m .32503 .24132 L p .3294 .23591 L .289 .763 .934 r
F P
0 g
s
.30703 .21659 m .31205 .20495 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.35794 .41337 m .32503 .40982 L .32503 .24132 L p .89 .727 .673 r
F P
0 g
s
.30455 .22916 m .30703 .21659 L p .31872 .2275 L .779 .636 .703 r
F P
0 g
s
.31872 .23993 m .30455 .22916 L .31872 .2275 L .779 .636 .703 r
F
.32503 .24132 m .32503 .29475 L p .31959 .27763 L .943 .77 .305 r
F P
0 g
s
.31872 .23539 m .32503 .24132 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.32063 .27753 m .31297 .26684 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.31297 .26684 m .31872 .27487 L p .31692 .2692 L 0 .18 .715 r
F P
0 g
s
.30475 .24211 m .30455 .22916 L p .31872 .23993 L .779 .636 .703 r
F P
0 g
s
.31872 .25065 m .30475 .24211 L .31872 .23993 L .779 .636 .703 r
F
.30759 .25485 m .30475 .24211 L p .3907 .29467 L F P
0 g
s
.31297 .26684 m .30759 .25485 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.3162 .23303 m .31872 .23539 L p .31872 .27487 L .943 .77 .305 r
F P
0 g
s
.31821 .27326 m .31872 .27487 L .31872 .28348 L .943 .77 .305 r
F
.3162 .23303 m .31872 .27487 L .31821 .27326 L F
.31692 .2692 m .3162 .26693 L .31297 .26684 L 0 .18 .715 r
F
.31528 .26403 m .31404 .26553 L p .3162 .26693 L F P
0 g
s
.31404 .26553 m .31297 .26684 L p .3162 .26693 L 0 .18 .715 r
F P
0 g
s
.30759 .25485 m .31297 .26684 L .31528 .26403 L p 0 .013 .588 r
F P
0 g
s
.3162 .26821 m .3162 .23303 L p .31847 .27855 L .943 .77 .305 r
F P
0 g
s
.3907 .29467 m .31872 .25065 L .31872 .23993 L .779 .636 .703 r
F
.3907 .29467 m .31872 .23993 L .31872 .2275 L F
.3162 .23303 m .31872 .23539 L p .32689 .23129 L .289 .763 .934 r
F P
0 g
s
.3162 .23303 m .3162 .26693 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.34319 .23208 m .32215 .21929 L .32215 .20807 L .779 .636 .703 r
F
.33113 .23149 m .32215 .22311 L .34319 .23208 L F
.32215 .22311 m .31039 .21213 L .32215 .21929 L F
.32215 .22311 m .32215 .21929 L .34319 .23208 L F
.3294 .23591 m .3329 .23158 L .31872 .23539 L .289 .763 .934 r
F
.3079 .22478 m .31039 .21213 L p .33113 .23149 L .779 .636 .703 r
F P
0 g
s
.31574 .23075 m .3079 .22478 L .33113 .23149 L .779 .636 .703 r
F
.3329 .23158 m .3374 .22601 L .32689 .23129 L .289 .763 .934 r
F
.3329 .23158 m .32689 .23129 L .31872 .23539 L F
.32215 .23106 m .3162 .23303 L p .32689 .23129 L F P
0 g
s
.32215 .23106 m .3162 .23303 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.36434 .17598 m .35173 .17686 L .35537 .17215 L p .361 .819 .928 r
F P
0 g
s
.37571 .23366 m .35537 .17215 L .38197 .23397 L .779 .636 .703 r
F
.35173 .17686 m .33969 .18039 L .34326 .17571 L p .441 .878 .864 r
F P
0 g
s
.34326 .17571 m .35537 .17215 L .35173 .17686 L p .441 .878 .864 r
F P
0 g
s
.34326 .17571 m .35537 .17215 L p .37571 .23366 L .779 .636 .703 r
F P
0 g
s
.36897 .23333 m .34326 .17571 L .37571 .23366 L .779 .636 .703 r
F
.37696 .1778 m .36434 .17598 L .36805 .17128 L p .272 .732 .952 r
F P
0 g
s
.35537 .17215 m .36805 .17128 L .36434 .17598 L p .361 .819 .928 r
F P
0 g
s
.35537 .17215 m .36805 .17128 L p .38197 .23397 L .779 .636 .703 r
F P
0 g
s
.41712 .20866 m .40957 .19801 L .41357 .19346 L p 0 .215 .74 r
F P
0 g
s
.40544 .23511 m .41357 .19346 L .41158 .23541 L .779 .636 .703 r
F
.40957 .19801 m .40007 .18907 L .40401 .18446 L p 0 .364 .833 r
F P
0 g
s
.40401 .18446 m .41357 .19346 L .40957 .19801 L p 0 .364 .833 r
F P
0 g
s
.40401 .18446 m .41357 .19346 L p .40544 .23511 L .779 .636 .703 r
F P
0 g
s
.39954 .23482 m .40401 .18446 L .40544 .23511 L .779 .636 .703 r
F
.42241 .22057 m .41712 .20866 L .42117 .20418 L p 0 .055 .619 r
F P
0 g
s
.41357 .19346 m .42117 .20418 L .41712 .20866 L p 0 .215 .74 r
F P
0 g
s
.41357 .19346 m .41546 .19613 L p .41158 .23541 L .779 .636 .703 r
F P
0 g
s
.41546 .19613 m .42117 .20418 L p .41546 .22276 L .779 .636 .703 r
F P
0 g
s
.41158 .23541 m .41546 .19613 L .41546 .22276 L .779 .636 .703 r
F
.40007 .18907 m .38904 .18223 L .39292 .17757 L p .086 .501 .901 r
F P
0 g
s
.39292 .17757 m .40401 .18446 L .40007 .18907 L p .086 .501 .901 r
F P
0 g
s
.39292 .17757 m .40401 .18446 L p .39954 .23482 L .779 .636 .703 r
F P
0 g
s
.40992 .23784 m .40992 .23532 L p .35512 .23715 L .289 .763 .934 r
F P
0 g
s
.35512 .23715 m .40992 .23532 L .37913 .23383 L .289 .763 .934 r
F
.39134 .2389 m .41762 .23794 L .35512 .23715 L F
.41145 .23987 m .41762 .23794 L p .39134 .2389 L F P
0 g
s
.3907 .29467 m .41145 .24618 L .41145 .25771 L .779 .636 .703 r
F
.3907 .29467 m .41145 .25771 L .41145 .26559 L F
.3907 .29467 m .41145 .26559 L .41145 .27142 L F
.42297 .25851 m .41803 .27008 L p .3907 .29467 L F P
0 g
s
.39458 .29074 m .39375 .23454 L .39954 .23482 L .779 .636 .703 r
F
.39375 .23454 m .39292 .17757 L .39954 .23482 L F
.38904 .18223 m .37696 .1778 L .38075 .17311 L p .18 .625 .941 r
F P
0 g
s
.38075 .17311 m .39292 .17757 L .38904 .18223 L p .18 .625 .941 r
F P
0 g
s
.38075 .17311 m .39292 .17757 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.36805 .17128 m .38075 .17311 L .37696 .1778 L p .272 .732 .952 r
F P
0 g
s
.36805 .17128 m .38075 .17311 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.40992 .23532 m .40992 .22957 L p .37913 .23383 L .289 .763 .934 r
F P
0 g
s
.4254 .24604 m .42521 .23321 L .42931 .2289 L p 0 0 .293 r
F P
0 g
s
.42649 .21617 m .42931 .2289 L .42521 .23321 L p 0 0 .47 r
F P
0 g
s
.42649 .21617 m .42931 .2289 L p .42528 .23607 L .779 .636 .703 r
F P
0 g
s
.41077 .23785 m .41762 .23794 L .41546 .23559 L .289 .763 .934 r
F
.41145 .25771 m .41664 .24012 L .42121 .24034 L .779 .636 .703 r
F
.41803 .27008 m .41078 .28024 L p .3907 .29467 L F P
0 g
s
.41762 .23794 m .41762 .40731 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41145 .23987 m .41762 .23794 L p .41145 .36098 L .175 .143 .58 r
F P
0 g
s
.41078 .28024 m .41145 .27929 L p .41737 .27189 L 0 0 0 r
F P
0 g
s
.41729 .27203 m .41078 .28024 L .41737 .27189 L 0 0 0 r
F
.41762 .40731 m .41762 .27144 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.40992 .40107 m .41546 .40556 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.41546 .40556 m .41762 .40731 L p .41546 .30778 L .923 .754 .269 r
F P
0 g
s
.41272 .27771 m .41145 .27929 L .41267 .27775 L 0 0 0 r
F
.4159 .2745 m .40992 .40107 L .41762 .27144 L .923 .754 .269 r
F
.41272 .27771 m .41267 .27775 L .42122 .26686 L 0 0 0 r
F
.42122 .26686 m .42208 .266 L p .41272 .27771 L F P
0 g
s
.4159 .2745 m .41546 .27527 L .41546 .28367 L .923 .754 .269 r
F
.41478 .27623 m .41078 .28024 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.42208 .266 m .41546 .27527 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.41546 .27527 m .41478 .27623 L p .41729 .27203 L 0 0 0 r
F P
0 g
s
.41546 .28367 m .41474 .27656 L .40992 .40107 L .923 .754 .269 r
F
.39458 .29074 m .41546 .27195 L .41478 .27623 L .779 .636 .703 r
F
.41762 .23794 m .41546 .23559 L p .41546 .27527 L .923 .754 .269 r
F P
0 g
s
.41762 .23794 m .41546 .27527 L .4159 .2745 L .923 .754 .269 r
F
.42241 .22057 m .42521 .23321 L p .42121 .24034 L .779 .636 .703 r
F P
0 g
s
.41762 .27144 m .41762 .23794 L p .4159 .2745 L .923 .754 .269 r
F P
0 g
s
.39458 .29074 m .41812 .23572 L .42528 .23607 L .779 .636 .703 r
F
.41077 .23785 m .41546 .23559 L .41051 .23535 L .289 .763 .934 r
F
.39458 .29074 m .40544 .23511 L .41158 .23541 L .779 .636 .703 r
F
.41078 .28024 m .40154 .28856 L .3907 .29467 L p F P
0 g
s
.40154 .28856 m .41078 .28024 L .41478 .27623 L p .496 .833 .546 r
F P
0 g
s
.41478 .27623 m .40548 .2846 L .40154 .28856 L p .496 .833 .546 r
F P
0 g
s
.42297 .25851 m .4254 .24604 L .4295 .24181 L p 0 0 .091 r
F P
0 g
s
.41803 .27008 m .42297 .25851 L .42705 .25436 L p 0 0 0 r
F P
0 g
s
.4295 .24181 m .42705 .25436 L .42297 .25851 L p 0 0 .091 r
F P
0 g
s
.4295 .24181 m .42705 .25436 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42931 .2289 m .4295 .24181 L .4254 .24604 L p 0 0 .293 r
F P
0 g
s
.42931 .2289 m .4295 .24181 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42705 .25436 m .42208 .266 L .41803 .27008 L p 0 0 0 r
F P
0 g
s
.42705 .25436 m .42208 .266 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.42521 .23321 m .42241 .22057 L .42649 .21617 L p 0 0 .47 r
F P
0 g
s
.42117 .20418 m .42649 .21617 L .42241 .22057 L p 0 .055 .619 r
F P
0 g
s
.42117 .20418 m .42649 .21617 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.41478 .27623 m .40548 .2846 L .39458 .29074 L p .779 .636 .703 r
F P
0 g
s
.40992 .22957 m .40992 .28511 L p .41474 .27656 L .923 .754 .269 r
F P
0 g
s
.40992 .28511 m .40992 .40107 L p .41474 .27656 L .923 .754 .269 r
F P
0 g
s
.42208 .266 m .41729 .27203 L .41737 .27189 L 0 0 0 r
F
.42208 .266 m .41546 .27527 L p .41546 .27195 L .779 .636 .703 r
F P
0 g
s
.41546 .27527 m .41478 .27623 L p .41546 .27195 L .779 .636 .703 r
F P
0 g
s
.41812 .23572 m .42649 .21617 L .42528 .23607 L .779 .636 .703 r
F
.41051 .23535 m .41546 .23559 L .40992 .22957 L .289 .763 .934 r
F
.41546 .23559 m .40992 .22957 L p .41546 .28367 L .923 .754 .269 r
F P
0 g
s
.39458 .29074 m .39954 .23482 L .40544 .23511 L .779 .636 .703 r
F
.35512 .23715 m .37913 .23383 L .34007 .23642 L .289 .763 .934 r
F
.37913 .23383 m .40992 .22957 L .37069 .23342 L F
.37913 .23383 m .37069 .23342 L .34007 .23642 L F
.34007 .23642 m .37069 .23342 L .35209 .23251 L F
.33969 .18039 m .32876 .18645 L .33225 .1818 L p .508 .9 .756 r
F P
0 g
s
.33225 .1818 m .34326 .17571 L .33969 .18039 L p .508 .9 .756 r
F P
0 g
s
.33225 .1818 m .34326 .17571 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32876 .18645 m .3194 .19475 L .32284 .19015 L p .552 .876 .601 r
F P
0 g
s
.32284 .19015 m .33225 .1818 L .32876 .18645 L p .552 .876 .601 r
F P
0 g
s
.32284 .19015 m .33225 .1818 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.34007 .23642 m .35209 .23251 L .3294 .23591 L .289 .763 .934 r
F
.35209 .23251 m .34494 .23217 L .3294 .23591 L F
.3294 .23591 m .34494 .23217 L .3329 .23158 L F
.31544 .20041 m .32284 .19015 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.40992 .22957 m .37656 .22455 L p .35209 .23251 L .289 .763 .934 r
F P
0 g
s
.37069 .23342 m .40992 .22957 L .35209 .23251 L .289 .763 .934 r
F
.39458 .29074 m .36897 .23333 L .37571 .23366 L .779 .636 .703 r
F
.35209 .23251 m .37656 .22455 L .34494 .23217 L .289 .763 .934 r
F
.37656 .22455 m .3374 .22601 L p .3329 .23158 L F P
0 g
s
.34494 .23217 m .37656 .22455 L .3329 .23158 L .289 .763 .934 r
F
.39458 .29074 m .37571 .23366 L .38197 .23397 L .779 .636 .703 r
F
.39458 .29074 m .32215 .23563 L .33113 .23149 L F
.33619 .23622 m .33113 .23149 L .33672 .23177 L F
.33619 .23622 m .33672 .23177 L .34319 .23208 L F
.39458 .29074 m .33619 .23622 L .34319 .23208 L F
.31872 .28348 m .31959 .27763 L .32503 .40982 L .943 .77 .305 r
F
.32503 .29475 m .32503 .40982 L p .31959 .27763 L F P
0 g
s
.32503 .40982 m .31872 .40541 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.33023 .28646 m .32063 .27753 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.34136 .29324 m .33023 .28646 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.33023 .28646 m .34136 .29324 L .34493 .28929 L p .037 .477 .882 r
F P
0 g
s
.32063 .27753 m .33023 .28646 L .33374 .28246 L p 0 .335 .813 r
F P
0 g
s
.34493 .28929 m .33374 .28246 L .33023 .28646 L p .037 .477 .882 r
F P
0 g
s
.33374 .28246 m .32407 .27347 L .32063 .27753 L p 0 .335 .813 r
F P
0 g
s
.30809 .23781 m .3079 .22478 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32215 .25544 m .3162 .26693 L .32215 .27079 L .149 .121 .569 r
F
.31095 .25064 m .30809 .23781 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.31636 .26271 m .31095 .25064 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32407 .27347 m .32215 .27079 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.32215 .27079 m .31636 .26271 L p .32215 .26478 L .779 .636 .703 r
F P
0 g
s
.39458 .29074 m .32215 .27079 L .32215 .26478 L .779 .636 .703 r
F
.3162 .40365 m .3162 .26821 L p .31872 .28348 L .943 .77 .305 r
F P
0 g
s
.31847 .27855 m .31872 .28348 L .3162 .26821 L .943 .77 .305 r
F
.31872 .40541 m .3162 .40365 L p .31872 .28348 L F P
0 g
s
.3162 .26693 m .3162 .40365 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32407 .27347 m .31636 .26271 L .31528 .26403 L p 0 .18 .715 r
F P
0 g
s
.32407 .27347 m .31528 .26403 L .31692 .2692 L 0 .18 .715 r
F
.32063 .27753 m .32407 .27347 L p .31692 .2692 L F P
0 g
s
.33374 .28246 m .32407 .27347 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.33135 .27675 m .32215 .27079 L .32215 .35378 L .149 .121 .569 r
F
.31872 .27487 m .32063 .27753 L p .31692 .2692 L 0 .18 .715 r
F P
0 g
s
.32215 .27079 m .3162 .26693 L .32215 .35378 L .149 .121 .569 r
F
.34493 .28929 m .33374 .28246 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.3374 .39843 m .3374 .22601 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.3162 .40365 m .32215 .40218 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32215 .40218 m .3374 .39843 L p .32215 .35378 L .149 .121 .569 r
F P
0 g
s
.32215 .23563 m .31574 .23075 L .32215 .23106 L .779 .636 .703 r
F
.32215 .23563 m .32215 .23106 L .33113 .23149 L F
.3374 .22601 m .32215 .25544 L .33135 .27675 L .149 .121 .569 r
F
.32215 .25544 m .32215 .27079 L .33135 .27675 L F
.3374 .22601 m .32215 .23106 L p .32689 .23129 L .289 .763 .934 r
F P
0 g
s
.3374 .22601 m .32215 .23106 L p .32215 .25544 L .149 .121 .569 r
F P
0 g
s
.31039 .21213 m .31544 .20041 L p .32215 .20807 L .779 .636 .703 r
F P
0 g
s
.32215 .21929 m .31039 .21213 L .32215 .20807 L .779 .636 .703 r
F
.31528 .26403 m .31636 .26271 L p .31465 .26117 L 0 .013 .588 r
F P
0 g
s
.31465 .26117 m .30759 .25485 L .31528 .26403 L 0 .013 .588 r
F
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.607 .39843 m .58299 .40365 L .5885 .40982 L p .224 .73 .894 r
F P
0 g
s
.64674 .39734 m .607 .39843 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.67809 .40107 m .64674 .39734 L p .5885 .40982 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.63108 .29929 m .61868 .29758 L p .65515 .29467 L .78 .637 .703 r
F P
0 g
s
.65515 .29467 m .64341 .2983 L .63108 .29929 L p .78 .637 .703 r
F P
0 g
s
.64341 .2983 m .65515 .29467 L .66075 .29074 L p .361 .831 .799 r
F P
0 g
s
.63108 .29929 m .64341 .2983 L .64894 .29439 L p .304 .792 .892 r
F P
0 g
s
.66075 .29074 m .64894 .29439 L .64341 .2983 L p .361 .831 .799 r
F P
0 g
s
.64894 .29439 m .63653 .29538 L .63108 .29929 L p .304 .792 .892 r
F P
0 g
s
.62406 .29366 m .61207 .28929 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.63653 .29538 m .62406 .29366 L p .66075 .29074 L .781 .637 .703 r
F P
0 g
s
.66075 .29074 m .64894 .29439 L .63653 .29538 L p .781 .637 .703 r
F P
0 g
s
.67809 .22957 m .64674 .22455 L .64674 .39734 L p .904 .738 .666 r
F P
0 g
s
.61868 .29758 m .63108 .29929 L .63653 .29538 L p .236 .716 .934 r
F P
0 g
s
.63653 .29538 m .62406 .29366 L .61868 .29758 L p .236 .716 .934 r
F P
0 g
s
.607 .39843 m .64674 .39734 L .64674 .22455 L p .647 .528 .705 r
F P
0 g
s
.64674 .22455 m .607 .22601 L .607 .39843 L p .647 .528 .705 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32503 .40982 m .35794 .41337 L .39597 .41234 L p .224 .73 .894 r
F P
0 g
s
.39597 .41234 m .41762 .40731 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3374 .39843 m .3162 .40365 L .32503 .40982 L p .224 .73 .894 r
F P
0 g
s
.37656 .39734 m .3374 .39843 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.40992 .40107 m .37656 .39734 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.41762 .40731 m .40992 .40107 L p .32503 .40982 L .224 .73 .894 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.3907 .29467 m .40154 .28856 L .40548 .2846 L p .457 .867 .709 r
F P
0 g
s
.40548 .2846 m .39458 .29074 L .3907 .29467 L p .457 .867 .709 r
F P
0 g
s
.37656 .39734 m .40992 .40107 L .40992 .22957 L p .895 .731 .67 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.35351 .29758 m .34136 .29324 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.36615 .29929 m .35351 .29758 L p .3907 .29467 L .779 .636 .703 r
F P
0 g
s
.3907 .29467 m .37873 .2983 L .36615 .29929 L p .779 .636 .703 r
F P
0 g
s
.37873 .2983 m .3907 .29467 L .39458 .29074 L p .395 .852 .828 r
F P
0 g
s
.36615 .29929 m .37873 .2983 L .38254 .29439 L p .316 .798 .9 r
F P
0 g
s
.39458 .29074 m .38254 .29439 L .37873 .2983 L p .395 .852 .828 r
F P
0 g
s
.35351 .29758 m .36615 .29929 L .36988 .29538 L p .227 .712 .929 r
F P
0 g
s
.38254 .29439 m .36988 .29538 L .36615 .29929 L p .316 .798 .9 r
F P
0 g
s
.34136 .29324 m .35351 .29758 L .35716 .29366 L p .133 .604 .922 r
F P
0 g
s
.36988 .29538 m .35716 .29366 L .35351 .29758 L p .227 .712 .929 r
F P
0 g
s
.35716 .29366 m .34493 .28929 L .34136 .29324 L p .133 .604 .922 r
F P
0 g
s
.59441 .18645 m .58523 .19475 L .59041 .19015 L p 0 0 0 r
F P
0 g
s
.59041 .19015 m .59963 .1818 L .59441 .18645 L p 0 0 0 r
F P
0 g
s
.58523 .19475 m .57802 .20495 L .58315 .20041 L p 0 0 0 r
F P
0 g
s
.58315 .20041 m .59041 .19015 L .58523 .19475 L p 0 0 0 r
F P
0 g
s
.3194 .19475 m .31205 .20495 L .31544 .20041 L p 0 0 0 r
F P
0 g
s
.31544 .20041 m .32284 .19015 L .3194 .19475 L p 0 0 0 r
F P
0 g
s
.57802 .20495 m .57309 .21659 L .57819 .21213 L p 0 0 0 r
F P
0 g
s
.57819 .21213 m .58315 .20041 L .57802 .20495 L p 0 0 0 r
F P
0 g
s
.31205 .20495 m .30703 .21659 L .31039 .21213 L p 0 0 0 r
F P
0 g
s
.31039 .21213 m .31544 .20041 L .31205 .20495 L p 0 0 0 r
F P
0 g
s
.57086 .24211 m .57365 .25485 L .57875 .25064 L p 0 0 .506 r
F P
0 g
s
.30475 .24211 m .30759 .25485 L .31095 .25064 L p 0 0 .431 r
F P
0 g
s
.31636 .26271 m .31095 .25064 L .30759 .25485 L p 0 .013 .588 r
F P
0 g
s
.57309 .21659 m .57067 .22916 L .57575 .22478 L p 0 0 .147 r
F P
0 g
s
.57575 .22478 m .57819 .21213 L .57309 .21659 L p 0 0 .147 r
F P
0 g
s
.30703 .21659 m .30455 .22916 L .3079 .22478 L p 0 0 .035 r
F P
0 g
s
.3079 .22478 m .31039 .21213 L .30703 .21659 L p 0 0 .035 r
F P
0 g
s
.57067 .22916 m .57086 .24211 L .57594 .23781 L p 0 0 .341 r
F P
0 g
s
.57875 .25064 m .57594 .23781 L .57086 .24211 L p 0 0 .506 r
F P
0 g
s
.30455 .22916 m .30475 .24211 L .30809 .23781 L p 0 0 .245 r
F P
0 g
s
.31095 .25064 m .30809 .23781 L .30475 .24211 L p 0 0 .431 r
F P
0 g
s
.57594 .23781 m .57575 .22478 L .57067 .22916 L p 0 0 .341 r
F P
0 g
s
.30809 .23781 m .3079 .22478 L .30455 .22916 L p 0 0 .245 r
F P
0 g
s
.35716 .29366 m .34493 .28929 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.36988 .29538 m .35716 .29366 L p .39458 .29074 L .779 .636 .703 r
F P
0 g
s
.39458 .29074 m .38254 .29439 L .36988 .29538 L p .779 .636 .703 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.40992 .22957 m .37656 .22455 L .37656 .39734 L p .895 .731 .67 r
F P
0 g
s
.3374 .39843 m .37656 .39734 L .37656 .22455 L p .646 .527 .705 r
F P
0 g
s
.37656 .22455 m .3374 .22601 L .3374 .39843 L p .646 .527 .705 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .70623 .8322 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70139 .8749 m .70559 .87438 L .74865 .87438 L .012 .587 .719 r
F
.75114 .87453 m .70139 .8749 L p .74865 .87438 L F P
0 g
s
.74865 .87438 m .74181 .87165 L .74467 .87415 L .631 .119 0 r
F
.74865 .87438 m .70623 .8322 L .71556 .86115 L p F P
0 g
s
.70996 .87384 m .77017 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70496 .91631 m .74865 .87438 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70996 1.10469 m .76548 .89235 L .74555 .88571 L .96 .784 .62 r
F
.70996 .93399 m .70996 1.10469 L p .73436 .95458 L F P
0 g
s
.73436 .95458 m .74555 .88571 L .70996 .93399 L .96 .784 .62 r
F
.70623 .8322 m .66253 .87438 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.70559 .87438 m .66253 .87438 L .70996 .87384 L .012 .587 .719 r
F
.67022 .87415 m .70996 .87384 L p .66253 .87438 L F P
0 g
s
.70139 .8749 m .64101 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.66253 .87438 m .70496 .91631 L p .70559 .87438 L .703 .639 .783 r
F P
0 g
s
.66253 .87438 m .70496 .91631 L .70996 .93399 L p .653 .141 0 r
F P
0 g
s
.64101 1.04449 m .69353 .91452 L .65546 .88543 L .333 .272 .638 r
F
.64101 .87438 m .64101 .89646 L p .65546 .88543 L F P
0 g
s
.64101 .89646 m .64101 1.04449 L p .65546 .88543 L .333 .272 .638 r
F P
0 g
s
.66253 .87438 m .70996 .93399 L .67582 .89355 L .653 .141 0 r
F
.70996 .87384 m .67022 .87415 L p .69353 .91452 L .333 .272 .638 r
F P
0 g
s
.70623 .8322 m .66253 .87438 L p .67022 .87415 L 0 0 0 r
F P
0 g
s
.66253 .87438 m .65965 .87438 L .67022 .87415 L .012 .587 .719 r
F
.65965 .87438 m .64101 .87438 L .67022 .87415 L F
.69353 .91452 m .66367 .87915 L .68405 .90728 L .333 .272 .638 r
F
.66367 .87915 m .66335 .87939 L .68405 .90728 L F
.65952 .87424 m .64101 .87438 L p .68405 .90728 L F P
0 g
s
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62791 1.2604 m .6274 1.28899 L .3726 1.28899 L p .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37209 1.2604 L .62791 1.2604 L p .691 .686 .84 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .6274 1.28899 L p .694 .457 .559 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.50802 1.25704 m .54018 1.25552 L .52667 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .54517 1.25817 L F
.54018 1.25552 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.51938 1.25967 m .51947 1.25865 L .52667 1.25967 L .365 .792 .97 r
F
.452 1.25967 m .51947 1.25865 L .51938 1.25967 L F
.452 1.25967 m .50802 1.25704 L .51947 1.25865 L F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L .365 .792 .97 r
F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.52783 1.09787 m .46974 1.09988 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L .066 0 0 r
F P
0 g
s
.36257 1.04436 m .3516 1.04413 L .36228 1.04465 L .066 0 0 r
F
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.29225 1.04601 m .29004 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.36099 1.04601 m .32488 1.04601 L p .36054 1.06375 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L .767 .626 .063 r
F
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36002 1.08458 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.40242 1.08458 m .32488 1.04601 L .39124 1.08458 L .68 .398 .487 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.29653 1.043 m .29225 1.04601 L .32488 1.04601 L p .066 0 0 r
F P
0 g
s
.32488 1.04601 m .36099 1.04601 L p .34335 1.04519 L .066 0 0 r
F P
0 g
s
.34335 1.04519 m .29653 1.043 L .32488 1.04601 L .066 0 0 r
F
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.32488 1.04601 m .29225 1.04601 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L F P
0 g
s
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.35851 1.02865 m .3605 .95121 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.36032 1.07254 m .32488 1.04601 L .31875 1.05634 L .68 .398 .487 r
F
.36047 1.0667 m .32488 1.04601 L .36032 1.07254 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.29004 1.10469 m .44284 1.10469 L p .31875 1.05634 L .68 .398 .487 r
F P
0 g
s
.36002 1.08458 m .35851 1.02865 L p .3605 1.06543 L .767 .626 .063 r
F P
0 g
s
.39124 1.08458 m .36047 1.0667 L .36032 1.07254 L .68 .398 .487 r
F
.44284 1.10469 m .40242 1.08458 L .39124 1.08458 L F
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L .767 .626 .063 r
F P
0 g
s
.3605 1.04653 m .3605 .95121 L .36194 1.04502 L .767 .626 .063 r
F
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.484 1.29086 m .47278 1.29329 L p .46863 1.25897 L .997 .814 .539 r
F P
0 g
s
.46983 1.25648 m .484 1.29086 L .46863 1.25897 L .997 .814 .539 r
F
.46771 1.25133 m .46983 1.25648 L .46863 1.25897 L F
.46771 1.28484 m .46771 1.25133 L p .47278 1.29329 L F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.28484 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.47278 1.29329 m .46133 1.29296 L p .46771 1.28484 L .526 .721 .962 r
F P
0 g
s
.6274 1.28899 m .62791 1.3207 L .37209 1.3207 L p .694 .457 .559 r
F P
0 g
s
.41389 1.31592 m .41923 1.29174 L .48168 1.29355 L p .577 .233 .351 r
F P
0 g
s
.46771 1.29439 m .46832 1.28585 L p .47278 1.29329 L .997 .814 .539 r
F P
0 g
s
.47058 1.25401 m .46771 1.28484 L .46846 1.28388 L .063 .051 .53 r
F
.46771 1.28484 m .47675 1.2746 L .47278 1.29329 L .526 .721 .962 r
F
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.48163 1.25846 m .48371 1.25952 L .48217 1.2658 L .997 .814 .539 r
F
.48371 1.25952 m .484 1.25967 L .48217 1.2658 L F
.484 1.25967 m .484 1.29086 L p .48217 1.2658 L F P
0 g
s
.47808 1.26098 m .47452 1.27245 L .48273 1.26531 L .063 .051 .53 r
F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48168 1.29355 m .47675 1.31785 L .41389 1.31592 L p .577 .233 .351 r
F P
0 g
s
.47675 1.31785 m .48168 1.29355 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.47174 1.29894 m .4765 1.31691 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.4765 1.31691 m .47675 1.31785 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.48371 1.29798 m .48371 1.29322 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .48204 1.29334 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47468 1.25782 m .48371 1.26622 L .51629 1.26622 L .513 .022 .027 r
F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L .513 .022 .027 r
F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62827 1.30072 m .62806 1.27693 L .62849 1.28848 L 0 0 .059 r
F
.62791 1.30812 m .62791 1.2604 L .62827 1.30072 L F
.62866 1.29284 m .65354 1.29355 L p .62899 1.30169 L .578 .237 .354 r
F P
0 g
s
.64977 1.2746 m .65354 1.29355 L .62866 1.29284 L p .529 .72 .961 r
F P
0 g
s
.62926 1.28051 m .64977 1.2746 L .62866 1.29284 L .529 .72 .961 r
F
.62958 1.27405 m .64977 1.2746 L p .62926 1.28051 L F P
0 g
s
.65354 1.29355 m .64977 1.31785 L .62958 1.31724 L p .578 .237 .354 r
F P
0 g
s
.62791 1.3207 m .62827 1.30072 L .62871 1.29411 L 0 0 .059 r
F
.62791 1.3207 m .62871 1.29411 L .62892 1.29966 L F
.62791 1.3207 m .62791 1.30812 L .62827 1.30072 L F
.62899 1.30169 m .65354 1.29355 L .62958 1.31724 L .578 .237 .354 r
F
.62958 1.31724 m .64977 1.31785 L p .62985 1.31176 L .526 .721 .962 r
F P
0 g
s
.62791 1.3207 m .63016 1.30551 L .6292 1.32493 L 0 0 .059 r
F
.64977 1.31785 m .64595 1.29894 L .63051 1.29849 L p .526 .721 .962 r
F P
0 g
s
.64595 1.29894 m .64977 1.2746 L .62958 1.27405 L p .576 .233 .35 r
F P
0 g
s
.63027 1.2921 m .64595 1.29894 L .62958 1.27405 L .576 .233 .35 r
F
.62791 1.3207 m .62983 1.28057 L .63041 1.29598 L 0 0 .059 r
F
.63051 1.29849 m .64595 1.29894 L p .63027 1.2921 L .576 .233 .35 r
F P
0 g
s
.62791 1.3207 m .63085 1.29168 L .63016 1.30551 L 0 0 .059 r
F
.62892 1.29966 m .62871 1.29411 L .63045 1.26755 L F
.62917 1.25133 m .63011 1.26323 L p .62827 1.30072 L F P
0 g
s
.63011 1.26323 m .63045 1.26755 L p .62827 1.30072 L 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62849 1.28848 L 0 0 .059 r
F P
0 g
s
.62806 1.27693 m .62791 1.2604 L .62849 1.28848 L 0 0 .059 r
F
.59029 1.29174 m .58611 1.27286 L .62958 1.27405 L p .529 .72 .961 r
F P
0 g
s
.59029 1.29174 m .62958 1.27405 L .62926 1.28051 L .529 .72 .961 r
F
.58611 1.31592 m .59029 1.29174 L .62866 1.29284 L p .578 .237 .354 r
F P
0 g
s
.58611 1.31592 m .62866 1.29284 L .62899 1.30169 L .578 .237 .354 r
F
.62866 1.29284 m .59029 1.29174 L p .62926 1.28051 L .529 .72 .961 r
F P
0 g
s
.59029 1.29174 m .58611 1.27286 L .58188 1.29708 L p .919 .751 .263 r
F P
0 g
s
.58188 1.29708 m .58611 1.31592 L .59029 1.29174 L p .919 .751 .263 r
F P
0 g
s
.58611 1.27286 m .58188 1.29708 L .63051 1.29849 L p .576 .233 .35 r
F P
0 g
s
.58611 1.27286 m .63051 1.29849 L .63027 1.2921 L .576 .233 .35 r
F
.62985 1.31176 m .64977 1.31785 L .63051 1.29849 L .526 .721 .962 r
F
.63085 1.29168 m .63099 1.29994 L p .63065 1.3022 L 0 0 .059 r
F P
0 g
s
.63016 1.30551 m .63051 1.29849 L .63065 1.3022 L 0 0 .059 r
F
.63051 1.29849 m .63085 1.29168 L .63065 1.3022 L F
.63045 1.26755 m .63085 1.29168 L p .63041 1.29598 L F P
0 g
s
.62983 1.28057 m .63045 1.26755 L .63041 1.29598 L 0 0 .059 r
F
.62958 1.27405 m .58611 1.27286 L p .63027 1.2921 L .576 .233 .35 r
F P
0 g
s
.61362 1.30679 m .62899 1.30169 L .62937 1.31161 L .578 .237 .354 r
F
.61362 1.30679 m .62937 1.31161 L .62958 1.31724 L F
.62958 1.31724 m .58611 1.31592 L p .61362 1.30679 L F P
0 g
s
.63051 1.29849 m .58188 1.29708 L p .62985 1.31176 L .526 .721 .962 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .6292 1.32493 L 0 0 .059 r
F P
0 g
s
.63016 1.30551 m .63099 1.29994 L .6292 1.32493 L 0 0 .059 r
F
.58188 1.29708 m .58611 1.31592 L .62958 1.31724 L p .526 .721 .962 r
F P
0 g
s
.58188 1.29708 m .62958 1.31724 L .62985 1.31176 L .526 .721 .962 r
F
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.46974 1.09988 m .46771 1.09965 L .484 1.09787 L .09 0 0 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L .707 .577 .707 r
F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.47544 1.27499 m .47675 1.2746 L .46771 1.28484 L .526 .721 .962 r
F
.48146 1.10121 m .46846 1.28388 L .48371 1.10147 L .063 .051 .53 r
F
.46846 1.28388 m .46771 1.29439 L .46859 1.28371 L F
.46846 1.28388 m .46859 1.28371 L .48371 1.10147 L F
.47452 1.27245 m .47261 1.27859 L .47577 1.27457 L F
.47144 1.24935 m .46771 1.29439 L .48371 1.24284 L F
.41923 1.29174 m .41389 1.27286 L .47577 1.27457 L p .526 .721 .962 r
F P
0 g
s
.47577 1.27457 m .47675 1.2746 L p .47544 1.27499 L .526 .721 .962 r
F P
0 g
s
.41923 1.29174 m .47577 1.27457 L .47544 1.27499 L .526 .721 .962 r
F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L .063 .051 .53 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L .09 0 0 r
F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L F P
0 g
s
.47675 1.2746 m .48168 1.29355 L .47278 1.29329 L p .526 .721 .962 r
F P
0 g
s
.46771 1.29439 m .4765 1.29636 L p .4765 1.27795 L .063 .051 .53 r
F P
0 g
s
.48168 1.29355 m .47675 1.2746 L .4765 1.27581 L p .941 .768 .3 r
F P
0 g
s
.47261 1.27859 m .46771 1.29439 L .4765 1.27795 L .063 .051 .53 r
F
.4765 1.27581 m .47675 1.2746 L .47577 1.27457 L p .574 .229 .346 r
F P
0 g
s
.47261 1.27859 m .4765 1.27795 L .4765 1.27364 L .063 .051 .53 r
F
.4765 1.27581 m .47174 1.29894 L p .4765 1.29636 L .941 .768 .3 r
F P
0 g
s
.4765 1.29636 m .48168 1.29355 L .4765 1.27581 L .941 .768 .3 r
F
.4765 1.27364 m .4765 1.27795 L .48371 1.26445 L .063 .051 .53 r
F
.48371 1.29798 m .48371 1.26622 L p .4765 1.27795 L F P
0 g
s
.48308 1.26563 m .4765 1.27795 L .48371 1.26622 L .063 .051 .53 r
F
.47452 1.27245 m .47577 1.27457 L .48291 1.26547 L F
.48273 1.26531 m .48291 1.26547 L .48371 1.26445 L F
.47452 1.27245 m .48291 1.26547 L .48273 1.26531 L F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.48371 1.26622 m .48371 1.26445 L p .48308 1.26563 L .063 .051 .53 r
F P
0 g
s
.4765 1.29636 m .48371 1.29798 L p .4765 1.27795 L .063 .051 .53 r
F P
0 g
s
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.48371 1.26445 m .48371 1.24284 L p .47808 1.26098 L .063 .051 .53 r
F P
0 g
s
.47808 1.26098 m .48273 1.26531 L .48371 1.26445 L .063 .051 .53 r
F
.46387 1.27844 m .47544 1.27499 L .46771 1.28484 L .526 .721 .962 r
F
.46771 1.28484 m .46771 1.29439 L p .46846 1.28388 L .063 .051 .53 r
F P
0 g
s
.41923 1.29174 m .46387 1.27844 L .46771 1.28484 L .526 .721 .962 r
F
.46133 1.29296 m .41923 1.29174 L p .46771 1.28484 L F P
0 g
s
.47174 1.29894 m .4765 1.27581 L p .46131 1.27417 L .574 .229 .346 r
F P
0 g
s
.47577 1.27457 m .46131 1.27417 L p .4765 1.27581 L .574 .229 .346 r
F P
0 g
s
.46131 1.27417 m .41389 1.27286 L p .45336 1.29066 L .574 .229 .346 r
F P
0 g
s
.45336 1.29066 m .47174 1.29894 L .46131 1.27417 L .574 .229 .346 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L .513 .022 .027 r
F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46974 1.09988 m .46368 1.10009 L .46771 1.09965 L F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.64107 1.0445 m .64107 1.04434 L .64101 1.04449 L .333 .272 .638 r
F
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.6578 1.04524 m .64107 1.04434 L .64107 1.0445 L .333 .272 .638 r
F
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70996 .87384 L .64107 1.04434 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44284 1.10469 m .36099 1.04601 L .36054 1.06375 L .68 .398 .487 r
F
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.30737 1.04679 m .32488 1.04601 L .35899 .87438 L .943 .77 .638 r
F
.35899 .98856 m .35899 .87438 L p .32488 1.04601 L F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70996 .93399 m .70496 .91631 L p .72618 .91199 L 0 0 0 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.77017 .87438 m .75114 .87453 L p .74865 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .75401 .87424 L p .76548 .89235 L .96 .784 .62 r
F P
0 g
s
.70496 .91631 m .74865 .87438 L .75038 .87915 L p 0 0 0 r
F P
0 g
s
.75401 .87424 m .74467 .87415 L p .75038 .87915 L .96 .784 .62 r
F P
0 g
s
.76548 .89235 m .75401 .87424 L .75038 .87915 L .96 .784 .62 r
F
.70496 .91631 m .75038 .87915 L .72881 .90842 L 0 0 0 r
F
.74467 .87415 m .70996 .87384 L p .76548 .89235 L .96 .784 .62 r
F P
0 g
s
.75038 .87915 m .75759 .89891 L p .72881 .90842 L 0 0 0 r
F P
0 g
s
.75759 .89891 m .75986 .90514 L p .74504 .90816 L 0 0 0 r
F P
0 g
s
.70496 .91631 m .75759 .89891 L .74504 .90816 L 0 0 0 r
F
.70996 1.04757 m .70996 .93399 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70996 .93399 m .70996 .87384 L p .68637 .95138 L .333 .272 .638 r
F P
0 g
s
.6578 1.04524 m .70996 .93399 L .68637 .95138 L .333 .272 .638 r
F
.71417 .94885 m .66987 .90514 L .66367 .87915 L p .653 .141 0 r
F P
0 g
s
.67582 .89355 m .71417 .94885 L .66367 .87915 L .653 .141 0 r
F
.66367 .87915 m .66253 .87438 L p .67582 .89355 L F P
0 g
s
.69353 .91452 m .67022 .87415 L .66367 .87915 L .333 .272 .638 r
F
.67582 .89355 m .70996 .93399 L .69528 .9216 L .653 .141 0 r
F
.66987 .90514 m .71556 .86115 L .70996 .84379 L p 0 0 0 r
F P
0 g
s
.70996 .84379 m .70623 .8322 L p .6946 .85553 L 0 0 0 r
F P
0 g
s
.6946 .85553 m .66987 .90514 L .70996 .84379 L 0 0 0 r
F
.66367 .87915 m .65952 .87424 L .66335 .87939 L .333 .272 .638 r
F
.66253 .87438 m .66367 .87915 L p .67022 .87415 L 0 0 0 r
F P
0 g
s
.67022 .87415 m .65952 .87424 L p .66367 .87915 L .333 .272 .638 r
F P
0 g
s
.6946 .85553 m .67022 .87415 L .68554 .87369 L 0 0 0 r
F
.70623 .8322 m .67022 .87415 L .6946 .85553 L F
.68554 .87369 m .67022 .87415 L .66987 .90514 L F
.66367 .87915 m .66987 .90514 L p .67022 .87415 L F P
0 g
s
.70996 .93399 m .71417 .94885 L p .69528 .9216 L .653 .141 0 r
F P
0 g
s
.75986 .90514 m .71417 .94885 L .70996 .93399 L p 0 0 0 r
F P
0 g
s
.72618 .91199 m .75986 .90514 L .70996 .93399 L 0 0 0 r
F
.70996 .87384 m .70996 .93399 L p .74555 .88571 L .96 .784 .62 r
F P
0 g
s
.71556 .86115 m .72766 .87316 L p .74467 .87415 L .631 .119 0 r
F P
0 g
s
.74181 .87165 m .71556 .86115 L .74467 .87415 L .631 .119 0 r
F
.72766 .87316 m .75986 .90514 L .74865 .87438 L p F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.38636 .3673 m .34485 .36852 L .34485 .18583 L p .642 .524 .704 r
F P
0 g
s
.34485 .18583 m .38636 .18419 L .38636 .3673 L p .642 .524 .704 r
F P
0 g
s
.34485 .36852 m .30878 .36429 L .30878 .18013 L p .902 .736 .667 r
F P
0 g
s
.30878 .18013 m .34485 .18583 L .34485 .36852 L p .902 .736 .667 r
F P
0 g
s
.38636 .3673 m .38636 .18419 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40993 .36128 m .40321 .363 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40321 .363 m .38636 .3673 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.41846 .18522 m .4158 .19884 L p .40321 .21289 L .785 .641 .702 r
F P
0 g
s
.40321 .20652 m .41846 .18522 L .40321 .21289 L .785 .641 .702 r
F
.41826 .1712 m .41846 .18522 L p .40321 .20652 L F P
0 g
s
.40321 .19791 m .41826 .1712 L .40321 .20652 L .785 .641 .702 r
F
.38636 .18419 m .40321 .17841 L p .40321 .2215 L .131 .107 .561 r
F P
0 g
s
.39308 .23472 m .40321 .2215 L .40321 .31079 L .131 .107 .561 r
F
.38636 .18419 m .40321 .2215 L .39308 .23472 L F
.40321 .2215 m .4104 .21146 L .41131 .21044 L p 0 0 0 r
F P
0 g
s
.41131 .21044 m .41385 .20761 L p .40993 .21273 L 0 0 0 r
F P
0 g
s
.40993 .21273 m .40321 .2215 L .41131 .21044 L 0 0 0 r
F
.38636 .18419 m .40321 .17841 L p .30878 .18013 L .289 .763 .934 r
F P
0 g
s
.40889 .17871 m .4152 .15736 L .41388 .17897 L .785 .641 .702 r
F
.40321 .1853 m .4061 .17856 L .40321 .19791 L F
.4061 .17856 m .4152 .15736 L .40889 .17871 L F
.4061 .17856 m .40889 .17871 L .40321 .19791 L F
.30878 .18013 m .40321 .17841 L .3812 .17725 L .289 .763 .934 r
F
.40941 .14432 m .4152 .15736 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.40115 .13264 m .40941 .14432 L p .39899 .17818 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .39231 .17783 L .39899 .17818 L .785 .641 .702 r
F
.39231 .17783 m .40115 .13264 L .39899 .17818 L F
.30878 .18013 m .34485 .18583 L .38636 .18419 L p .289 .763 .934 r
F P
0 g
s
.39076 .12281 m .40115 .13264 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .3812 .17725 L .34157 .17516 L .289 .763 .934 r
F
.3787 .11528 m .39076 .12281 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.36547 .11038 m .3787 .11528 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.35166 .10832 m .36547 .11038 L p .37328 .17683 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .36679 .17649 L .37328 .17683 L .785 .641 .702 r
F
.36679 .17649 m .35166 .10832 L .37328 .17683 L F
.33786 .10921 m .35166 .10832 L p .3805 .23822 L F P
0 g
s
.32468 .11301 m .33786 .10921 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.31271 .11957 m .32468 .11301 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .34157 .17516 L .32509 .17429 L .289 .763 .934 r
F
.30247 .1286 m .31271 .11957 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.30878 .18013 m .32509 .17429 L .31341 .17367 L .289 .763 .934 r
F
.29441 .13972 m .30247 .1286 L p .33537 .17483 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .3246 .17426 L .33537 .17483 L .785 .641 .702 r
F
.3246 .17426 m .29441 .13972 L .33537 .17483 L F
.30171 .17305 m .30878 .18013 L p .31341 .17367 L .289 .763 .934 r
F P
0 g
s
.28891 .15243 m .29441 .13972 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.2862 .16617 m .28891 .15243 L p .30171 .16442 L .785 .641 .702 r
F P
0 g
s
.30171 .17802 m .2862 .16617 L .30171 .16442 L .785 .641 .702 r
F
.30878 .18013 m .30878 .23853 L p .3027 .21933 L .934 .763 .288 r
F P
0 g
s
.30171 .17305 m .30878 .18013 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.3038 .21915 m .29541 .20742 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.29541 .20742 m .30171 .21623 L p .2997 .20987 L 0 .166 .704 r
F P
0 g
s
.28641 .18033 m .2862 .16617 L p .30171 .17802 L .785 .641 .702 r
F P
0 g
s
.30171 .18974 m .28641 .18033 L .30171 .17802 L .785 .641 .702 r
F
.28953 .19429 m .28641 .18033 L p .3805 .23822 L F P
0 g
s
.29541 .20742 m .28953 .19429 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.29889 .17022 m .30171 .17305 L p .30171 .21623 L .934 .763 .288 r
F P
0 g
s
.30114 .21442 m .30171 .21623 L .30171 .22565 L .934 .763 .288 r
F
.29889 .17022 m .30171 .21623 L .30114 .21442 L F
.2997 .20987 m .29889 .20732 L .29541 .20742 L 0 .166 .704 r
F
.29786 .20405 m .29655 .20585 L p .29889 .20732 L F P
0 g
s
.29655 .20585 m .29541 .20742 L p .29889 .20732 L 0 .166 .704 r
F P
0 g
s
.28953 .19429 m .29541 .20742 L .29786 .20405 L p 0 0 .572 r
F P
0 g
s
.29889 .20872 m .29889 .17022 L p .30144 .22023 L .934 .763 .288 r
F P
0 g
s
.3805 .23822 m .30171 .18974 L .30171 .17802 L .785 .641 .702 r
F
.3805 .23822 m .30171 .17802 L .30171 .16442 L F
.29889 .17022 m .30171 .17305 L p .31055 .16814 L .289 .763 .934 r
F P
0 g
s
.29889 .17022 m .29889 .20732 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.3284 .16909 m .30535 .15498 L .30535 .14271 L .785 .641 .702 r
F
.31518 .16839 m .30535 .15917 L .3284 .16909 L F
.30535 .15917 m .29246 .14708 L .30535 .15498 L F
.30535 .15917 m .30535 .15498 L .3284 .16909 L F
.31341 .17367 m .31713 .16849 L .30171 .17305 L .289 .763 .934 r
F
.28973 .16092 m .29246 .14708 L p .31518 .16839 L .785 .641 .702 r
F P
0 g
s
.29832 .16749 m .28973 .16092 L .31518 .16839 L .785 .641 .702 r
F
.31713 .16849 m .32192 .16181 L .31055 .16814 L .289 .763 .934 r
F
.31713 .16849 m .31055 .16814 L .30171 .17305 L F
.30535 .16786 m .29889 .17022 L p .31055 .16814 L F P
0 g
s
.30535 .16786 m .29889 .17022 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.35166 .10832 m .33786 .10921 L .34174 .10357 L p .363 .82 .929 r
F P
0 g
s
.36401 .17098 m .34174 .10357 L .37088 .17135 L .785 .641 .702 r
F
.33786 .10921 m .32468 .11301 L .32848 .1074 L p .448 .882 .87 r
F P
0 g
s
.32848 .1074 m .34174 .10357 L .33786 .10921 L p .448 .882 .87 r
F P
0 g
s
.32848 .1074 m .34174 .10357 L p .36401 .17098 L .785 .641 .702 r
F P
0 g
s
.35663 .17059 m .32848 .1074 L .36401 .17098 L .785 .641 .702 r
F
.36547 .11038 m .35166 .10832 L .35563 .10269 L p .27 .731 .951 r
F P
0 g
s
.34174 .10357 m .35563 .10269 L .35166 .10832 L p .363 .82 .929 r
F P
0 g
s
.34174 .10357 m .35563 .10269 L p .37088 .17135 L .785 .641 .702 r
F P
0 g
s
.40941 .14432 m .40115 .13264 L .40546 .1272 L p 0 .202 .73 r
F P
0 g
s
.39657 .17271 m .40546 .1272 L .40329 .17307 L .785 .641 .702 r
F
.40115 .13264 m .39076 .12281 L .39501 .1173 L p 0 .355 .827 r
F P
0 g
s
.39501 .1173 m .40546 .1272 L .40115 .13264 L p 0 .355 .827 r
F P
0 g
s
.39501 .1173 m .40546 .1272 L p .39657 .17271 L .785 .641 .702 r
F P
0 g
s
.39011 .17237 m .39501 .1173 L .39657 .17271 L .785 .641 .702 r
F
.4152 .15736 m .40941 .14432 L .41378 .13897 L p 0 .037 .606 r
F P
0 g
s
.40546 .1272 m .41378 .13897 L .40941 .14432 L p 0 .202 .73 r
F P
0 g
s
.40546 .1272 m .40754 .13013 L p .40329 .17307 L .785 .641 .702 r
F P
0 g
s
.40754 .13013 m .41378 .13897 L p .40754 .15926 L .785 .641 .702 r
F P
0 g
s
.40329 .17307 m .40754 .13013 L .40754 .15926 L .785 .641 .702 r
F
.39076 .12281 m .3787 .11528 L .38286 .10971 L p .075 .496 .897 r
F P
0 g
s
.38286 .10971 m .39501 .1173 L .39076 .12281 L p .075 .496 .897 r
F P
0 g
s
.38286 .10971 m .39501 .1173 L p .39011 .17237 L .785 .641 .702 r
F P
0 g
s
.40139 .17598 m .40139 .17297 L p .34157 .17516 L .289 .763 .934 r
F P
0 g
s
.34157 .17516 m .40139 .17297 L .36777 .17118 L .289 .763 .934 r
F
.3812 .17725 m .40993 .1761 L .34157 .17516 L F
.40321 .17841 m .40993 .1761 L p .3812 .17725 L F P
0 g
s
.3805 .23822 m .40321 .1853 L .40321 .19791 L .785 .641 .702 r
F
.3805 .23822 m .40321 .19791 L .40321 .20652 L F
.3805 .23822 m .40321 .20652 L .40321 .21289 L F
.38468 .23352 m .38377 .17203 L .39011 .17237 L F
.38377 .17203 m .38286 .10971 L .39011 .17237 L F
.3787 .11528 m .36547 .11038 L .36954 .10476 L p .173 .622 .939 r
F P
0 g
s
.36954 .10476 m .38286 .10971 L .3787 .11528 L p .173 .622 .939 r
F P
0 g
s
.36954 .10476 m .38286 .10971 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.35563 .10269 m .36954 .10476 L .36547 .11038 L p .27 .731 .951 r
F P
0 g
s
.35563 .10269 m .36954 .10476 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40139 .17297 m .40139 .16608 L p .36777 .17118 L .289 .763 .934 r
F P
0 g
s
.41846 .18522 m .41826 .1712 L .42269 .16604 L p 0 0 .27 r
F P
0 g
s
.41961 .15211 m .42269 .16604 L .41826 .1712 L p 0 0 .452 r
F P
0 g
s
.41961 .15211 m .42269 .16604 L p .41828 .17386 L .785 .641 .702 r
F P
0 g
s
.40241 .176 m .40993 .1761 L .40754 .17329 L .289 .763 .934 r
F
.40321 .19791 m .40889 .17871 L .41388 .17897 L .785 .641 .702 r
F
.4158 .19884 m .4104 .21146 L p .3805 .23822 L F P
0 g
s
.4104 .21146 m .40247 .22253 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.40993 .1761 m .40993 .36128 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40321 .17841 m .40993 .1761 L p .40321 .31079 L .131 .107 .561 r
F P
0 g
s
.40247 .22253 m .40321 .2215 L p .40965 .21319 L 0 0 0 r
F P
0 g
s
.40956 .21334 m .40247 .22253 L .40965 .21319 L 0 0 0 r
F
.40993 .36128 m .40993 .21273 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40139 .35382 m .40754 .3592 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40754 .3592 m .40993 .36128 L p .40754 .25224 L .913 .745 .252 r
F P
0 g
s
.40531 .21879 m .40321 .2215 L .40525 .21883 L 0 0 0 r
F
.40802 .2159 m .40139 .35382 L .40993 .21273 L .913 .745 .252 r
F
.40531 .21879 m .40525 .21883 L .41385 .20761 L 0 0 0 r
F
.41385 .20761 m .41477 .20658 L p .40531 .21879 L F P
0 g
s
.40802 .2159 m .40754 .21669 L .40754 .22587 L .913 .745 .252 r
F
.40679 .21773 m .40247 .22253 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.41477 .20658 m .40754 .21669 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.40754 .21669 m .40679 .21773 L p .40956 .21334 L 0 0 0 r
F P
0 g
s
.40754 .22587 m .40673 .21803 L .40139 .35382 L .913 .745 .252 r
F
.38468 .23352 m .40754 .21306 L .40679 .21773 L .785 .641 .702 r
F
.40993 .1761 m .40754 .17329 L p .40754 .21669 L .913 .745 .252 r
F P
0 g
s
.40993 .1761 m .40754 .21669 L .40802 .2159 L .913 .745 .252 r
F
.4152 .15736 m .41826 .1712 L p .41388 .17897 L .785 .641 .702 r
F P
0 g
s
.40993 .21273 m .40993 .1761 L p .40802 .2159 L .913 .745 .252 r
F P
0 g
s
.38468 .23352 m .41045 .17345 L .41828 .17386 L .785 .641 .702 r
F
.40241 .176 m .40754 .17329 L .4021 .173 L .289 .763 .934 r
F
.38468 .23352 m .39657 .17271 L .40329 .17307 L .785 .641 .702 r
F
.40247 .22253 m .39236 .23159 L .3805 .23822 L p F P
0 g
s
.39236 .23159 m .40247 .22253 L .40679 .21773 L p .514 .847 .564 r
F P
0 g
s
.40679 .21773 m .39661 .22685 L .39236 .23159 L p .514 .847 .564 r
F P
0 g
s
.4158 .19884 m .41846 .18522 L .42289 .18016 L p 0 0 .065 r
F P
0 g
s
.42289 .18016 m .42022 .19387 L .4158 .19884 L p 0 0 .065 r
F P
0 g
s
.42289 .18016 m .42022 .19387 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.42269 .16604 m .42289 .18016 L .41846 .18522 L p 0 0 .27 r
F P
0 g
s
.42269 .16604 m .42289 .18016 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.4104 .21146 m .4158 .19884 L .42022 .19387 L p 0 0 0 r
F P
0 g
s
.42022 .19387 m .41477 .20658 L .4104 .21146 L p 0 0 0 r
F P
0 g
s
.42022 .19387 m .41477 .20658 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.41826 .1712 m .4152 .15736 L .41961 .15211 L p 0 0 .452 r
F P
0 g
s
.41378 .13897 m .41961 .15211 L .4152 .15736 L p 0 .037 .606 r
F P
0 g
s
.41378 .13897 m .41961 .15211 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40679 .21773 m .39661 .22685 L .38468 .23352 L p .785 .641 .702 r
F P
0 g
s
.40139 .16608 m .40139 .22688 L p .40673 .21803 L .913 .745 .252 r
F P
0 g
s
.40139 .22688 m .40139 .35382 L p .40673 .21803 L .913 .745 .252 r
F P
0 g
s
.41477 .20658 m .40956 .21334 L .40965 .21319 L 0 0 0 r
F
.41477 .20658 m .40754 .21669 L p .40754 .21306 L .785 .641 .702 r
F P
0 g
s
.40754 .21669 m .40679 .21773 L p .40754 .21306 L .785 .641 .702 r
F P
0 g
s
.41045 .17345 m .41961 .15211 L .41828 .17386 L .785 .641 .702 r
F
.4021 .173 m .40754 .17329 L .40139 .16608 L .289 .763 .934 r
F
.40754 .17329 m .40139 .16608 L p .40754 .22587 L .913 .745 .252 r
F P
0 g
s
.38468 .23352 m .39011 .17237 L .39657 .17271 L .785 .641 .702 r
F
.34157 .17516 m .36777 .17118 L .32509 .17429 L .289 .763 .934 r
F
.36777 .17118 m .40139 .16608 L .35852 .17069 L F
.36777 .17118 m .35852 .17069 L .32509 .17429 L F
.32509 .17429 m .35852 .17069 L .33815 .16961 L F
.32468 .11301 m .31271 .11957 L .31642 .114 L p .519 .907 .766 r
F P
0 g
s
.31642 .114 m .32848 .1074 L .32468 .11301 L p .519 .907 .766 r
F P
0 g
s
.31642 .114 m .32848 .1074 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.31271 .11957 m .30247 .1286 L .30611 .1231 L p .569 .888 .618 r
F P
0 g
s
.30611 .1231 m .31642 .114 L .31271 .11957 L p .569 .888 .618 r
F P
0 g
s
.30611 .1231 m .31642 .114 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.32509 .17429 m .33815 .16961 L .31341 .17367 L .289 .763 .934 r
F
.33815 .16961 m .33032 .16919 L .31341 .17367 L F
.31341 .17367 m .33032 .16919 L .31713 .16849 L F
.30247 .1286 m .29441 .13972 L .298 .13429 L p .59 .819 .43 r
F P
0 g
s
.298 .13429 m .30611 .1231 L .30247 .1286 L p .59 .819 .43 r
F P
0 g
s
.298 .13429 m .30611 .1231 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.40139 .16608 m .36478 .16006 L p .33815 .16961 L .289 .763 .934 r
F P
0 g
s
.35852 .17069 m .40139 .16608 L .33815 .16961 L .289 .763 .934 r
F
.38468 .23352 m .35663 .17059 L .36401 .17098 L .785 .641 .702 r
F
.33815 .16961 m .36478 .16006 L .33032 .16919 L .289 .763 .934 r
F
.36478 .16006 m .32192 .16181 L p .31713 .16849 L F P
0 g
s
.33032 .16919 m .36478 .16006 L .31713 .16849 L .289 .763 .934 r
F
.38468 .23352 m .36401 .17098 L .37088 .17135 L .785 .641 .702 r
F
.38468 .23352 m .30535 .17287 L .31518 .16839 L F
.32055 .17341 m .31518 .16839 L .3211 .1687 L F
.32055 .17341 m .3211 .1687 L .3284 .16909 L F
.38468 .23352 m .32055 .17341 L .3284 .16909 L F
.30171 .22565 m .3027 .21933 L .30878 .36429 L .934 .763 .288 r
F
.30878 .23853 m .30878 .36429 L p .3027 .21933 L F P
0 g
s
.30878 .36429 m .30171 .35902 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.31432 .22896 m .3038 .21915 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.3265 .23643 m .31432 .22896 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.31432 .22896 m .3265 .23643 L .33031 .2317 L p .025 .471 .877 r
F P
0 g
s
.3038 .21915 m .31432 .22896 L .31805 .22418 L p 0 .326 .805 r
F P
0 g
s
.33031 .2317 m .31805 .22418 L .31432 .22896 L p .025 .471 .877 r
F P
0 g
s
.31805 .22418 m .30745 .21429 L .3038 .21915 L p 0 .326 .805 r
F P
0 g
s
.28994 .17518 m .28973 .16092 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30535 .19455 m .29889 .20732 L .30535 .21135 L .101 .083 .548 r
F
.29308 .18924 m .28994 .17518 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.29901 .20247 m .29308 .18924 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30745 .21429 m .30535 .21135 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.30535 .21135 m .29901 .20247 L p .30535 .20477 L .785 .641 .702 r
F P
0 g
s
.38468 .23352 m .30535 .21135 L .30535 .20477 L .785 .641 .702 r
F
.29889 .35691 m .29889 .20872 L p .30171 .22565 L .934 .763 .288 r
F P
0 g
s
.30144 .22023 m .30171 .22565 L .29889 .20872 L .934 .763 .288 r
F
.30171 .35902 m .29889 .35691 L p .30171 .22565 L F P
0 g
s
.29889 .20732 m .29889 .35691 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30745 .21429 m .29901 .20247 L .29786 .20405 L p 0 .166 .704 r
F P
0 g
s
.30745 .21429 m .29786 .20405 L .2997 .20987 L 0 .166 .704 r
F
.3038 .21915 m .30745 .21429 L p .2997 .20987 L F P
0 g
s
.31805 .22418 m .30745 .21429 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.31534 .21758 m .30535 .21135 L .30535 .30218 L .101 .083 .548 r
F
.30171 .21623 m .3038 .21915 L p .2997 .20987 L 0 .166 .704 r
F P
0 g
s
.30535 .21135 m .29889 .20732 L .30535 .30218 L .101 .083 .548 r
F
.33031 .2317 m .31805 .22418 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.32192 .35065 m .32192 .16181 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.29889 .35691 m .30535 .35515 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30535 .35515 m .32192 .35065 L p .30535 .30218 L .101 .083 .548 r
F P
0 g
s
.30535 .17287 m .29832 .16749 L .30535 .16786 L .785 .641 .702 r
F
.30535 .17287 m .30535 .16786 L .31518 .16839 L F
.32192 .16181 m .30535 .19455 L .31534 .21758 L .101 .083 .548 r
F
.30535 .19455 m .30535 .21135 L .31534 .21758 L F
.32192 .16181 m .30535 .16786 L p .31055 .16814 L .289 .763 .934 r
F P
0 g
s
.32192 .16181 m .30535 .16786 L p .30535 .19455 L .101 .083 .548 r
F P
0 g
s
.29246 .14708 m .298 .13429 L p .30535 .14271 L .785 .641 .702 r
F P
0 g
s
.30535 .15498 m .29246 .14708 L .30535 .14271 L .785 .641 .702 r
F
.29786 .20405 m .29901 .20247 L p .29715 .20087 L 0 0 .572 r
F P
0 g
s
.29715 .20087 m .28953 .19429 L .29786 .20405 L 0 0 .572 r
F
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.30878 .36429 m .34485 .36852 L .38636 .3673 L p .224 .73 .894 r
F P
0 g
s
.38636 .3673 m .40993 .36128 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.32192 .35065 m .29889 .35691 L .30878 .36429 L p .224 .73 .894 r
F P
0 g
s
.36478 .34935 m .32192 .35065 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.40139 .35382 m .36478 .34935 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.40993 .36128 m .40139 .35382 L p .30878 .36429 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.33981 .24123 m .3265 .23643 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.35364 .24315 m .33981 .24123 L p .3805 .23822 L .785 .641 .702 r
F P
0 g
s
.3805 .23822 m .36741 .24213 L .35364 .24315 L p .785 .641 .702 r
F P
0 g
s
.35364 .24315 m .36741 .24213 L .37149 .23746 L p .319 .799 .901 r
F P
0 g
s
.33981 .24123 m .35364 .24315 L .35763 .23848 L p .225 .711 .928 r
F P
0 g
s
.37149 .23746 m .35763 .23848 L .35364 .24315 L p .319 .799 .901 r
F P
0 g
s
.35763 .23848 m .3437 .23654 L .33981 .24123 L p .225 .711 .928 r
F P
0 g
s
.3437 .23654 m .33031 .2317 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.35763 .23848 m .3437 .23654 L p .38468 .23352 L .785 .641 .702 r
F P
0 g
s
.38468 .23352 m .37149 .23746 L .35763 .23848 L p .785 .641 .702 r
F P
0 g
s
.32192 .35065 m .36478 .34935 L .36478 .16006 L p .64 .523 .704 r
F P
0 g
s
.3265 .23643 m .33981 .24123 L .3437 .23654 L p .127 .6 .918 r
F P
0 g
s
.3437 .23654 m .33031 .2317 L .3265 .23643 L p .127 .6 .918 r
F P
0 g
s
.36478 .16006 m .32192 .16181 L .32192 .35065 L p .64 .523 .704 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3805 .23822 m .39236 .23159 L .39661 .22685 L p .47 .875 .721 r
F P
0 g
s
.39661 .22685 m .38468 .23352 L .3805 .23822 L p .47 .875 .721 r
F P
0 g
s
.36478 .34935 m .40139 .35382 L .40139 .16608 L p .907 .741 .664 r
F P
0 g
s
.36741 .24213 m .3805 .23822 L .38468 .23352 L p .402 .857 .834 r
F P
0 g
s
.38468 .23352 m .37149 .23746 L .36741 .24213 L p .402 .857 .834 r
F P
0 g
s
.40139 .16608 m .36478 .16006 L .36478 .34935 L p .907 .741 .664 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67268 .3673 m .63052 .36852 L .63052 .18583 L p .643 .525 .704 r
F P
0 g
s
.63052 .36852 m .59672 .36429 L .59672 .18013 L p .911 .744 .662 r
F P
0 g
s
.59672 .18013 m .63052 .18583 L .63052 .36852 L p .911 .744 .662 r
F P
0 g
s
.59249 .17305 m .57731 .16617 L .59249 .16442 L .787 .642 .702 r
F
.59249 .17802 m .58566 .17268 L .59249 .17305 L F
.58566 .17268 m .57731 .16617 L .59249 .17305 L F
.59249 .17305 m .59672 .18013 L p .60394 .17367 L .289 .763 .934 r
F P
0 g
s
.63052 .18583 m .67268 .18419 L .67268 .3673 L p .643 .525 .704 r
F P
0 g
s
.59672 .18013 m .63052 .18583 L .67268 .18419 L p .289 .763 .934 r
F P
0 g
s
.67268 .18419 m .69185 .17841 L p .59672 .18013 L .289 .763 .934 r
F P
0 g
s
.59672 .18013 m .69185 .17841 L .67031 .17725 L .289 .763 .934 r
F
.59672 .18013 m .59672 .23853 L p .59308 .21933 L .866 .707 .183 r
F P
0 g
s
.59249 .17305 m .59672 .18013 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59454 .21915 m .58633 .20742 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.58633 .20742 m .59249 .21623 L p .59129 .20987 L 0 .225 .746 r
F P
0 g
s
.57751 .18033 m .57731 .16617 L p .59249 .17802 L .787 .642 .702 r
F P
0 g
s
.59249 .18974 m .57751 .18033 L .59249 .17802 L .787 .642 .702 r
F
.58056 .19429 m .57751 .18033 L p .66962 .23822 L F P
0 g
s
.58633 .20742 m .58056 .19429 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.5908 .17022 m .59249 .17305 L p .59249 .21623 L .866 .707 .183 r
F P
0 g
s
.5908 .17022 m .59249 .21623 L .59228 .21512 L .866 .707 .183 r
F
.5908 .17022 m .59249 .22148 L .59233 .22023 L F
.59129 .20987 m .5908 .20732 L .58633 .20742 L 0 .225 .746 r
F
.59018 .20405 m .58812 .20585 L p .5908 .20732 L F P
0 g
s
.58812 .20585 m .58633 .20742 L p .5908 .20732 L 0 .225 .746 r
F P
0 g
s
.5862 .18924 m .58056 .19429 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.5908 .20872 m .5908 .17022 L p .59233 .22023 L .866 .707 .183 r
F P
0 g
s
.66962 .23822 m .59249 .18974 L .59249 .17802 L .787 .642 .702 r
F
.66255 .17683 m .6549 .11038 L .66874 .17716 L F
.64138 .10832 m .6549 .11038 L p .66255 .17683 L F P
0 g
s
.6562 .17649 m .64138 .10832 L .66255 .17683 L .787 .642 .702 r
F
.6549 .11038 m .66785 .11528 L p .66874 .17716 L F P
0 g
s
.69468 .17856 m .70358 .15736 L .70229 .17897 L .787 .642 .702 r
F
.69792 .14432 m .70358 .15736 L p .69185 .1853 L F P
0 g
s
.67268 .3673 m .67268 .18419 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69185 .16447 m .69792 .14432 L .69185 .1853 L .787 .642 .702 r
F
.69185 .19791 m .69468 .17856 L .70229 .17897 L F
.67268 .18419 m .69185 .17841 L p .69185 .2215 L .191 .156 .586 r
F P
0 g
s
.68033 .23472 m .69185 .2215 L .69185 .31079 L .191 .156 .586 r
F
.67268 .18419 m .69185 .2215 L .68033 .23472 L F
.69185 .2215 m .69888 .21146 L .70022 .21044 L p 0 0 0 r
F P
0 g
s
.70022 .21044 m .70395 .20761 L p .69949 .21273 L 0 0 0 r
F P
0 g
s
.69949 .21273 m .69185 .2215 L .70022 .21044 L 0 0 0 r
F
.70678 .18522 m .70418 .19884 L p .69185 .21289 L .787 .642 .702 r
F P
0 g
s
.66962 .23822 m .69185 .20652 L .69185 .21289 L .787 .642 .702 r
F
.69185 .20652 m .70678 .18522 L .69185 .21289 L F
.70658 .1712 m .70678 .18522 L p .66962 .23822 L F P
0 g
s
.70418 .19884 m .69888 .21146 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.69888 .21146 m .70418 .19884 L .71063 .19387 L p 0 0 0 r
F P
0 g
s
.69888 .21146 m .69112 .22253 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.71063 .19387 m .70718 .2021 L p .69888 .21146 L 0 0 0 r
F P
0 g
s
.70718 .2021 m .7053 .20658 L .70395 .20761 L p 0 0 0 r
F P
0 g
s
.70395 .20761 m .69888 .21146 L p .70718 .2021 L 0 0 0 r
F P
0 g
s
.69185 .31079 m .69703 .21939 L .69949 .36128 L .191 .156 .586 r
F
.69949 .1761 m .69949 .21521 L p .69703 .21939 L F P
0 g
s
.69949 .21521 m .69949 .36128 L p .69703 .21939 L .191 .156 .586 r
F P
0 g
s
.69949 .36128 m .69185 .363 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69949 .36128 m .69949 .21273 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69847 .2159 m .69496 .35382 L .69949 .21273 L .833 .68 .14 r
F
.69185 .1853 m .69468 .17856 L .69185 .19791 L .787 .642 .702 r
F
.69185 .17841 m .69949 .1761 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.69112 .22253 m .69185 .2215 L p .69934 .21319 L 0 0 0 r
F P
0 g
s
.7053 .20658 m .69929 .21334 L .69934 .21319 L 0 0 0 r
F
.69929 .21334 m .69112 .22253 L .69934 .21319 L F
.70395 .20761 m .7053 .20658 L p .69185 .2215 L F P
0 g
s
.69496 .22688 m .69496 .35382 L p .69847 .2159 L .833 .68 .14 r
F P
0 g
s
.7053 .20658 m .69749 .21773 L .69112 .22253 L p 0 0 0 r
F P
0 g
s
.67585 .23352 m .69822 .21306 L .69749 .21773 L .787 .643 .702 r
F
.66962 .23822 m .69185 .16447 L .69185 .1853 L .787 .642 .702 r
F
.68983 .13264 m .69792 .14432 L p .66962 .23822 L F P
0 g
s
.67966 .12281 m .68983 .13264 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.59672 .18013 m .67031 .17725 L .63151 .17516 L .289 .763 .934 r
F
.66785 .11528 m .67966 .12281 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.62787 .10921 m .64138 .10832 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61498 .11301 m .62787 .10921 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.60325 .11957 m .61498 .11301 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.59672 .18013 m .63151 .17516 L .61538 .17429 L .289 .763 .934 r
F
.59323 .1286 m .60325 .11957 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.69949 .1761 m .69822 .17329 L p .63151 .17516 L .289 .763 .934 r
F P
0 g
s
.70358 .15736 m .69792 .14432 L .70433 .13897 L p 0 .111 .657 r
F P
0 g
s
.69822 .17329 m .70433 .13897 L .70107 .17345 L .787 .643 .702 r
F
.69406 .17307 m .69822 .15926 L .69822 .17329 L F
.69822 .15926 m .70433 .13897 L .69822 .17329 L F
.63151 .17516 m .69822 .17329 L .65929 .17118 L .289 .763 .934 r
F
.66962 .23822 m .69185 .1853 L .69185 .19791 L .787 .642 .702 r
F
.67031 .17725 m .69949 .1761 L .63151 .17516 L .289 .763 .934 r
F
.69792 .14432 m .68983 .13264 L .69619 .1272 L p 0 .256 .765 r
F P
0 g
s
.69619 .1272 m .70433 .13897 L .69792 .14432 L p 0 .256 .765 r
F P
0 g
s
.69619 .1272 m .70433 .13897 L p .69406 .17307 L .787 .643 .702 r
F P
0 g
s
.69185 .17841 m .69949 .1761 L p .67031 .17725 L .289 .763 .934 r
F P
0 g
s
.67585 .23352 m .68748 .17271 L .69406 .17307 L .787 .643 .702 r
F
.68748 .17271 m .69619 .1272 L .69406 .17307 L F
.68983 .13264 m .67966 .12281 L .68596 .1173 L p .043 .391 .851 r
F P
0 g
s
.68596 .1173 m .69619 .1272 L .68983 .13264 L p .043 .391 .851 r
F P
0 g
s
.68596 .1173 m .69619 .1272 L p .68748 .17271 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .68116 .17237 L .68748 .17271 L .787 .643 .702 r
F
.68116 .17237 m .68596 .1173 L .68748 .17271 L F
.59672 .18013 m .61538 .17429 L .60394 .17367 L .289 .763 .934 r
F
.58535 .13972 m .59323 .1286 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.63151 .17516 m .65929 .17118 L .61538 .17429 L .289 .763 .934 r
F
.67966 .12281 m .66785 .11528 L .67406 .10971 L p .122 .518 .912 r
F P
0 g
s
.67406 .10971 m .68596 .1173 L .67966 .12281 L p .122 .518 .912 r
F P
0 g
s
.67406 .10971 m .68596 .1173 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.66785 .11528 m .6549 .11038 L .66103 .10476 L p .2 .633 .948 r
F P
0 g
s
.66103 .10476 m .67406 .10971 L .66785 .11528 L p .2 .633 .948 r
F P
0 g
s
.66103 .10476 m .67406 .10971 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.6549 .11038 m .64138 .10832 L .64742 .10269 L p .278 .735 .954 r
F P
0 g
s
.64742 .10269 m .66103 .10476 L .6549 .11038 L p .278 .735 .954 r
F P
0 g
s
.64742 .10269 m .66103 .10476 L p .66873 .17169 L .787 .643 .702 r
F P
0 g
s
.66962 .23822 m .66255 .17683 L .66874 .17716 L .787 .642 .702 r
F
.67585 .23352 m .66234 .17135 L .66873 .17169 L .787 .643 .702 r
F
.66234 .17135 m .64742 .10269 L .66873 .17169 L F
.57996 .15243 m .58535 .13972 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.65929 .17118 m .65025 .17069 L .61538 .17429 L .289 .763 .934 r
F
.66962 .23822 m .6562 .17649 L .66255 .17683 L .787 .642 .702 r
F
.64138 .10832 m .62787 .10921 L .63382 .10357 L p .352 .815 .923 r
F P
0 g
s
.63382 .10357 m .64742 .10269 L .64138 .10832 L p .352 .815 .923 r
F P
0 g
s
.63382 .10357 m .64742 .10269 L p .66234 .17135 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .65562 .17098 L .66234 .17135 L .787 .643 .702 r
F
.65562 .17098 m .63382 .10357 L .66234 .17135 L F
.61538 .17429 m .63031 .16961 L .60394 .17367 L .289 .763 .934 r
F
.61538 .17429 m .65025 .17069 L .63031 .16961 L F
.62787 .10921 m .61498 .11301 L .62084 .1074 L p .417 .865 .846 r
F P
0 g
s
.62084 .1074 m .63382 .10357 L .62787 .10921 L p .417 .865 .846 r
F P
0 g
s
.62084 .1074 m .63382 .10357 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.61498 .11301 m .60325 .11957 L .60904 .114 L p .466 .873 .718 r
F P
0 g
s
.60904 .114 m .62084 .1074 L .61498 .11301 L p .466 .873 .718 r
F P
0 g
s
.60904 .114 m .62084 .1074 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60325 .11957 m .59323 .1286 L .59895 .1231 L p .489 .828 .539 r
F P
0 g
s
.59895 .1231 m .60904 .114 L .60325 .11957 L p .489 .828 .539 r
F P
0 g
s
.59895 .1231 m .60904 .114 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.63031 .16961 m .62265 .16919 L .60394 .17367 L .289 .763 .934 r
F
.60394 .17367 m .62265 .16919 L .60973 .16849 L F
.59339 .17872 m .59249 .17802 L .59249 .17578 L .787 .642 .702 r
F
.59339 .17872 m .59249 .17578 L .59249 .17305 L F
.66962 .23822 m .59339 .17872 L .59249 .17305 L F
.5908 .17022 m .5908 .20732 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.63138 .16966 m .59821 .14271 L .59895 .1231 L .787 .643 .702 r
F
.67585 .23352 m .62076 .16909 L .63138 .16966 L F
.62076 .16909 m .59821 .14271 L .63138 .16966 L F
.60205 .17357 m .59249 .17305 L .59249 .16442 L .787 .642 .702 r
F
.5908 .17022 m .59249 .17305 L p .60329 .16814 L .289 .763 .934 r
F P
0 g
s
.58558 .14708 m .59101 .13429 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.60394 .17367 m .60973 .16849 L .59249 .17305 L .289 .763 .934 r
F
.62076 .16909 m .59821 .15917 L .59821 .14271 L .787 .643 .702 r
F
.60783 .16839 m .59821 .15917 L .62076 .16909 L F
.60973 .16849 m .60329 .16814 L .59249 .17305 L .289 .763 .934 r
F
.59821 .16786 m .5908 .17022 L p .60329 .16814 L F P
0 g
s
.66962 .23822 m .59249 .17305 L .60205 .17357 L .787 .642 .702 r
F
.59821 .16786 m .5908 .17022 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.57731 .16617 m .57996 .15243 L p .59249 .16442 L .787 .642 .702 r
F P
0 g
s
.58292 .16092 m .58558 .14708 L p .59821 .15917 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .59821 .17287 L .59821 .15917 L .787 .643 .702 r
F
.59821 .17287 m .58292 .16092 L .59821 .15917 L F
.67585 .23352 m .60783 .16839 L .62076 .16909 L F
.66075 .16006 m .61719 .16181 L p .60973 .16849 L .289 .763 .934 r
F P
0 g
s
.62265 .16919 m .66075 .16006 L .60973 .16849 L .289 .763 .934 r
F
.60484 .22896 m .59454 .21915 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61676 .23643 m .60484 .22896 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.62978 .24123 m .61676 .23643 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.61676 .23643 m .62978 .24123 L .63574 .23654 L p .156 .614 .932 r
F P
0 g
s
.60484 .22896 m .61676 .23643 L .62263 .2317 L p .076 .496 .897 r
F P
0 g
s
.63574 .23654 m .62263 .2317 L .61676 .23643 L p .156 .614 .932 r
F P
0 g
s
.59454 .21915 m .60484 .22896 L .61063 .22418 L p 0 .366 .835 r
F P
0 g
s
.62263 .2317 m .61063 .22418 L .60484 .22896 L p .076 .496 .897 r
F P
0 g
s
.61063 .22418 m .60026 .21429 L .59454 .21915 L p 0 .366 .835 r
F P
0 g
s
.58312 .17518 m .58292 .16092 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.59821 .19455 m .5908 .20732 L .59821 .21135 L .166 .136 .576 r
F
.5862 .18924 m .58312 .17518 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.592 .20247 m .5862 .18924 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60026 .21429 m .59821 .21135 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.59821 .21135 m .592 .20247 L p .59821 .20477 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .59821 .21135 L .59821 .20477 L .787 .643 .702 r
F
.5908 .35691 m .5908 .20872 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59233 .22023 m .59249 .22565 L .5908 .20872 L .866 .707 .183 r
F
.59249 .22565 m .59308 .21933 L .59672 .36429 L F
.59672 .23853 m .59672 .36429 L p .59308 .21933 L F P
0 g
s
.59672 .36429 m .59249 .35902 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.59249 .35902 m .5908 .35691 L p .59249 .22565 L .866 .707 .183 r
F P
0 g
s
.5908 .20732 m .5908 .35691 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.60026 .21429 m .592 .20247 L .59018 .20405 L p 0 .225 .746 r
F P
0 g
s
.60026 .21429 m .59018 .20405 L .59129 .20987 L 0 .225 .746 r
F
.59454 .21915 m .60026 .21429 L p .59129 .20987 L F P
0 g
s
.61063 .22418 m .60026 .21429 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.60965 .21758 m .59821 .21135 L .59821 .30218 L .166 .136 .576 r
F
.59228 .21512 m .59249 .21623 L .59249 .22148 L .866 .707 .183 r
F
.59233 .22023 m .59249 .22148 L .59249 .22565 L F
.59249 .21623 m .59454 .21915 L p .59129 .20987 L 0 .225 .746 r
F P
0 g
s
.59821 .21135 m .5908 .20732 L .59821 .30218 L .166 .136 .576 r
F
.62263 .2317 m .61063 .22418 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.61719 .35065 m .61719 .16181 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.5908 .35691 m .59821 .35515 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.59821 .35515 m .61719 .35065 L p .59821 .30218 L .166 .136 .576 r
F P
0 g
s
.60973 .16849 m .61719 .16181 L .60329 .16814 L .289 .763 .934 r
F
.59821 .15917 m .58558 .14708 L .59821 .14271 L .787 .643 .702 r
F
.61719 .16181 m .59821 .19455 L .60965 .21758 L .166 .136 .576 r
F
.59821 .19455 m .59821 .21135 L .60965 .21758 L F
.61719 .16181 m .59821 .16786 L p .60329 .16814 L .289 .763 .934 r
F P
0 g
s
.61719 .16181 m .59821 .16786 L p .59821 .19455 L .166 .136 .576 r
F P
0 g
s
.59101 .13429 m .59821 .12414 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.59821 .12414 m .59895 .1231 L p .59821 .14271 L .787 .643 .702 r
F P
0 g
s
.63031 .16961 m .66075 .16006 L .62265 .16919 L .289 .763 .934 r
F
.65929 .17118 m .69496 .16608 L .65025 .17069 L F
.69496 .16608 m .66075 .16006 L p .63031 .16961 L F P
0 g
s
.65025 .17069 m .69496 .16608 L .63031 .16961 L .289 .763 .934 r
F
.69822 .17329 m .69496 .16608 L p .65929 .17118 L F P
0 g
s
.69949 .1761 m .69822 .17329 L p .69822 .19032 L .833 .68 .14 r
F P
0 g
s
.67585 .23352 m .69406 .17307 L .69822 .17329 L .787 .643 .702 r
F
.69949 .1761 m .69822 .19032 L .69847 .2159 L .833 .68 .14 r
F
.69949 .21273 m .69949 .1761 L p .69847 .2159 L F P
0 g
s
.69822 .18023 m .69822 .17329 L .70107 .17345 L .787 .643 .702 r
F
.67585 .23352 m .69822 .17329 L .69822 .18023 L F
.69822 .21669 m .69749 .21773 L p .69822 .21306 L F P
0 g
s
.68123 .23159 m .69112 .22253 L .69749 .21773 L p 0 0 0 r
F P
0 g
s
.69749 .21773 m .68753 .22685 L .68123 .23159 L p 0 0 0 r
F P
0 g
s
.69822 .19032 m .69822 .21669 L .69847 .2159 L .833 .68 .14 r
F
.70418 .19884 m .70678 .18522 L .71325 .18016 L p 0 0 .173 r
F P
0 g
s
.71325 .18016 m .71063 .19387 L .70418 .19884 L p 0 0 .173 r
F P
0 g
s
.71325 .18016 m .71063 .19387 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.70678 .18522 m .70658 .1712 L .71305 .16604 L p 0 0 .362 r
F P
0 g
s
.71305 .16604 m .71325 .18016 L .70678 .18522 L p 0 0 .362 r
F P
0 g
s
.71305 .16604 m .71325 .18016 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.70358 .15736 m .70658 .1712 L p .70229 .17897 L .787 .642 .702 r
F P
0 g
s
.70658 .1712 m .70358 .15736 L .71003 .15211 L p 0 0 .523 r
F P
0 g
s
.71003 .15211 m .71305 .16604 L .70658 .1712 L p 0 0 .523 r
F P
0 g
s
.71003 .15211 m .71305 .16604 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.71063 .19387 m .7053 .20658 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.69112 .22253 m .68123 .23159 L .66962 .23822 L p .787 .642 .702 r
F P
0 g
s
.69749 .21773 m .68753 .22685 L .67585 .23352 L p .787 .643 .702 r
F P
0 g
s
.69822 .19032 m .69496 .22688 L .69822 .21669 L .833 .68 .14 r
F
.69496 .16608 m .69496 .22688 L p .69822 .19032 L F P
0 g
s
.69822 .17329 m .69496 .16608 L p .69822 .19032 L .833 .68 .14 r
F P
0 g
s
.70433 .13897 m .71003 .15211 L .70358 .15736 L p 0 .111 .657 r
F P
0 g
s
.70433 .13897 m .71003 .15211 L p .70107 .17345 L .787 .643 .702 r
F P
0 g
s
.7053 .20658 m .69822 .21669 L p .69822 .21306 L .787 .643 .702 r
F P
0 g
s
.69496 .35382 m .69822 .3592 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69822 .3592 m .69949 .36128 L p .69822 .25224 L .833 .68 .14 r
F P
0 g
s
.69185 .363 m .67268 .3673 L p .69185 .31079 L .191 .156 .586 r
F P
0 g
s
.592 .20247 m .5891 .19586 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.5891 .19586 m .5862 .18924 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.58056 .19429 m .58633 .20742 L .59018 .20405 L p 0 .074 .632 r
F P
0 g
s
.59018 .20405 m .592 .20247 L p .58976 .20087 L 0 .074 .632 r
F P
0 g
s
.58976 .20087 m .58056 .19429 L .59018 .20405 L 0 .074 .632 r
F
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59672 .36429 m .63052 .36852 L .67268 .3673 L p .224 .73 .894 r
F P
0 g
s
.67268 .3673 m .69949 .36128 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.61719 .35065 m .5908 .35691 L .59672 .36429 L p .224 .73 .894 r
F P
0 g
s
.66075 .34935 m .61719 .35065 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.69496 .35382 m .66075 .34935 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.69949 .36128 m .69496 .35382 L p .59672 .36429 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64333 .24315 m .62978 .24123 L p .66962 .23822 L .787 .642 .702 r
F P
0 g
s
.66962 .23822 m .6568 .24213 L .64333 .24315 L p .787 .642 .702 r
F P
0 g
s
.6568 .24213 m .66962 .23822 L .67585 .23352 L p .368 .836 .806 r
F P
0 g
s
.64333 .24315 m .6568 .24213 L .66294 .23746 L p .307 .793 .893 r
F P
0 g
s
.67585 .23352 m .66294 .23746 L .6568 .24213 L p .368 .836 .806 r
F P
0 g
s
.62978 .24123 m .64333 .24315 L .64938 .23848 L p .234 .716 .933 r
F P
0 g
s
.66294 .23746 m .64938 .23848 L .64333 .24315 L p .307 .793 .893 r
F P
0 g
s
.64938 .23848 m .63574 .23654 L .62978 .24123 L p .234 .716 .933 r
F P
0 g
s
.63574 .23654 m .62263 .2317 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.64938 .23848 m .63574 .23654 L p .67585 .23352 L .787 .643 .702 r
F P
0 g
s
.67585 .23352 m .66294 .23746 L .64938 .23848 L p .787 .643 .702 r
F P
0 g
s
.61719 .35065 m .66075 .34935 L .66075 .16006 L p .641 .523 .704 r
F P
0 g
s
.66075 .16006 m .61719 .16181 L .61719 .35065 L p .641 .523 .704 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.66962 .23822 m .68123 .23159 L .68753 .22685 L p .412 .833 .666 r
F P
0 g
s
.68753 .22685 m .67585 .23352 L .66962 .23822 L p .412 .833 .666 r
F P
0 g
s
.66075 .34935 m .69496 .35382 L .69496 .16608 L p .917 .748 .658 r
F P
0 g
s
.69496 .16608 m .66075 .16006 L .66075 .34935 L p .917 .748 .658 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.41923 1.29174 m .41389 1.27286 L .40848 1.29708 L p .952 .777 .322 r
F P
0 g
s
.40848 1.29708 m .41389 1.31592 L .41923 1.29174 L p .952 .777 .322 r
F P
0 g
s
.65354 1.29355 m .64977 1.2746 L .64595 1.29894 L p .904 .738 .238 r
F P
0 g
s
.64595 1.29894 m .64977 1.31785 L .65354 1.29355 L p .904 .738 .238 r
F P
0 g
s
.41389 1.27286 m .40848 1.29708 L .47174 1.29894 L p .574 .229 .346 r
F P
0 g
s
.40848 1.29708 m .41389 1.31592 L .47675 1.31785 L p .522 .721 .964 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.47675 1.31785 m .47174 1.29894 L .40848 1.29708 L p .522 .721 .964 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.75986 .90514 m .73989 .88531 L p .72051 .91463 L .702 .642 .786 r
F P
0 g
s
.72082 .89564 m .72051 .91463 L .73989 .88531 L .702 .642 .786 r
F
.72004 .94324 m .73919 .92491 L p .72051 .91463 L F P
0 g
s
.73919 .92491 m .75986 .90514 L p .72051 .91463 L .702 .642 .786 r
F P
0 g
s
.71476 .91147 m .72007 .91432 L .72051 .91463 L p .402 0 0 r
F P
0 g
s
.71476 .91147 m .69637 .90888 L .71417 .94885 L .702 .642 .786 r
F
.6817 .91682 m .71417 .94885 L p .69637 .90888 L F P
0 g
s
.68201 .89345 m .66987 .90514 L p .69637 .90888 L .702 .642 .786 r
F P
0 g
s
.70327 .90514 m .69637 .90888 L .71476 .91147 L .702 .642 .786 r
F
.68201 .89345 m .69637 .90888 L .70327 .90514 L F
.70378 .90453 m .71476 .91147 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.70378 .90453 m .70767 .93077 L .70375 .90794 L .662 .108 0 r
F
.72038 .89534 m .71496 .89881 L p .71476 .91147 L .791 .714 .78 r
F P
0 g
s
.71476 .91147 m .72007 .91432 L .72008 .91395 L p .791 .714 .78 r
F P
0 g
s
.72008 .91395 m .72038 .89534 L p .71476 .91147 L .791 .714 .78 r
F P
0 g
s
.72007 .91432 m .72038 .89534 L .74996 .91582 L p 0 0 .398 r
F P
0 g
s
.72038 .89534 m .71496 .89881 L p .72056 .89578 L .106 0 0 r
F P
0 g
s
.71417 .94885 m .72004 .94324 L p .71556 .86115 L .702 .642 .786 r
F P
0 g
s
.72082 .89564 m .72038 .89534 L p .72056 .89578 L .106 0 0 r
F P
0 g
s
.72051 .91463 m .72007 .91432 L p .72051 .91434 L 0 0 .398 r
F P
0 g
s
.72128 .86683 m .71556 .86115 L p .72004 .94324 L .702 .642 .786 r
F P
0 g
s
.72026 .91494 m .72027 .91457 L p .72011 .91448 L .605 .56 .778 r
F P
0 g
s
.71476 .91147 m .72051 .91463 L .72027 .91457 L .402 0 0 r
F
.71476 .91147 m .72026 .91494 L p .71496 .89906 L .605 .56 .778 r
F P
0 g
s
.72026 .91494 m .70767 .93077 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.71476 .91147 m .72026 .91494 L p .70406 .90648 L .662 .108 0 r
F P
0 g
s
.72026 .91494 m .72027 .91457 L p .71344 .91535 L .892 .759 .259 r
F P
0 g
s
.72026 .91494 m .71344 .91535 L .71335 .91558 L .892 .759 .259 r
F
.70767 .93077 m .70353 .93598 L p .70375 .90794 L .662 .108 0 r
F P
0 g
s
.70796 .91138 m .70382 .91646 L p .72027 .91457 L .892 .759 .259 r
F P
0 g
s
.70382 .91646 m .70353 .93598 L .72026 .91494 L p .892 .759 .259 r
F P
0 g
s
.721 .91498 m .7496 .93532 L p .71476 .91147 L .402 0 0 r
F P
0 g
s
.72056 .89632 m .71496 .89906 L .72011 .91448 L .605 .56 .778 r
F
.70378 .90453 m .71476 .91147 L p .71496 .89906 L F P
0 g
s
.71496 .89881 m .70378 .90453 L p .72056 .89632 L .605 .56 .778 r
F P
0 g
s
.70327 .90514 m .70378 .90453 L p .70377 .90542 L .662 .108 0 r
F P
0 g
s
.71496 .89881 m .70327 .90514 L .71476 .91147 L .702 .642 .786 r
F
.71496 .89881 m .70413 .90575 L .71476 .91147 L p .791 .714 .78 r
F P
0 g
s
.70413 .90575 m .71476 .91147 L p .71487 .91154 L .402 0 0 r
F P
0 g
s
.70413 .90575 m .71487 .91154 L .7496 .93532 L .402 0 0 r
F
.7496 .93532 m .73325 .92655 L .70413 .90575 L p F P
0 g
s
.70413 .90575 m .71431 .91303 L p .72055 .89635 L .106 0 0 r
F P
0 g
s
.72027 .91457 m .72056 .89632 L p .72011 .91448 L .605 .56 .778 r
F P
0 g
s
.72056 .89578 m .71723 .8978 L .72056 .89632 L .106 0 0 r
F
.71496 .89881 m .70413 .90575 L p .72056 .89578 L F P
0 g
s
.72009 .89653 m .72057 .89594 L .71496 .89881 L p .605 .56 .778 r
F P
0 g
s
.72057 .89594 m .72041 .89639 L p .72056 .89632 L .605 .56 .778 r
F P
0 g
s
.72027 .91457 m .72056 .89632 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.71723 .8978 m .70413 .90575 L .72075 .89623 L .106 0 0 r
F
.72057 .89594 m .70796 .91138 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.72056 .89632 m .72057 .89594 L p .71431 .91303 L .892 .759 .259 r
F P
0 g
s
.72067 .89604 m .72056 .89632 L .72075 .89623 L .106 0 0 r
F
.72056 .89578 m .72056 .89632 L .72067 .89604 L F
.74996 .91582 m .7496 .93532 L .72051 .91463 L p 0 0 .398 r
F P
0 g
s
.72051 .91434 m .74996 .91582 L .72051 .91463 L 0 0 .398 r
F
.72075 .89623 m .72055 .89635 L .73325 .92655 L .106 0 0 r
F
.72051 .91463 m .721 .91498 L p .72027 .91457 L .402 0 0 r
F P
0 g
s
.71431 .91303 m .73325 .92655 L p .72055 .89635 L .106 0 0 r
F P
0 g
s
.71335 .91558 m .71344 .91535 L .70382 .91646 L .892 .759 .259 r
F
.71496 .89881 m .70378 .90453 L .70327 .90514 L p 0 0 0 r
F P
0 g
s
.71556 .86115 m .68201 .89345 L p .70327 .90514 L .702 .642 .786 r
F P
0 g
s
.71556 .86115 m .70327 .90514 L .71496 .89881 L .702 .642 .786 r
F
.70353 .93598 m .68657 .92525 L .70327 .90514 L p .662 .108 0 r
F P
0 g
s
.70377 .90542 m .70353 .93598 L .70327 .90514 L .662 .108 0 r
F
.72057 .89594 m .71496 .89881 L p .68657 .92525 L 0 0 0 r
F P
0 g
s
.70327 .90514 m .68657 .92525 L p .71496 .89881 L 0 0 0 r
F P
0 g
s
.66987 .90514 m .6817 .91682 L p .69637 .90888 L .702 .642 .786 r
F P
0 g
s
.73325 .92655 m .74996 .91582 L .72082 .89564 L p .106 0 0 r
F P
0 g
s
.72056 .89578 m .73325 .92655 L .72082 .89564 L .106 0 0 r
F
.73989 .88531 m .72128 .86683 L p .72082 .89564 L .702 .642 .786 r
F P
0 g
s
.68657 .92525 m .70382 .91646 L .72057 .89594 L p 0 0 0 r
F P
0 g
s
.59323 .1286 m .58535 .13972 L .59101 .13429 L p 0 0 0 r
F P
0 g
s
.59101 .13429 m .59895 .1231 L .59323 .1286 L p 0 0 0 r
F P
0 g
s
.29441 .13972 m .28891 .15243 L .29246 .14708 L p 0 0 0 r
F P
0 g
s
.29246 .14708 m .298 .13429 L .29441 .13972 L p 0 0 0 r
F P
0 g
s
.58535 .13972 m .57996 .15243 L .58558 .14708 L p 0 0 0 r
F P
0 g
s
.58558 .14708 m .59101 .13429 L .58535 .13972 L p 0 0 0 r
F P
0 g
s
.28641 .18033 m .28953 .19429 L .29308 .18924 L p 0 0 .411 r
F P
0 g
s
.29901 .20247 m .29308 .18924 L .28953 .19429 L p 0 0 .572 r
F P
0 g
s
.57751 .18033 m .58056 .19429 L .5862 .18924 L p 0 0 .491 r
F P
0 g
s
.28891 .15243 m .2862 .16617 L .28973 .16092 L p 0 0 .007 r
F P
0 g
s
.28973 .16092 m .29246 .14708 L .28891 .15243 L p 0 0 .007 r
F P
0 g
s
.57996 .15243 m .57731 .16617 L .58292 .16092 L p 0 0 .123 r
F P
0 g
s
.58292 .16092 m .58558 .14708 L .57996 .15243 L p 0 0 .123 r
F P
0 g
s
.2862 .16617 m .28641 .18033 L .28994 .17518 L p 0 0 .22 r
F P
0 g
s
.29308 .18924 m .28994 .17518 L .28641 .18033 L p 0 0 .411 r
F P
0 g
s
.57731 .16617 m .57751 .18033 L .58312 .17518 L p 0 0 .321 r
F P
0 g
s
.5862 .18924 m .58312 .17518 L .57751 .18033 L p 0 0 .491 r
F P
0 g
s
.28994 .17518 m .28973 .16092 L .2862 .16617 L p 0 0 .22 r
F P
0 g
s
.58312 .17518 m .58292 .16092 L .57731 .16617 L p 0 0 .321 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.74996 .91582 m .73325 .92655 L .7496 .93532 L closepath p .793 .719 .782 r
F P
0 g
s
.70382 .91646 m .68657 .92525 L .70353 .93598 L closepath p .601 .56 .78 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00g`3oool900000;80oooo2@00003M0?oo
o`00f@3oool6000000T0b:Bc1P00002V0?ooo`H000002@39Y;<600000=L0oooo003E0?ooo`@00000
5@38Y;<3000009l0oooo1000000E0<VT/`800000e@3oool00=80oooo0`00000L0<RT/`<00000V@3o
ool3000001/0bJBc0`00003B0?ooo`00d03oool200000280b:Bc0P00002E0?ooo`8000008@39Y;<2
00000=00oooo003>0?ooo`8000009P38Y;<200000940oooo0P00000U0<VT/`800000cP3oool00<`0
oooo0P00000Z0<RT/`030000003oool0oooo08`0oooo0P00000Y0<VT/`030000003oool0oooo0</0
oooo003:0?ooo`800000;@38Y;<00`000000oooo0?ooo`290?ooo`800000;039Y;<00`000000oooo
0?ooo`3:0?ooo`00b@3oool00`000000b:Bc0<RT/`0^0<RT/`800000R03oool00`000000bJBc0<VT
/`0]0<VT/`800000bP3oool00<P0oooo00<000000<RT/`38Y;<0<@38Y;<00`000000oooo0?ooo`24
0?ooo`0300000039Y;<0bJBc0300bJBc00<000000?ooo`3oool0a`3oool00<H0oooo0P00000e0<RT
/`030000003oool0oooo0880oooo00<000000<VT/`39Y;<0<P39Y;<00`000000oooo0?ooo`360?oo
o`00a@3oool00`000000b:Bc0<RT/`0f0<RT/`030000003oool0oooo0800oooo00<000000<VT/`39
Y;<0=039Y;<00`000000oooo0?ooo`350?ooo`00a03oool00`000000b:Bc0<RT/`0h0<RT/`030000
003oool0oooo07h0oooo00<000000<VT/`39Y;<0=P39Y;<00`000000oooo0?ooo`340?ooo`00``3o
ool00`000000b:Bc0<RT/`0j0<RT/`030000003oool0oooo07`0oooo00<000000<VT/`39Y;<0>039
Y;<00`000000oooo0?ooo`330?ooo`00`P3oool00`000000b:Bc0<RT/`0l0<RT/`030000003oool0
oooo07X0oooo00<000000<VT/`39Y;<0>P39Y;<00`000000oooo0?ooo`320?ooo`00`P3oool00`00
0000b:Bc0<RT/`0m0<RT/`030000003oool0oooo07P0oooo0P00000m0<VT/`030000003oool0oooo
0<40oooo00310?ooo`0300000038Y;<0b:Bc03l0b:Bc00<000000?ooo`3oool0MP3oool2000003l0
bJBc00<000000?ooo`3oool0`03oool00<00oooo00<000000<RT/`38Y;<0@038Y;<2000007H0oooo
0P0000110<VT/`030000003oool0oooo0;l0oooo002o0?ooo`0300000038Y;<0b:Bc0480b:Bc00<0
00000?ooo`3oool0L`3oool200000480bJBc00<000000?ooo`3oool0_`3oool00;l0oooo00<00000
0<RT/`38Y;<0@`38Y;<00`000000oooo0?ooo`1b0?ooo`800000@`39Y;<00`000000oooo0?ooo`2n
0?ooo`00_P3oool00`000000b:Bc0<RT/`150<RT/`030000003oool0oooo0700oooo0P0000150<VT
/`030000003oool0oooo0;d0oooo002m0?ooo`800000A`38Y;<200000700oooo0P0000170<VT/`03
0000003oool0oooo0;`0oooo002m0?ooo`0300000038Y;<0b:Bc04L0b:Bc00<000000?ooo`3oool0
K@3oool3000004L0bJBc00<000000?ooo`3oool0_03oool00;`0oooo0P00001:0<RT/`030000003o
ool0oooo06`0oooo0P0000190<VT/`030000003oool0oooo0;/0oooo002l0?ooo`0300000038Y;<0
b:Bc04T0b:Bc00<000000?ooo`3oool0J`3oool3000004T0bJBc00<000000?ooo`3oool0^`3oool0
0;/0oooo0P00001<0<RT/`030000003oool0oooo06X0oooo0P00001;0<VT/`030000003oool0oooo
0;X0oooo002k0?ooo`800000C038Y;<00`000000oooo0?ooo`1Y0?ooo`<00000B`39Y;<00`000000
oooo0?ooo`2j0?ooo`00^P3oool2000004h0b:Bc00<000000?ooo`3oool0J03oool2000004d0bJBc
00<000000?ooo`3oool0^@3oool00;X0oooo0P00001>0<RT/`030000003oool0oooo06L0oooo0`00
001=0<VT/`030000003oool0oooo0;T0oooo002i0?ooo`<00000C`38Y;<00`000000oooo0?ooo`1V
0?ooo`<00000CP39Y;<00`000000oooo0?ooo`2h0?ooo`00^@3oool00`00000000010000001?0<RT
/`030000003oool0oooo06H0oooo00<0000000007`000000CP39Y;<00`000000oooo0?ooo`2h0?oo
o`00^03oool300000540b:Bc00<000000?ooo`3oool0I03oool20000000300007`000000bJBc04h0
bJBc00<000000?ooo`3oool0]`3oool00;P0oooo00<0000000000@000000D@38Y;<00`000000oooo
0?ooo`1T0?ooo`040000000001l0000O000004l0bJBc00<000000?ooo`3oool0]`3oool00;P0oooo
00<0000000000@000000D@38Y;<00`000000oooo0?ooo`1T0?ooo`030000000001l000000500bJBc
00<000000?ooo`3oool0]`3oool00;P0oooo00<0000000000@000000D@38Y;<00`000000oooo0?oo
o`1T0?ooo`030000000001l000000500bJBc00<000000?ooo`3oool0]`3oool00;P0oooo0P00001C
0<RT/`030000003oool0oooo0680oooo00@0000000007`0001l00000D@39Y;<00`000000oooo0?oo
o`2f0?ooo`00^03oool2000005<0b:Bc00<000000?ooo`3oool0HP3oool010000000000O00007`00
001A0<VT/`030000003oool0oooo0;H0oooo002g0?ooo`0300000000004000000280b:Bc4000000Q
0<RT/`030000003oool0oooo0680oooo00@0000000007`0001l000008`39Y;<@000001h0bJBc00<0
00000?ooo`3oool0]P3oool00;L0oooo0`00000C0<RT/`l000003@2SQK@00`000000j;fY0>RmZ@06
000001/0b:Bc00<000000?ooo`3oool0HP3oool010000000000O00000000000C0<VT/a0000003@2T
QK@00`000000j[nX0>ZoZ006000001P0bJBc00<000000?ooo`3oool0]P3oool00;L0oooo0`00000@
0<RT/`<0000000<06AF<0000002SQK@06@2SQK@00`000000j;fY0>RmZ@060>RmZ@H000005P38Y;<0
0`000000oooo0?ooo`1P0?ooo`050000000001l000000000DP0000004039Y;<30000000302XRT`00
0000Y8Fd01X0Y8Fd00<000000>ZoZ03Z_jP01P3Z_jP5000000l0bJBc00<000000<VT/`39Y;<00P39
Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h0000000>0<RT/`800000100I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY00`0j;fY1P00000@0<RT/`030000003oool0
oooo0600oooo0P0000020000DP0300000039Y;<0bJBc00/0bJBc0`00000402XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP02`3Z_jP6000000h0bJBc00<000000?ooo`3oool0]@3oool0
0;L0oooo00<000000000>00000002`38Y;<3000000H06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0B0>RmZ@<000003@38Y;<00`000000oooo0?ooo`1P0?ooo`05000000000580001B
0000DP0000002P39Y;<3000000L0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00A
0>ZoZ0<000002`39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT
/`8000002@0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY0P00000<0<RT
/`030000003oool0oooo0600oooo00D000000000DP000580001B000000080<VT/`8000002P0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000<VT/`39Y;<02@39Y;<0
0`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT/`/06AF<00<000000:>5
]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00000000/0b:Bc00<000000?oo
o`3oool0H03oool01@000000001B0000DP000580000000P0bJBc300Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX0P00000:0<VT/`030000003oool0oooo0;D0oooo002g0?oo
o`030000000003P0000000T0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00@000000>Vn@03Y_T0000002P38Y;<00`000000oooo0?ooo`1P0?ooo`05000000000580
001B0000DP0000002039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z
_jP2000000X0bJBc00<000000?ooo`3oool0]@3oool00;L0oooo00<000000000>00000002@38Y;<:
01TES0030<RT/`000000XhFd01T0XhFd00<000000>RmZ@3X_JT0503X_JT01@000000jKi00>Vn@03Y
_T00000000T0b:Bc00<000000?ooo`3oool0H03oool01@000000001B0000DP000580000000P0bJBc
300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`000000
2@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool00`000000000h000000090<RT/`X06AF<00<0
b:Bc0000002SQK@06@2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0L0b:Bc
00@000000<RT/`38Y;<00000HP3oool01@000000001B0000DP000580000000P0bJBc300Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<02@39Y;<00`00
0000oooo0?ooo`2e0?ooo`00]`3oool3000000T0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T00jKi02P38Y;<00`000000oooo0?ooo`1P0?oo
o`03000000000580001B008000002039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>Zo
Z03Z_jP04`3Z_jP00`000000eJhS0<VT/`090<VT/`030000003oool0oooo0;D0oooo002g0?ooo`<0
00002@38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000
jKi00>Vn@03Y_T0:0<RT/`030000003oool0oooo0600oooo00D000000000DP000000001m00000008
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
bJBc000000P0bJBc00<000000?ooo`3oool0]@3oool00;L0oooo00@000000000J@0006T000002038
Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000jKi00>Vn
@03Y_T0:0<RT/`030000003oool0oooo0600oooo0P0000030000O@0300000039Y;<0bJBc00D0bJBc
300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<0
2@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT/`/06AF<
00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0X0
b:Bc00<000000?ooo`3oool0H03oool00`000000001m0000O@020000O@0300000039Y;<0bJBc00D0
bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`3E
[R<02@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT/`/0
6AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn
@0X0b:Bc00<000000?ooo`3oool0H03oool00`000000001m0000O@020000O@0300000039Y;<0bJBc
00D0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^
8`39Y;<02@39Y;<00`000000oooo0?ooo`2e0?ooo`00]`3oool010000000001Y0000J@0000080<RT
/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
0>Vn@0T0b:Bc00<000000?ooo`3oool0H@3oool00`000000001m0000O@020000O@0300000039Y;<0
bJBc00D0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<00000
0=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000J@000007
0<RT/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00
jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@0300000039
Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<0
00000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000J@00
00070<RT/`T06AF<00<0b:Bc01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@030000
0039Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX
00<000000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y0000
J@0000070<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000
003Y_T00jKi00>Vn@0T0b:Bc00<000000?ooo`3oool0HP3oool00`000000001m0000O@020000O@03
00000039Y;<0bJBc00@0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0
j[nX00<000000=F^8`39Y;<02039Y;<00`000000oooo0?ooo`2f0?ooo`00^03oool010000000001Y
0000000000070<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@04
0000003Y_T00jKi00>Vn@0P0b:Bc00<000000?ooo`3oool0H`3oool010000000001m0000O@0007d2
000000H0bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<00000
0=F^8`39Y;<01`39Y;<00`000000oooo0?ooo`2g0?ooo`00^@3oool2000000030000TP000000b:Bc
00D0b:Bc2`0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00H000000>Vn
@03Y_T00jKi00<RT/`3Y_T060<RT/`030000003oool0oooo06@0oooo00@000000000O@00000001:Q
0P0000050<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000
003E[R<0bJBc00L0bJBc00<000000?ooo`3oool0]`3oool00;T0oooo00@000000000TP0009800000
1P38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT010000000jKi0
0>Vn@03Y_T080<RT/`030000003oool0oooo06@0oooo0P000003000BX@0300000039Y;<0bJBc00<0
bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39
Y;<01`39Y;<00`000000oooo0?ooo`2g0?ooo`00^@3oool01@000000002B0000TP000980000000D0
b:Bc200I5H`01038Y;<06AF<01TES000000J0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn
@03Y_T00jKi01`38Y;<2000006H0oooo00<00000000BX@004Z400P004Z400`000000bJBc0<VT/`03
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0
bJBc00L0bJBc00<000000?ooo`3oool0]`3oool00;T0oooo00D000000000TP000980002B00000005
0<RT/`P06AF<00@0b:Bc01TES00I5H`000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0L0b:Bc00<000000?ooo`3oool0I@3oool00`00000001:Q000BX@02000BX@800000
1039Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP00`000000eJhS
0<VT/`060<VT/`030000003oool0oooo0;P0oooo002j0?ooo`05000000000980002B0000TP000000
1038Y;<801TES0040<RT/`0I5H`06AF<000001X0XhFd00<000000>RmZ@3X_JT0503X_JT010000000
jKi00>Vn@03Y_T070<RT/`030000003oool0oooo06H0oooo00@00000000BX@004Z4001:Q0P000004
0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0
bJBc00H0bJBc00<000000?ooo`3oool0^03oool00;X0oooo00D000000000TP000980002B00000004
0<RT/`P06AF<00@0b:Bc01TES00I5H`000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y
_T00jKi00>Vn@0H0b:Bc0P00001W0?ooo`80000010004Z400`000000bJBc0<VT/`020<VT/``0:R:C
00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0bJBc00D0bJBc
0P00002j0?ooo`00^`3oool01@000000002B0000TP000980000000<0b:Bc2`0I5H`00`000000XhFd
0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T00jKi01P38Y;<3000006H0
oooo0`000003000BX@8000000`39Y;<<02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z
_jP04`3Z_jP00`000000eJhS0<VT/`050<VT/`030000003oool0oooo0;T0oooo002k0?ooo`050000
00000980002B0000TP0000000`38Y;<;01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X
_JT0503X_JT010000000jKi00>Vn@03Y_T060<RT/`0300000037X[<0000006D0oooo10000004000B
X@0400000039Y;<0bJBc0<VT/``0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0030000003E[R<0bJBc00D0bJBc00<000000?ooo`3oool0^@3oool00;`0oooo00D000000000
TP00000002Zd000000020<RT/`/06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@040000003Y_T00jKi00>Vn@0D0b:Bc00D000000<NR/`37X[<0aj:c0000001S0?ooo`@00000
00L0aj>c000000004Z4001:Q00000000>Kh000000080bJBc300Z8Y<00`000000Y8Fd0:B5]00I0:B5
]0030000003Z_jP0j[nX01<0j[nX00<000000=F^8`39Y;<01039Y;<00`000000oooo0?ooo`2j0?oo
o`00_03oool20000008002Zd0P0000000`38Y;<06AF<01TES00501TES0050<RT/`0I5H`06AF<01TE
S00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0D0b:Bc00D00000
0<NR/`37X[<0aj:c0000001S0?ooo`<000000P37Xk<00`00000001:Q00000003000i_P0300000039
Y;<0:R:C00/0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E
[R<0bJBc00@0bJBc00<000000?ooo`3oool0^P3oool00;d0oooo00H00000000Z]000:[@002Zd0000
0038Y;<701TES0050<RT/`0I5H`06AF<01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@04
0000003Y_T00jKi00>Vn@0@0b:Bc00<000000<NR/`37X[<00`37X[<00`000000oooo0?ooo`1O0?oo
o`@000000`37Xk<00`00000003Vn000i_P03000i_P030000000Z8Y<0:R:C00X0:R:C00<000000:B5
]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0030000003E[R<0bJBc00<0bJBc00<000000?oo
o`3oool0^`3oool00;h0oooo0P00:[@00`0I5H`002Zd0000000701TES0050<RT/`0I5H`06AF<01TE
S00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi00>Vn@0@0b:Bc00L00000
0<NR/`37X[<0aj:c000>WP37X[<000000640oooo100000040<NS/`0600000000>Kh003Vn02XRT`00
>Kh00000300Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00<000000=F^
8`39Y;<00`39Y;<00`000000oooo0?ooo`2k0?ooo`00_P3oool00`00000002Zd01TES00901TES005
0<RT/`0I5H`06AF<01TES00000006P2SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
0>Vn@0<0b:Bc00<000000<NR/`37X[<01037X[<00`000000oooo0?ooo`1N0?ooo`@000001@37Xk<0
0`00000003Vn000i_P0?02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
0`000000eJhS0<VT/`020<VT/`030000003oool0oooo0;`0oooo002o0?ooo`030000000I5H`06AF<
00P06AF<00D0b:Bc01TES00I5H`06AF<0000000J0:>5]0030000003X_JT0j;fY01@0j;fY00@00000
0>Vn@03Y_T00jKi00P38Y;<00`000000aj:c0<NR/`060<NR/`030000003oool0oooo05d0oooo1000
00060<NS/`8000003`0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00D0
00000=F^8`39Y;<0bJBc0000002o0?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01@000000jKi00>Vn@03Y_T00b:Bc00800000
2037X[<00`000000oooo0?ooo`1M0?ooo`@000001`37Xk<00`000000:R:C02XRT`0=02XRT`030000
002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP00`000000eJhS0<VT/`0200000;l0oooo
002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>Rm
Z@0D0>RmZ@050000003Y_T00jKi00>Vn@038Y;<00P0000090<NR/`030000003oool0oooo05/0oooo
100000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX
0>ZoZ00C0>ZoZ0040000003E[R<0bJBc00000<00oooo002o0?ooo`030000000I5H`06AF<00L06AF<
00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY
00L000000>Vn@03Y_T00jKi00000003Y_T00000000T0aj:c00<000000?ooo`3oool0F`3oool01000
0000000U00009@0000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0000000000<00oooo002o0?ooo`030000000I5H`0
6AF<00L06AF<00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00L000000>Vn@03Y_T00jKi00000003Y_T00000000T0aj:c00<000000?ooo`3oool0
F`3oool010000000000U00009@0000080<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02T
QK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0000000000<00oooo002o0?ooo`03
0000000I5H`06AF<00L06AF<00<0b:Bc01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000aj:c0<NR/`070<NR/`03
0000003oool0oooo05/0oooo00@0000000009@0002D000002037Xk<00`000000:R:C02XRT`0=02XR
T`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`000030
0?ooo`00_`3oool00`0000006AF<01TES00701TES0030000000I5H`06AF<00806AF<00<000000:>5
]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000<NR
/`37X[<02037X[<00`000000oooo0?ooo`1J0?ooo`030000000002D0000000T0aj>c00<0000002XR
T`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^
8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01`0I5H`00`00Dlh06AF<01TES00201TE
S0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn
@00300000037X[<0aj:c00P0aj:c00<000000?ooo`3oool0F@3oool010000000000U00009@000009
0<NS/`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00L06AF<00<005?>
01TES00I5H`00P0I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T000`000000aj:c0<NR/`080<NR/`030000003oool0oooo05T0oooo00@00000
00009@0002D000002@37Xk<00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<0
00000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TE
S00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01`000000jKi00>Vn
@03Y_T008A^?0>Vn@00000002P37X[<00`000000oooo0?ooo`1I0?ooo`040000000002D000000000
00T0aj>c00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX
01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`00
0000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y
_T00000000/0aj:c00<000000?ooo`3oool0F03oool2000000030000E`000000aj>c00P0aj>c00<0
000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@0
00000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5
]00H0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T00000000/0
aj:c00<000000?ooo`3oool0F03oool010000000001G0000E`0000090<NS/`030000000Z8Y<0:R:C
00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS
00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0D0>RmZ@060000003Y_T00jKi00>Vn@00Q6hl0jKi00P0000080<NR/`0300000037
X[<0000005X0oooo00@000000000E`0005L000002037Xk<2000000l0:R:C00<000000:B5]02TQK@0
6@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000
000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H0:>5]0030000
003X_JT0j;fY01@0j;fY00H000000>Vn@03Y_T00jKi0024KS`3Y_T02000000P0aj:c00<000000<NR
/`000000FP3oool010000000001G0000E`0000080<NS/`0303@[U`000000:R:C00h0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00T000000>Vn@03Y_T00jKi0024KS`3Y_T0000000>c1A000
00002@37X[<00`000000oooo0?ooo`1H0?ooo`040000000005L0001G000000P0aj>c00<0=2^G0000
000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^
8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01P0I5H`00`3V_:X06AF<01TES00301TE
S0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT01`000000jKi00>Vn@03Y_T00
8A^?0>Vn@00000000P3/`D@00`000000aj:c0<NR/`060<NR/`030000003oool0oooo05P0oooo00@0
00000000E`0005L000002037Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd
00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<
01TES00601TES0030>JlZP0I5H`06AF<00<06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY
0>RmZ@0D0>RmZ@070000003Y_T00jKi00>Vn@00Q6hl0jKi0000000020>c1A0T0aj:c00<000000?oo
o`3oool0F03oool010000000001G0000E`0000080<NS/`0303@[U`000000:R:C00h0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00H06AF<00<0i[bZ01TES00I5H`00`0I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T0000000080k<54
2@37X[<00`000000oooo0?ooo`1H0?ooo`040000000005L00000000000P0aj>c00<0=2^G0000000Z
8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E
[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]003
0000003X_JT0j;fY01@0j;fY00L000000>Vn@03Y_T00jKi0024KS`3Y_T0000000080k<542@37X[<0
0`000000oooo0?ooo`1H0?ooo`80000000<0002100000037Xk<01`37Xk<00`0d:iL0000002XRT`0>
02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`00
00300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<00000
0>RmZ@3X_JT0503X_JT01`000000jKi00>Vn@03Y_T008A^?0>Vn@00000000P3/`D@90<NR/`030000
003oool0oooo05P0oooo00D000000000P@0008400021000000070<NS/`0303@[U`000000:R:C00h0
:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS0000
0<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000
j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@02@37X[<00`000000
oooo0?ooo`1H0?ooo`0500000000084000210000P@0000001`37Xk<00`0d:iL0000002XRT`0>02XR
T`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`000030
0?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>Rm
Z@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c0P00001J0?oo
o`0500000000084000210000P@0000001`37Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00501TES0030>JlZP0I5H`06AF<00@06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@01`37X[<0
0`000000aj:c0000001K0?ooo`040000000008400021000000L0aj>c00<0=2^G0000000Z8Y<03P0Z
8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000
`03oool00;l0oooo00<0000001TES00I5H`01@0I5H`00`3V_:X06AF<01TES00401TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/
`D@0k<5400P0aj:c00<000000?ooo`3oool0FP3oool01@00000000210000P@000840000000H0aj>c
00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX
00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`01@0I5H`00`3V_:X06AF<
01TES00401TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0
0>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3oool0FP3oool01@0000000021
0000P@000840000000H0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]003
0000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I
5H`01@0I5H`00`3V_:X06AF<01TES00401TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X
_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3o
ool0FP3oool01@00000000210000P@000840000000H0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool0
0;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0080<NR/`030000003oool0oooo
05/0oooo100000060<NS/`0303@[U`000000:R:C00h0:R:C00<000000:B5]02TQK@06@2TQK@00`00
0000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<
00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi0
00<0jKi000<000000>c1A03/`D@02037X[<00`000000oooo0?ooo`1K0?ooo`05000000005j@001NT
000GY00000001@37Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0030000003/`D@0k<5400P0aj:c00<000000?ooo`3oool0F`3oool01@00000001NT000GY000
5j@0000000D0aj>c00<0=2^G0000000Z8Y<03P0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z
_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I
5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y
_T000`000000k<540>c1A0070<NR/`030000003oool0oooo05d0oooo00D00000000GY0005j@001NT
000000040<NS/`0303@[U`000000:R:C00h0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX
0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<
00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80
jKi000<000000>c1A03/`D@01`37X[<00`000000oooo0?ooo`1M0?ooo`05000000005j@001NT000G
Y00000001037Xk<00`0d:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>Zo
Z03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00401TE
S0030>JlZP0I5H`06AF<00D06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>Rm
Z@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/`D@01P37X[<00`000000oooo0?ooo`1N
0?ooo`03000000005j@001NT008001NT00H000000<NS/`37Xk<0aj>c03@[U`00000?02XRT`030000
002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00
_`3oool00`0000006AF<01TES00401TES0030>JlZP0I5H`06AF<00D06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/
`D@01P37X[<00`000000oooo0?ooo`1O0?ooo`05000000005j@001NT000GY00000000`37Xk<00`0d
:iL0000002XRT`0>02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP01000
0000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00401TES0030>JlZP0I5H`06AF<
00D06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
024KS`80jKi000<000000>c1A03/`D@01@37X[<00`000000oooo0?ooo`1P0?ooo`0:000000005j@0
01NT00000000?<40000003@[U`37Xk<0=2^G000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`00
0000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<
00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0
024KS`80jKi000<000000>c1A03/`D@01@37X[<00`000000oooo0?ooo`1Q0?ooo`8000000P00?<40
1@000000aj>c0<NS/`0d:iL0000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>Zo
Z00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<0
00000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi0
00<000000>c1A03/`D@01037X[<00`000000oooo0?ooo`1R0?ooo`0300000000?<4003c1008003c1
00@000000<NS/`0d:iL000003`0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0
j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000
XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00@000000>Vn@03Y_T008A^?0P3Y_T000`00
0000k<540>c1A0030<NR/`030000003oool0oooo06@0oooo00P00000000l`@00?<40=2^G000l`@00
0000=2^G000000l0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000
003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@040000003Y_T00jKi0024KS`80jKi000<000000>c1A03/
`D@00P37X[<2000006H0oooo0P0000001P00?<40=2^G03@[U`00?<40=2^G000000l0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P37X[<00`000000oooo0?ooo`1V
0?ooo`800000100d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0040000003/`D@0k<540<NR/`800000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z
8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E
[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00<06AF<00<0000001TES00I5H`01P0I
5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y
_T001P000000k<540>c1A0000000k<54000006T0oooo00<0000003@[U`0d:iL00P0d:iL00`000000
:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000
eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00301TES0030000000I5H`06AF<00H0
6AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0
jKi000H000000>c1A03/`D@000000>c1A000001Y0?ooo`030000000d:iL0=2^G0080=2^G00<00000
02XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@00000
0=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A002
0>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=
02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`00
00300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<00000
0>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<00000
0?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<00000
0:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D
0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W
0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<00000
01TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0oooo06L0oooo00<00000
03@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@003
0>Vn@0060000003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000
000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000
003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0
602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0
;2BD0>c1A000001Y0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`00
0000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool0
0;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY
01@0j;fY00<000000>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0
000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<0
00000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TE
S00201TES0030>o3B@0I5H`06AF<00L06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>Rm
Z@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y0?ooo`03
0000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]003
0000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I
5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@00Q
6hl00`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0024KS`030>Vn@0060000003/`D@0
k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C
00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00
oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY
0>RmZ@0D0>RmZ@030000003Y_T008A^?00<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y0?oo
o`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5
]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TE
S00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn
@00Q6hl00`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL00P0d
:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z
_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002S
QK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi0024KS`030>Vn@0060000003/
`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0
:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS0000
0<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000
j;fY0>RmZ@0D0>RmZ@030000003Y_T008A^?00<0jKi000H000000>c1A03/`D@0;2BD0>c1A000001Y
0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I
0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<00000
01TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000
0>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d:iL0
0P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP0
4`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000
002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0060000
003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C
00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS
00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`00
0000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000H000000>c1A03/`D@0;2BD0>c1A000
001Y0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5
]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0
000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<0
00000>Vn@03Y_T000`3Y_T001P000000k<540>c1A00/99@0k<54000006T0oooo00<0000003@[U`0d
:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z
_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES003
0000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@006
0000003/`D@0k<5402`TU03/`D@00000J@3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<540>c1A0020>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`000000jKi00>Vn@0030>Vn@0030000003/`D@0
k<540080k<5400<000000?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00jKi000<0jKi000<000000>c1A03/`D@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<540>c1A0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0k<540080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A03/`D@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<00000024KS`3Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL0
0`000000:R:C02XRT`0=02XRT`030000002TQK@0Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP0
10000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<01TES0030000002SQK@0
XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT00`0000008A^?0>Vn@0030>Vn@0030000003/`D@0
;2BD0080k<5400<000000?ooo`3oool0I`3oool00`000000=2^G03@[U`0203@[U`030000000Z8Y<0
:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0
eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0602SQK@0
0`000000j;fY0>RmZ@0D0>RmZ@030000000Q6hl0jKi000<0jKi000<000000>c1A00/99@00P3/`D@0
0`000000oooo0?ooo`1W0?ooo`030000000d:iL0=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<0
0`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@000000=F^8`3E[R<00000`03o
ool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H0:>5]0030000003X_JT0
j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T000`000000k<5402`TU0020>c1A0030000003oool0
oooo06L0oooo00<0000003@[U`0d:iL00P0d:iL00`000000:R:C02XRT`0=02XRT`030000002TQK@0
Y8Fd01T0Y8Fd00<000000>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool0
0`0000006AF<01TES00<01TES0030000002SQK@0XhFd01P0XhFd00<000000>RmZ@3X_JT0503X_JT0
0`000000jKi00>Vn@0030>Vn@0030000003/`D@0;2BD0080k<5400<000000?ooo`3oool0I`3oool0
0`000000=2^G03@[U`0203@[U`030000000Z8Y<0:R:C00d0:R:C00<000000:B5]02TQK@06@2TQK@0
0`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@0D0>RmZ@030000003Y_T00
jKi000<0jKi000<000000>c1A00/99@00P3/`D@00`000000oooo0?ooo`1W0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo01@0oooo?000000G0?ooo`030000000d:iL0
=2^G0080=2^G00<0000002XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0
j[nX01<0j[nX00@000000=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`0
0`000000XhFd0:>5]00H0:>5]0030000003X_JT0j;fY01@0j;fY00<000000>Vn@03Y_T000`3Y_T00
0`000000k<5402`TU0020>c1A0030000003oool0oooo01@000002@2NPK<00`000000]9>d0;BC]00V
0;BC]00300000038Y;<0b:Bc00L0b:Bc500000030?ooo`030000000d:iL0=2^G0080=2^G00<00000
02XRT`0Z8Y<03@0Z8Y<00`000000Y8Fd0:B5]00I0:B5]0030000003Z_jP0j[nX01<0j[nX00@00000
0=F^8`3E[R<00000`03oool00;l0oooo00<0000001TES00I5H`0300I5H`00`000000XhFd0:>5]00H
0:>5]0030000003X_JT0j;fY0140j;fY4@00000M09j1/`030000002dTk@0]9>d02H0]9>d00<00000
0<RT/`38Y;<06`38Y;<A000000L0:R:C00<000000:B5]02TQK@06@2TQK@00`000000j[nX0>ZoZ00C
0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`06AF<00`06AF<00<00000
0:>5]02SQK@0602SQK@00`000000j;fY0>RmZ@050>RmZ@`000001P24K:l00`000000WX6c09j1/`0U
09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`04
0=^b[``000005`2TQK@00`000000j[nX0>ZoZ00C0>ZoZ0040000003E[R<0eJhS00000<00oooo002o
0?ooo`030000000I5H`06AF<00`06AF<00<000000:>5]02SQK@0502SQK@<00000180Q6b_00<00000
09j1/`2NPK<04P2NPK=@000001@0b:Bc00<000000=^b[`3K/Zl0403K/Zl<000000/0Y8Fd00<00000
0>ZoZ03Z_jP04`3Z_jP010000000eJhS0=F^8`0000300?ooo`00_`3oool00`0000006AF<01TES00<
01TES0030000002SQK@0XhFd00X0XhFd2P00000H08A/[a/00000D00h^^@E000001h0fk:_2P000000
0`2TQK@000000>ZoZ00D0>ZoZ0040000003E[R<0eJhS00000<00oooo002o0?ooo`030000000I5H`0
6AF<00`06AF<00<000000:>5]02SQK@00P2SQK@8000000<0He2W00<0000008A/[`24K:l04024K:l<
000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0Y`P000003`3Z_jP010000000eJhS0=F^
8`0000300?ooo`00_`3oool00`0000006AF<01TES00901TES0P000002`1SD:L00`000000Q6b_08A/
[`0408A/[``00000WP0h^^@<000000H0fk:_00<000000>c0Y`3/`:L02@3/`:L8000000L0j[nX00@0
00000=F^8`3E[R<00000`03oool00;l0oooo00@0000001TES00I5H`06AF<2000000@06=@Y`X00000
]P0h^^@7000001<0k<2W200000020=F^8`030000003oool0oooo0;h0oooo002m0?ooo`H00000401S
D:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0
He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?oo
o`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<
V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D0
0000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo
002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool2
000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`0
000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rj
i1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0
001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0
om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000
V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F
0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool30000
00H0001l0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`00
04/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool0
0940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000
003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540
>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[T
E@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h
^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=
0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?oo
o`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000
S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2
000008`0oooo002<0?ooo`8000005@0h^^@203Vji9X0>;[T00<0000003Rji00h^^@03@0h^^@00`3F
[k40>;[T03Rji02P03Rji0800000S03oool008`0oooo0P00000[03Rji0@0>K[TJ@0h^^@2000000<0
001a2`0h^^@908ab/@030000003F[k40eZna00L0eZna200h^^@00`3F[k40>;[T03Rji02N03Rji080
0000S03oool008`0oooo00<0000003Rji00h^^@0?`0h^^@603Vji5P0>;[T00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0>;[T0P00002<0?ooo`00S03o
ool00`000000>;[T03Rji02K03Rji080001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma09d0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<00000
03Rji00h^^@0V00h^^@50000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@030?k?LIX0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rj
i00h^^@0U@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T09D0>;[T00<000000?oo
o`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0<@0h^^@=03Vji5H0>;[T00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000>K[T03Vji02D03Rji0030000003oool0oooo08/0oooo002>0?ooo`800000
IP0h^^@I03Vji1D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00=03Rji100>K[T
M@0h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>;[T03Rji00]03Rji0`0>K[TF00h^^@00`000000oooo0?ooo`2>0?ooo`00T@3oool0
0`000000>;[T03Rji02@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@09P0h^^@0
0`0i^^@0>;[T03Rji00T03Rji0P0>K[T>`0h^^@00`000000oooo0?ooo`2?0?ooo`00TP3oool20000
0900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rji0@0>K[T7@0h^^@20000
0980oooo002D0?ooo`030000000h^^@0>;[T08d0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji02=03Rji0030000003oool0oooo0980oooo002F0?ooo`800000S00h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T08X0>;[T0P00002F0?ooo`00V03oool2000008X0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji02803Rji0800000V03oool009X0oooo0`000027
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h^^@3000009X0oooo002M0?oo
o`800000Q@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08<0>;[T0P00002M0?oo
o`00W`3oool2000008<0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02103Rji080
0000W`3oool00:40oooo1000001o03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0
O@0h^^@400000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h
^^@0>;[T07P0>;[T1@00002U0?ooo`00ZP3oool5000007D0>;[T00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00001`03Rji003000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<0000003Rji00h^^@0KP0h^^@500000:l0oooo002d0?ooo`D00000J`0h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T06T0>;[T1@00002d0?ooo`00^@3oool5000006H0>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01T03Rji0D00000^@3oool00;h0oooo1@00
001Q03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0G`0h^^@500000;h0oooo0033
0?ooo`D00000G00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05X0>;[T1@000033
0?ooo`00b03oool5000005L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01E03Rj
i0D00000b03oool00<d0oooo1`00001@03Rji003000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h
^^@0CP0h^^@700000<d0oooo003D0?ooo`X00000AP0h^^@00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
000h^^@0>;[T04@0>;[T2P00003D0?ooo`00gP3oool:000003`0>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>;[T03Rji00j03Rji0X00000gP3oool00>P0oooo3@00000_03Rji003000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<0000003Rji00h^^@0;@0h^^@=00000>P0oooo003e0?oooa0000007`0h^^@00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000000h^^@0>;[T01d0>;[T4000003e0?ooo`00o`3oool60?oooaT0
00001P0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0
oooo003o0?oooal0oooo1`0000070000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@L00000o`3ooolO0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00``3oool3000005h0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002`0?ooo`800000
4@3oool00`000000NUVP07YIX005000005T0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj0000000000003`3oool00`000000NUVP07YI
X00607YIX0<00000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0000007YIX01jFJ00201jFJ00
0`000000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00001F0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool00`000000
Nfjj07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YIX0800000EP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0
1`1kK[X2000000d0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1E0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^
^P0807]^^P030<1i003oool0oooo00/0oooo00<0000007YIX01jFJ00201jFJ000`000000oooo0?oo
o`1E0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z03oool0
0`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00/0oooo00<0000007YIX01jFJ001`1jFJ02
000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?oo
o`030000001kK[X0Nfjj00P0Nfjj0P00000<0?ooo`030000001jFJ00NUVP00L0NUVP0P00001G0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000
Nfjj07]^^P0707]^^P8000002`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05H0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000
001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool02@3oool00`000000NUVP07YIX00807YIX0030000
003oool0oooo05H0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02@3oool00`000000NUVP07YI
X00707YIX0800000F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00
NUVP00L0NUVP0P00001H0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^^P030<1i00000000oooo00P0oooo00<0000007YI
X01jFJ00201jFJ000`000000oooo0?ooo`1G0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00ZP3oool00`000000Nfjj07]^^P0707]^^P8000002@3oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool0
1`3oool00`000000NUVP07YIX00707YIX0800000F@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:X0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?oo
o`070?ooo`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool0
0`000000NUVP07YIX00707YIX0030=fn^P000000oooo05T0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?oo
o`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0F03oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00
00000?ooo`050?ooo`030000001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i
00000000oooo00D0oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00
00050?ooo`030000001jFJ00NUVP00P0NUVP0P00001J0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P8000001@3oool0
0`000000NUVP07YIX00807YIX0030000003oool0oooo05T0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002/0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000040?oo
o`030000001jFJ00NUVP00L0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00[03oool2000000T0Nfjj00<0`7T00000003oool00`3oool00`000000
NUVP07YIX00707YIX0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00:d0oooo00<0000007]^^P1kK[X01`1kK[X2000000<0oooo00<0000007YIX01jFJ00
201jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0NUVP00<0
00000?ooo`3oool0FP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00:d0oooo00<0000007]^^P1kK[X0201kK[X200000080oooo00<0000007YIX01jFJ001`1jFJ02
000005`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?oo
o`8000002@1kK[X01@30N@0000000?ooo`3oool0000000T0NUVP0P00001L0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^
^P80000000<0oooo0000001jFJ002@1jFJ02000005`0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj1000000807YIX003
0=fn^P000000000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002^0?ooo`030000001kK[X0Nfjj00P0Nfjj0`00000907YIX0800000G@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo0P00000907]^^P<000002@1j
FJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_
0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000807YIX0040=fn^P1jFJ00b<M6000005d0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?ooo`030000001kK[X0
Nfjj00L0Nfjj0P00000907YIX0800000GP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:l0oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00707YI
X0800000GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:l0
oooo0P00000907]^^P030000001jFJ00NUVP00L0NUVP0P00001N0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool00`000000Nfjj07]^^P0707]^^P030000
001jFJ00NUVP00L0NUVP00<0b<M60000003oool0G@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00;00oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YI
X00507YIX0800000G`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/03oool2000000T0Nfjj00<0000007YI
X01jFJ001@1jFJ02000005l0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002a0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YIX01jFJ001@1jFJ000`38adH0
00000?ooo`1N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
/@3oool00`000000Nfjj07]^^P0807]^^P030000001jFJ00NUVP00<0NUVP0`00001O0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/@3oool2000000T0Nfjj00H0
000007YIX01jFJ00NUVP0=fn^P1jFJ0200000600oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002a0?ooo`8000002@1kK[X00`000000NUVP07YIX00307YIX0800000
H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;80oooo00<0
000007]^^P1kK[X01`1kK[X00`000000NUVP07YIX00307YIX0030<S7AP000000oooo05l0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002b0?ooo`030000001kK[X0
Nfjj00P0Nfjj00@0000007YIX03M_[X0NUVP0`00001P0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/P3oool2000000T0Nfjj00@0000007YIX01jFJ00NUVP0P00
001Q0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00/P3oool2
000000T0Nfjj00@0000007YIX01jFJ00NUVP0P00001Q0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00/`3oool00`000000Nfjj07]^^P0707]^^P060000003M_[X0
NUVP07YIX038adH00000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00;<0oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP0000000200000640oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002c0?ooo`8000002@1kK[X0
10000000NUVP00000000001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000HP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;@0oooo00<0000007]^^P1kK[X01`1kK[X0
10000000NUVP0<S7AP00001R0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00]03oool00`000000Nfjj07]^^P0807]^^P<00000HP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo8`00001C0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool>000000`0B3^N00<000000?74X`3a
a:<0303aa:<?000004`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`3o0?ooob<0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
04L0oooo?P00003o0?ooob80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`/000002@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om2600L0om262`00003o0?oooaL0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@09`2dTk@2000001<0om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3o
oolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3o
oolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo0?l0oooo5@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`3o0?oooaD0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0?l0oooo5@3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0o`3ooolE0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`3o0?oooaD0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo05L0oooo00<000000?ooo`3oool0^P3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0EP3oool300000;/0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo05D0oooo1@00002j
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`1D0?ooo`D0000000<0XAh00000003oool0^03oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0D`3oool7000000030:4N00000000oooo0;L0oooo002P0?ooo`030000
0018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000
000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000
003oool0oooo0580oooo200000020:4N00030000003oool0oooo0;D0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo0540oooo2P0000020:4N00030000003oool0oooo0;@0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0500oooo2`0000030:4N00030000003oool0oooo0;<0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
04l0oooo300000040:4N00030000003oool0oooo0;80oooo002P0?ooo`0300000018>ih0B3^N01L0
B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04h0
oooo3P0000040:4N00030000003oool0oooo0;40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04d0oooo
3`0000050:4N00030000003oool0oooo0;00oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04`0oooo4000
00060:4N00030000003oool0oooo0:l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04/0oooo4@000007
0:4N00030000003oool0oooo0:h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04X0oooo4`0000070:4N
00030000003oool0oooo0:d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo04P0oooo5@0000080:4N0080
0000[@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0A`3ooolF000000X0XAh000<000000?ooo`3oool0
ZP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0AP3ooolG000000/0XAh000<000000?ooo`3oool0Z@3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0A@3ooolI000000/0XAh000<000000?ooo`3oool0Z03oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0A03ooolJ000000`0XAh000<000000?ooo`3oool0Y`3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0@`3ooolJ000000030;>Tb@000000XAh000/0XAh000<000000?ooo`3o
ool0YP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0@P3ooolJ000000<0/jC900<000000:4N002Q7P00
2P2Q7P000`000000oooo0?ooo`2U0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`110?oooaX000001@2c
Y<T00`000000XAh00:4N000:0:4N00030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo0400oooo6P0000070;>Tb@030000002Q7P00XAh000X0XAh000<000000?ooo`3oool0X`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0?`3ooolJ000000T0/jC900<000000:4N002Q7P002P2Q7P000`00
0000oooo0?ooo`2R0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?oooaX000002`2cY<T00`000000
XAh00:4N000:0:4N00030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N
00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^6
00<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03d0oooo
6P00000=0;>Tb@030000002Q7P00XAh000L0XAh000@0/j?80:4N002Q7P000000XP3oool00:00oooo
00<0000004PkWP18>ih01018>ihX000000P0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0l0?ooo`h0000000<0/j?80000000000002@00000?0;>Tb@030000002Q7P00XAh000X0XAh0
00<000000?ooo`3oool0W`3oool009<0oooo5000000B04LjWP030000003aaJ<0lLFS01<0lLFS5`00
000`0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo9`00000A0;>Tb@030000002Q7P00XAh000X0XAh03P00
002C0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00h0EDFS2P000000
0`1EAJ<0000000000008000001<0/jC900<000000:4N002Q7P002@2Q7P000`000000mLRN0?G8WP0:
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<03@1EAJ<E000001D0/jC900<000000:4N002Q7P002@2Q7P000`000000mLRN0?G8WP090?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<02`1EAJ<<0000000305E5X`000000000000L000005`2cY<T00`000000XAh00:4N00080:4N0003
0000003eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0;05E5XaD000006@2cY<T00`000000XAh00:4N00070:4N00030000
001HB:@0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0;05E5X`/0000000<0EDFS0000000000001P00000K0;>Tb@030000002Q
7P00XAh000L0XAh000<0000005Q8Y03eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00`0EDFS4P00000M0;>Tb@030000002Q7P00
XAh000H0XAh000<000000?G8WP3eb9h0203eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00`0EDFS2@0000000`1EAJ<00000000000050000
01l0/jC900<000000:4N002Q7P001P2Q7P000`000000mLRN0?G8WP070?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<@00000240
/jC900<000000:4N002Q7P001@2Q7P000`000000mLRN0?G8WP070?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo
0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om26
0?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0301EAJ<80000000305E5
X`000000000000@000008`2cY<T2000000D0XAh000<0000005Q8Y03eb9h01`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00d0EDFS3@00
000U0;>Tb@8000001@2Q7P0010000000mLRN0?G8WP1HB:@50?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?oo
o`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@
QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<03@1EAJ<60000000305E5X`00
0000000000<000009`2cY<T2000000@0XAh000<000000?G8WP3eb9h00`3eb9h0101HB:@0mLRN0?G8
WP00002C0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS00d0EDFS2`00
000Y0;>Tb@8000000`2Q7P000`000000mLRN0?G8WP060?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<03@1EAJ<5000000030:LT00000000
0000008000006@2cY<T00`000000/jC90;>Tb@0?0;>Tb@8000000`2Q7P000`000000mLRN0?G8WP05
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<03P1EAJ<8000001P0/jC900<06`000000000000000P00000A0;>Tb@040000002Q7P00XAh0
000000L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0>05E5X`<0000000@0Yb@000000000000000005`2cY<T4000000<06`0000<00000
0;>Tb@2cY<T03`2cY<T010000000XAh00:4N000000020?G8WP0505Q8Y03eb9h0mLRN0?G8WP000000
T`3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0>05E5X`H000005`2c
Y<T4000000030>C2@P0K0000001U00806`0000<000000;>Tb@2cY<T03`2cY<T00`000000XAh00000
00060?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<00000
0;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<00000
05E5X`1EAJ<03P1EAJ<2000000030:LT00000000/jC901H0/jC91@0000000`3T`T806`0001/00004
01/000800000402cY<T2000000H0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0?05E5X`8000005P2cY<T7000000030>C2@P0K00006`00
00H06`0000<000000;>Tb@2cY<T03P2cY<T2000000D0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0?05E5X`030000002cY<T0/jC901<0
/jC9200000020>C2@PT06`0000<000000;>Tb@2cY<T03P2cY<T00`000000F4RT0?G8WP030?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
401EAJ<00`000000/jC90;>Tb@0A0;>Tb@P000000P3T`T8;01/0008000003@2cY<T00`000000mLRN
0?G8WP040?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0
000005E5X`1EAJ<04@1EAJ<00`000000/jC90;>Tb@0?0;>Tb@P000000`3T`T8501/000030000I@0K
00006`0000D06`0000<000000;>Tb@2cY<T02@2cY<T00`000000mLRN0?G8WP050?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<04P1EAJ<0
0`000000/jC90;>Tb@0=0;>Tb@P00000103T`T8>01/000800000202cY<T00`000000mLRN0?G8WP06
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5
X`1EAJ<04`1EAJ<00`000000/jC90;>Tb@0<0;>Tb@L00000103T`T8A01/000030000002cY<T0/jC9
00@0/jC900D000000?G8WP3eb9h0mLRN05Q8Y0050?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?oo
o`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@
QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0501EAJ<00`000000/jC90;>Tb@0:0;>T
b@P00000103T`T8B01/000030000002cY<T0/jC90080/jC900<000000?G8WP3eb9h0203eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01D0
EDFS00<000000;>Tb@2cY<T0202cY<T8000000@0i<9200<0000001/0000K00004@0K000200000003
0;>Tb@000000mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0F05E5X`030000002cY<T0/jC900H0/jC9200000060>C2@P800000
4`0K00000`000000mLRN0?G8WP0:0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<05`1EAJ<00`000000/jC90;>Tb@040;>Tb@P00000203T
`T82000001006`000`0000050?G8WP0305Q8Y03eb9h0mLRN00@0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0H05E5X`030000002cY<T0
/jC90080/jC91`0000000`2ISlL000000>C2@P060>C2@P030000002cY<T0/jC9008000003@0K0000
10000000bkS80<^hb000000<0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<06@1EAJ<010000000/jC90;>Tb@2cY<T5000000<0VHo700<0
00000>C2@P3T`T801@3T`T800`000000/jC90;>Tb@020;>Tb@030000000K00006`0000T06`0000D0
00000<^hb03;^<P0bkS80000000<0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<06P1EAJ<00`000000/jC900000003000000D0VHo700<0
00000>C2@P3T`T80103T`T800`000000/jC90;>Tb@040;>Tb@8000001`0K0002000000@0bkS800<0
00000?G8WP3eb9h02P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^
0?ooo`030000001EAJ<0EDFS01/0EDFS0`00000709V?a`030000003T`T80i<9200<0i<9200<00000
0;>Tb@2cY<T01`2cY<T00`0000006`0001/0000301/000030000003;^<P0bkS800@0bkS800<00000
0?G8WP3eb9h02P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS01X0EDFS0P00000909V?a`030000003T`T80i<920080i<9200<000000;>T
b@2cY<T02@2cY<T20000000301/000000000000000L0bkS800<000000?G8WP3eb9h02P3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01/0
EDFS0P00000809V?a`030000003T`T80i<920080i<9200<000000;>Tb@2cY<T02`2cY<T00`000000
bkS80<^hb0070<^hb0030000003eb9h0mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0M05E5X`030000002ISlL0VHo700D0VHo7
00D000000>C2@P3T`T80i<920000000?0;>Tb@8000001`3;^<P00`000000mLRN0?G8WP0:0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
7P1EAJ<2000000D0VHo700@000000>C2@P3T`T800000402cY<T010000000mLRN0000000000050<^h
b0030000003eb9h0mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0J05E5X`030?C7X01EAJ<0EDFS00<0EDFS0P00000309V?a`03
0000003T`T8000000100/jC900H000000?G8WP3eb9h0F4RT0?G8WP0000040<^hb0030000003eb9h0
mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Q05E5X`8000000P2ISlL00`000000i<920000000?0;>Tb@050000003eb9h0mLRN
0?G8WP1HB:@00P3eb9h200000080bkS800<000000?G8WP3eb9h02P3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01T0EDFS00D0m<NP05E5
X`1EAJ<0EDFS0?C7X00505E5X`@000003P2cY<T2000000T0mLRN0`00000<0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<20000
00h0/jC900<000000?G8WP3eb9h02`3eb9h00`000000mLRN0?G8WP0:0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<09@1EAJ<00`000000
/jC90;>Tb@0;0;>Tb@030000003eb9h0mLRN00@0mLRN00<0F4RT0?G8WP3eb9h04P3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01P0EDFS
00<0m<NP05E5X`1EAJ<02`1EAJ<00`000000/jC90;>Tb@090;>Tb@030000003eb9h0mLRN00D0mLRN
00<0F4RT0?G8WP3eb9h04P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS01`0EDFS00<0m<NP05E5X`1EAJ<0201EAJ<00`000000/jC90;>T
b@070;>Tb@030000003eb9h0mLRN00H0mLRN00<0F4RT0?G8WP3eb9h04P3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS01L0EDFS00<0m<NP
05E5X`1EAJ<03P1EAJ<00`000000/jC90;>Tb@050;>Tb@030000003eb9h0mLRN00L0mLRN00<0F4RT
0?G8WP3eb9h04P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000;>Tb@2cY<T00`2cY<T00`000000mLRN0?G8WP0M0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02d
Tk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1E
AJ<06`1EAJ<00`3daj00EDFS05E5X`0;05E5X`8000000`2cY<T00`000000mLRN0?G8WP0N0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
5P1EAJ<00`3daj00EDFS05E5X`0@05E5X`050000003eb9h000000;>Tb@0000002`3eb9h00`1HB:@0
mLRN0?G8WP070?G8WP0305Q8Y03eb9h0mLRN00T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`040000003eb9h0mLRN000000`0
mLRN00<0F4RT0?G8WP3eb9h04`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;`00000C00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H_00000080oooo00<0000005E5X`1EAJ<0
5@1EAJ<00`3daj00EDFS05E5X`0205E5X`030?C7X01EAJ<0EDFS00`0EDFS00<000000?G8WP3eb9h0
3@3eb9h00`1HB:@0mLRN0?G8WP0C0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<a000000<03@^63P00000300d;QP030000002d
Tk@0]9>d02P0]9>d503od8H9000000P01@008@00000[05E5X`030000003eb9h0mLRN00d0mLRN00<0
F4RT0?G8WP3eb9h04`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@0
10000000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0F0?G8WP0305Q8Y03e
b9h0mLRN00X0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@00000
0?o@QP3od8H0om26@02]I7/2000001H0EDFS00<0m<NP05E5X`1EAJ<00P1EAJ<00`3daj00EDFS05E5
X`0=05E5X`030000003eb9h0mLRN00`0mLRN00<0F4RT0?G8WP3eb9h0503eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P000010
0:eTN`<03@^600<000000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`8000006`1E
AJ<00`3daj00EDFS05E5X`0=05E5X`030000003eb9h0mLRN00`0mLRN00<0F4RT0?G8WP3eb9h0503e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP11
0:eTN`8000005@1EAJ<00`3daj00EDFS05E5X`0C05E5X`030000003eb9h0mLRN00`0mLRN00<0F4RT
0?G8WP3eb9h0503eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP110:eTN`8000006P1EAJ<00`3daj00EDFS05E5X`0>05E5X`030000003eb9h0mLRN
00`0mLRN00<0F4RT0?G8WP3eb9h01P3eb9h00`1HB:@0mLRN0?G8WP0;0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440
[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440[FAk0P00000J05E5X`03
0?C7X01EAJ<0EDFS00h0EDFS00<000000?G8WP3eb9h0303eb9h00`1HB:@0mLRN0?G8WP0D0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0[FAk0440[FAk
0P00000D05E5X`030?C7X01EAJ<0EDFS01@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00
00120:eTN`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]I7/0@@2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eTN`0300d;QP000000]9>d02T0]9>d00<00000
0?o@QP2]I7/0@@2]I7/2000001T0EDFS00<0m<NP05E5X`1EAJ<03`1EAJ<00`000000mLRN0?G8WP0;
0?G8WP0305Q8Y03eb9h0mLRN00H0mLRN00<0F4RT0?G8WP3eb9h0303eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eT
N`0300d;QP000000]9>d02T0]9>d00<000000:eTN`2]I7/0@@2]I7/2000002/0EDFS00<000000?G8
WP3eb9h02`3eb9h00`1HB:@0mLRN0?G8WP0E0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002d
Tk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0;0?G8WP03
05Q8Y03eb9h0mLRN01D0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]0030000
002]I7/0[FAk0440[FAk0P00000B05E5X`030?C7X01EAJ<0EDFS00<0EDFS00<0m<NP05E5X`1EAJ<0
401EAJ<00`000000mLRN0?G8WP0;0?G8WP0305Q8Y03eb9h0mLRN01D0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000G05E5
X`030?C7X01EAJ<0EDFS0140EDFS00<000000?G8WP3eb9h02P3eb9h00`1HB:@0mLRN0?G8WP0F0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN00X0mLRN00<0F4RT0?G8WP3e
b9h05P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000401EAJ<00`3daj00EDFS05E5X`0H05E5X`030000
003eb9h0mLRN00X0mLRN00<0F4RT0?G8WP3eb9h05P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`8000005P1E
AJ<00`3daj00EDFS05E5X`0B05E5X`030000003eb9h0mLRN00X0mLRN00<0F4RT0?G8WP3eb9h05P3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<20000
0;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`8000003P1EAJ<00`3daj00EDFS
05E5X`0405E5X`030?C7X01EAJ<0EDFS01<0EDFS00<000000?G8WP3eb9h02@3eb9h00`1HB:@0mLRN
0?G8WP0G0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN00T0mLRN00<0
F4RT0?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP09
0?G8WP0305Q8Y03eb9h0mLRN01L0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;40[FAk0P00000D05E5
X`030?C7X01EAJ<0EDFS01@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0G@2]I7/00`2^]]l0[FAk0:eTN`1B0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0:05E5X`030?C7
X01EAJ<0EDFS01`0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0I02]
I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0EDFS0140EDFS00<0m<NP05E5X`1EAJ<05@1E
AJ<00`000000mLRN0?G8WP080?G8WP0305Q8Y03eb9h0mLRN01P0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP080?G8WP0305Q8Y03eb9h0
mLRN01P0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP080?G8WP0305Q8Y03eb9h0mLRN01P0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk06l0
[FAk00<0[[KO0:eTN`2]I7/0@02]I7/00`000000EDFS05E5X`0@05E5X`030?C7X01EAJ<0EDFS01H0
EDFS00<000000?G8WP3eb9h0203eb9h00`1HB:@0mLRN0?G8WP0H0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`2b0:eTN`030000001EAJ<0EDFS00P0EDFS00<0m<NP05E5X`1EAJ<07P1EAJ<00`000000mLRN
0?G8WP0>0?G8WP0305Q8Y03eb9h0mLRN0180mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk07H0[FAk00<0
[[KO0:eTN`2]I7/0>@2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP07
0?G8WP0305Q8Y03eb9h0mLRN01T0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk07d0[FAk00<0[[KO0:eT
N`2]I7/0<P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00L0mLRN00<0F4RT0?G8
WP3eb9h06@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN00L0mLRN00<0F4RT0?G8WP3eb9h00`3eb9h00`1HB:@0mLRN0?G8WP0C0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`240:eTN`030:jfg`2]I7/0[FAk02/0[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP070?G8WP0305Q8Y03eb9h0mLRN01T0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]
I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000[FAk0:eTN`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000
EDFS05E5X`0=05E5X`030?C7X01EAJ<0EDFS01T0EDFS00<000000?G8WP3eb9h01P3eb9h00`1HB:@0
mLRN0?G8WP0J0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h01P3eb9h00`1HB:@0mLRN0?G8WP0J0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h01P3eb9h00`1HB:@0mLRN0?G8
WP0J0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00`0EDFS00<0m<NP
05E5X`1EAJ<06P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eT
N`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]
I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP050?G8WP0305Q8
Y03eb9h0mLRN01/0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP050?G8WP0305Q8Y03eb9h0mLRN01/0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP050?G8WP0305Q8Y03eb9h0
mLRN01/0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75XkH00000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h0103eb9h00`1HB:@0mLRN0?G8WP0L0?G8WP030000003oool0oooo0940oooo002C0?oo
o`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fh
h@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0103eb9h00`1HB:@0mLRN0?G8WP0L0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN00<0mLRN00<0F4RT0?G8WP3eb9h07@3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS01<0
lLFS5`00002d0:fhhA/000004@1EAJ<00`000000mLRN0?G8WP030?G8WP0305Q8Y03eb9h0mLRN01d0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0C0?75XaH0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO1D0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^
IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40
[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^IG`D05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75
XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS0140lLFS602^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0
[VEl4`1EAJ<00`000000mLRN0?G8WP020?G8WP0305Q8Y03eb9h0mLRN01h0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0@0?75XaT0[VEl
00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00G0:iUO180EDFS00<000000?G8WP3eb9h0
0P3eb9h0101HB:@0mLRN0?G8WP1HB:@M0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<03`3aaJ<K0:iUO0030000002]^>40[KSQ0;00[KSQ
0P00000J0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6`2^IG`00`000000[KSQ0:fh
h@2`0:fhh@8000006P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75XaD0[VEl00<0lLFS
0:iUO02^IG`0102^IG`00`000000[KSQ0:fhh@2`0:fhh@8000006`2^IG`@05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0>0?75Xa`0[VEl00<000000:fhh@2]^>40/02]^>42000001/0[VEl401EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<03@3aaJ<M0:iUO0030000002]^>40[KSQ0;00[KSQ0P00000L0:iUO0l0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ0:fhh@2`0:fhh@800000
7@2^IG`>05E5X`050000003eb9h0mLRN0?G8WP1HB:@08@3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00`0lLFS7P2^IG`00`000000[KSQ
0:fhh@2`0:fhh@030000002^IG`0[VEl01`0[VEl3P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3a
aJ<O0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0;0?75Xal0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M
0:iUO0d0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00X0lLFS802^IG`00`000000[KSQ0:fhh@2`0:fh
h@030000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<Q0:iUO003
0000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07`2^IG`;05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`090?75Xb40[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS
00@000000?G8WP3eb9h0F4RT8P3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS00P0lLFS8P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000
002^IG`0[VEl0200[VEl2P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0203aaJ<R0:iUO0030000002]
^>40[KSQ0;00[KSQ00<000000:iUO02^IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`07
0?75Xb<0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00Q0:iUO0T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl
0280[VEl201EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00
[KSQ00<000000:iUO02^IG`01@2^IG`00`1EAJ<0[VEl0:iUO00J0:iUO0P0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS00D0lLFS9@2^IG`00`000000[KSQ0:fhh@0b0:fhh@030;^I1P2]^>40[KSQ04H0[KSQ
00<000000:fhh@2]^>40<P2]^>400`000000[VEl0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00D0lLFSFP2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<0
00000:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`040?75Xcl0[VEl00<0[KSQ
0:iUO02^IG`06@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<00000
0:iUO02^IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
00<0lLFSCP2^IG`00`2]^>40[VEl0:iUO00;0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iU
O02^IG`0<P2^IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0
lLFSA@2^IG`00`2]^>40[VEl0:iUO00D0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^
IG`0<P2^IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFS
G@2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0
5@2^IG`00`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSB`2^
IG`00`2]^>40[VEl0:iUO00?0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^
IG`00`000000[VEl0:iUO00V0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP040000003aaJ<0lLFS0?75Xeh0[VEl00<0
^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0F02^IG`00`2]^>40[VEl0:iUO0040:iUO0030;^I1P2]^>40
[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00X0:iUO080EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS05l0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02P0[VEl0P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`L000007`17>Yh00`000000lLFS0:iUO01O0:iUO0030;^I1P2]^>40[KSQ04H0
[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y0:iUO00305E5X`000000mLRN01h0
mLRN1`00002C0?ooo`00VP3oool<000001<0AcZN00<000000?75X`2^IG`0G`2^IG`00`2kV@H0[KSQ
0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:@2^IG`00`1EAJ<00000
0?G8WP0B0?G8WP`00000VP3oool00:H0oooo3@00000604LjWP030000002^IG`0[VEl05l0[VEl00<0
^iT6000000000000A`00000d0:iUO0030000002^IG`0[VEl02X0[VEl00<000000?G8WP3eb9h0103e
b9h=00000:H0oooo002c0?ooofX000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
000006L00000/`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`03
0000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]
^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0
]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80
[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>80
0`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0
oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo
0?ooo`2g0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<00000
0:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O
0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?oo
o`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo
0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo
00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?oo
o`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fh
hP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo0P00001O0:fhhP030000003oool0oooo0;T0oooo002k0?ooo`030000
002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo0P00001O0:fhhP030000
003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR00<000000?ooo`3oool03@3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0=0?ooo`030000002]^>80[KSR05d0[KSR00<000000?ooo`3oool0^@3o
ool00;/0ooooH@00000?0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00d0ooooH@00002k0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0
oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700<040f700D0om29
010=Q`0@3HL040f70000000D0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool01@00000040f7
010=Q`0@3HL0om2900D040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00@00000010=Q`0@3HL0
om291P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`040000000@3HL040f70?o@R@H040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00>d0oooo?`000009010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8Lo00000>d0oooo003]0?ooo`03000000231@H0P`D600@0P`D600<0GL[h08<5
1P231@H0=@231@H9010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01P3od8Lo08<5
1P030000003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D600/0P`D600<0GL[h08<51P23
1@H0;`231@H8010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01@3od8M008<51P03
0000003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D60180P`D600<0GL[h08<51P231@H0
:@231@H7010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0103od8M108<51P030000
003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D601P0P`D60`1Mb_PT08<51PH040f700<0
00000;BC]02dTk@04P2dTk@00`000000om270?o@Q`030?o@Qd80P`D600<000000?ooo`3oool0j`3o
ool00>`0oooo00<0000008<51P231@H080231@H305g:n1l0P`D6100@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om270080om27@`231@H200000>`0oooo003/0?ooo`03000000231@H0P`D6
02L0P`D60`00000H08<51P@040f700<000000;BC]02dTk@04P2dTk@010000000om270?o@Q`3od8M5
08<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D602d0P`D61@2`[mLA08<5
1P<040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`1608<51P030000003oool0oooo
0>X0oooo003/0?ooo`03000000231@H0P`D603@0P`D61@2`[mL;08<51P8040f700<000000;BC]02d
Tk@04P2dTk@00`000000om2708<51P0M08<51PD0/:oG90231@H00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000P`D608<51P0k08<51P030;2_e`00000040f7008040f71P231@H00`000000]9>d
0;BC]00B0;BC]003000000231@H0P`D602/0P`D62@2`[mLB08<51P030000003oool0oooo0>X0oooo
003/0?ooojP00000k03oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`03
0000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSPd00000h03o
ool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<kF@0909<kF@030000003oool0
oooo0=h0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<0000009<kF@2C>eT02@2C>eT00`00
0000oooo0?ooo`3N0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00T0
Tc]I0P00003O0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00P0Tc]I
00<000000>Nl?0000000g`3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<k
F@0809<kF@030000003W_3`000000=l0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<00000
09<kF@2C>eT0202C>eT00`000000ik`l0000003O0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5c
SP030000002C>eT0Tc]I00P0Tc]I00@000000>Nl?03W_3`00000gP3oool00>`0oooo00<000000;5c
SP2aLhh0Y02aLhh00`000000Tc]I09<kF@0809<kF@040000003W_3`0ik`l00000=h0oooo003/0?oo
o`030000002aLhh0/G>>0:@0/G>>00<0000009<kF@2C>eT0202C>eT010000000ik`l0>Nl?000003N
0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000002C>eT0Tc]I00P0Tc]I00@000000>Nl
?03W_3`00000gP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<kF@0809<k
F@050000003W_3`0ik`l0>Nl?0000000g@3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`00
0000Tc]I09<kF@0709<kF@030000003W_3`0ik`l0080ik`l00<000000?ooo`3oool0f`3oool00>`0
oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I09<kF@0709<kF@030000003W_3`0ik`l0080
ik`l00<000000?ooo`3oool0f`3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000Tc]I
09<kF@0709<kF@030000003W_3`0ik`l0080ik`l00<000000?ooo`3oool0f`3oool00>`0oooo00<0
00000;5cSP2aLhh0Y02aLhh;000000<0ik`l00<000000?ooo`3oool0g03oool00>`0ooooZ0000009
08JhmP050000003W_3`0ik`l0>Nl?0000000gP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L0
0`000000Q[Sf08JhmP0708JhmP050000003W_3`0ik`l0>Nl?0000000gP3oool00>`0oooo00<00000
0;2`e`2`/=L0Y02`/=L00`000000Q[Sf08JhmP0708JhmP050000003W_3`0ik`l0>Nl?0000000gP3o
ool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000Q[Sf08JhmP0808JhmP040000003W_3`0
ik`l00000=h0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<0000008JhmP26^?H02026^?H0
0`000000ik`l0000003O0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`0300000026^?H0Q[Sf
00P0Q[Sf00<000000>Nl?0000000g`3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000
Q[Sf08JhmP0808JhmP030000003W_3`000000=l0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G
00<0000008JhmP26^?H02026^?H00`000000ik`l0000003O0?ooo`00k03oool00`000000/;3G0;2`
e`2T0;2`e`0300000026^?H0Q[Sf00P0Q[Sf00<000000>Nl?0000000g`3oool00>`0oooo00<00000
0;2`e`2`/=L0Y02`/=L00`000000Q[Sf08JhmP0908JhmP800000g`3oool00>`0oooo00<000000;2`
e`2`/=L0Y02`/=L00`000000Q[Sf08JhmP0908JhmP030000003oool0oooo0=h0oooo003/0?ooo`03
0000002`/=L0/;3G0:@0/;3G1P00000608JhmP030000003oool0oooo0=h0oooo003/0?ooo`030000
002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool00`3oool700000>00oooo003/0?ooo`030000002`
/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L0
0`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo
0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`
e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooojP00000k03oool00>`0oooo00<0000005K8
m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000E/Se05K8m@2T05K8m@03
0000003oool0oooo0>X0oooo003]0?ooo`030000001Fb?D0E/Se0:80E/Se00<000000?ooo`3oool0
j`3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D00`000000oooo0?ooo`3[0?ooo`00k@3ooonV
00000>d0oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.58974 .24896 m .58987 .2453 L p .60116 .26076 L .42 .343 .664 r
F P
0 g
s
.58987 .2453 m .59019 .23617 L p .59397 .24462 L .42 .343 .664 r
F P
0 g
s
.60116 .26076 m .58987 .2453 L .59397 .24462 L .42 .343 .664 r
F
.59019 .23617 m .58974 .24896 L .57748 .24561 L p .97 .809 .626 r
F P
0 g
s
.59019 .23617 m .59276 .22341 L p .5995 .24371 L .42 .343 .664 r
F P
0 g
s
.59712 .2441 m .59019 .23617 L .5995 .24371 L .42 .343 .664 r
F
.60116 .26076 m .59019 .23617 L .60116 .24873 L F
.59276 .22341 m .59019 .23617 L .57793 .23275 L p .95 .869 .722 r
F P
0 g
s
.57748 .24561 m .57793 .23275 L .59019 .23617 L p .97 .809 .626 r
F P
0 g
s
.60116 .29094 m .60456 .28459 L .62507 .41352 L .865 .706 .683 r
F
.62507 .24629 m .62507 .29588 L p .60456 .28459 L F P
0 g
s
.62507 .29588 m .62507 .41352 L p .60456 .28459 L .865 .706 .683 r
F P
0 g
s
.60077 .28229 m .60116 .28272 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.59276 .22341 m .59732 .21122 L p .60116 .22791 L .42 .343 .664 r
F P
0 g
s
.60116 .24344 m .62507 .24629 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.60116 .24344 m .62507 .24629 L p .60976 .24202 L .289 .763 .934 r
F P
0 g
s
.61675 .29571 m .60116 .24873 L .60116 .22791 L .42 .343 .664 r
F
.60116 .24873 m .59276 .22341 L .60116 .22791 L F
.60116 .24873 m .59712 .2441 L .5995 .24371 L F
.60116 .26873 m .58974 .24896 L .60116 .26076 L F
.5914 .26125 m .58974 .24896 L p .61675 .29571 L F P
0 g
s
.59513 .27252 m .5914 .26125 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.60077 .28229 m .59513 .27252 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.59513 .27252 m .60077 .28229 L .60005 .2821 L p .88 .45 .163 r
F P
0 g
s
.59937 .28173 m .60116 .28298 L .60116 .29094 L .865 .706 .683 r
F
.59933 .28154 m .60005 .2821 L .59937 .28173 L F
.60005 .2821 m .60116 .28298 L .59937 .28173 L F
.59193 .27571 m .59513 .27252 L .60005 .2821 L .88 .45 .163 r
F
.59168 .41055 m .59168 .27895 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.5914 .26125 m .59441 .27034 L p .5842 .26964 L .947 .612 .356 r
F P
0 g
s
.59441 .27034 m .59513 .27252 L .59383 .27218 L p .947 .612 .356 r
F P
0 g
s
.59383 .27218 m .5842 .26964 L p .59441 .27034 L .947 .612 .356 r
F P
0 g
s
.58347 .26873 m .5914 .26125 L .5842 .26964 L .947 .612 .356 r
F
.59168 .27552 m .59168 .27895 L p .59112 .27639 L .959 .783 .339 r
F P
0 g
s
.59168 .27895 m .59168 .41055 L p .58893 .36112 L .959 .783 .339 r
F P
0 g
s
.58545 .29858 m .58893 .28761 L .58893 .36112 L .959 .783 .339 r
F
.58893 .28761 m .59168 .27895 L .58893 .36112 L F
.59168 .27895 m .59168 .27552 L p .60112 .2907 L .865 .706 .683 r
F P
0 g
s
.5842 .26964 m .59383 .27218 L p .59142 .27532 L .88 .45 .163 r
F P
0 g
s
.59933 .28154 m .60112 .2907 L .59168 .27552 L .865 .706 .683 r
F
.59383 .27218 m .59513 .27252 L p .59088 .27676 L .88 .45 .163 r
F P
0 g
s
.58853 .2791 m .59383 .27218 L .59088 .27676 L .88 .45 .163 r
F
.59168 .27552 m .59168 .24231 L p .59933 .28154 L .865 .706 .683 r
F P
0 g
s
.58853 .2791 m .58288 .26929 L .5842 .26964 L p .88 .45 .163 r
F P
0 g
s
.58853 .2791 m .5842 .26964 L .59142 .27532 L .88 .45 .163 r
F
.58893 .28186 m .59168 .27895 L .58893 .28761 L .959 .783 .339 r
F
.58853 .2791 m .58288 .26929 L p .58893 .27579 L .417 .341 .663 r
F P
0 g
s
.58893 .27953 m .58853 .2791 L .58925 .27929 L p .748 .228 0 r
F P
0 g
s
.58893 .27944 m .58853 .2791 L .58893 .27579 L .417 .341 .663 r
F
.58925 .27929 m .58853 .2791 L p .59088 .27676 L .88 .45 .163 r
F P
0 g
s
.58974 .24896 m .5914 .26125 L .57915 .25796 L p .972 .727 .507 r
F P
0 g
s
.57915 .25796 m .57748 .24561 L .58974 .24896 L p .972 .727 .507 r
F P
0 g
s
.58288 .26929 m .57915 .25796 L .5914 .26125 L p .947 .612 .356 r
F P
0 g
s
.57748 .24561 m .57793 .23275 L p .58893 .25746 L .417 .341 .663 r
F P
0 g
s
.58457 .28276 m .58925 .27929 L .58476 .28627 L .959 .783 .339 r
F
.59112 .27639 m .59168 .27895 L .58893 .28186 L F
.58893 .2798 m .58893 .28186 L .58476 .28627 L F
.59112 .27639 m .58893 .28186 L .58893 .2798 L F
.5842 .26964 m .58288 .26929 L p .58347 .26873 L .947 .612 .356 r
F P
0 g
s
.58288 .26929 m .57915 .25796 L p .58893 .27129 L .417 .341 .663 r
F P
0 g
s
.59833 .2841 m .59621 .28122 L .60005 .2821 L .748 .228 0 r
F
.60112 .2907 m .60116 .29094 L .59168 .27895 L .865 .706 .683 r
F
.59585 .28698 m .59621 .28122 L .59833 .2841 L .748 .228 0 r
F
.59585 .28698 m .58893 .27953 L p .59621 .28122 L F P
0 g
s
.58893 .27731 m .59112 .27639 L .58925 .27929 L .959 .783 .339 r
F
.58893 .26642 m .59112 .27639 L .58893 .27731 L F
.58925 .27929 m .60005 .2821 L p .58893 .27953 L .748 .228 0 r
F P
0 g
s
.60005 .2821 m .58925 .27929 L p .59193 .27571 L .88 .45 .163 r
F P
0 g
s
.59088 .27676 m .59193 .27571 L .58925 .27929 L .88 .45 .163 r
F
.58893 .26548 m .57748 .24561 L .58893 .25746 L .417 .341 .663 r
F
.59168 .24231 m .59168 .27552 L p .58893 .26395 L .959 .783 .339 r
F P
0 g
s
.58893 .24005 m .59168 .24231 L p .58893 .26395 L .959 .783 .339 r
F P
0 g
s
.57793 .23275 m .5805 .21992 L .59276 .22341 L p .95 .869 .722 r
F P
0 g
s
.57793 .23275 m .5805 .21992 L p .58726 .24033 L .417 .341 .663 r
F P
0 g
s
.59732 .21122 m .60371 .20013 L p .60943 .24208 L .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .6046 .24287 L .60943 .24208 L .42 .343 .664 r
F
.6046 .24287 m .59732 .21122 L .60943 .24208 L F
.62507 .24629 m .61839 .2406 L .60976 .24202 L .289 .763 .934 r
F
.60371 .20013 m .61165 .19061 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.62507 .24629 m .63066 .23858 L .61839 .2406 L .289 .763 .934 r
F
.61165 .19061 m .62081 .18307 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6629 .41183 m .62507 .41352 L .62507 .24629 L p .607 .496 .701 r
F P
0 g
s
.62507 .24629 m .6629 .24402 L .6629 .41183 L p .607 .496 .701 r
F P
0 g
s
.65156 .17528 m .66142 .17807 L p .63896 .23722 L .42 .343 .664 r
F P
0 g
s
.62507 .24629 m .6606 .23365 L .63066 .23858 L .289 .763 .934 r
F
.68375 .23673 m .67749 .23087 L p .62507 .24629 L F P
0 g
s
.62507 .24629 m .67749 .23087 L .6606 .23365 L .289 .763 .934 r
F
.62507 .24629 m .6629 .24402 L .68375 .23673 L p F P
0 g
s
.68375 .4064 m .6629 .41183 L .6629 .24402 L p .122 .1 .557 r
F P
0 g
s
.6629 .24402 m .68375 .23673 L .68375 .4064 L p .122 .1 .557 r
F P
0 g
s
.68375 .23673 m .67749 .23087 L p .67749 .2705 L .943 .77 .305 r
F P
0 g
s
.68132 .28215 m .67749 .2705 L .67749 .35363 L .943 .77 .305 r
F
.68375 .23673 m .67749 .2705 L .68132 .28215 L F
.68148 .26376 m .67485 .27496 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.68375 .4064 m .68375 .23673 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.68626 .25135 m .68148 .26376 L p .67749 .26573 L .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .67749 .25695 L .67749 .26573 L .42 .343 .664 r
F
.67749 .25695 m .68626 .25135 L .67749 .26573 L F
.67499 .40031 m .67749 .40205 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.67749 .40205 m .68375 .4064 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.68895 .23829 m .68626 .25135 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.67485 .27496 m .67749 .2705 L p .67235 .26408 L .863 .947 .869 r
F P
0 g
s
.67101 .26468 m .67485 .27496 L .67235 .26408 L .863 .947 .869 r
F
.61675 .29571 m .67749 .22453 L .67749 .23676 L .42 .343 .664 r
F
.68377 .20112 m .68767 .2126 L p .61675 .29571 L F P
0 g
s
.6779 .19127 m .68377 .20112 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.67749 .23087 m .67499 .22854 L p .6606 .23365 L .289 .763 .934 r
F P
0 g
s
.61675 .29571 m .68479 .22967 L .68895 .23829 L .42 .343 .664 r
F
.67499 .2629 m .67499 .22854 L p .66737 .26631 L .87 .71 .682 r
F P
0 g
s
.67465 .26186 m .66942 .26041 L p .67749 .2705 L .863 .947 .869 r
F P
0 g
s
.67485 .27496 m .66666 .28447 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66666 .28447 m .67485 .27496 L .66277 .27168 L p .787 .956 .924 r
F P
0 g
s
.66277 .27168 m .67485 .27496 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.67499 .22854 m .66542 .24251 L .66737 .26631 L .87 .71 .682 r
F
.61675 .29571 m .6334 .23813 L .63896 .23722 L .42 .343 .664 r
F
.61675 .29571 m .60116 .26076 L .60116 .24873 L F
.61675 .29571 m .60116 .26873 L .60116 .26076 L F
.61675 .29571 m .60807 .29013 L .60077 .28229 L p F P
0 g
s
.60807 .29013 m .61675 .29571 L .60455 .29258 L p .531 0 0 r
F P
0 g
s
.67033 .18347 m .6779 .19127 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66142 .17807 m .67033 .18347 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6412 .17522 m .65156 .17528 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.6308 .17786 m .6412 .17522 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.62081 .18307 m .6308 .17786 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.60455 .29258 m .66542 .26239 L .66277 .27168 L .417 .341 .663 r
F
.66542 .26719 m .66277 .27168 L p .66542 .26239 L F P
0 g
s
.66542 .24251 m .66542 .26719 L .66737 .26631 L .87 .71 .682 r
F
.67421 .24793 m .66942 .26041 L p .66542 .26239 L .417 .341 .663 r
F P
0 g
s
.60455 .29258 m .66542 .25356 L .66542 .26239 L .417 .341 .663 r
F
.66542 .25356 m .67421 .24793 L .66542 .26239 L F
.6334 .23813 m .65156 .17528 L .63896 .23722 L .42 .343 .664 r
F
.67499 .22854 m .66542 .22735 L p .63066 .23858 L .289 .763 .934 r
F P
0 g
s
.63066 .23858 m .66542 .22735 L .63516 .23238 L .289 .763 .934 r
F
.6606 .23365 m .67499 .22854 L .63066 .23858 L F
.67499 .22854 m .66542 .22735 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.60807 .29013 m .59585 .28698 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.60116 .28272 m .60807 .29013 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.60455 .29258 m .59585 .28698 L .60807 .29013 L p .531 0 0 r
F P
0 g
s
.67563 .20897 m .67738 .22162 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.67171 .19744 m .67563 .20897 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.66583 .18754 m .67171 .19744 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.65825 .17971 m .66583 .18754 L p .64016 .23155 L .417 .341 .663 r
F P
0 g
s
.63302 .23273 m .65825 .17971 L .64016 .23155 L .417 .341 .663 r
F
.63066 .23858 m .63516 .23238 L .61839 .2406 L .289 .763 .934 r
F
.65156 .17528 m .6412 .17522 L .62905 .17144 L p .125 .651 .877 r
F P
0 g
s
.66142 .17807 m .65156 .17528 L .63944 .1715 L p 0 .408 .698 r
F P
0 g
s
.62905 .17144 m .63944 .1715 L .65156 .17528 L p .125 .651 .877 r
F P
0 g
s
.63944 .1715 m .64931 .17429 L .66142 .17807 L p 0 .408 .698 r
F P
0 g
s
.64931 .17429 m .65825 .17971 L p .63302 .23273 L .417 .341 .663 r
F P
0 g
s
.62681 .23376 m .64931 .17429 L .63302 .23273 L .417 .341 .663 r
F
.63516 .23238 m .641 .22434 L .62822 .23353 L .289 .763 .934 r
F
.63516 .23238 m .62822 .23353 L .61839 .2406 L F
.61839 .2406 m .62822 .23353 L .61304 .23605 L F
.60455 .29258 m .62681 .23376 L .63302 .23273 L .417 .341 .663 r
F
.60455 .29258 m .63302 .23273 L .64016 .23155 L F
.60976 .24202 m .60725 .23701 L .59754 .23862 L .289 .763 .934 r
F
.60371 .20013 m .59732 .21122 L .58508 .20767 L p .863 .936 .869 r
F P
0 g
s
.61165 .19061 m .60371 .20013 L .59148 .19651 L p .792 .947 .923 r
F P
0 g
s
.58508 .20767 m .59148 .19651 L .60371 .20013 L p .863 .936 .869 r
F P
0 g
s
.62081 .18307 m .61165 .19061 L .59943 .18694 L p .696 .937 .964 r
F P
0 g
s
.59148 .19651 m .59943 .18694 L .61165 .19061 L p .792 .947 .923 r
F P
0 g
s
.59943 .18694 m .60861 .17935 L .62081 .18307 L p .696 .937 .964 r
F P
0 g
s
.59943 .18694 m .60861 .17935 L p .60654 .23713 L .417 .341 .663 r
F P
0 g
s
.60976 .24202 m .59754 .23862 L .60116 .24344 L .289 .763 .934 r
F
.59732 .21122 m .59276 .22341 L .5805 .21992 L p .915 .91 .802 r
F P
0 g
s
.5805 .21992 m .58508 .20767 L .59732 .21122 L p .915 .91 .802 r
F P
0 g
s
.5805 .21992 m .58508 .20767 L p .59237 .23948 L .417 .341 .663 r
F P
0 g
s
.58726 .24033 m .5805 .21992 L .59237 .23948 L .417 .341 .663 r
F
.59754 .23862 m .59272 .23942 L .60116 .24344 L .289 .763 .934 r
F
.59168 .24231 m .60116 .24344 L p .60116 .28298 L .865 .706 .683 r
F P
0 g
s
.58508 .20767 m .59148 .19651 L p .59721 .23867 L .417 .341 .663 r
F P
0 g
s
.59168 .24231 m .60116 .24344 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.58893 .24005 m .59168 .24231 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.60455 .29258 m .59237 .23948 L .59721 .23867 L .417 .341 .663 r
F
.59237 .23948 m .58508 .20767 L .59721 .23867 L F
.58187 .23425 m .58893 .24005 L p .59272 .23942 L .289 .763 .934 r
F P
0 g
s
.59148 .19651 m .59943 .18694 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.59754 .23862 m .58187 .23425 L .59272 .23942 L .289 .763 .934 r
F
.60005 .2821 m .60077 .28229 L p .60063 .28242 L .748 .228 0 r
F P
0 g
s
.59168 .24231 m .60116 .28298 L .59933 .28154 L .865 .706 .683 r
F
.60455 .29258 m .58726 .24033 L .59237 .23948 L .417 .341 .663 r
F
.60455 .29258 m .6019 .2379 L .60654 .23713 L F
.6019 .2379 m .59943 .18694 L .60654 .23713 L F
.61839 .2406 m .61304 .23605 L .60976 .24202 L .289 .763 .934 r
F
.61304 .23605 m .60725 .23701 L .60976 .24202 L F
.6308 .17786 m .62081 .18307 L .60861 .17935 L p .562 .897 .982 r
F P
0 g
s
.6412 .17522 m .6308 .17786 L .61863 .17411 L p .376 .809 .962 r
F P
0 g
s
.60861 .17935 m .61863 .17411 L .6308 .17786 L p .562 .897 .982 r
F P
0 g
s
.61863 .17411 m .62905 .17144 L .6412 .17522 L p .376 .809 .962 r
F P
0 g
s
.61863 .17411 m .62905 .17144 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.60861 .17935 m .61863 .17411 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.61304 .23605 m .60211 .22675 L .60725 .23701 L .289 .763 .934 r
F
.63944 .1715 m .64931 .17429 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.62905 .17144 m .63944 .1715 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.641 .22434 m .60211 .22675 L p .61304 .23605 L .289 .763 .934 r
F P
0 g
s
.62822 .23353 m .641 .22434 L .61304 .23605 L .289 .763 .934 r
F
.66542 .22735 m .641 .22434 L p .63516 .23238 L F P
0 g
s
.67749 .35363 m .67575 .26663 L .67499 .40031 L .943 .77 .305 r
F
.67499 .22854 m .67499 .26334 L p .67575 .26663 L F P
0 g
s
.67499 .26334 m .67499 .40031 L p .67575 .26663 L .943 .77 .305 r
F P
0 g
s
.67749 .23087 m .67499 .22854 L p .67749 .35363 L .943 .77 .305 r
F P
0 g
s
.67421 .24793 m .67247 .25245 L p .68148 .26376 L .918 .921 .8 r
F P
0 g
s
.67247 .25245 m .66942 .26041 L .67465 .26186 L p .918 .921 .8 r
F P
0 g
s
.67465 .26186 m .68148 .26376 L p .67247 .25245 L .918 .921 .8 r
F P
0 g
s
.60455 .29258 m .67274 .22614 L .6769 .2348 L .417 .341 .663 r
F
.67738 .22162 m .67724 .22539 L p .67274 .22614 L F P
0 g
s
.67724 .22539 m .6769 .2348 L p .67274 .22614 L .417 .341 .663 r
F P
0 g
s
.6769 .2348 m .67421 .24793 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.641 .22434 m .641 .27815 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.66542 .22735 m .641 .22434 L p .66542 .24251 L .87 .71 .682 r
F P
0 g
s
.66542 .24251 m .641 .27815 L .66542 .26719 L .87 .71 .682 r
F
.66942 .26041 m .66542 .26719 L p .66542 .26239 L .417 .341 .663 r
F P
0 g
s
.66942 .26041 m .66542 .26719 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.66542 .26719 m .66277 .27168 L p .67101 .26468 L .863 .947 .869 r
F P
0 g
s
.64716 .29681 m .63672 .29914 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.65729 .29185 m .64716 .29681 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.66666 .28447 m .65729 .29185 L p .61675 .29571 L .42 .343 .664 r
F P
0 g
s
.63672 .29914 m .64716 .29681 L .63502 .29366 L p .336 .794 .943 r
F P
0 g
s
.64517 .28867 m .63502 .29366 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.65456 .28124 m .64517 .28867 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.66277 .27168 m .65456 .28124 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.64716 .29681 m .65729 .29185 L .64517 .28867 L p .537 .895 .975 r
F P
0 g
s
.64517 .28867 m .63502 .29366 L .64716 .29681 L p .537 .895 .975 r
F P
0 g
s
.65729 .29185 m .66666 .28447 L .65456 .28124 L p .682 .942 .962 r
F P
0 g
s
.65456 .28124 m .64517 .28867 L .65729 .29185 L p .682 .942 .962 r
F P
0 g
s
.66277 .27168 m .65456 .28124 L .66666 .28447 L p .787 .956 .924 r
F P
0 g
s
.641 .27815 m .641 .39718 L p .66737 .26631 L .87 .71 .682 r
F P
0 g
s
.641 .39718 m .67499 .40031 L .67499 .2629 L p .87 .71 .682 r
F P
0 g
s
.66737 .26631 m .641 .39718 L .67499 .2629 L .87 .71 .682 r
F
.66942 .26041 m .67101 .26468 L .67235 .26408 L .863 .947 .869 r
F
.67749 .2705 m .68148 .26376 L .67465 .26186 L p F P
0 g
s
.68767 .2126 m .68943 .22518 L p .67749 .23676 L .42 .343 .664 r
F P
0 g
s
.67749 .22453 m .68767 .2126 L .67749 .23676 L .42 .343 .664 r
F
.68943 .22518 m .68929 .22893 L p .68479 .22967 L F P
0 g
s
.68929 .22893 m .68895 .23829 L p .68479 .22967 L .42 .343 .664 r
F P
0 g
s
.60211 .22675 m .58187 .23425 L p .59754 .23862 L .289 .763 .934 r
F P
0 g
s
.60725 .23701 m .60211 .22675 L .59754 .23862 L .289 .763 .934 r
F
.58893 .24537 m .58488 .24072 L .58726 .24033 L .417 .341 .663 r
F
.58488 .24072 m .57793 .23275 L .58726 .24033 L F
.59585 .28698 m .60005 .2821 L .60063 .28242 L .748 .228 0 r
F
.60455 .29258 m .58893 .25746 L .58893 .24537 L .417 .341 .663 r
F
.58893 .25746 m .57793 .23275 L .58893 .24537 L F
.57915 .25796 m .57748 .24561 L p .58893 .26548 L F P
0 g
s
.58893 .27129 m .57915 .25796 L .58893 .26548 L .417 .341 .663 r
F
.58893 .27579 m .58288 .26929 L .58893 .27129 L F
.58187 .23425 m .58893 .27731 L .58457 .28276 L .959 .783 .339 r
F
.58893 .27731 m .58925 .27929 L .58893 .27953 L F
.58893 .27953 m .58853 .2791 L p .58893 .27944 L .417 .341 .663 r
F P
0 g
s
.58893 .27731 m .58893 .27953 L .58457 .28276 L .959 .783 .339 r
F
.58187 .23425 m .58893 .24005 L p .58893 .26395 L F P
0 g
s
.58187 .23425 m .59168 .27552 L .59112 .27639 L .959 .783 .339 r
F
.60455 .29258 m .58893 .27129 L .58893 .26548 L .417 .341 .663 r
F
.60455 .29258 m .58893 .27579 L .58893 .27129 L F
.60455 .29258 m .58893 .26548 L .58893 .25746 L F
.58187 .23425 m .58893 .26642 L .58893 .27731 L .959 .783 .339 r
F
.60455 .29258 m .59585 .28698 L .58893 .27953 L p .417 .341 .663 r
F P
0 g
s
.60455 .29258 m .58893 .27953 L .58893 .27944 L .417 .341 .663 r
F
.58476 .28627 m .58893 .28186 L .58545 .29858 L .959 .783 .339 r
F
.58893 .28186 m .58893 .28761 L .58545 .29858 L F
.60455 .29258 m .58893 .27944 L .58893 .27579 L .417 .341 .663 r
F
.62507 .41352 m .60116 .4114 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.60116 .4114 m .59168 .41055 L p .60116 .29094 L .865 .706 .683 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62507 .41352 m .6629 .41183 L .68375 .4064 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.59168 .41055 m .58187 .40456 L .58187 .23425 L p .959 .783 .339 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58187 .40456 m .59168 .41055 L .62507 .41352 L p .224 .73 .894 r
F P
0 g
s
.60211 .39897 m .58187 .40456 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.641 .39718 m .60211 .39897 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.67499 .40031 m .641 .39718 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.68375 .4064 m .67499 .40031 L p .62507 .41352 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.58187 .40456 m .60211 .39897 L .60211 .22675 L p .094 .077 .545 r
F P
0 g
s
.60211 .22675 m .58187 .23425 L .58187 .40456 L p .094 .077 .545 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.32786 .24896 m .32799 .2453 L p .33854 .26076 L .399 .326 .658 r
F P
0 g
s
.32799 .2453 m .32829 .23617 L p .33181 .24462 L .399 .326 .658 r
F P
0 g
s
.33854 .26076 m .32799 .2453 L .33181 .24462 L .399 .326 .658 r
F
.32829 .23617 m .32786 .24896 L .31426 .24561 L p .959 .799 .64 r
F P
0 g
s
.32829 .23617 m .33069 .22341 L p .33698 .24371 L .399 .326 .658 r
F P
0 g
s
.33476 .2441 m .32829 .23617 L .33698 .24371 L .399 .326 .658 r
F
.33854 .26076 m .32829 .23617 L .33854 .24873 L F
.33069 .22341 m .32829 .23617 L .31468 .23275 L p .941 .854 .728 r
F P
0 g
s
.31426 .24561 m .31468 .23275 L .32829 .23617 L p .959 .799 .64 r
F P
0 g
s
.33854 .29094 m .3421 .28459 L .36358 .41352 L .859 .702 .685 r
F
.36358 .24629 m .36358 .29588 L p .3421 .28459 L F P
0 g
s
.36358 .29588 m .36358 .41352 L p .3421 .28459 L .859 .702 .685 r
F P
0 g
s
.33817 .28229 m .33854 .28272 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.33069 .22341 m .33495 .21122 L p .33854 .22791 L .399 .326 .658 r
F P
0 g
s
.33854 .24344 m .36358 .24629 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33854 .24344 m .36358 .24629 L p .34657 .24202 L .289 .763 .934 r
F P
0 g
s
.34175 .24287 m .33854 .24344 L .33854 .22791 L .399 .326 .658 r
F
.33854 .24873 m .33069 .22341 L .33854 .22791 L F
.33495 .21122 m .34092 .20013 L p .3531 .29571 L F P
0 g
s
.36358 .24629 m .35463 .2406 L .34657 .24202 L .289 .763 .934 r
F
.34092 .20013 m .34833 .19061 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.36358 .24629 m .36609 .23858 L .35463 .2406 L .289 .763 .934 r
F
.34833 .19061 m .35689 .18307 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40051 .41183 m .36358 .41352 L .36358 .24629 L p .604 .493 .701 r
F P
0 g
s
.36358 .24629 m .40051 .24402 L .40051 .41183 L p .604 .493 .701 r
F P
0 g
s
.37594 .17522 m .38562 .17528 L p .36865 .23813 L .399 .326 .658 r
F P
0 g
s
.36358 .24629 m .39406 .23365 L .36609 .23858 L .289 .763 .934 r
F
.41844 .23673 m .40984 .23087 L p .36358 .24629 L F P
0 g
s
.36358 .24629 m .40984 .23087 L .39406 .23365 L .289 .763 .934 r
F
.36358 .24629 m .40051 .24402 L .41844 .23673 L p F P
0 g
s
.41844 .4064 m .40051 .41183 L .40051 .24402 L p .048 .04 .524 r
F P
0 g
s
.40051 .24402 m .41844 .23673 L .41844 .4064 L p .048 .04 .524 r
F P
0 g
s
.41844 .23673 m .40984 .23087 L p .40984 .2705 L .979 .8 .389 r
F P
0 g
s
.4151 .28215 m .40984 .2705 L .40984 .35363 L .979 .8 .389 r
F
.41844 .23673 m .40984 .2705 L .4151 .28215 L F
.41357 .26376 m .40737 .27496 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.41844 .4064 m .41844 .23673 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.41803 .25135 m .41357 .26376 L p .40984 .26573 L .399 .326 .658 r
F P
0 g
s
.3531 .29571 m .40984 .25695 L .40984 .26573 L .399 .326 .658 r
F
.40984 .25695 m .41803 .25135 L .40984 .26573 L F
.4064 .40031 m .40984 .40205 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.40984 .40205 m .41844 .4064 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.42054 .23829 m .41803 .25135 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40737 .27496 m .40984 .2705 L p .40364 .26408 L .863 .933 .868 r
F P
0 g
s
.40223 .26468 m .40737 .27496 L .40364 .26408 L .863 .933 .868 r
F
.3531 .29571 m .40984 .22453 L .40984 .23676 L .399 .326 .658 r
F
.41571 .20112 m .41935 .2126 L p .3531 .29571 L F P
0 g
s
.41022 .19127 m .41571 .20112 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.40984 .23087 m .4064 .22854 L p .39406 .23365 L .289 .763 .934 r
F P
0 g
s
.3531 .29571 m .41666 .22967 L .42054 .23829 L .399 .326 .658 r
F
.4064 .2629 m .4064 .22854 L p .39841 .26631 L .864 .705 .684 r
F P
0 g
s
.40593 .26186 m .4001 .26041 L p .40984 .2705 L .863 .933 .868 r
F P
0 g
s
.40737 .27496 m .39972 .28447 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39972 .28447 m .40737 .27496 L .39389 .27168 L p .793 .946 .923 r
F P
0 g
s
.39389 .27168 m .40737 .27496 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.4064 .22854 m .39636 .24251 L .39841 .26631 L .864 .705 .684 r
F
.3531 .29571 m .36386 .23898 L .36865 .23813 L .399 .326 .658 r
F
.3531 .29571 m .33854 .24873 L .33854 .24344 L F
.3531 .29571 m .33854 .24344 L .34175 .24287 L F
.33854 .24873 m .33476 .2441 L .33698 .24371 L F
.33854 .26873 m .32786 .24896 L .33854 .26076 L F
.32942 .26125 m .32786 .24896 L p .3531 .29571 L F P
0 g
s
.3329 .27252 m .32942 .26125 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.33817 .28229 m .3329 .27252 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.3531 .29571 m .34499 .29013 L .33817 .28229 L p .399 .326 .658 r
F P
0 g
s
.3286 .24231 m .33854 .24344 L p .33854 .28298 L .859 .702 .685 r
F P
0 g
s
.33666 .28173 m .33854 .28298 L .33854 .29094 L .859 .702 .685 r
F
.3329 .27252 m .33817 .28229 L .33737 .2821 L p .887 .474 .217 r
F P
0 g
s
.32886 .27571 m .3329 .27252 L .33737 .2821 L .887 .474 .217 r
F
.32786 .24896 m .32942 .26125 L .31582 .25796 L p .962 .724 .532 r
F P
0 g
s
.3286 .41055 m .3286 .27895 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.32942 .26125 m .33223 .27034 L p .32077 .26964 L .942 .62 .395 r
F P
0 g
s
.33223 .27034 m .3329 .27252 L .33145 .27218 L p .942 .62 .395 r
F P
0 g
s
.33145 .27218 m .32077 .26964 L p .33223 .27034 L .942 .62 .395 r
F P
0 g
s
.32001 .26873 m .32942 .26125 L .32077 .26964 L .942 .62 .395 r
F
.3286 .27552 m .3286 .27895 L p .32786 .27639 L .988 .806 .415 r
F P
0 g
s
.3286 .27895 m .3286 .41055 L p .32495 .36112 L .988 .806 .415 r
F P
0 g
s
.32032 .29858 m .32495 .28761 L .32495 .36112 L .988 .806 .415 r
F
.32495 .28761 m .3286 .27895 L .32495 .36112 L F
.32077 .26964 m .3193 .26929 L p .32001 .26873 L .942 .62 .395 r
F P
0 g
s
.3193 .26929 m .31582 .25796 L .32942 .26125 L p .942 .62 .395 r
F P
0 g
s
.3286 .27895 m .3286 .27552 L p .33849 .2907 L .859 .702 .685 r
F P
0 g
s
.32077 .26964 m .33145 .27218 L p .32833 .27532 L .887 .474 .217 r
F P
0 g
s
.33662 .28154 m .33849 .2907 L .3286 .27552 L .859 .702 .685 r
F
.33145 .27218 m .3329 .27252 L p .32754 .27676 L .887 .474 .217 r
F P
0 g
s
.32457 .2791 m .33145 .27218 L .32754 .27676 L .887 .474 .217 r
F
.3286 .27552 m .3286 .24231 L p .33662 .28154 L .859 .702 .685 r
F P
0 g
s
.32457 .2791 m .3193 .26929 L .32077 .26964 L p .887 .474 .217 r
F P
0 g
s
.32457 .2791 m .32077 .26964 L .32833 .27532 L .887 .474 .217 r
F
.32457 .2791 m .3193 .26929 L p .32495 .27579 L .396 .324 .657 r
F P
0 g
s
.32495 .28186 m .3286 .27895 L .32495 .28761 L .988 .806 .415 r
F
.32538 .27929 m .32457 .2791 L p .32754 .27676 L .887 .474 .217 r
F P
0 g
s
.32495 .27944 m .32457 .2791 L .32495 .27579 L .396 .324 .657 r
F
.32495 .27731 m .32786 .27639 L .32538 .27929 L .988 .806 .415 r
F
.3193 .26929 m .31582 .25796 L p .32495 .27129 L .396 .324 .657 r
F P
0 g
s
.32495 .27579 m .3193 .26929 L .32495 .27129 L .396 .324 .657 r
F
.31582 .25796 m .31426 .24561 L .32786 .24896 L p .962 .724 .532 r
F P
0 g
s
.31426 .24561 m .31468 .23275 L p .32495 .25746 L .396 .324 .657 r
F P
0 g
s
.31915 .28276 m .32495 .27953 L .31941 .28627 L .988 .806 .415 r
F
.32495 .27953 m .32538 .27929 L .32495 .2798 L F
.32495 .27953 m .32495 .2798 L .31941 .28627 L F
.32786 .27639 m .3286 .27895 L .31941 .28627 L F
.33849 .2907 m .33854 .29094 L .3286 .27895 L .859 .702 .685 r
F
.33238 .28618 m .32495 .27953 L p .33737 .2821 L .772 .267 0 r
F P
0 g
s
.33737 .2821 m .33854 .28298 L .33666 .28173 L .859 .702 .685 r
F
.33141 .28698 m .33737 .2821 L .33798 .28242 L .772 .267 0 r
F
.34499 .29013 m .33141 .28698 L p .33798 .28242 L F P
0 g
s
.36358 .41352 m .33854 .4114 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33854 .4114 m .3286 .41055 L p .33854 .29094 L .859 .702 .685 r
F P
0 g
s
.33953 .29258 m .33141 .28698 L .34499 .29013 L p .569 0 0 r
F P
0 g
s
.33953 .29258 m .33141 .28698 L .32495 .27953 L p .396 .324 .657 r
F P
0 g
s
.32495 .27953 m .32457 .2791 L .32538 .27929 L p .772 .267 0 r
F P
0 g
s
.32495 .27953 m .32457 .2791 L p .32495 .27944 L .396 .324 .657 r
F P
0 g
s
.32538 .27929 m .33737 .2821 L p .32495 .27953 L .772 .267 0 r
F P
0 g
s
.33953 .29258 m .32495 .27953 L .32495 .27944 L .396 .324 .657 r
F
.33662 .28154 m .33737 .2821 L .33666 .28173 L .859 .702 .685 r
F
.33737 .2821 m .32538 .27929 L p .32886 .27571 L .887 .474 .217 r
F P
0 g
s
.32495 .26548 m .31426 .24561 L .32495 .25746 L .396 .324 .657 r
F
.3286 .24231 m .3286 .27552 L p .32495 .26395 L .988 .806 .415 r
F P
0 g
s
.32495 .24005 m .3286 .24231 L p .32495 .26395 L .988 .806 .415 r
F P
0 g
s
.31468 .23275 m .31708 .21992 L .33069 .22341 L p .941 .854 .728 r
F P
0 g
s
.31468 .23275 m .31708 .21992 L p .32339 .24033 L .396 .324 .657 r
F P
0 g
s
.32116 .24072 m .31468 .23275 L .32339 .24033 L .396 .324 .657 r
F
.32495 .25746 m .31821 .24125 L .32495 .24537 L F
.31821 .24125 m .31468 .23275 L .32116 .24072 L F
.31821 .24125 m .32116 .24072 L .32495 .24537 L F
.3286 .24231 m .33854 .24344 L p .32849 .23942 L .289 .763 .934 r
F P
0 g
s
.32495 .24005 m .3286 .24231 L p .32849 .23942 L .289 .763 .934 r
F P
0 g
s
.33737 .2821 m .33817 .28229 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.3286 .24231 m .33854 .28298 L .33662 .28154 L .859 .702 .685 r
F
.33495 .21122 m .33069 .22341 L .31708 .21992 L p .909 .895 .803 r
F P
0 g
s
.31708 .21992 m .32136 .20767 L .33495 .21122 L p .909 .895 .803 r
F P
0 g
s
.31708 .21992 m .32136 .20767 L p .32816 .23948 L .396 .324 .657 r
F P
0 g
s
.33953 .29258 m .32339 .24033 L .32816 .23948 L .396 .324 .657 r
F
.32339 .24033 m .31708 .21992 L .32816 .23948 L F
.34657 .24202 m .33299 .23862 L .33854 .24344 L .289 .763 .934 r
F
.33299 .23862 m .32849 .23942 L .33854 .24344 L F
.33854 .28272 m .34499 .29013 L p .33798 .28242 L .772 .267 0 r
F P
0 g
s
.34092 .20013 m .33495 .21122 L .32136 .20767 L p .862 .923 .867 r
F P
0 g
s
.32136 .20767 m .32733 .19651 L .34092 .20013 L p .862 .923 .867 r
F P
0 g
s
.32136 .20767 m .32733 .19651 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34657 .24202 m .34205 .23701 L .33299 .23862 L .289 .763 .934 r
F
.34833 .19061 m .34092 .20013 L .32733 .19651 L p .797 .937 .922 r
F P
0 g
s
.32733 .19651 m .33475 .18694 L .34833 .19061 L p .797 .937 .922 r
F P
0 g
s
.32733 .19651 m .33475 .18694 L p .33706 .2379 L .396 .324 .657 r
F P
0 g
s
.33953 .29258 m .33268 .23867 L .33706 .2379 L .396 .324 .657 r
F
.33268 .23867 m .32733 .19651 L .33706 .2379 L F
.36386 .23898 m .37594 .17522 L .36865 .23813 L .399 .326 .658 r
F
.36623 .17786 m .37594 .17522 L p .3531 .29571 L F P
0 g
s
.35689 .18307 m .36623 .17786 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.35689 .18307 m .34833 .19061 L .33475 .18694 L p .704 .932 .964 r
F P
0 g
s
.33475 .18694 m .34332 .17935 L .35689 .18307 L p .704 .932 .964 r
F P
0 g
s
.33475 .18694 m .34332 .17935 L p .34139 .23713 L .396 .324 .657 r
F P
0 g
s
.3531 .29571 m .33854 .26076 L .33854 .24873 L .399 .326 .658 r
F
.3531 .29571 m .33854 .26873 L .33854 .26076 L F
.33953 .29258 m .33706 .2379 L .34139 .23713 L .396 .324 .657 r
F
.33706 .2379 m .33475 .18694 L .34139 .23713 L F
.35463 .2406 m .34746 .23605 L .34657 .24202 L .289 .763 .934 r
F
.34746 .23605 m .34205 .23701 L .34657 .24202 L F
.35463 .2406 m .36163 .23353 L .34746 .23605 L F
.36623 .17786 m .35689 .18307 L .34332 .17935 L p .572 .897 .985 r
F P
0 g
s
.37594 .17522 m .36623 .17786 L .35268 .17411 L p .379 .811 .964 r
F P
0 g
s
.34332 .17935 m .35268 .17411 L .36623 .17786 L p .572 .897 .985 r
F P
0 g
s
.35268 .17411 m .36241 .17144 L .37594 .17522 L p .379 .811 .964 r
F P
0 g
s
.35268 .17411 m .36241 .17144 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34332 .17935 m .35268 .17411 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.34746 .23605 m .33281 .22675 L .34205 .23701 L .289 .763 .934 r
F
.40316 .18347 m .41022 .19127 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39483 .17807 m .40316 .18347 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.38562 .17528 m .39483 .17807 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.4064 .22854 m .39636 .22735 L p .36609 .23858 L .289 .763 .934 r
F P
0 g
s
.38967 .17971 m .39636 .18711 L p .37238 .23162 L .396 .324 .657 r
F P
0 g
s
.36612 .23273 m .38967 .17971 L .37238 .23162 L .396 .324 .657 r
F
.36609 .23858 m .39636 .22735 L .36811 .23238 L .289 .763 .934 r
F
.39406 .23365 m .4064 .22854 L .36609 .23858 L F
.33953 .29258 m .39636 .18711 L .39636 .18825 L .396 .324 .657 r
F
.4064 .22854 m .39636 .22735 L p .39636 .24251 L .864 .705 .684 r
F P
0 g
s
.40589 .20897 m .40753 .22162 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40224 .19744 m .40589 .20897 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39675 .18754 m .40224 .19744 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39636 .22735 m .37073 .22434 L p .36811 .23238 L .289 .763 .934 r
F P
0 g
s
.36609 .23858 m .36811 .23238 L .35463 .2406 L .289 .763 .934 r
F
.38562 .17528 m .37594 .17522 L .36241 .17144 L p .112 .643 .867 r
F P
0 g
s
.36241 .17144 m .3721 .1715 L .38562 .17528 L p .112 .643 .867 r
F P
0 g
s
.38132 .17429 m .38967 .17971 L p .36612 .23273 L .396 .324 .657 r
F P
0 g
s
.36031 .23376 m .38132 .17429 L .36612 .23273 L .396 .324 .657 r
F
.36811 .23238 m .37073 .22434 L .36163 .23353 L .289 .763 .934 r
F
.36811 .23238 m .36163 .23353 L .35463 .2406 L F
.33953 .29258 m .36031 .23376 L .36612 .23273 L .396 .324 .657 r
F
.33953 .29258 m .36612 .23273 L .37238 .23162 L F
.39636 .18711 m .39675 .18754 L p .39636 .18825 L F P
0 g
s
.34499 .29013 m .3531 .29571 L .33953 .29258 L p .569 0 0 r
F P
0 g
s
.33953 .29258 m .39636 .26239 L .39389 .27168 L .396 .324 .657 r
F
.37073 .27601 m .37073 .27815 L p .37323 .27468 L .864 .705 .684 r
F P
0 g
s
.39636 .24251 m .39636 .26719 L .39841 .26631 L .864 .705 .684 r
F
.40456 .24793 m .4001 .26041 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40984 .35363 m .40745 .26663 L .4064 .40031 L .979 .8 .389 r
F
.4064 .22854 m .4064 .26334 L p .40745 .26663 L F P
0 g
s
.4064 .26334 m .4064 .40031 L p .40745 .26663 L .979 .8 .389 r
F P
0 g
s
.40984 .23087 m .4064 .22854 L p .40984 .35363 L .979 .8 .389 r
F P
0 g
s
.40456 .24793 m .40294 .25245 L p .41357 .26376 L .913 .905 .802 r
F P
0 g
s
.40294 .25245 m .4001 .26041 L .40593 .26186 L p .913 .905 .802 r
F P
0 g
s
.40593 .26186 m .41357 .26376 L p .40294 .25245 L .913 .905 .802 r
F P
0 g
s
.40708 .2348 m .40456 .24793 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.40753 .22162 m .40708 .2348 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39636 .24251 m .37073 .27601 L .37323 .27468 L .864 .705 .684 r
F
.37073 .22434 m .37073 .27601 L p .39636 .24251 L F P
0 g
s
.39636 .22735 m .37073 .22434 L p .39636 .24251 L .864 .705 .684 r
F P
0 g
s
.3721 .1715 m .38132 .17429 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.36241 .17144 m .3721 .1715 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.37073 .22434 m .33281 .22675 L p .34746 .23605 L .289 .763 .934 r
F P
0 g
s
.36163 .23353 m .37073 .22434 L .34746 .23605 L .289 .763 .934 r
F
.33299 .23862 m .31557 .23425 L .32849 .23942 L F
.31557 .23425 m .32495 .24005 L p .32849 .23942 L F P
0 g
s
.33281 .22675 m .31557 .23425 L p .33299 .23862 L .289 .763 .934 r
F P
0 g
s
.34205 .23701 m .33281 .22675 L .33299 .23862 L .289 .763 .934 r
F
.32495 .24537 m .32116 .24072 L .32339 .24033 L .396 .324 .657 r
F
.33953 .29258 m .32495 .25746 L .32495 .24537 L F
.32495 .26642 m .3286 .27552 L .32786 .27639 L .988 .806 .415 r
F
.31582 .25796 m .31426 .24561 L p .32495 .26548 L .396 .324 .657 r
F P
0 g
s
.32495 .27129 m .31582 .25796 L .32495 .26548 L .396 .324 .657 r
F
.31557 .23425 m .32495 .26395 L .32495 .26642 L .988 .806 .415 r
F
.32495 .26395 m .3286 .27552 L .32495 .26642 L F
.31557 .23425 m .32495 .24005 L p .32495 .26395 L F P
0 g
s
.32495 .26642 m .32786 .27639 L .32495 .27731 L .988 .806 .415 r
F
.32754 .27676 m .32886 .27571 L .32538 .27929 L .887 .474 .217 r
F
.33953 .29258 m .32495 .27129 L .32495 .26548 L .396 .324 .657 r
F
.33953 .29258 m .32495 .26548 L .32495 .25746 L F
.31557 .23425 m .32495 .27731 L .31915 .28276 L .988 .806 .415 r
F
.32495 .27731 m .32538 .27929 L .32495 .27953 L F
.32495 .27731 m .32495 .27953 L .31915 .28276 L F
.31557 .23425 m .32495 .26642 L .32495 .27731 L F
.33953 .29258 m .32495 .27944 L .32495 .27579 L .396 .324 .657 r
F
.31941 .28627 m .32495 .28186 L .32032 .29858 L .988 .806 .415 r
F
.32495 .28186 m .32495 .28761 L .32032 .29858 L F
.33953 .29258 m .32495 .27579 L .32495 .27129 L .396 .324 .657 r
F
.39636 .26719 m .39389 .27168 L p .39636 .26239 L F P
0 g
s
.39636 .24251 m .37073 .27815 L .39636 .26719 L .864 .705 .684 r
F
.4001 .26041 m .39636 .26719 L p .39636 .26239 L .396 .324 .657 r
F P
0 g
s
.4001 .26041 m .39636 .26719 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.39636 .26719 m .39389 .27168 L p .40223 .26468 L .863 .933 .868 r
F P
0 g
s
.37176 .29914 m .36215 .29876 L .3531 .29571 L p .399 .326 .658 r
F P
0 g
s
.38151 .29681 m .37176 .29914 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39097 .29185 m .38151 .29681 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.39972 .28447 m .39097 .29185 L p .3531 .29571 L .399 .326 .658 r
F P
0 g
s
.36215 .29876 m .37176 .29914 L .35822 .29601 L p .056 .608 .826 r
F P
0 g
s
.37176 .29914 m .38151 .29681 L .36798 .29366 L p .34 .796 .945 r
F P
0 g
s
.36798 .29366 m .35822 .29601 L .37176 .29914 L p .34 .796 .945 r
F P
0 g
s
.37746 .28867 m .36798 .29366 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.38622 .28124 m .37746 .28867 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39389 .27168 m .38622 .28124 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.38151 .29681 m .39097 .29185 L .37746 .28867 L p .548 .896 .979 r
F P
0 g
s
.37746 .28867 m .36798 .29366 L .38151 .29681 L p .548 .896 .979 r
F P
0 g
s
.39097 .29185 m .39972 .28447 L .38622 .28124 L p .693 .938 .964 r
F P
0 g
s
.38622 .28124 m .37746 .28867 L .39097 .29185 L p .693 .938 .964 r
F P
0 g
s
.39389 .27168 m .38622 .28124 L .39972 .28447 L p .793 .946 .923 r
F P
0 g
s
.37073 .27815 m .37073 .39718 L p .39841 .26631 L .864 .705 .684 r
F P
0 g
s
.37073 .39718 m .4064 .40031 L .4064 .2629 L p .864 .705 .684 r
F P
0 g
s
.39841 .26631 m .37073 .39718 L .4064 .2629 L .864 .705 .684 r
F
.4001 .26041 m .40223 .26468 L .40364 .26408 L .863 .933 .868 r
F
.40984 .2705 m .41357 .26376 L .40593 .26186 L p F P
0 g
s
.41935 .2126 m .42099 .22518 L p .40984 .23676 L .399 .326 .658 r
F P
0 g
s
.40984 .22453 m .41935 .2126 L .40984 .23676 L .399 .326 .658 r
F
.42099 .22518 m .42086 .22893 L p .41666 .22967 L F P
0 g
s
.42086 .22893 m .42054 .23829 L p .41666 .22967 L .399 .326 .658 r
F P
0 g
s
.3286 .41055 m .31557 .40456 L .31557 .23425 L p .988 .806 .415 r
F P
0 g
s
.63672 .29914 m .62644 .29876 L .61675 .29571 L p .42 .343 .664 r
F P
0 g
s
.61675 .29571 m .62644 .29876 L .61426 .29564 L p .239 0 0 r
F P
0 g
s
.62644 .29876 m .63672 .29914 L .62456 .29601 L p .07 .617 .837 r
F P
0 g
s
.62456 .29601 m .61426 .29564 L .62644 .29876 L p .07 .617 .837 r
F P
0 g
s
.63502 .29366 m .62456 .29601 L .63672 .29914 L p .336 .794 .943 r
F P
0 g
s
.63502 .29366 m .62456 .29601 L p .60455 .29258 L .417 .341 .663 r
F P
0 g
s
.60211 .39897 m .641 .39718 L .641 .22434 L p .604 .493 .7 r
F P
0 g
s
.61426 .29564 m .60455 .29258 L .61675 .29571 L p .239 0 0 r
F P
0 g
s
.62456 .29601 m .61426 .29564 L .60455 .29258 L p .417 .341 .663 r
F P
0 g
s
.641 .22434 m .60211 .22675 L .60211 .39897 L p .604 .493 .7 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.31557 .40456 m .3286 .41055 L .36358 .41352 L p .224 .73 .894 r
F P
0 g
s
.33281 .39897 m .31557 .40456 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.37073 .39718 m .33281 .39897 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.4064 .40031 m .37073 .39718 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.41844 .4064 m .4064 .40031 L p .36358 .41352 L .224 .73 .894 r
F P
0 g
s
.36358 .41352 m .40051 .41183 L .41844 .4064 L p .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3531 .29571 m .36215 .29876 L .3486 .29564 L p .273 0 0 r
F P
0 g
s
.3486 .29564 m .33953 .29258 L .3531 .29571 L p .273 0 0 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31557 .40456 m .33281 .39897 L .33281 .22675 L p .014 .012 .507 r
F P
0 g
s
.33281 .22675 m .31557 .23425 L .31557 .40456 L p .014 .012 .507 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.35822 .29601 m .3486 .29564 L .36215 .29876 L p .056 .608 .826 r
F P
0 g
s
.35822 .29601 m .3486 .29564 L .33953 .29258 L p .396 .324 .657 r
F P
0 g
s
.36798 .29366 m .35822 .29601 L p .33953 .29258 L .396 .324 .657 r
F P
0 g
s
.39483 .17807 m .38562 .17528 L .3721 .1715 L p .215 0 0 r
F P
0 g
s
.67033 .18347 m .66142 .17807 L .64931 .17429 L p .484 0 0 r
F P
0 g
s
.40316 .18347 m .39483 .17807 L .38132 .17429 L p .527 0 0 r
F P
0 g
s
.3721 .1715 m .38132 .17429 L .39483 .17807 L p .215 0 0 r
F P
0 g
s
.6779 .19127 m .67033 .18347 L .65825 .17971 L p .722 .191 0 r
F P
0 g
s
.64931 .17429 m .65825 .17971 L .67033 .18347 L p .484 0 0 r
F P
0 g
s
.41022 .19127 m .40316 .18347 L .38967 .17971 L p .752 .234 0 r
F P
0 g
s
.38132 .17429 m .38967 .17971 L .40316 .18347 L p .527 0 0 r
F P
0 g
s
.68377 .20112 m .6779 .19127 L .66583 .18754 L p .871 .43 .119 r
F P
0 g
s
.65825 .17971 m .66583 .18754 L .6779 .19127 L p .722 .191 0 r
F P
0 g
s
.41571 .20112 m .41022 .19127 L .39675 .18754 L p .882 .458 .179 r
F P
0 g
s
.38967 .17971 m .39675 .18754 L .41022 .19127 L p .752 .234 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.33281 .39897 m .37073 .39718 L .37073 .22434 L p .601 .491 .7 r
F P
0 g
s
.37073 .22434 m .33281 .22675 L .33281 .39897 L p .601 .491 .7 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.68148 .26376 m .68626 .25135 L .67421 .24793 L p .918 .921 .8 r
F P
0 g
s
.41357 .26376 m .41803 .25135 L .40456 .24793 L p .913 .905 .802 r
F P
0 g
s
.68767 .2126 m .68377 .20112 L .67171 .19744 L p .948 .605 .328 r
F P
0 g
s
.66583 .18754 m .67171 .19744 L .68377 .20112 L p .871 .43 .119 r
F P
0 g
s
.41935 .2126 m .41571 .20112 L .40224 .19744 L p .945 .615 .371 r
F P
0 g
s
.39675 .18754 m .40224 .19744 L .41571 .20112 L p .882 .458 .179 r
F P
0 g
s
.68626 .25135 m .68895 .23829 L .6769 .2348 L p .956 .878 .717 r
F P
0 g
s
.6769 .2348 m .67421 .24793 L .68626 .25135 L p .956 .878 .717 r
F P
0 g
s
.41803 .25135 m .42054 .23829 L .40708 .2348 L p .947 .863 .725 r
F P
0 g
s
.40708 .2348 m .40456 .24793 L .41803 .25135 L p .947 .863 .725 r
F P
0 g
s
.68943 .22518 m .68767 .2126 L .67563 .20897 L p .978 .728 .489 r
F P
0 g
s
.67171 .19744 m .67563 .20897 L .68767 .2126 L p .948 .605 .328 r
F P
0 g
s
.42099 .22518 m .41935 .2126 L .40589 .20897 L p .968 .726 .518 r
F P
0 g
s
.40224 .19744 m .40589 .20897 L .41935 .2126 L p .945 .615 .371 r
F P
0 g
s
.68895 .23829 m .68943 .22518 L .67738 .22162 L p .977 .816 .616 r
F P
0 g
s
.67738 .22162 m .6769 .2348 L .68895 .23829 L p .977 .816 .616 r
F P
0 g
s
.42054 .23829 m .42099 .22518 L .40753 .22162 L p .966 .805 .632 r
F P
0 g
s
.40753 .22162 m .40708 .2348 L .42054 .23829 L p .966 .805 .632 r
F P
0 g
s
.67563 .20897 m .67738 .22162 L .68943 .22518 L p .978 .728 .489 r
F P
0 g
s
.40589 .20897 m .40753 .22162 L .42099 .22518 L p .968 .726 .518 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.74865 .87438 m .70383 .84123 L .70996 .765 L p .156 .364 .817 r
F P
0 g
s
.70996 .765 m .71107 .75129 L p .72726 .80432 L .156 .364 .817 r
F P
0 g
s
.74865 .87438 m .70996 .765 L .72726 .80432 L .156 .364 .817 r
F
.74865 .87438 m .70383 .84123 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.70996 .87484 m .70139 .8749 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.70996 .87438 m .70996 .87484 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.71107 .75129 m .75756 .78483 L .74865 .87438 L p .156 .364 .817 r
F P
0 g
s
.70996 .87384 m .717 .8739 L p .71303 .87482 L .012 .587 .719 r
F P
0 g
s
.74865 .87438 m .75038 .85691 L p .72128 .87397 L .884 .991 .792 r
F P
0 g
s
.75038 .85691 m .75756 .78483 L p .72244 .87113 L .884 .991 .792 r
F P
0 g
s
.72128 .87397 m .75038 .85691 L .72244 .87113 L .884 .991 .792 r
F
.71303 .87482 m .717 .8739 L .75582 .87449 L .012 .587 .719 r
F
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70739 .90811 m .74865 .87438 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.717 .8739 m .70996 .87384 L p .71436 .87524 L .96 .784 .62 r
F P
0 g
s
.70996 .87384 m .70996 .87748 L p .71436 .87524 L .96 .784 .62 r
F P
0 g
s
.75756 .78483 m .71489 .81897 L .70996 .87748 L p .884 .991 .792 r
F P
0 g
s
.70996 .87748 m .70739 .90811 L p .72244 .87113 L .884 .991 .792 r
F P
0 g
s
.72244 .87113 m .75756 .78483 L .70996 .87748 L .884 .991 .792 r
F
.70739 .90811 m .74865 .87438 L p .72128 .87397 L F P
0 g
s
.70996 1.10469 m .76566 .89165 L .71436 .87524 L .96 .784 .62 r
F
.70996 .87748 m .70996 1.10469 L p .71436 .87524 L F P
0 g
s
.717 .8739 m .77017 .87438 L p .75582 .87449 L .012 .587 .719 r
F P
0 g
s
.75802 .87427 m .717 .8739 L p .76566 .89165 L .96 .784 .62 r
F P
0 g
s
.76566 .89165 m .717 .8739 L .71436 .87524 L .96 .784 .62 r
F
.70996 .87384 m .70996 .87438 L p .70559 .87438 L .012 .587 .719 r
F P
0 g
s
.77017 .87438 m .75802 .87427 L p .76566 .89165 L .96 .784 .62 r
F P
0 g
s
.70383 .84123 m .66253 .87438 L .66367 .85691 L p .888 .988 .798 r
F P
0 g
s
.66367 .85691 m .66836 .78483 L p .68592 .81275 L .888 .988 .798 r
F P
0 g
s
.70383 .84123 m .66367 .85691 L .68592 .81275 L .888 .988 .798 r
F
.70139 .8749 m .65491 .8745 L p .66487 .87438 L .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .66487 .87438 L .70559 .87438 L .012 .587 .719 r
F
.70383 .84123 m .66253 .87438 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.66836 .78483 m .71107 .75129 L .70383 .84123 L p .888 .988 .798 r
F P
0 g
s
.71489 .81897 m .66836 .78483 L .66367 .85691 L p .138 .355 .814 r
F P
0 g
s
.66367 .85691 m .66253 .87438 L p .6745 .86172 L .138 .355 .814 r
F P
0 g
s
.6745 .86172 m .71489 .81897 L .66367 .85691 L .138 .355 .814 r
F
.65491 .8745 m .64101 .87438 L p .65493 .87427 L .012 .587 .719 r
F P
0 g
s
.65868 .87446 m .65823 .87443 L p .70996 .87384 L .012 .587 .719 r
F P
0 g
s
.65823 .87443 m .70191 .8739 L .70996 .87384 L .012 .587 .719 r
F
.66253 .87438 m .70739 .90811 L p .70559 .87438 L .656 .321 .393 r
F P
0 g
s
.70559 .87438 m .66487 .87438 L .70996 .87384 L .012 .587 .719 r
F
.70996 .87384 m .70191 .8739 L p .70872 .87693 L .333 .272 .638 r
F P
0 g
s
.66253 .87438 m .70739 .90811 L .70996 .87748 L p .138 .355 .814 r
F P
0 g
s
.66253 .87438 m .70996 .87748 L .70191 .8739 L .138 .355 .814 r
F
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.62095 1.28726 m .63485 1.26808 L .6489 1.29143 L p .252 .206 .61 r
F P
0 g
s
.6489 1.29143 m .63485 1.31058 L .62095 1.28726 L p .252 .206 .61 r
F P
0 g
s
.63485 1.26808 m .62713 1.27873 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62307 1.27263 m .63485 1.26808 L .60413 1.28899 L .774 .963 .927 r
F
.46484 1.31058 m .45185 1.28726 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.46795 1.30604 m .46484 1.31058 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.62095 1.28726 m .62713 1.29763 L p .61759 1.30188 L .796 .382 .262 r
F P
0 g
s
.61093 1.2955 m .62095 1.28726 L .61759 1.30188 L .796 .382 .262 r
F
.45185 1.28726 m .45892 1.29995 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.44093 1.2955 m .45185 1.28726 L .45717 1.31139 L .798 .39 .278 r
F
.45892 1.27682 m .45185 1.28726 L .43426 1.28899 L p .779 .957 .927 r
F P
0 g
s
.45185 1.28726 m .46484 1.26808 L .46795 1.27361 L p .223 .182 .599 r
F P
0 g
s
.46268 1.28899 m .45185 1.28726 L .46795 1.27361 L .223 .182 .599 r
F
.37209 1.3207 m .37211 1.31966 L p .45539 1.30965 L .694 .457 .559 r
F P
0 g
s
.37209 1.3207 m .45539 1.30965 L .45603 1.31027 L .694 .457 .559 r
F
.37211 1.31966 m .3726 1.28899 L .43426 1.28899 L p F P
0 g
s
.37211 1.31966 m .43426 1.28899 L .45539 1.30965 L .694 .457 .559 r
F
.46484 1.31058 m .45717 1.31139 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.45892 1.29995 m .46484 1.31058 L p .45418 1.29784 L .798 .39 .278 r
F P
0 g
s
.46484 1.31058 m .46795 1.30604 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.43837 1.3207 m .37209 1.3207 L p .46054 1.30971 L .694 .457 .559 r
F P
0 g
s
.41389 1.31592 m .401 1.29226 L .43426 1.28899 L p .798 .39 .278 r
F P
0 g
s
.41389 1.31592 m .43426 1.28899 L .44093 1.2955 L .798 .39 .278 r
F
.45717 1.31139 m .41389 1.31592 L p .44093 1.2955 L F P
0 g
s
.42691 1.29654 m .41389 1.31592 L .45717 1.31139 L p .777 .96 .927 r
F P
0 g
s
.45717 1.31139 m .46484 1.31058 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.43426 1.28899 m .45185 1.28726 L p .44093 1.2955 L .798 .39 .278 r
F P
0 g
s
.43426 1.28899 m .50237 1.28899 L p .45539 1.30965 L .694 .457 .559 r
F P
0 g
s
.45539 1.30965 m .50237 1.28899 L .46236 1.30881 L .694 .457 .559 r
F
.45603 1.31027 m .45539 1.30965 L .60672 1.29147 L F
.60413 1.28899 m .62095 1.28726 L p .61093 1.2955 L .796 .382 .262 r
F P
0 g
s
.6068 1.29155 m .60672 1.29147 L .6274 1.28899 L .694 .457 .559 r
F
.45603 1.31027 m .60672 1.29147 L .6068 1.29155 L F
.50237 1.28899 m .6274 1.28899 L p .46236 1.30881 L F P
0 g
s
.47249 1.3207 m .6068 1.29155 L .62286 1.31372 L .694 .457 .559 r
F
.62791 1.3207 m .60892 1.3207 L p .62286 1.31372 L F P
0 g
s
.60892 1.3207 m .47249 1.3207 L p .62286 1.31372 L .694 .457 .559 r
F P
0 g
s
.46877 1.30869 m .6068 1.29155 L .47249 1.3207 L .694 .457 .559 r
F
.62776 1.31162 m .62791 1.3207 L p .62286 1.31372 L F P
0 g
s
.6068 1.29155 m .62752 1.31139 L .62286 1.31372 L .694 .457 .559 r
F
.62752 1.31139 m .62776 1.31162 L .62286 1.31372 L F
.58611 1.31592 m .60413 1.28899 L .61093 1.2955 L .796 .382 .262 r
F
.60008 1.29654 m .58611 1.31592 L p .60586 1.29967 L .772 .965 .926 r
F P
0 g
s
.58611 1.31592 m .61093 1.2955 L .61759 1.30188 L .796 .382 .262 r
F
.62775 1.31136 m .58611 1.31592 L p .62713 1.29763 L F P
0 g
s
.58611 1.31592 m .62752 1.31139 L p .60586 1.29967 L .772 .965 .926 r
F P
0 g
s
.62713 1.29763 m .63485 1.31058 L .62775 1.31136 L p .796 .382 .262 r
F P
0 g
s
.62095 1.28726 m .60413 1.28899 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62713 1.27873 m .62095 1.28726 L p .62748 1.27309 L .774 .963 .927 r
F P
0 g
s
.62791 1.2604 m .62776 1.26859 L p .6272 1.26866 L .691 .686 .84 r
F P
0 g
s
.46268 1.28899 m .49129 1.28404 L .49377 1.28514 L .691 .686 .84 r
F
.46268 1.28899 m .43426 1.28899 L p .46628 1.2785 L F P
0 g
s
.42186 1.28347 m .44324 1.28108 L .43426 1.28899 L .691 .686 .84 r
F
.43426 1.28899 m .3726 1.28899 L p .42186 1.28347 L F P
0 g
s
.3726 1.28899 m .46669 1.2604 L .44324 1.28108 L .691 .686 .84 r
F
.43426 1.28899 m .401 1.29226 L p .44336 1.28097 L .779 .957 .927 r
F P
0 g
s
.44336 1.28097 m .45892 1.27682 L .43426 1.28899 L .779 .957 .927 r
F
.3726 1.28899 m .37209 1.2604 L .46669 1.2604 L p .691 .686 .84 r
F P
0 g
s
.46484 1.26808 m .45892 1.27682 L p .44336 1.28097 L .779 .957 .927 r
F P
0 g
s
.45282 1.27263 m .46484 1.26808 L .44336 1.28097 L .779 .957 .927 r
F
.401 1.29226 m .41389 1.27286 L .46484 1.26808 L p F P
0 g
s
.46795 1.27361 m .46484 1.26808 L .45717 1.2688 L p .797 .387 .272 r
F P
0 g
s
.46669 1.2604 m .62791 1.2604 L p .44324 1.28108 L .691 .686 .84 r
F P
0 g
s
.44324 1.28108 m .46628 1.2785 L .43426 1.28899 L .691 .686 .84 r
F
.401 1.29226 m .45282 1.27263 L .44336 1.28097 L .779 .957 .927 r
F
.60413 1.28899 m .46268 1.28899 L p .62776 1.26859 L .691 .686 .84 r
F P
0 g
s
.46628 1.2785 m .62791 1.2604 L .46268 1.28899 L .691 .686 .84 r
F
.46795 1.27361 m .47797 1.29143 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.47797 1.29143 m .46795 1.27361 L p .41389 1.27286 L .797 .387 .272 r
F P
0 g
s
.45717 1.2688 m .41389 1.27286 L p .46795 1.27361 L .797 .387 .272 r
F P
0 g
s
.49377 1.28514 m .61418 1.26278 L .6272 1.26866 L .691 .686 .84 r
F
.49129 1.28404 m .61418 1.26278 L .49377 1.28514 L F
.61418 1.26278 m .62791 1.2604 L .6272 1.26866 L F
.62775 1.26878 m .63485 1.26808 L p .62762 1.27088 L .774 .963 .927 r
F P
0 g
s
.63485 1.26808 m .62775 1.26878 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.6489 1.29143 m .63818 1.27361 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.63818 1.27361 m .63485 1.26808 L p .62796 1.269 L .796 .378 .256 r
F P
0 g
s
.62851 1.2854 m .6489 1.29143 L .62775 1.26878 L .796 .378 .256 r
F
.63168 1.3093 m .62776 1.31126 L .63485 1.31058 L .772 .965 .926 r
F
.62775 1.31136 m .63485 1.31058 L p .62776 1.31126 L F P
0 g
s
.62752 1.31139 m .62775 1.31136 L p .62776 1.31126 L .772 .965 .926 r
F P
0 g
s
.6274 1.28899 m .62776 1.31162 L p .6068 1.29155 L .694 .457 .559 r
F P
0 g
s
.60008 1.29654 m .62752 1.31139 L .62776 1.31126 L .772 .965 .926 r
F
.62798 1.30781 m .62776 1.31126 L .63168 1.3093 L F
.62791 1.30886 m .62791 1.27225 L .62821 1.30413 L 0 0 .059 r
F
.62791 1.27225 m .62791 1.26622 L .62797 1.27351 L F
.62791 1.27225 m .62797 1.27351 L .62821 1.30413 L F
.62888 1.29353 m .6489 1.29143 L p .62851 1.2854 L .796 .378 .256 r
F P
0 g
s
.62821 1.30413 m .62791 1.26622 L .62917 1.25133 L 0 0 .059 r
F
.5723 1.29226 m .58611 1.27286 L .62775 1.26878 L p .774 .963 .927 r
F P
0 g
s
.5723 1.29226 m .62775 1.26878 L .62762 1.27088 L .774 .963 .927 r
F
.6274 1.28899 m .60413 1.28899 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.6274 1.28899 m .62776 1.26891 L p .62788 1.30936 L 0 0 .059 r
F P
0 g
s
.62788 1.30936 m .62776 1.26891 L .62776 1.26907 L 0 0 .059 r
F
.62781 1.31039 m .6274 1.28899 L .62788 1.30936 L F
.58611 1.31592 m .5723 1.29226 L .60413 1.28899 L p .796 .382 .262 r
F P
0 g
s
.62776 1.31162 m .62776 1.31126 L p .62789 1.3145 L 0 0 .059 r
F P
0 g
s
.62776 1.31126 m .6274 1.28899 L p .62781 1.31039 L 0 0 .059 r
F P
0 g
s
.62776 1.31126 m .62781 1.31039 L .62789 1.3145 L 0 0 .059 r
F
.6489 1.29143 m .62888 1.29353 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.62791 1.3207 m .62776 1.26859 L .62791 1.26622 L 0 0 .059 r
F
.62798 1.30781 m .63168 1.3093 L .62888 1.29353 L .772 .965 .926 r
F
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62888 1.29353 m .60008 1.29654 L p .62798 1.30781 L .772 .965 .926 r
F P
0 g
s
.60413 1.28899 m .5723 1.29226 L p .62307 1.27263 L .774 .963 .927 r
F P
0 g
s
.58611 1.27286 m .60008 1.29654 L .62888 1.29353 L p .796 .378 .256 r
F P
0 g
s
.62776 1.26891 m .6274 1.28899 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.58611 1.27286 m .62888 1.29353 L .62851 1.2854 L .796 .378 .256 r
F
.60008 1.29654 m .62776 1.31126 L .62798 1.30781 L .772 .965 .926 r
F
.62791 1.3207 m .62791 1.30886 L .62821 1.30413 L 0 0 .059 r
F
.62791 1.2604 m .62857 1.25566 L p .62791 1.26622 L F P
0 g
s
.62857 1.25566 m .62917 1.25133 L p .62791 1.26622 L 0 0 .059 r
F P
0 g
s
.58611 1.27286 m .62784 1.27079 L .62776 1.26891 L .796 .378 .256 r
F
.58611 1.27286 m .62851 1.2854 L .62784 1.27079 L F
.62775 1.26878 m .62752 1.2688 L p .62776 1.26891 L F P
0 g
s
.62752 1.2688 m .58611 1.27286 L p .62776 1.26891 L .796 .378 .256 r
F P
0 g
s
.62776 1.26859 m .62776 1.26891 L p .62752 1.2688 L .691 .686 .84 r
F P
0 g
s
.62776 1.26891 m .62776 1.26859 L p .62776 1.26907 L 0 0 .059 r
F P
0 g
s
.62789 1.3145 m .62781 1.31039 L .62788 1.30936 L 0 0 .059 r
F
.63485 1.31058 m .63818 1.30604 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.63818 1.30604 m .6489 1.29143 L p .63168 1.3093 L .772 .965 .926 r
F P
0 g
s
.42691 1.29654 m .45717 1.31139 L .46138 1.3093 L .777 .96 .927 r
F
.47249 1.3207 m .43837 1.3207 L p .46877 1.30869 L .694 .457 .559 r
F P
0 g
s
.46054 1.30971 m .46877 1.30869 L .43837 1.3207 L .694 .457 .559 r
F
.47797 1.29143 m .46795 1.30604 L p .46268 1.28899 L .223 .182 .599 r
F P
0 g
s
.47797 1.29143 m .46176 1.29305 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.46795 1.30604 m .47797 1.29143 L p .46138 1.3093 L .777 .96 .927 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L .09 0 0 r
F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.62917 1.25133 m .62801 1.25967 L p .58275 1.25967 L .365 .792 .97 r
F P
0 g
s
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.37083 1.25133 m .53229 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.548 1.25967 m .62917 1.25133 L .58275 1.25967 L F
.452 1.25967 m .54018 1.25552 L .548 1.25967 L F
.54018 1.25552 m .62917 1.25133 L .548 1.25967 L F
.45621 1.25744 m .53833 1.25454 L .452 1.25967 L F
.53833 1.25454 m .62917 1.25133 L .54018 1.25552 L F
.53833 1.25454 m .54018 1.25552 L .452 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.41389 1.27286 m .42691 1.29654 L .47797 1.29143 L p .797 .387 .272 r
F P
0 g
s
.46771 1.29439 m .47032 1.25768 L p .484 1.29086 L .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.48371 1.25362 m .48371 1.10147 L p .47089 1.2543 L .063 .051 .53 r
F P
0 g
s
.47089 1.2543 m .46869 1.2806 L .47909 1.26192 L .063 .051 .53 r
F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L F
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.62776 1.26859 m .62791 1.2604 L p .62791 1.26622 L 0 0 .059 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.47468 1.25782 m .48371 1.26622 L .50936 1.26622 L .513 .022 .027 r
F
.48824 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.47468 1.25782 m .50936 1.26622 L .52213 1.26079 L .513 .022 .027 r
F
.50936 1.26622 m .51486 1.26755 L .51629 1.26622 L F
.50936 1.26622 m .51629 1.26622 L .52213 1.26079 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.52783 1.09787 m .46368 1.10009 L .484 1.09787 L F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L F P
0 g
s
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L F
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L F
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.29653 1.043 m .29225 1.04601 L .36099 1.04601 L p F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36099 1.04601 m .29225 1.04601 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36032 1.07254 m .29225 1.04601 L .35951 1.10469 L .68 .398 .487 r
F
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.3605 1.10246 m .35851 1.02865 L .3605 .95121 L p .767 .626 .063 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44284 1.10469 m .36099 1.04601 L .36032 1.07254 L .68 .398 .487 r
F
.3605 1.04653 m .3605 .95121 L .36159 1.02223 L .767 .626 .063 r
F
.36099 1.04601 m .36159 1.02223 L .36194 1.04502 L F
.3605 1.04653 m .36159 1.02223 L .36099 1.04601 L F
.35951 1.10469 m .44284 1.10469 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L F P
0 g
s
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.35899 .98856 m .35899 .87438 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.29225 1.04601 m .29004 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.32488 1.04601 m .35899 .98856 L .30737 1.04679 L F
.29004 1.10469 m .35951 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.52998 1.0994 m .47138 1.10147 L .4687 1.10147 L F
.47138 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.53019 1.09942 m .47166 1.10147 L .52998 1.0994 L .09 0 0 r
F
.47166 1.10147 m .44324 1.10246 L .47138 1.10147 L F
.47166 1.10147 m .47138 1.10147 L .52998 1.0994 L F
.51629 1.26622 m .51629 1.10147 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.53926 1.09886 m .44328 1.10233 L .46043 1.10045 L .09 0 0 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L F
.53645 1.09918 m .44328 1.10233 L .53926 1.09886 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.10147 m .51629 1.26622 L p .52972 1.09994 L .998 .815 .53 r
F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48146 1.10121 m .46869 1.2806 L .48371 1.10147 L F
.53019 1.09942 m .53225 1.09966 L .44324 1.10246 L .09 0 0 r
F
.53008 1.0999 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.52972 1.09994 m .51629 1.26622 L .53008 1.0999 L F
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.55676 1.10246 m .50754 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.50754 1.10246 m .44324 1.10246 L p .53225 1.09966 L .09 0 0 r
F P
0 g
s
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L .09 0 0 r
F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.55566 1.09853 m .53019 1.09942 L .52998 1.0994 L F
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52972 1.09994 L .53008 1.0999 L .998 .815 .53 r
F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52972 1.09994 L .998 .815 .53 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L .998 .815 .53 r
F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L F P
0 g
s
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.59496 1.09076 m .61173 1.08458 L .57144 1.08458 L .676 .72 .882 r
F
.6395 1.10246 m .61173 1.08458 L .59496 1.09076 L F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70899 .87705 L .64101 1.04449 L .333 .272 .638 r
F
.70899 .87705 m .70872 .87693 L .64101 1.04449 L F
.64101 1.04449 m .70872 .87693 L .65493 .87427 L F
.64101 .90192 m .64101 1.04449 L p .65493 .87427 L F P
0 g
s
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .61173 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .50936 1.26622 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .50936 1.26622 L .513 .022 .027 r
F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .52213 1.26079 L .513 .022 .027 r
F P
0 g
s
.47089 1.2543 m .47909 1.26192 L .48371 1.25362 L .063 .051 .53 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.46771 1.29439 m .48371 1.29798 L .48371 1.25362 L p .063 .051 .53 r
F P
0 g
s
.46869 1.2806 m .46771 1.29439 L .48371 1.25362 L .063 .051 .53 r
F
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L .48514 1.26755 L p .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L .513 .022 .027 r
F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.46176 1.29305 m .42691 1.29654 L p .45419 1.30664 L .777 .96 .927 r
F P
0 g
s
.45419 1.30664 m .46138 1.3093 L .46176 1.29305 L .777 .96 .927 r
F
.62791 1.3207 m .62776 1.31162 L p .62789 1.3145 L 0 0 .059 r
F P
0 g
s
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.70899 .87705 m .70996 .87384 L .70872 .87693 L .333 .272 .638 r
F
.70996 .87748 m .71027 .8738 L p .70191 .8739 L .138 .355 .814 r
F P
0 g
s
.71027 .8738 m .71489 .81897 L p .66253 .87438 L .138 .355 .814 r
F P
0 g
s
.65823 .87443 m .65493 .87427 L p .70191 .8739 L .012 .587 .719 r
F P
0 g
s
.70191 .8739 m .65493 .87427 L p .70872 .87693 L .333 .272 .638 r
F P
0 g
s
.65493 .87427 m .64101 .87438 L .64101 .90192 L p .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.46099 .95734 m .43542 .98202 L .43542 .87593 L p .996 .813 .543 r
F P
0 g
s
.46712 .98062 m .46712 .97686 L p .46828 .98057 L .996 .813 .543 r
F P
0 g
s
.46554 .96355 m .46828 .98057 L .43542 .87593 L .996 .813 .543 r
F
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L .053 .044 .526 r
F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.54711 .95101 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.5498 .95093 m .4456 .95022 L .54711 .95101 L F
.45972 .95121 m .5907 .95121 L p .43542 .9505 L F P
0 g
s
.57946 .95091 m .4456 .95022 L .5907 .95121 L .023 0 0 r
F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.7687 .39814 m .52928 .39402 L .5186 .39814 L .222 .729 .893 r
F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.4814 .39814 m .43789 .39657 L .43408 .39814 L .222 .729 .893 r
F
.47807 .39686 m .44009 .39566 L .4814 .39814 L F
.44009 .39566 m .22014 .38872 L .43789 .39657 L F
.44009 .39566 m .43789 .39657 L .4814 .39814 L F
.45694 .38333 m .46911 .38807 L p .46895 .39334 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46895 .39334 L .45712 .38878 L .997 .814 .46 r
F
.46911 .38807 m .46985 .38836 L p .46967 .39362 L F P
0 g
s
.46911 .38807 m .46967 .39362 L .46895 .39334 L .997 .814 .46 r
F
.46985 .38836 m .46985 .39369 L p .46967 .39362 L F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .39369 m .22014 .38872 L .47807 .39686 L .222 .729 .893 r
F
.46799 .39297 m .45622 .39277 L .46985 .39369 L F
.45622 .39277 m .22014 .38872 L .46985 .39369 L F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.52117 .39715 m .48505 .39471 L .5186 .39814 L .222 .729 .893 r
F
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .39369 m .46985 .38836 L p .47027 .39372 L F P
0 g
s
.46799 .39297 m .47807 .39686 L .5186 .39814 L .222 .729 .893 r
F
.5186 .39814 m .47807 .39686 L .4814 .39814 L F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.52928 .39402 m .46799 .39297 L .48505 .39471 L .222 .729 .893 r
F
.52928 .39402 m .48505 .39471 L .52117 .39715 L F
.46324 .57549 m .46967 .39362 L .46985 .77742 L .997 .814 .46 r
F
.46985 .39369 m .46985 .77742 L p .46967 .39362 L F P
0 g
s
.46895 .39334 m .46967 .39362 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .46799 .39297 L .222 .729 .893 r
F P
0 g
s
.526 .39397 m .46245 .39084 L .46799 .39297 L .222 .729 .893 r
F
.46245 .39084 m .22102 .37893 L .46799 .39297 L F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.55161 .39224 m .45263 .38705 L .526 .39397 L .222 .729 .893 r
F
.54706 .39037 m .45263 .38705 L .55161 .39224 L F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.54706 .39037 m .45861 .38438 L .43098 .3863 L .222 .729 .893 r
F
.53525 .3855 m .48317 .38268 L .54706 .39037 L F
.31198 .18889 m .31211 .18489 L p .32359 .20159 L .369 .301 .649 r
F P
0 g
s
.31211 .18489 m .31244 .17491 L p .31628 .18408 L .369 .301 .649 r
F P
0 g
s
.32359 .20159 m .31211 .18489 L .31628 .18408 L .369 .301 .649 r
F
.31244 .17491 m .31198 .18889 L .29702 .18489 L p .968 .807 .629 r
F P
0 g
s
.31244 .17491 m .31505 .16093 L p .3219 .18299 L .369 .301 .649 r
F P
0 g
s
.31949 .18346 m .31244 .17491 L .3219 .18299 L .369 .301 .649 r
F
.32359 .20159 m .31244 .17491 L .32359 .18845 L F
.31505 .16093 m .31244 .17491 L .29749 .17083 L p .948 .866 .724 r
F P
0 g
s
.29702 .18489 m .29749 .17083 L .31244 .17491 L p .968 .807 .629 r
F P
0 g
s
.32359 .23457 m .3275 .22767 L .35102 .3687 L .87 .71 .681 r
F
.35102 .18607 m .35102 .24023 L p .3275 .22767 L F P
0 g
s
.35102 .24023 m .35102 .3687 L p .3275 .22767 L .87 .71 .681 r
F P
0 g
s
.32319 .22512 m .32359 .22558 L p .32298 .22525 L .753 .236 0 r
F P
0 g
s
.31505 .16093 m .31969 .14754 L p .32359 .16571 L .369 .301 .649 r
F P
0 g
s
.32359 .18267 m .35102 .18607 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32359 .18267 m .35102 .18607 L p .33233 .18098 L .289 .763 .934 r
F P
0 g
s
.32709 .18199 m .32359 .18267 L .32359 .16571 L .369 .301 .649 r
F
.32359 .18845 m .31505 .16093 L .32359 .16571 L F
.31969 .14754 m .32618 .1353 L p .33945 .23954 L F P
0 g
s
.35102 .18607 m .34111 .17928 L .33233 .18098 L .289 .763 .934 r
F
.32618 .1353 m .33425 .12476 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.35102 .18607 m .3536 .17687 L .34111 .17928 L .289 .763 .934 r
F
.33425 .12476 m .34357 .11636 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39131 .36668 m .35102 .3687 L .35102 .18607 L p .594 .485 .699 r
F P
0 g
s
.35102 .18607 m .39131 .18336 L .39131 .36668 L p .594 .485 .699 r
F P
0 g
s
.36433 .1074 m .37489 .10728 L p .35638 .17633 L .369 .301 .649 r
F P
0 g
s
.35102 .18607 m .38409 .17097 L .3536 .17687 L .289 .763 .934 r
F
.41081 .17465 m .40132 .16764 L p .35102 .18607 L F P
0 g
s
.35102 .18607 m .40132 .16764 L .38409 .17097 L .289 .763 .934 r
F
.35102 .18607 m .39131 .18336 L .41081 .17465 L p F P
0 g
s
.41081 .3602 m .39131 .36668 L .39131 .18336 L p .001 .001 .501 r
F P
0 g
s
.39131 .18336 m .41081 .17465 L .41081 .3602 L p .001 .001 .501 r
F P
0 g
s
.41081 .17465 m .40132 .16764 L p .40132 .21102 L .971 .793 .367 r
F P
0 g
s
.40712 .22411 m .40132 .21102 L .40132 .302 L .971 .793 .367 r
F
.41081 .17465 m .40132 .21102 L .40712 .22411 L F
.40539 .20357 m .39862 .21594 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.41081 .3602 m .41081 .17465 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.41026 .18991 m .40539 .20357 L p .40132 .20579 L .369 .301 .649 r
F P
0 g
s
.33945 .23954 m .40132 .19618 L .40132 .20579 L .369 .301 .649 r
F
.40132 .19618 m .41026 .18991 L .40132 .20579 L F
.39752 .35291 m .40132 .35499 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.40132 .35499 m .41081 .3602 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.41301 .17557 m .41026 .18991 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39862 .21594 m .40132 .21102 L p .39449 .20373 L .863 .944 .869 r
F P
0 g
s
.39295 .20437 m .39862 .21594 L .39449 .20373 L .863 .944 .869 r
F
.33945 .23954 m .40132 .1607 L .40132 .17409 L .369 .301 .649 r
F
.40773 .13497 m .41171 .14746 L p .33945 .23954 L F P
0 g
s
.40174 .12429 m .40773 .13497 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.40132 .16764 m .39752 .16484 L p .38409 .17097 L .289 .763 .934 r
F P
0 g
s
.33945 .23954 m .40877 .1662 L .41301 .17557 L .369 .301 .649 r
F
.39752 .20246 m .39752 .16484 L p .38876 .20611 L .875 .714 .68 r
F P
0 g
s
.39701 .2013 m .39059 .19955 L p .40132 .21102 L .863 .944 .869 r
F P
0 g
s
.39862 .21594 m .39027 .22647 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39027 .22647 m .39862 .21594 L .38381 .212 L p .788 .954 .924 r
F P
0 g
s
.38381 .212 m .39862 .21594 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.39752 .16484 m .38651 .18002 L .38876 .20611 L .875 .714 .68 r
F
.33945 .23954 m .35116 .17734 L .35638 .17633 L .369 .301 .649 r
F
.33945 .23954 m .32359 .18845 L .32359 .18267 L F
.33945 .23954 m .32359 .18267 L .32709 .18199 L F
.32359 .18845 m .31949 .18346 L .3219 .18299 L F
.32359 .2103 m .31198 .18889 L .32359 .20159 L F
.31368 .20229 m .31198 .18889 L p .33945 .23954 L F P
0 g
s
.31746 .21454 m .31368 .20229 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.32319 .22512 m .31746 .21454 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.33945 .23954 m .33062 .23358 L .32319 .22512 L p .369 .301 .649 r
F P
0 g
s
.31271 .18132 m .32359 .18267 L p .32359 .22587 L .87 .71 .681 r
F P
0 g
s
.32153 .22448 m .32359 .22587 L .32359 .23457 L .87 .71 .681 r
F
.31746 .21454 m .32319 .22512 L .32232 .2249 L p .882 .455 .174 r
F P
0 g
s
.31299 .21783 m .31746 .21454 L .32232 .2249 L .882 .455 .174 r
F
.31198 .18889 m .31368 .20229 L .29872 .19836 L p .97 .727 .513 r
F P
0 g
s
.31271 .36517 m .31271 .22135 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.31368 .20229 m .31673 .21217 L p .30412 .21109 L .946 .614 .365 r
F P
0 g
s
.31673 .21217 m .31746 .21454 L .31587 .21413 L p .946 .614 .365 r
F P
0 g
s
.31587 .21413 m .30412 .21109 L p .31673 .21217 L .946 .614 .365 r
F P
0 g
s
.30329 .2101 m .31368 .20229 L .30412 .21109 L .946 .614 .365 r
F
.31271 .21761 m .31271 .22135 L p .31188 .21852 L .981 .801 .395 r
F P
0 g
s
.31271 .22135 m .31271 .36517 L p .30865 .31096 L .981 .801 .395 r
F P
0 g
s
.30352 .24233 m .30865 .23061 L .30865 .31096 L .981 .801 .395 r
F
.30865 .23061 m .31271 .22135 L .30865 .31096 L F
.30412 .21109 m .30251 .21068 L p .30329 .2101 L .946 .614 .365 r
F P
0 g
s
.30251 .21068 m .29872 .19836 L .31368 .20229 L p .946 .614 .365 r
F P
0 g
s
.31271 .22135 m .31271 .21761 L p .32354 .2343 L .87 .71 .681 r
F P
0 g
s
.30412 .21109 m .31587 .21413 L p .31241 .21739 L .882 .455 .174 r
F P
0 g
s
.32149 .22427 m .32354 .2343 L .31271 .21761 L .87 .71 .681 r
F
.30825 .22131 m .30251 .21068 L .30412 .21109 L p .882 .455 .174 r
F P
0 g
s
.30825 .22131 m .30412 .21109 L .31241 .21739 L .882 .455 .174 r
F
.30825 .22131 m .30251 .21068 L p .30865 .21768 L .366 .299 .648 r
F P
0 g
s
.30913 .22154 m .31271 .22135 L .30865 .22432 L .981 .801 .395 r
F
.30913 .22154 m .30865 .22432 L .30865 .22207 L F
.31188 .21852 m .3123 .21997 L .30913 .22154 L F
.3123 .21997 m .31271 .22135 L .30913 .22154 L F
.30251 .22882 m .30865 .22432 L .30352 .24233 L F
.30865 .22432 m .31271 .22135 L .30865 .23061 L F
.30865 .22432 m .30865 .23061 L .30352 .24233 L F
.30865 .22178 m .30825 .22131 L .30913 .22154 L p .753 .236 0 r
F P
0 g
s
.30865 .22178 m .30825 .22131 L p .30865 .22167 L .366 .299 .648 r
F P
0 g
s
.30825 .22131 m .31587 .21413 L .31153 .2189 L .882 .455 .174 r
F
.30913 .22154 m .30825 .22131 L p .31153 .2189 L F P
0 g
s
.30865 .22167 m .30825 .22131 L .30865 .21768 L .366 .299 .648 r
F
.30251 .21068 m .29872 .19836 L p .30865 .21277 L F P
0 g
s
.30865 .21768 m .30251 .21068 L .30865 .21277 L .366 .299 .648 r
F
.29872 .19836 m .29702 .18489 L .31198 .18889 L p .97 .727 .513 r
F P
0 g
s
.29702 .18489 m .29749 .17083 L p .30865 .19765 L .366 .299 .648 r
F P
0 g
s
.30865 .20641 m .29702 .18489 L .30865 .19765 L .366 .299 .648 r
F
.30865 .20744 m .31188 .21852 L .30865 .22207 L .981 .801 .395 r
F
.32354 .2343 m .32359 .23457 L .31271 .22135 L .87 .71 .681 r
F
.31681 .22898 m .30865 .22178 L p .32232 .2249 L .753 .236 0 r
F P
0 g
s
.30913 .22154 m .32232 .2249 L p .30865 .22178 L .753 .236 0 r
F P
0 g
s
.31153 .2189 m .3123 .21806 L .31243 .21824 L .882 .455 .174 r
F
.3123 .21806 m .31587 .21413 L .31243 .21824 L F
.31587 .21413 m .31746 .21454 L p .31243 .21824 L F P
0 g
s
.31271 .21761 m .31271 .18132 L p .32149 .22427 L .87 .71 .681 r
F P
0 g
s
.32149 .22427 m .32232 .2249 L .32153 .22448 L .87 .71 .681 r
F
.32232 .2249 m .30913 .22154 L p .31299 .21783 L .882 .455 .174 r
F P
0 g
s
.31153 .2189 m .31299 .21783 L .30913 .22154 L .882 .455 .174 r
F
.31271 .18132 m .31271 .21761 L p .30865 .20474 L .981 .801 .395 r
F P
0 g
s
.30865 .17862 m .31271 .18132 L p .30865 .20474 L .981 .801 .395 r
F P
0 g
s
.29749 .17083 m .3001 .15677 L .31505 .16093 L p .948 .866 .724 r
F P
0 g
s
.29749 .17083 m .3001 .15677 L p .30696 .17895 L .366 .299 .648 r
F P
0 g
s
.30454 .17942 m .29749 .17083 L .30696 .17895 L .366 .299 .648 r
F
.32232 .2249 m .32359 .22587 L .32153 .22448 L .87 .71 .681 r
F
.31569 .22981 m .32232 .2249 L .32298 .22525 L .753 .236 0 r
F
.32232 .2249 m .32319 .22512 L p .32298 .22525 L F P
0 g
s
.31271 .18132 m .32359 .22587 L .32149 .22427 L .87 .71 .681 r
F
.32327 .23173 m .31569 .22981 L p .32155 .22615 L .753 .236 0 r
F P
0 g
s
.32155 .22615 m .32298 .22525 L .32327 .23173 L .753 .236 0 r
F
.33062 .23358 m .32327 .23173 L p .32298 .22525 L F P
0 g
s
.31271 .18132 m .32359 .18267 L p .31251 .17787 L .289 .763 .934 r
F P
0 g
s
.31969 .14754 m .31505 .16093 L .3001 .15677 L p .913 .907 .802 r
F P
0 g
s
.3001 .15677 m .30474 .1433 L .31969 .14754 L p .913 .907 .802 r
F P
0 g
s
.3001 .15677 m .30474 .1433 L p .31215 .17794 L .366 .299 .648 r
F P
0 g
s
.30696 .17895 m .3001 .15677 L .31215 .17794 L .366 .299 .648 r
F
.30865 .17862 m .31271 .18132 L p .31251 .17787 L .289 .763 .934 r
F P
0 g
s
.32359 .22558 m .33062 .23358 L p .32298 .22525 L .753 .236 0 r
F P
0 g
s
.32618 .1353 m .31969 .14754 L .30474 .1433 L p .863 .934 .868 r
F P
0 g
s
.30474 .1433 m .31124 .13099 L .32618 .1353 L p .863 .934 .868 r
F P
0 g
s
.30474 .1433 m .31124 .13099 L p .31707 .17698 L .366 .299 .648 r
F P
0 g
s
.3174 .17691 m .31251 .17787 L .32359 .18267 L .289 .763 .934 r
F
.35102 .3687 m .32359 .36617 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32359 .36617 m .31271 .36517 L p .32359 .23457 L .87 .71 .681 r
F P
0 g
s
.32453 .2358 m .31569 .22981 L .33062 .23358 L p .539 0 0 r
F P
0 g
s
.32453 .2358 m .31215 .17794 L .31707 .17698 L .366 .299 .648 r
F
.31215 .17794 m .30474 .1433 L .31707 .17698 L F
.33233 .18098 m .3174 .17691 L .32359 .18267 L .289 .763 .934 r
F
.33233 .18098 m .32727 .17499 L .3174 .17691 L F
.33425 .12476 m .32618 .1353 L .31124 .13099 L p .793 .945 .923 r
F P
0 g
s
.31124 .13099 m .31933 .12037 L .33425 .12476 L p .793 .945 .923 r
F P
0 g
s
.31124 .13099 m .31933 .12037 L p .32184 .17605 L .366 .299 .648 r
F P
0 g
s
.32453 .2358 m .31707 .17698 L .32184 .17605 L .366 .299 .648 r
F
.31707 .17698 m .31124 .13099 L .32184 .17605 L F
.35116 .17734 m .36433 .1074 L .35638 .17633 L .369 .301 .649 r
F
.35374 .11048 m .36433 .1074 L p .33945 .23954 L F P
0 g
s
.34357 .11636 m .35374 .11048 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.34357 .11636 m .33425 .12476 L .31933 .12037 L p .697 .936 .964 r
F P
0 g
s
.31933 .12037 m .32866 .11191 L .34357 .11636 L p .697 .936 .964 r
F P
0 g
s
.31933 .12037 m .32866 .11191 L p .32655 .17513 L .366 .299 .648 r
F P
0 g
s
.33945 .23954 m .32359 .20159 L .32359 .18845 L .369 .301 .649 r
F
.33945 .23954 m .32359 .2103 L .32359 .20159 L F
.32453 .2358 m .32184 .17605 L .32655 .17513 L .366 .299 .648 r
F
.32184 .17605 m .31933 .12037 L .32655 .17513 L F
.34111 .17928 m .33316 .17384 L .33233 .18098 L .289 .763 .934 r
F
.33316 .17384 m .32727 .17499 L .33233 .18098 L F
.34111 .17928 m .34862 .17082 L .33316 .17384 L F
.35374 .11048 m .34357 .11636 L .32866 .11191 L p .564 .897 .983 r
F P
0 g
s
.36433 .1074 m .35374 .11048 L .33885 .10599 L p .376 .81 .963 r
F P
0 g
s
.32866 .11191 m .33885 .10599 L .35374 .11048 L p .564 .897 .983 r
F P
0 g
s
.33885 .10599 m .34946 .10288 L .36433 .1074 L p .376 .81 .963 r
F P
0 g
s
.33885 .10599 m .34946 .10288 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.32866 .11191 m .33885 .10599 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.33316 .17384 m .3169 .1627 L .32727 .17499 L .289 .763 .934 r
F
.39402 .11589 m .40174 .12429 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.38493 .11014 m .39402 .11589 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.37489 .10728 m .38493 .11014 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39752 .16484 m .38651 .16342 L p .3536 .17687 L .289 .763 .934 r
F P
0 g
s
.3792 .11138 m .38651 .11936 L p .36033 .16853 L .366 .299 .648 r
F P
0 g
s
.3535 .16987 m .3792 .11138 L .36033 .16853 L .366 .299 .648 r
F
.3536 .17687 m .38651 .16342 L .35568 .16944 L .289 .763 .934 r
F
.38409 .17097 m .39752 .16484 L .3536 .17687 L F
.32453 .2358 m .38651 .11936 L .38651 .1206 L .366 .299 .648 r
F
.39752 .16484 m .38651 .16342 L p .38651 .18002 L .875 .714 .68 r
F P
0 g
s
.39692 .14311 m .39871 .15693 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.39293 .13055 m .39692 .14311 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38693 .11982 m .39293 .13055 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38651 .16342 m .35839 .1598 L p .35568 .16944 L .289 .763 .934 r
F P
0 g
s
.3536 .17687 m .35568 .16944 L .34111 .17928 L .289 .763 .934 r
F
.37489 .10728 m .36433 .1074 L .34946 .10288 L p .122 .65 .875 r
F P
0 g
s
.38493 .11014 m .37489 .10728 L .36003 .10274 L p 0 .402 .691 r
F P
0 g
s
.34946 .10288 m .36003 .10274 L .37489 .10728 L p .122 .65 .875 r
F P
0 g
s
.36003 .10274 m .37009 .10561 L .38493 .11014 L p 0 .402 .691 r
F P
0 g
s
.37009 .10561 m .3792 .11138 L p .3535 .16987 L .366 .299 .648 r
F P
0 g
s
.34717 .1711 m .37009 .10561 L .3535 .16987 L .366 .299 .648 r
F
.35568 .16944 m .35839 .1598 L .34862 .17082 L .289 .763 .934 r
F
.35568 .16944 m .34862 .17082 L .34111 .17928 L F
.32453 .2358 m .34717 .1711 L .3535 .16987 L .366 .299 .648 r
F
.32453 .2358 m .3535 .16987 L .36033 .16853 L F
.38651 .11936 m .38693 .11982 L p .38651 .1206 L F P
0 g
s
.32453 .2358 m .38651 .20179 L .38381 .212 L .366 .299 .648 r
F
.35839 .21722 m .35839 .21876 L p .36024 .21621 L .875 .714 .68 r
F P
0 g
s
.38651 .18002 m .38651 .20705 L .38876 .20611 L .875 .714 .68 r
F
.39547 .18581 m .39059 .19955 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.40132 .302 m .39868 .20661 L .39752 .35291 L .971 .793 .367 r
F
.39752 .16484 m .39752 .20294 L p .39868 .20661 L F P
0 g
s
.39752 .20294 m .39752 .35291 L p .39868 .20661 L .971 .793 .367 r
F P
0 g
s
.40132 .16764 m .39752 .16484 L p .40132 .302 L .971 .793 .367 r
F P
0 g
s
.39547 .18581 m .3937 .19079 L p .40539 .20357 L .917 .917 .801 r
F P
0 g
s
.3937 .19079 m .39059 .19955 L .39701 .2013 L p .917 .917 .801 r
F P
0 g
s
.39701 .2013 m .40539 .20357 L p .3937 .19079 L .917 .917 .801 r
F P
0 g
s
.39822 .17138 m .39547 .18581 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.39871 .15693 m .39822 .17138 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38651 .18002 m .35839 .21722 L .36024 .21621 L .875 .714 .68 r
F
.35839 .1598 m .35839 .21722 L p .38651 .18002 L F P
0 g
s
.38651 .16342 m .35839 .1598 L p .38651 .18002 L .875 .714 .68 r
F P
0 g
s
.36003 .10274 m .37009 .10561 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.34946 .10288 m .36003 .10274 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.35839 .1598 m .3169 .1627 L p .33316 .17384 L .289 .763 .934 r
F P
0 g
s
.34862 .17082 m .35839 .1598 L .33316 .17384 L .289 .763 .934 r
F
.3174 .17691 m .29824 .17169 L .31251 .17787 L F
.29824 .17169 m .30865 .17862 L p .31251 .17787 L F P
0 g
s
.32453 .2358 m .30696 .17895 L .31215 .17794 L .366 .299 .648 r
F
.3169 .1627 m .29824 .17169 L p .3174 .17691 L .289 .763 .934 r
F P
0 g
s
.32727 .17499 m .3169 .1627 L .3174 .17691 L .289 .763 .934 r
F
.30865 .18444 m .30454 .17942 L .30696 .17895 L .366 .299 .648 r
F
.32453 .2358 m .30865 .19765 L .30865 .18444 L F
.30865 .19765 m .29749 .17083 L .30865 .18444 L F
.30865 .20744 m .31271 .21761 L .31188 .21852 L .981 .801 .395 r
F
.29872 .19836 m .29702 .18489 L p .30865 .20641 L .366 .299 .648 r
F P
0 g
s
.30865 .21277 m .29872 .19836 L .30865 .20641 L .366 .299 .648 r
F
.29824 .17169 m .30865 .20474 L .30865 .20744 L .981 .801 .395 r
F
.30865 .20474 m .31271 .21761 L .30865 .20744 L F
.29824 .17169 m .30865 .17862 L p .30865 .20474 L F P
0 g
s
.32453 .2358 m .30865 .21277 L .30865 .20641 L .366 .299 .648 r
F
.29824 .17169 m .30865 .20744 L .30251 .22882 L .981 .801 .395 r
F
.30865 .20744 m .30865 .22207 L .30251 .22882 L F
.32453 .2358 m .30865 .20641 L .30865 .19765 L .366 .299 .648 r
F
.32453 .2358 m .31569 .22981 L .30865 .22178 L p F P
0 g
s
.32453 .2358 m .30865 .22178 L .30865 .22167 L .366 .299 .648 r
F
.32453 .2358 m .30865 .22167 L .30865 .21768 L F
.30865 .22207 m .30865 .22432 L .30251 .22882 L .981 .801 .395 r
F
.32453 .2358 m .30865 .21768 L .30865 .21277 L .366 .299 .648 r
F
.38651 .20705 m .38381 .212 L p .38651 .20179 L F P
0 g
s
.38651 .18002 m .35839 .21876 L .38651 .20705 L .875 .714 .68 r
F
.39059 .19955 m .38651 .20705 L p .38651 .20179 L .366 .299 .648 r
F P
0 g
s
.39059 .19955 m .38651 .20705 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.38651 .20705 m .38381 .212 L p .39295 .20437 L .863 .944 .869 r
F P
0 g
s
.35977 .24299 m .34931 .24273 L .33945 .23954 L p .369 .301 .649 r
F P
0 g
s
.3704 .24028 m .35977 .24299 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.38072 .2347 m .3704 .24028 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.39027 .22647 m .38072 .2347 L p .33945 .23954 L .369 .301 .649 r
F P
0 g
s
.34931 .24273 m .35977 .24299 L .34489 .23924 L p .067 .616 .835 r
F P
0 g
s
.35977 .24299 m .3704 .24028 L .35554 .23651 L p .337 .794 .943 r
F P
0 g
s
.35554 .23651 m .34489 .23924 L .35977 .24299 L p .337 .794 .943 r
F P
0 g
s
.33062 .23358 m .33945 .23954 L .32453 .2358 L p .539 0 0 r
F P
0 g
s
.36587 .23089 m .35554 .23651 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.37544 .2226 m .36587 .23089 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.38381 .212 m .37544 .2226 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.3704 .24028 m .38072 .2347 L .36587 .23089 L p .539 .895 .976 r
F P
0 g
s
.36587 .23089 m .35554 .23651 L .3704 .24028 L p .539 .895 .976 r
F P
0 g
s
.38072 .2347 m .39027 .22647 L .37544 .2226 L p .685 .941 .963 r
F P
0 g
s
.37544 .2226 m .36587 .23089 L .38072 .2347 L p .685 .941 .963 r
F P
0 g
s
.38381 .212 m .37544 .2226 L .39027 .22647 L p .788 .954 .924 r
F P
0 g
s
.35839 .21876 m .35839 .34916 L p .38876 .20611 L .875 .714 .68 r
F P
0 g
s
.35839 .34916 m .39752 .35291 L .39752 .20246 L p .875 .714 .68 r
F P
0 g
s
.38876 .20611 m .35839 .34916 L .39752 .20246 L .875 .714 .68 r
F
.39059 .19955 m .39295 .20437 L .39449 .20373 L .863 .944 .869 r
F
.40132 .21102 m .40539 .20357 L .39701 .2013 L p F P
0 g
s
.41171 .14746 m .4135 .1612 L p .40132 .17409 L .369 .301 .649 r
F P
0 g
s
.40132 .1607 m .41171 .14746 L .40132 .17409 L .369 .301 .649 r
F
.4135 .1612 m .41336 .16532 L p .40877 .1662 L F P
0 g
s
.41336 .16532 m .41301 .17557 L p .40877 .1662 L .369 .301 .649 r
F P
0 g
s
.31271 .36517 m .29824 .358 L .29824 .17169 L p .981 .801 .395 r
F P
0 g
s
.29824 .358 m .3169 .35131 L .3169 .1627 L p 0 0 .481 r
F P
0 g
s
.3169 .1627 m .29824 .17169 L .29824 .358 L p 0 0 .481 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.48317 .38268 m .23459 .36923 L .45861 .38438 L .222 .729 .893 r
F
.48317 .38268 m .45861 .38438 L .54706 .39037 L F
.45263 .38705 m .46245 .39084 L .526 .39397 L F
.45263 .38705 m .22102 .37893 L .46245 .39084 L F
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .63709 .39101 L .222 .729 .893 r
F P
0 g
s
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.53075 .37821 m .5 .37606 L .5 .77447 L p .837 .684 .692 r
F P
0 g
s
.29824 .358 m .31271 .36517 L .35102 .3687 L p .224 .73 .894 r
F P
0 g
s
.3169 .35131 m .29824 .358 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.35839 .34916 m .3169 .35131 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.39752 .35291 m .35839 .34916 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.41081 .3602 m .39752 .35291 L p .35102 .3687 L .224 .73 .894 r
F P
0 g
s
.35102 .3687 m .39131 .36668 L .41081 .3602 L p .224 .73 .894 r
F P
0 g
s
.2609 .36006 m .2492 .36414 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .2492 .36414 L .63709 .39101 L .222 .729 .893 r
F
.53032 .39362 m .53075 .39346 L .53075 .40633 L 0 0 .46 r
F
.53075 .39346 m .54306 .38872 L .53075 .40633 L F
.54306 .38872 m .54306 .77622 L p .53075 .40633 L F P
0 g
s
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.23459 .36923 m .22102 .37893 L p .43098 .3863 L .222 .729 .893 r
F P
0 g
s
.45861 .38438 m .23459 .36923 L .43098 .3863 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.56837 .39111 m .54706 .39037 L .55161 .39224 L .222 .729 .893 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.22014 .38872 m .2313 .39814 L p .43408 .39814 L .222 .729 .893 r
F P
0 g
s
.43789 .39657 m .22014 .38872 L .43408 .39814 L .222 .729 .893 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.5907 .95121 m .5498 .95093 L .54711 .95101 L .023 0 0 r
F
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53288 .97414 m .53288 .77394 L p .47006 .97414 L F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.33945 .23954 m .34931 .24273 L .33441 .23899 L p .246 0 0 r
F P
0 g
s
.33441 .23899 m .32453 .2358 L .33945 .23954 L p .246 0 0 r
F P
0 g
s
.34489 .23924 m .33441 .23899 L .34931 .24273 L p .067 .616 .835 r
F P
0 g
s
.34489 .23924 m .33441 .23899 L .32453 .2358 L p .366 .299 .648 r
F P
0 g
s
.35554 .23651 m .34489 .23924 L p .32453 .2358 L .366 .299 .648 r
F P
0 g
s
.3169 .35131 m .35839 .34916 L .35839 .1598 L p .59 .482 .699 r
F P
0 g
s
.35839 .1598 m .3169 .1627 L .3169 .35131 L p .59 .482 .699 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.59802 .18889 m .59816 .18489 L p .61053 .20159 L .393 .321 .656 r
F P
0 g
s
.59816 .18489 m .59852 .17491 L p .60265 .18408 L .393 .321 .656 r
F P
0 g
s
.61053 .20159 m .59816 .18489 L .60265 .18408 L .393 .321 .656 r
F
.59852 .17491 m .59802 .18889 L .58466 .18489 L p .979 .818 .612 r
F P
0 g
s
.59852 .17491 m .60132 .16093 L p .6087 .18299 L .393 .321 .656 r
F P
0 g
s
.60132 .16093 m .59852 .17491 L .58517 .17083 L p .958 .881 .715 r
F P
0 g
s
.61053 .23457 m .61424 .22767 L .63659 .3687 L .877 .716 .679 r
F
.63659 .18607 m .63659 .24023 L p .61424 .22767 L F P
0 g
s
.63659 .24023 m .63659 .3687 L p .61424 .22767 L .877 .716 .679 r
F P
0 g
s
.61009 .22512 m .61053 .22558 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.60132 .16093 m .60632 .14754 L p .61053 .16571 L .393 .321 .656 r
F P
0 g
s
.61053 .18267 m .63659 .18607 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.61053 .18267 m .63659 .18607 L p .61994 .18098 L .289 .763 .934 r
F P
0 g
s
.62761 .23954 m .61053 .18845 L .61053 .16571 L .393 .321 .656 r
F
.61053 .18845 m .60132 .16093 L .61053 .16571 L F
.61053 .18845 m .6061 .18346 L .6087 .18299 L F
.6061 .18346 m .59852 .17491 L .6087 .18299 L F
.61053 .20159 m .59852 .17491 L .61053 .18845 L F
.61053 .2103 m .59802 .18889 L .61053 .20159 L F
.59984 .20229 m .59802 .18889 L p .62761 .23954 L F P
0 g
s
.60392 .21454 m .59984 .20229 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.61009 .22512 m .60392 .21454 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.60392 .21454 m .61009 .22512 L .60931 .2249 L p .87 .427 .113 r
F P
0 g
s
.60857 .22448 m .61053 .22587 L .61053 .23457 L .877 .716 .679 r
F
.60853 .22427 m .60931 .2249 L .60857 .22448 L F
.60931 .2249 m .61053 .22587 L .60857 .22448 L F
.60045 .21783 m .60392 .21454 L .60931 .2249 L .87 .427 .113 r
F
.60018 .36517 m .60018 .22135 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.59984 .20229 m .60313 .21217 L p .59202 .21109 L .948 .603 .32 r
F P
0 g
s
.60313 .21217 m .60392 .21454 L .6025 .21413 L p .948 .603 .32 r
F P
0 g
s
.6025 .21413 m .59202 .21109 L p .60313 .21217 L .948 .603 .32 r
F P
0 g
s
.59123 .2101 m .59984 .20229 L .59202 .21109 L .948 .603 .32 r
F
.60018 .21761 m .60018 .22135 L p .59957 .21852 L .947 .773 .313 r
F P
0 g
s
.60018 .22135 m .60018 .36517 L p .5972 .31096 L .947 .773 .313 r
F P
0 g
s
.59344 .24233 m .5972 .23061 L .5972 .31096 L .947 .773 .313 r
F
.5972 .23061 m .60018 .22135 L .5972 .31096 L F
.60018 .22135 m .60018 .21761 L p .61047 .2343 L .877 .716 .679 r
F P
0 g
s
.59202 .21109 m .6025 .21413 L p .5999 .21739 L .87 .427 .113 r
F P
0 g
s
.60853 .22427 m .61047 .2343 L .60018 .21761 L .877 .716 .679 r
F
.6025 .21413 m .60392 .21454 L p .59932 .2189 L .87 .427 .113 r
F P
0 g
s
.59677 .22131 m .6025 .21413 L .59932 .2189 L .87 .427 .113 r
F
.60018 .21761 m .60018 .18132 L p .60853 .22427 L .877 .716 .679 r
F P
0 g
s
.59677 .22131 m .59058 .21068 L .59202 .21109 L p .87 .427 .113 r
F P
0 g
s
.59677 .22131 m .59202 .21109 L .5999 .21739 L .87 .427 .113 r
F
.5972 .22432 m .60018 .22135 L .5972 .23061 L .947 .773 .313 r
F
.59677 .22131 m .59058 .21068 L p .5972 .21768 L .391 .319 .656 r
F P
0 g
s
.5972 .22178 m .59677 .22131 L .59755 .22154 L p .724 .193 0 r
F P
0 g
s
.59755 .22154 m .59677 .22131 L p .59932 .2189 L .87 .427 .113 r
F P
0 g
s
.5972 .22167 m .59677 .22131 L .5972 .21768 L .391 .319 .656 r
F
.59802 .18889 m .59984 .20229 L .5865 .19836 L p .979 .729 .483 r
F P
0 g
s
.5865 .19836 m .58466 .18489 L .59802 .18889 L p .979 .729 .483 r
F P
0 g
s
.58466 .18489 m .58517 .17083 L .59852 .17491 L p .979 .818 .612 r
F P
0 g
s
.59058 .21068 m .5865 .19836 L .59984 .20229 L p .948 .603 .32 r
F P
0 g
s
.58466 .18489 m .58517 .17083 L p .5972 .19765 L .391 .319 .656 r
F P
0 g
s
.59248 .22497 m .59755 .22154 L .59269 .22882 L .947 .773 .313 r
F
.59957 .21852 m .60018 .22135 L .5972 .22432 L F
.5972 .22207 m .5972 .22432 L .59269 .22882 L F
.59957 .21852 m .5972 .22432 L .5972 .22207 L F
.59202 .21109 m .59058 .21068 L p .59123 .2101 L .948 .603 .32 r
F P
0 g
s
.59058 .21068 m .5865 .19836 L p .5972 .21277 L .391 .319 .656 r
F P
0 g
s
.6076 .22676 m .60549 .22391 L .60931 .2249 L .724 .193 0 r
F
.61047 .2343 m .61053 .23457 L .60018 .22135 L .877 .716 .679 r
F
.60479 .22981 m .60549 .22391 L .6076 .22676 L .724 .193 0 r
F
.60479 .22981 m .5972 .22178 L p .60549 .22391 L F P
0 g
s
.5972 .21935 m .59957 .21852 L .59755 .22154 L .947 .773 .313 r
F
.5972 .20744 m .59957 .21852 L .5972 .21935 L F
.59755 .22154 m .60931 .2249 L p .5972 .22178 L .724 .193 0 r
F P
0 g
s
.60931 .2249 m .59755 .22154 L p .60045 .21783 L .87 .427 .113 r
F P
0 g
s
.59932 .2189 m .60045 .21783 L .59755 .22154 L .87 .427 .113 r
F
.5972 .20641 m .58466 .18489 L .5972 .19765 L .391 .319 .656 r
F
.60018 .18132 m .60018 .21761 L p .5972 .20474 L .947 .773 .313 r
F P
0 g
s
.5972 .17862 m .60018 .18132 L p .5972 .20474 L .947 .773 .313 r
F P
0 g
s
.58517 .17083 m .58798 .15677 L .60132 .16093 L p .958 .881 .715 r
F P
0 g
s
.58517 .17083 m .58798 .15677 L p .59537 .17895 L .391 .319 .656 r
F P
0 g
s
.60632 .14754 m .61331 .1353 L p .61959 .18104 L .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .61429 .18199 L .61959 .18104 L .393 .321 .656 r
F
.61429 .18199 m .60632 .14754 L .61959 .18104 L F
.63659 .18607 m .6294 .17928 L .61994 .18098 L .289 .763 .934 r
F
.61331 .1353 m .62201 .12476 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.63659 .18607 m .64285 .17687 L .6294 .17928 L .289 .763 .934 r
F
.62201 .12476 m .63205 .11636 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67797 .36668 m .63659 .3687 L .63659 .18607 L p .597 .488 .7 r
F P
0 g
s
.63659 .18607 m .67797 .18336 L .67797 .36668 L p .597 .488 .7 r
F P
0 g
s
.66579 .10728 m .67661 .11014 L p .65196 .17523 L .393 .321 .656 r
F P
0 g
s
.63659 .18607 m .6757 .17097 L .64285 .17687 L .289 .763 .934 r
F
.70095 .17465 m .69426 .16764 L p .63659 .18607 L F P
0 g
s
.63659 .18607 m .69426 .16764 L .6757 .17097 L .289 .763 .934 r
F
.63659 .18607 m .67797 .18336 L .70095 .17465 L p F P
0 g
s
.70095 .3602 m .67797 .36668 L .67797 .18336 L p .083 .068 .54 r
F P
0 g
s
.67797 .18336 m .70095 .17465 L .70095 .3602 L p .083 .068 .54 r
F P
0 g
s
.70095 .17465 m .69426 .16764 L p .69426 .21102 L .928 .758 .278 r
F P
0 g
s
.69835 .22411 m .69426 .21102 L .69426 .302 L .928 .758 .278 r
F
.70095 .17465 m .69426 .21102 L .69835 .22411 L F
.69865 .20357 m .69136 .21594 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.70095 .3602 m .70095 .17465 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.7039 .18991 m .69865 .20357 L p .69426 .20579 L .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .69426 .19618 L .69426 .20579 L .393 .321 .656 r
F
.69426 .19618 m .7039 .18991 L .69426 .20579 L F
.69159 .35291 m .69426 .35499 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.69426 .35499 m .70095 .3602 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.70686 .17557 m .7039 .18991 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.69136 .21594 m .69426 .21102 L p .68871 .20373 L .862 .958 .868 r
F P
0 g
s
.68725 .20437 m .69136 .21594 L .68871 .20373 L .862 .958 .868 r
F
.62761 .23954 m .69426 .1607 L .69426 .17409 L .393 .321 .656 r
F
.70117 .13497 m .70546 .14746 L p .62761 .23954 L F P
0 g
s
.69471 .12429 m .70117 .13497 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.69426 .16764 m .69159 .16484 L p .6757 .17097 L .289 .763 .934 r
F P
0 g
s
.62761 .23954 m .70229 .1662 L .70686 .17557 L .393 .321 .656 r
F
.69159 .20246 m .69159 .16484 L p .68327 .20611 L .882 .72 .677 r
F P
0 g
s
.69122 .2013 m .68554 .19955 L p .69426 .21102 L .862 .958 .868 r
F P
0 g
s
.69136 .21594 m .68236 .22647 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.68236 .22647 m .69136 .21594 L .67823 .212 L p .781 .963 .923 r
F P
0 g
s
.67823 .212 m .69136 .21594 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.69159 .16484 m .68114 .18002 L .68327 .20611 L .882 .72 .677 r
F
.62761 .23954 m .64585 .17633 L .65196 .17523 L .393 .321 .656 r
F
.62761 .23954 m .61053 .20159 L .61053 .18845 L F
.62761 .23954 m .61053 .2103 L .61053 .20159 L F
.62761 .23954 m .6181 .23358 L .61009 .22512 L p F P
0 g
s
.6181 .23358 m .62761 .23954 L .61432 .2358 L p .497 0 0 r
F P
0 g
s
.6864 .11589 m .69471 .12429 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67661 .11014 m .6864 .11589 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.65442 .1074 m .66579 .10728 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.64301 .11048 m .65442 .1074 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.63205 .11636 m .64301 .11048 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.61432 .2358 m .68114 .20179 L .67823 .212 L .391 .319 .656 r
F
.68114 .20705 m .67823 .212 L p .68114 .20179 L F P
0 g
s
.68114 .18002 m .68114 .20705 L .68327 .20611 L .882 .72 .677 r
F
.6908 .18581 m .68554 .19955 L p .68114 .20179 L .391 .319 .656 r
F P
0 g
s
.60018 .18132 m .61053 .18267 L p .61053 .22587 L .877 .716 .679 r
F P
0 g
s
.60931 .2249 m .61009 .22512 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.60018 .18132 m .61053 .22587 L .60853 .22427 L .877 .716 .679 r
F
.6181 .23358 m .60479 .22981 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.61053 .22558 m .6181 .23358 L p .60994 .22525 L .724 .193 0 r
F P
0 g
s
.61432 .2358 m .60479 .22981 L .6181 .23358 L p .497 0 0 r
F P
0 g
s
.61432 .2358 m .68114 .19212 L .68114 .20179 L .391 .319 .656 r
F
.68114 .19212 m .6908 .18581 L .68114 .20179 L F
.64585 .17633 m .66579 .10728 L .65196 .17523 L .393 .321 .656 r
F
.69159 .16484 m .68114 .16342 L p .64285 .17687 L .289 .763 .934 r
F P
0 g
s
.64285 .17687 m .68114 .16342 L .64791 .16944 L .289 .763 .934 r
F
.6757 .17097 m .69159 .16484 L .64285 .17687 L F
.69159 .16484 m .68114 .16342 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.69236 .14311 m .6943 .15693 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.68806 .13055 m .69236 .14311 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.68159 .11982 m .68806 .13055 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.67326 .11138 m .68159 .11982 L p .65339 .16845 L .391 .319 .656 r
F P
0 g
s
.64556 .16987 m .67326 .11138 L .65339 .16845 L .391 .319 .656 r
F
.64285 .17687 m .64791 .16944 L .6294 .17928 L .289 .763 .934 r
F
.66579 .10728 m .65442 .1074 L .6412 .10288 L p .136 .657 .884 r
F P
0 g
s
.67661 .11014 m .66579 .10728 L .65259 .10274 L p 0 .43 .725 r
F P
0 g
s
.6412 .10288 m .65259 .10274 L .66579 .10728 L p .136 .657 .884 r
F P
0 g
s
.65259 .10274 m .66344 .10561 L .67661 .11014 L p 0 .43 .725 r
F P
0 g
s
.66344 .10561 m .67326 .11138 L p .64556 .16987 L .391 .319 .656 r
F P
0 g
s
.63873 .1711 m .66344 .10561 L .64556 .16987 L .391 .319 .656 r
F
.64791 .16944 m .65446 .1598 L .64029 .17082 L .289 .763 .934 r
F
.64791 .16944 m .64029 .17082 L .6294 .17928 L F
.6294 .17928 m .64029 .17082 L .62363 .17384 L F
.61432 .2358 m .63873 .1711 L .64556 .16987 L .391 .319 .656 r
F
.61432 .2358 m .64556 .16987 L .65339 .16845 L F
.61994 .18098 m .61728 .17499 L .60664 .17691 L .289 .763 .934 r
F
.61331 .1353 m .60632 .14754 L .59299 .1433 L p .863 .948 .869 r
F P
0 g
s
.62201 .12476 m .61331 .1353 L .6 .13099 L p .788 .955 .924 r
F P
0 g
s
.59299 .1433 m .6 .13099 L .61331 .1353 L p .863 .948 .869 r
F P
0 g
s
.63205 .11636 m .62201 .12476 L .60871 .12037 L p .688 .94 .963 r
F P
0 g
s
.6 .13099 m .60871 .12037 L .62201 .12476 L p .788 .955 .924 r
F P
0 g
s
.60871 .12037 m .61877 .11191 L .63205 .11636 L p .688 .94 .963 r
F P
0 g
s
.60871 .12037 m .61877 .11191 L p .6165 .17513 L .391 .319 .656 r
F P
0 g
s
.61994 .18098 m .60664 .17691 L .61053 .18267 L .289 .763 .934 r
F
.60632 .14754 m .60132 .16093 L .58798 .15677 L p .919 .923 .8 r
F P
0 g
s
.58798 .15677 m .59299 .1433 L .60632 .14754 L p .919 .923 .8 r
F P
0 g
s
.58798 .15677 m .59299 .1433 L p .60098 .17794 L .391 .319 .656 r
F P
0 g
s
.59537 .17895 m .58798 .15677 L .60098 .17794 L .391 .319 .656 r
F
.60664 .17691 m .60136 .17787 L .61053 .18267 L .289 .763 .934 r
F
.59299 .1433 m .6 .13099 L p .60628 .17698 L .391 .319 .656 r
F P
0 g
s
.60018 .18132 m .61053 .18267 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.5972 .17862 m .60018 .18132 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.61432 .2358 m .60098 .17794 L .60628 .17698 L .391 .319 .656 r
F
.60098 .17794 m .59299 .1433 L .60628 .17698 L F
.58956 .17169 m .5972 .17862 L p .60136 .17787 L .289 .763 .934 r
F P
0 g
s
.6 .13099 m .60871 .12037 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.60664 .17691 m .58956 .17169 L .60136 .17787 L .289 .763 .934 r
F
.61432 .2358 m .59537 .17895 L .60098 .17794 L .391 .319 .656 r
F
.61432 .2358 m .61142 .17605 L .6165 .17513 L F
.61142 .17605 m .60871 .12037 L .6165 .17513 L F
.6294 .17928 m .62363 .17384 L .61994 .18098 L .289 .763 .934 r
F
.62363 .17384 m .61728 .17499 L .61994 .18098 L F
.64301 .11048 m .63205 .11636 L .61877 .11191 L p .553 .896 .98 r
F P
0 g
s
.65442 .1074 m .64301 .11048 L .62976 .10599 L p .373 .808 .961 r
F P
0 g
s
.61877 .11191 m .62976 .10599 L .64301 .11048 L p .553 .896 .98 r
F P
0 g
s
.62976 .10599 m .6412 .10288 L .65442 .1074 L p .373 .808 .961 r
F P
0 g
s
.62976 .10599 m .6412 .10288 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.61877 .11191 m .62976 .10599 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.62363 .17384 m .61182 .1627 L .61728 .17499 L .289 .763 .934 r
F
.65259 .10274 m .66344 .10561 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.6412 .10288 m .65259 .10274 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .61182 .1627 L p .62363 .17384 L .289 .763 .934 r
F P
0 g
s
.64029 .17082 m .65446 .1598 L .62363 .17384 L .289 .763 .934 r
F
.68114 .16342 m .65446 .1598 L p .64791 .16944 L F P
0 g
s
.69426 .302 m .6924 .20661 L .69159 .35291 L .928 .758 .278 r
F
.69159 .16484 m .69159 .20294 L p .6924 .20661 L F P
0 g
s
.69159 .20294 m .69159 .35291 L p .6924 .20661 L .928 .758 .278 r
F P
0 g
s
.69426 .16764 m .69159 .16484 L p .69426 .302 L .928 .758 .278 r
F P
0 g
s
.6908 .18581 m .68889 .19079 L p .69865 .20357 L .922 .933 .797 r
F P
0 g
s
.68889 .19079 m .68554 .19955 L .69122 .2013 L p .922 .933 .797 r
F P
0 g
s
.69122 .2013 m .69865 .20357 L p .68889 .19079 L .922 .933 .797 r
F P
0 g
s
.61432 .2358 m .68919 .16197 L .69377 .17138 L .391 .319 .656 r
F
.6943 .15693 m .69414 .16107 L p .68919 .16197 L F P
0 g
s
.69414 .16107 m .69377 .17138 L p .68919 .16197 L .391 .319 .656 r
F P
0 g
s
.69377 .17138 m .6908 .18581 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .65446 .21876 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.68114 .16342 m .65446 .1598 L p .68114 .18002 L .882 .72 .677 r
F P
0 g
s
.68114 .18002 m .65446 .21876 L .68114 .20705 L .882 .72 .677 r
F
.68554 .19955 m .68114 .20705 L p .68114 .20179 L .391 .319 .656 r
F P
0 g
s
.68554 .19955 m .68114 .20705 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.68114 .20705 m .67823 .212 L p .68725 .20437 L .862 .958 .868 r
F P
0 g
s
.66095 .24028 m .6495 .24299 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.67207 .2347 m .66095 .24028 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.68236 .22647 m .67207 .2347 L p .62761 .23954 L .393 .321 .656 r
F P
0 g
s
.6495 .24299 m .66095 .24028 L .64775 .23651 L p .332 .793 .941 r
F P
0 g
s
.65889 .23089 m .64775 .23651 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.66921 .2226 m .65889 .23089 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.67823 .212 m .66921 .2226 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.66095 .24028 m .67207 .2347 L .65889 .23089 L p .527 .893 .972 r
F P
0 g
s
.65889 .23089 m .64775 .23651 L .66095 .24028 L p .527 .893 .972 r
F P
0 g
s
.67207 .2347 m .68236 .22647 L .66921 .2226 L p .673 .945 .961 r
F P
0 g
s
.66921 .2226 m .65889 .23089 L .67207 .2347 L p .673 .945 .961 r
F P
0 g
s
.67823 .212 m .66921 .2226 L .68236 .22647 L p .781 .963 .923 r
F P
0 g
s
.65446 .21876 m .65446 .34916 L p .68327 .20611 L .882 .72 .677 r
F P
0 g
s
.65446 .34916 m .69159 .35291 L .69159 .20246 L p .882 .72 .677 r
F P
0 g
s
.68327 .20611 m .65446 .34916 L .69159 .20246 L .882 .72 .677 r
F
.68554 .19955 m .68725 .20437 L .68871 .20373 L .862 .958 .868 r
F
.69426 .21102 m .69865 .20357 L .69122 .2013 L p F P
0 g
s
.70546 .14746 m .70738 .1612 L p .69426 .17409 L .393 .321 .656 r
F P
0 g
s
.69426 .1607 m .70546 .14746 L .69426 .17409 L .393 .321 .656 r
F
.70738 .1612 m .70723 .16532 L p .70229 .1662 L F P
0 g
s
.70723 .16532 m .70686 .17557 L p .70229 .1662 L .393 .321 .656 r
F P
0 g
s
.61182 .1627 m .58956 .17169 L p .60664 .17691 L .289 .763 .934 r
F P
0 g
s
.61728 .17499 m .61182 .1627 L .60664 .17691 L .289 .763 .934 r
F
.5972 .18444 m .59277 .17942 L .59537 .17895 L .391 .319 .656 r
F
.59277 .17942 m .58517 .17083 L .59537 .17895 L F
.60479 .22981 m .60931 .2249 L .60994 .22525 L .724 .193 0 r
F
.61432 .2358 m .5972 .19765 L .5972 .18444 L .391 .319 .656 r
F
.5972 .19765 m .58517 .17083 L .5972 .18444 L F
.5865 .19836 m .58466 .18489 L p .5972 .20641 L F P
0 g
s
.5972 .21277 m .5865 .19836 L .5972 .20641 L .391 .319 .656 r
F
.5972 .21768 m .59058 .21068 L .5972 .21277 L F
.58956 .17169 m .5972 .21935 L .59248 .22497 L .947 .773 .313 r
F
.5972 .21935 m .59755 .22154 L .5972 .22178 L F
.5972 .22178 m .59677 .22131 L p .5972 .22167 L .391 .319 .656 r
F P
0 g
s
.5972 .21935 m .5972 .22178 L .59248 .22497 L .947 .773 .313 r
F
.58956 .17169 m .5972 .17862 L p .5972 .20474 L F P
0 g
s
.58956 .17169 m .60018 .21761 L .59957 .21852 L .947 .773 .313 r
F
.61432 .2358 m .5972 .21277 L .5972 .20641 L .391 .319 .656 r
F
.61432 .2358 m .5972 .21768 L .5972 .21277 L F
.61432 .2358 m .5972 .20641 L .5972 .19765 L F
.58956 .17169 m .5972 .20744 L .5972 .21935 L .947 .773 .313 r
F
.61432 .2358 m .60479 .22981 L .5972 .22178 L p .391 .319 .656 r
F P
0 g
s
.61432 .2358 m .5972 .22178 L .5972 .22167 L .391 .319 .656 r
F
.59269 .22882 m .5972 .22432 L .59344 .24233 L .947 .773 .313 r
F
.5972 .22432 m .5972 .23061 L .59344 .24233 L F
.61432 .2358 m .5972 .22167 L .5972 .21768 L .391 .319 .656 r
F
.63659 .3687 m .61053 .36617 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.61053 .36617 m .60018 .36517 L p .61053 .23457 L .877 .716 .679 r
F P
0 g
s
.60018 .36517 m .58956 .358 L .58956 .17169 L p .947 .773 .313 r
F P
0 g
s
.58956 .358 m .61182 .35131 L .61182 .1627 L p .052 .042 .525 r
F P
0 g
s
.61182 .1627 m .58956 .17169 L .58956 .358 L p .052 .042 .525 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.58956 .358 m .60018 .36517 L .63659 .3687 L p .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.61182 .35131 m .58956 .358 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.65446 .34916 m .61182 .35131 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.69159 .35291 m .65446 .34916 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.70095 .3602 m .69159 .35291 L p .63659 .3687 L .224 .73 .894 r
F P
0 g
s
.63659 .3687 m .67797 .36668 L .70095 .3602 L p .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6495 .24299 m .63823 .24273 L .62761 .23954 L p .393 .321 .656 r
F P
0 g
s
.62761 .23954 m .63823 .24273 L .62497 .23899 L p .211 0 0 r
F P
0 g
s
.63823 .24273 m .6495 .24299 L .63627 .23924 L p .081 .625 .846 r
F P
0 g
s
.62497 .23899 m .61432 .2358 L .62761 .23954 L p .211 0 0 r
F P
0 g
s
.63627 .23924 m .62497 .23899 L .63823 .24273 L p .081 .625 .846 r
F P
0 g
s
.64775 .23651 m .63627 .23924 L .6495 .24299 L p .332 .793 .941 r
F P
0 g
s
.64775 .23651 m .63627 .23924 L p .61432 .2358 L .391 .319 .656 r
F P
0 g
s
.61182 .35131 m .65446 .34916 L .65446 .1598 L p .593 .484 .699 r
F P
0 g
s
.63627 .23924 m .62497 .23899 L .61432 .2358 L p .391 .319 .656 r
F P
0 g
s
.65446 .1598 m .61182 .1627 L .61182 .35131 L p .593 .484 .699 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.401 1.29226 m .41389 1.27286 L .42691 1.29654 L p .208 .17 .593 r
F P
0 g
s
.42691 1.29654 m .41389 1.31592 L .401 1.29226 L p .208 .17 .593 r
F P
0 g
s
.5723 1.29226 m .58611 1.27286 L .60008 1.29654 L p .238 .195 .605 r
F P
0 g
s
.60008 1.29654 m .58611 1.31592 L .5723 1.29226 L p .238 .195 .605 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.71872 .79305 m .71787 .7784 L .71828 .77752 L p 0 0 .217 r
F P
0 g
s
.72043 .81454 m .75756 .78483 L .73646 .76961 L p .651 .305 .374 r
F P
0 g
s
.73646 .76961 m .71701 .75558 L p .71828 .77752 L .651 .305 .374 r
F P
0 g
s
.71828 .77752 m .71913 .79217 L .73646 .76961 L .651 .305 .374 r
F
.72977 .72344 m .74563 .71885 L .71828 .77752 L p .765 .976 .918 r
F P
0 g
s
.71828 .77752 m .71787 .7784 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.71872 .79305 m .71828 .77752 L .71912 .79195 L 0 0 .217 r
F
.71107 .75129 m .67982 .77583 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.71107 .75129 m .69041 .78023 L .71269 .77995 L .651 .305 .374 r
F
.69041 .78023 m .68068 .79387 L .70147 .78483 L F
.69041 .78023 m .70147 .78483 L .71269 .77995 L F
.71269 .77995 m .70201 .78659 L .70086 .78283 L p .835 .924 .892 r
F P
0 g
s
.71789 .77869 m .7127 .78014 L .71854 .79267 L .752 .386 .361 r
F
.71872 .79305 m .7187 .79276 L p .71854 .79267 L F P
0 g
s
.7187 .79276 m .71789 .77869 L p .71854 .79267 L .752 .386 .361 r
F P
0 g
s
.71789 .77869 m .71787 .7784 L .71269 .77995 L p .752 .386 .361 r
F P
0 g
s
.71324 .78972 m .71872 .79305 L p .71854 .79267 L .752 .386 .361 r
F P
0 g
s
.7127 .78014 m .71324 .78972 L .71854 .79267 L .752 .386 .361 r
F
.70489 .7848 m .70201 .78659 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71318 .78864 m .70489 .7848 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71269 .77995 m .70147 .78483 L .71324 .78972 L .651 .305 .374 r
F
.71269 .77995 m .70228 .78306 L p .7127 .78014 L .752 .386 .361 r
F P
0 g
s
.71269 .77995 m .7127 .78014 L .71789 .77869 L .752 .386 .361 r
F
.71787 .7784 m .71269 .77995 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.74563 .71885 m .74661 .7336 L .71872 .79305 L p 0 0 .217 r
F P
0 g
s
.71324 .78972 m .71872 .79305 L .71913 .79217 L p .388 .543 .888 r
F P
0 g
s
.71701 .75558 m .71107 .75129 L p .71699 .79128 L .651 .305 .374 r
F P
0 g
s
.71699 .79128 m .72043 .81454 L .71913 .79217 L .651 .305 .374 r
F
.71699 .79128 m .71913 .79217 L .71701 .75558 L F
.71828 .77752 m .74563 .71885 L p .71912 .79195 L 0 0 .217 r
F P
0 g
s
.71489 .81897 m .72043 .81454 L p .71107 .75129 L .651 .305 .374 r
F P
0 g
s
.71324 .78972 m .71913 .79217 L .71885 .791 L .388 .543 .888 r
F
.71504 .77849 m .71507 .7786 L p .71802 .77663 L .538 .22 .377 r
F P
0 g
s
.68386 .72713 m .70025 .717 L .71802 .77663 L p .835 .924 .892 r
F P
0 g
s
.71802 .77663 m .70463 .73168 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.71804 .77762 m .71485 .77872 L .71804 .77692 L .765 .976 .918 r
F
.71802 .77663 m .71269 .77995 L p .68386 .72713 L .835 .924 .892 r
F P
0 g
s
.70086 .78283 m .68386 .72713 L p .71269 .77995 L .835 .924 .892 r
F P
0 g
s
.71269 .77995 m .70228 .78306 L p .71804 .77762 L .765 .976 .918 r
F P
0 g
s
.71804 .77762 m .71821 .77682 L .71828 .77752 L .765 .976 .918 r
F
.71821 .77682 m .72977 .72344 L .71846 .77668 L F
.71821 .77682 m .71846 .77668 L .71828 .77752 L F
.71507 .7786 m .71887 .79129 L .71804 .77692 L p .538 .22 .377 r
F P
0 g
s
.71804 .77692 m .71802 .77663 L p .71507 .7786 L .538 .22 .377 r
F P
0 g
s
.71804 .77692 m .71802 .77663 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.71821 .77682 m .71803 .77689 L .72977 .72344 L .765 .976 .918 r
F
.70228 .78306 m .71193 .76213 L p .71803 .77689 L F P
0 g
s
.71193 .76213 m .72977 .72344 L p .71803 .77689 L .765 .976 .918 r
F P
0 g
s
.71485 .77872 m .70228 .78306 L .71821 .77682 L .765 .976 .918 r
F
.71885 .791 m .71804 .77692 L p .71193 .76213 L .838 .598 .05 r
F P
0 g
s
.7196 .79117 m .74661 .7336 L p .71702 .78336 L .388 .543 .888 r
F P
0 g
s
.71766 .79073 m .71318 .78864 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71324 .78972 m .71885 .791 L .71702 .78336 L .388 .543 .888 r
F
.71885 .791 m .7196 .79117 L .71702 .78336 L F
.71814 .77717 m .71804 .77692 L .71821 .77682 L .765 .976 .918 r
F
.71804 .77762 m .71804 .77692 L .71814 .77717 L F
.70228 .78306 m .71324 .78972 L p .7127 .78014 L .752 .386 .361 r
F P
0 g
s
.70228 .78306 m .71324 .78972 L p .74661 .7336 L .388 .543 .888 r
F P
0 g
s
.74661 .7336 m .72977 .72344 L .70228 .78306 L p .388 .543 .888 r
F P
0 g
s
.71887 .79129 m .71885 .791 L p .71108 .76007 L .838 .598 .05 r
F P
0 g
s
.711 .75987 m .71108 .76007 L .70025 .717 L .838 .598 .05 r
F
.71887 .79129 m .71108 .76007 L .711 .75987 L F
.70463 .73168 m .70025 .717 L p .71885 .791 L F P
0 g
s
.71913 .79217 m .7196 .79117 L p .71885 .791 L .388 .543 .888 r
F P
0 g
s
.71887 .79129 m .71766 .79073 L p .71324 .78972 L .538 .22 .377 r
F P
0 g
s
.71324 .78972 m .71887 .79129 L .71048 .78819 L .261 .542 .923 r
F
.71324 .78972 m .71048 .78819 L .70198 .78504 L F
.71887 .79129 m .70105 .73175 L p .70195 .78344 L F P
0 g
s
.70198 .78504 m .71048 .78819 L .70195 .78344 L .261 .542 .923 r
F
.71048 .78819 m .71887 .79129 L .70195 .78344 L F
.70201 .78659 m .71324 .78972 L p .70198 .78504 L F P
0 g
s
.68068 .79387 m .71489 .81897 L p .71324 .78972 L .651 .305 .374 r
F P
0 g
s
.70147 .78483 m .70201 .78659 L p .70198 .78504 L .261 .542 .923 r
F P
0 g
s
.70147 .78483 m .68068 .79387 L .71324 .78972 L .651 .305 .374 r
F
.70105 .73175 m .68386 .72713 L .70147 .78483 L p .261 .542 .923 r
F P
0 g
s
.70198 .78504 m .70105 .73175 L .70147 .78483 L .261 .542 .923 r
F
.66836 .78483 m .68068 .79387 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.67982 .77583 m .66836 .78483 L p .69041 .78023 L .651 .305 .374 r
F P
0 g
s
.71913 .79217 m .72043 .81454 L .72722 .79553 L .651 .305 .374 r
F
.71913 .79217 m .72722 .79553 L .73646 .76961 L F
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.70025 .717 m .70105 .73175 L .71887 .79129 L p .838 .598 .05 r
F P
0 g
s
.39402 .11589 m .38493 .11014 L .37009 .10561 L p .493 0 0 r
F P
0 g
s
.6864 .11589 m .67661 .11014 L .66344 .10561 L p .446 0 0 r
F P
0 g
s
.40174 .12429 m .39402 .11589 L .3792 .11138 L p .729 .2 0 r
F P
0 g
s
.37009 .10561 m .3792 .11138 L .39402 .11589 L p .493 0 0 r
F P
0 g
s
.69471 .12429 m .6864 .11589 L .67326 .11138 L p .693 .152 0 r
F P
0 g
s
.66344 .10561 m .67326 .11138 L .6864 .11589 L p .446 0 0 r
F P
0 g
s
.40773 .13497 m .40174 .12429 L .38693 .11982 L p .874 .436 .132 r
F P
0 g
s
.3792 .11138 m .38693 .11982 L .40174 .12429 L p .729 .2 0 r
F P
0 g
s
.70117 .13497 m .69471 .12429 L .68159 .11982 L p .858 .404 .064 r
F P
0 g
s
.67326 .11138 m .68159 .11982 L .69471 .12429 L p .693 .152 0 r
F P
0 g
s
.40539 .20357 m .41026 .18991 L .39547 .18581 L p .917 .917 .801 r
F P
0 g
s
.69865 .20357 m .7039 .18991 L .6908 .18581 L p .922 .933 .797 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.41171 .14746 m .40773 .13497 L .39293 .13055 L p .948 .607 .337 r
F P
0 g
s
.38693 .11982 m .39293 .13055 L .40773 .13497 L p .874 .436 .132 r
F P
0 g
s
.70546 .14746 m .70117 .13497 L .68806 .13055 L p .948 .593 .286 r
F P
0 g
s
.68159 .11982 m .68806 .13055 L .70117 .13497 L p .858 .404 .064 r
F P
0 g
s
.74563 .71885 m .72977 .72344 L .74661 .7336 L closepath p .751 .377 .347 r
F P
0 g
s
.41026 .18991 m .41301 .17557 L .39822 .17138 L p .954 .875 .719 r
F P
0 g
s
.39822 .17138 m .39547 .18581 L .41026 .18991 L p .954 .875 .719 r
F P
0 g
s
.7039 .18991 m .70686 .17557 L .69377 .17138 L p .963 .89 .709 r
F P
0 g
s
.69377 .17138 m .6908 .18581 L .7039 .18991 L p .963 .89 .709 r
F P
0 g
s
.4135 .1612 m .41171 .14746 L .39692 .14311 L p .976 .728 .496 r
F P
0 g
s
.39293 .13055 m .39692 .14311 L .41171 .14746 L p .948 .607 .337 r
F P
0 g
s
.70738 .1612 m .70546 .14746 L .69236 .14311 L p .984 .729 .462 r
F P
0 g
s
.68806 .13055 m .69236 .14311 L .70546 .14746 L p .948 .593 .286 r
F P
0 g
s
.70025 .717 m .68386 .72713 L .70105 .73175 L closepath p .529 .206 .363 r
F P
0 g
s
.41301 .17557 m .4135 .1612 L .39871 .15693 L p .975 .814 .619 r
F P
0 g
s
.39871 .15693 m .39822 .17138 L .41301 .17557 L p .975 .814 .619 r
F P
0 g
s
.70686 .17557 m .70738 .1612 L .6943 .15693 L p .985 .824 .6 r
F P
0 g
s
.6943 .15693 m .69377 .17138 L .70686 .17557 L p .985 .824 .6 r
F P
0 g
s
.39692 .14311 m .39871 .15693 L .4135 .1612 L p .976 .728 .496 r
F P
0 g
s
.69236 .14311 m .6943 .15693 L .70738 .1612 L p .984 .729 .462 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00gP3oool:00000;40oooo2P00003M0?oo
o`00fP3oool4000000X0GDbU0`00002Z0?ooo`@000002P1TDJL400000=T0oooo003H0?ooo`800000
4@1MC:D300000:D0oooo0P00000B06AAY`<00000eP3oool00=H0oooo0P00000E05e<Y@@00000X03o
ool2000001H0I56W0`00003D0?ooo`00e@3oool00`000000GDbU05e<Y@0G05e<Y@030000001n0000
OP0000<00000VP3oool2000001X0I56W00@000000780000000000000d@3oool00=<0oooo0P00000K
05e<Y@8000000`1n0002000009H0oooo0P00000M06AAY`8000000P1b000200000<h0oooo003B0?oo
o`030000001MC:D0GDbU01d0GDbU0`00000207h000800000TP3oool200000240I56W0`0000000`1b
000000000000003<0?ooo`00d@3oool00`000000GDbU05e<Y@0O05e<Y@030000002j<`00000000D0
0000S`3oool00`000000I56W06AAY`0R06AAY`030000002a9P00000000@00000bP3oool00=00oooo
00<0000005e<Y@1MC:D08@1MC:D00`000000^S<00;Xc00030;Xc00<00000S03oool00`000000I56W
06AAY`0T06AAY`030000002a9P00/BH00080/BH00`0000380?ooo`00cP3oool2000002D0GDbU00<0
00000;Xc002j<`001@2j<`000`000000oooo0?ooo`270?ooo`800000:01TDJL2000000D0/BH000<0
00000?ooo`3oool0a@3oool00<d0oooo00<0000005e<Y@1MC:D09P1MC:D00`000000^S<00;Xc0005
0;Xc00030000003oool0oooo08D0oooo00<0000006AAY`1TDJL0:P1TDJL00`000000/BH00;4V0003
0;4V00030000003oool0oooo0<@0oooo003<0?ooo`030000001MC:D0GDbU02P0GDbU0P0000050;Xc
00030000003oool0oooo08@0oooo00<0000006AAY`1TDJL0;01TDJL2000000<0/BH000<000000?oo
o`3oool0a03oool00</0oooo00<0000005e<Y@1MC:D0:P1MC:D4000000<0^S<000<000000?ooo`3o
ool0PP3oool00`000000I56W06AAY`0^06AAY`<000000P2a9P000`000000oooo0?ooo`330?ooo`00
b`3oool00`000000GDbU05e<Y@0Z05e<Y@040000003OKb40gflQ0=m_8@D00000PP3oool00`000000
I56W06AAY`0_06AAY`030000003KIa00ffL@00@00000a03oool00<X0oooo00<0000005e<Y@1MC:D0
;01MC:D00`000000gflQ0=m_8@040=m_8@800000P03oool00`000000I56W06AAY`0a06AAY`030000
003KIa00ffL@0080ffL@0P0000330?ooo`00b@3oool00`000000GDbU05e<Y@0]05e<Y@030000003O
Kb40gflQ00D0gflQ00<000000?ooo`3oool0OP3oool00`000000I56W06AAY`0a06AAY`030000003K
Ia00ffL@00@0ffL@00<000000?ooo`3oool0`03oool00<P0oooo00<0000005e<Y@1MC:D0;`1MC:D0
0`000000gflQ0=m_8@050=m_8@030000003oool0oooo07`0oooo00<0000006AAY`1TDJL0<`1TDJL0
0`000000ffL@0=]W40030=]W40030000003oool0oooo0<00oooo00380?ooo`030000001MC:D0GDbU
02l0GDbU00<000000=m_8@3OKb401@3OKb400`000000oooo0?ooo`1k0?ooo`030000001TDJL0I56W
03@0I56W00<000000=]W403KIa00103KIa000`000000oooo0?ooo`2o0?ooo`00a`3oool00`000000
GDbU05e<Y@0a05e<Y@8000001P3OKb400`000000oooo0?ooo`1i0?ooo`030000001TDJL0I56W03H0
I56W0P0000040=]W40030000003oool0oooo0;l0oooo00360?ooo`030000001MC:D0GDbU0380GDbU
00<000000?:KEP0000000P0000030=m_8@030000003oool0oooo07P0oooo00<0000006AAY`1TDJL0
=`1TDJL010000000lYM90000000000030=]W40030000003oool0oooo0;h0oooo00360?ooo`030000
001MC:D0GDbU03<0GDbU00@000000?:KEP3bVeH0lY]F0`0000000`3OKb4000000?ooo`1h0?ooo`03
0000001TDJL0I56W03P0I56W00<000000?:GB@3bUdT0100000300?ooo`00a@3oool00`000000GDbU
05e<Y@0d05e<Y@030000003bVeH0lY]F00@0lY]F0P00001h0?ooo`030000001TDJL0I56W03T0I56W
00<000000?:GB@3bUdT00`3bUdT200000;l0oooo00350?ooo`030000001MC:D0GDbU02T0GDbU00<0
GTfV05e<Y@1MC:D0201MC:D00`000000lY]F0?:KEP050?:KEP030000003oool0oooo07H0oooo00<0
000006AAY`1TDJL0>@1TDJL00`000000lYM90?:GB@040?:GB@030000003oool0oooo0;d0oooo0034
0?ooo`030000001MC:D0GDbU03H0GDbU00<000000?:KEP3bVeH01@3bVeH00`000000oooo0?ooo`1d
0?ooo`030000001TDJL0I56W03/0I56W00<000000?:GB@3bUdT0103bUdT00`000000oooo0?ooo`2l
0?ooo`00a03oool00`000000GDbU05e<Y@0f05e<Y@030000003bVeH0lY]F00D0lY]F00<000000?oo
o`3oool0M03oool00`000000I56W06AAY`0k06AAY`030000003bUdT0lYM900@0lYM900<000000?oo
o`3oool0_03oool00<<0oooo00<0000005e<Y@1MC:D07P1MC:D00`1NCJH0GDbU05e<Y@0G05e<Y@03
0000003bVeH0lY]F00@0lY]F00<000000?ooo`3oool0L`3oool00`000000I56W06AAY`0206AAY`03
0=cbgP1TDJL0I56W03P0I56W00<000000?:GB@3bUdT00`3bUdT00`000000oooo0?ooo`2l0?ooo`00
``3oool00`000000GDbU05e<Y@0;05e<Y@0305i=YP1MC:D0GDbU02X0GDbU0P0000060?:KEP030000
003oool0oooo0780oooo00<0000006AAY`1TDJL0?@1TDJL2000000D0lYM900<000000?ooo`3oool0
^`3oool00<<0oooo00<0000005e<Y@1MC:D02`1MC:D00`1NCJH0GDbU05e<Y@0Z05e<Y@030000003i
^Wh00000008000000`3bVeH00`000000oooo0?ooo`1b0?ooo`030000001TDJL0I56W03d0I56W00@0
00000?^jMP00000000000`3bUdT00`000000oooo0?ooo`2k0?ooo`00`P3oool00`000000GDbU05e<
Y@0<05e<Y@0305i=YP1MC:D0GDbU00l0GDbU00<0GTfV05e<Y@1MC:D0601MC:D00`000000nKYn0?Vj
OP020?VjOP<0000000<0lY]F0000003oool0L@3oool00`000000I56W06AAY`0n06AAY`040000003k
^WH0nkYf0?^jMP<0000000<0lYM90000003oool0^`3oool00<80oooo00<0000005e<Y@1MC:D0301M
C:D00`1NCJH0GDbU05e<Y@0Z05e<Y@030000003i^Wh0nKYn00D0nKYn0P00001b0?ooo`030000001T
DJL0I56W03h0I56W00<000000?^jMP3k^WH0103k^WH200000;`0oooo00320?ooo`030000001MC:D0
GDbU00`0GDbU00<0GTfV05e<Y@1MC:D0:P1MC:D00`000000nKYn0?VjOP060?VjOP030000003oool0
oooo0700oooo00<0000006AAY`1TDJL0?P1TDJL00`000000nkYf0?^jMP050?^jMP030000003oool0
oooo0;X0oooo00310?ooo`030000001MC:D0GDbU00d0GDbU00<0GTfV05e<Y@1MC:D03P1MC:D00`1N
CJH0GDbU05e<Y@0J05e<Y@030000003i^Wh0nKYn00D0nKYn00<000000?ooo`3oool0K`3oool00`00
0000I56W06AAY`1006AAY`030000003k^WH0nkYf00@0nkYf00<000000?ooo`3oool0^P3oool00<40
oooo00<0000005e<Y@1MC:D03@1MC:D00`1NCJH0GDbU05e<Y@0[05e<Y@030000003i^Wh0nKYn00D0
nKYn00<000000?ooo`3oool0K`3oool00`000000I56W06AAY`0506AAY`030>_/c01TDJL0I56W03P0
I56W00<000000?^jMP3k^WH0103k^WH00`000000oooo0?ooo`2j0?ooo`00`@3oool00`000000GDbU
05e<Y@0W05e<Y@0305i=YP1MC:D0GDbU0140GDbU00<000000?VjOP3i^Wh01@3i^Wh00`000000oooo
0?ooo`1_0?ooo`030000001TDJL0I56W00D0I56W00<0jnc<06AAY`1TDJL0>01TDJL00`000000nkYf
0?^jMP040?^jMP030000003oool0oooo0;X0oooo00300?ooo`030000001MC:D0GDbU01h0GDbU00<0
GTfV05e<Y@1MC:D06`1MC:D00`000000nKYn0?VjOP060?VjOP030000003oool0oooo06d0oooo00<0
000006AAY`1TDJL0@@1TDJL00`000000nkYf0?^jMP050?^jMP030000003oool0oooo0;T0oooo0030
0?ooo`030000001MC:D0GDbU02L0GDbU00<0GTfV05e<Y@1MC:D04P1MC:D3000000H0nKYn00<00000
0?ooo`3oool0K@3oool00`000000I56W06AAY`1106AAY`8000001P3k^WH00`000000oooo0?ooo`2i
0?ooo`00`03oool00`000000GDbU05e<Y@0l05e<Y@030000003id9h0nM2N00@000000P3i^Wh00`00
0000oooo0?ooo`1]0?ooo`030000001TDJL0I56W0440I56W00<000000?cBV@0000000`0000020?^j
MP030000003oool0oooo0;T0oooo00300?ooo`030000001MC:D0GDbU01D0GDbU4P00000E05e<Y@03
0000003id9h0nM2N00@0nM2N0`00001_0?ooo`030000001TDJL0I56W01X0I56W4P00000E06AAY`03
0000003ldYT0o=:I00<0o=:I0`00002k0?ooo`00_`3oool00`000000GDbU05e<Y@0805e<Y@h00000
3@2GNk800`000000gkJ^0=nf[P020=nf[PT00000301MC:D00`000000nM2N0?W@WP060?W@WP030000
003oool0oooo06`0oooo00<0000006AAY`1TDJL0301TDJL?000000d0Ug^b00<000000>6h[@3Q^:d0
0P3Q^:d8000000d0I56W00<000000?cBV@3ldYT01@3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3o
ool00`000000GDbU05e<Y@0605e<Y@<000006P2GNk800`000000gkJ^0=nf[P0;0=nf[PD000001`1M
C:D00`000000nM2N0?W@WP060?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL0201T
DJL01P1TDZL0I56W0000000000003@Z6000001X0Ug^b00<000000>6h[@3Q^:d02P3Q^:d5000000P0
I56W00<000000?cBV@3ldYT01@3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3oool00`000000GDbU
05e<Y@0405e<Y@8000000P0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^
1`1MC:D00`000000nM2N0?W@WP070?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL0
201TDJL2000000<03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W
00<000000?cBV@3ldYT01P3ldYT00`000000oooo0?ooo`2i0?ooo`00_`3oool00`000000GDbU05e<
Y@0205e<Y@800000100007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^1`1M
C:D00`000000nM2N0?W@WP070?W@WP030000003oool0oooo06`0oooo00<0000006AAY`1TDJL01@1T
DJL3000000D03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<0
00000?cBV@3ldYT01P3ldYT00`000000oooo0?ooo`2i0?ooo`00_P3oool010000000GDbU05e<Y@1M
C:D2000000H0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[PL0GDbU00<0
00000?W@WP3id9h01`3id9h00`000000oooo0?ooo`1[0?ooo`030000001TDJL0I56W00@0I56W0P00
000800d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d806AAY`030000003l
dYT0o=:I00H0o=:I00<000000?ooo`3oool0^@3oool00;h0oooo00@0000005e<Y@00000000002000
07/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^1`1MC:D00`000000nM2N0?W@
WP070?W@WP030000003oool0oooo06/0oooo00<0000006AAY`1TDJL00P1TDJL2000000X03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<000000?cBV@3ldYT01P3l
dYT00`000000oooo0?ooo`2i0?ooo`00_P3oool2000000X0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0?0=nf[PL0GDbU0P0000080?W@WP030000003oool0oooo06/0oooo00<00000
06AAY`1TDJL00P00000<00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d8
06AAY`8000001`3ldYT00`000000oooo0?ooo`2i0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh705e<Y@030000003dgkP00000
008000001@3id9h00`000000oooo0?ooo`1[0?ooo`040000001TDJL0I56W000000d03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@P0I56W00<000000?KS]@0000000P000004
0?cBV@030000003oool0oooo0;T0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[PL0GDbU00<000000?CO^03dgkP00P3dgkP40000
00030?W@WP000000oooo06`0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H
09Mk/P030000003Q^:d0hKR]00h0hKR]201TDJL00`000000m^>e0?KS]@020?KS]@<0000000<0o=:I
0000003oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1`1MC:D00`000000m=nh0?CO^0060?CO^0800000K@3oool01000
0000I56W06AAY`00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d8
06AAY`030000003fhkD0m^>e00D0m^>e0P00002k0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh705e<Y@030000003dgkP0m=nh
00L0m=nh00<000000?ooo`3oool0J`3oool010000000I56W06AAY`00000=00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d806AAY`030000003fhkD0m^>e00H0m^>e00<00000
0?ooo`3oool0^@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1P1MC:D00`000000m=nh0?CO^0080?CO^0030000003oool0oooo
06/0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1`1TDJL00`000000m^>e0?KS]@070?KS]@030000003oool0oooo0;T0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[PH0GDbU00<000000?CO^03dgkP01`3dgkP00`000000oooo0?ooo`1/0?ooo`040000001TDJL0I56W
000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@L0I56W00<00000
0?KS]@3fhkD01P3fhkD00`000000oooo0?ooo`2j0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O]Zh605e<Y@030000003dgkP0m=nh
00L0m=nh00<000000?ooo`3oool0K03oool010000000I56W06AAY`00000=00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d03P3Q^:d706AAY`030000003fhkD0m^>e00H0m^>e00<00000
0?ooo`3oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1P1MC:D00`000000m=nh0?CO^0070?CO^0030000003oool0oooo
06`0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1`1TDJL00`000000m^>e0?KS]@060?KS]@030000003oool0oooo0;X0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[PH0GDbU0P0000080?CO^0030000003oool0oooo06`0oooo00@0000006AAY`1TDJL000003@0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]1`1TDJL2000000L0m^>e00<00000
0?ooo`3oool0^P3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^1@1MC:D00`000000j^[=0>[Zc@03000000@0m=nh00<000000?oo
o`3oool0K@3oool010000000I56W06AAY`00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d03P3Q^:d606AAY`030000003/k/`0k>k<00800000103fhkD00`000000oooo0?ooo`2k
0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf
[P3O]Zh03`3O]Zh505e<Y@030000003Zj/d0j^[=00<0j^[=0`0000000`3dgkP000000?ooo`1^0?oo
o`040000001TDJL0I56W000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>
0>6h[@H0I56W00<000000>c^c03/k/`00P3/k/`3000000030?KS]@000000oooo0;`0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[P@0GDbU00<000000>[Zc@3Zj/d01`3Zj/d2000006l0oooo00@0000006AAY`1TDJL000003@0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]1@1TDJL00`000000k>k<0>c^c006
0>c^c0800000_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^00l0gkJ^101MC:D00`000000j^[=0>[Zc@080>[Zc@030000003oool0oooo
06d0oooo00@0000006AAY`1TDJL000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]00h0hKR]1@1TDJL00`000000k>k<0>c^c0070>c^c0030000003oool0oooo0;/0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf
[P<0GDbU00<000000>[Zc@3Zj/d0203Zj/d3000006l0oooo00<0000006AAY`0000003@0=2XH00`00
0000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]101TDJL00`000000k>k<0>c^c0070>c^
c0030000003oool0oooo0;`0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2G
Nk80602GNk800`000000gkJ^0=nf[P0?0=nf[P<0GDbU00<000000>[Zc@3Zj/d0203Zj/d3000006l0
oooo00<0000006AAY`0000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0
hKR]101TDJL00`000000k>k<0>c^c0070>c^c0030000003oool0oooo0;`0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P<0GDbU
00<000000>[Zc@3Zj/d0203Zj/d2000000030>5e;@000000oooo06d0oooo00<0000006AAY`000000
3@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]101TDJL00`000000k>k<
0>c^c0070>c^c0030000003oool0oooo0;`0oooo002n0?ooo`030000000007/0001k00T0001k00<0
000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P80GDbU00<000000>[Zc@3Zj/d0203Z
j/d00`000000n<]M000000020>5e;@030000003oool0oooo06/0oooo00<0000006AAY`0000003@0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]0`1TDJL00`000000k>k<0>c^
c0070>c^c0030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P80GDbU0`0000080>[Zc@060000003hbed0
00000000003QMBd00000K@3oool00`000000I56W0000000=00d:QP030000002GNk80Ug^b01P0Ug^b
00<000000>6h[@3Q^:d03P3Q^:d306AAY`800000203/k/`00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh03`3O
]Zh205e<Y@030000003LlMh0g?7N00@00000103Zj/d010000000n<]M0000003aWEh3000006`0oooo
00<0000006AAY`0000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]00h0hKR]
0P1TDJL00`000000g?GN0=cegP04000000@0k>k<00<000000?ooo`3oool0_@3oool00;h0oooo00<0
00000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^00l0gkJ^00<0
GDbU0000003LlMh0103LlMh01P000000g?7N000000000000j^[=00000080n<]M00D000000?6MGP3a
WEh0lIeN0000001]0?ooo`8000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
00h0hKR]0P1TDJL00`000000g?GN0=cegP020=cegP050000003LmMh000000000003/k/`00P00002o
0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf
[P3O]Zh03`3O]Zh00`1MC:D000000=cagP020=cagP80gkJ^00@000000=cagP3LlMh0g?7N0P000002
0?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J@3oool3000000d03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@0306AAY`000000g?GN0080g?GN0P3Q^:d0
10000000g?GN0=cegP3LmMh300000;l0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0?0=nf[P030000003O]Zh0gkJ^00@0gkJ^00D00000
0=cagP3LlMh0g?7N000000030?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J@3o
ool3000000d03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0>0>6h[@0306AAY`00
0000hKR]00@0hKR]00L000000=cegP3LmMh0g?GN0000000E4HX000000;l0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0g?7N008000000`3hbed00`000000lIeN0?6MGP020?6MGP030000003oool0oooo06P0oooo
00@0000006YGZ@00000000003@0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0
hKR]00<000000>g2A`3LmMh00P0000000`3]`TL000000?ooo`2n0?ooo`00_P3oool00`000000001k
0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh010000000n<]M
0=cagP0000040?S;G@030000003aWEh0lIeN0080lIeN00<000000?ooo`3oool0J03oool010000000
JUNY06YGZ@00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d01000
0000kL970=cegP0000020>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k
00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P040000003hbed00000
000000@0n<]M100000020?6MGP030000003oool0oooo06H0oooo00D0000006YGZ@1ZEjT0JUNY0000
000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970000
00030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0000000D0n<]M00@00000
0?NiQ03g^H@0mkV40`00001X0?ooo`050000001ZEjT0JUNY06YGZ@0000003@0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo
0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<0
00000=nf[P3O]Zh05P3O]Zh00`000000n<]M000000050?S;G@030000003g^H@0mkV400<0mkV400<0
00000?ooo`3oool0I@3oool00`000000JUNY06YGZ@0206YGZ@030000000=2XH03@Z600/03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<0
00000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H
09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000mkV40?NiQ003
0?NiQ0030000003oool0oooo06D0oooo00<0000006YGZ@1ZEjT00P1ZEjT00`0000003@Z600d:QP0;
00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`03
0>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?Ni
Q03g^H@00`3g^H@00`000000oooo0?ooo`1U0?ooo`030000001ZEjT0JUNY0080JUNY00<0000000d:
QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2
A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`03
0000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@03
0000003g^H@0mkV400<0mkV400<000000?ooo`3oool0I03oool00`000000JUNY06YGZ@0306YGZ@03
0000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@03
0000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/0
2@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed0
1@3hbed00`000000mkV40?NiQ0040?NiQ0030000003oool0oooo06<0oooo00<0000006YGZ@1ZEjT0
0`1ZEjT00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d0
5@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?NiQ03g^H@0103g^H@00`000000oooo0?ooo`1S0?ooo`030000001Z
EjT0JUNY00<0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@D000000P3g^H@00`000000oooo0?ooo`1R0?ooo`030000001ZEjT0
JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`00
0000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`00
0000n<]M0?S;G@050?S;G@030000003gcZ40mljQ0080mljQ0`00001T0?ooo`030000001ZEjT0JUNY
00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`030000000007/0
001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0
n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1R0?ooo`030000001ZEjT0
JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0
hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1R0?ooo`030000001Z
EjT0JUNY00@0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1Q0?ooo`030000
001ZEjT0JUNY00D0JUNY00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo002n0?ooo`03
0000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P03
0000003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?ooo`1Q0?ooo`03
0000001ZEjT0JUNY00@0JUNY0P00000=00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d01`000000kL970>g2A`3]`TL05A6:0>g2A`000000_`3oool00;h0oooo00<000000000
N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;
G@3hbed01@3hbed00`000000mljQ0?O>X@040?O>X@030000003oool0oooo0640oooo00<0000006YG
Z@1ZEjT00P1ZEjT20000000301PCR`0000003@Z600`03@Z600<0000009Mk/P2GNk80602GNk800`00
0000hKR]0>6h[@0E0>6h[@070000003]`TL0kL970>g2A`0E4HX0kL970000002o0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003gcZ40mljQ00@0mljQ00<000000?ooo`3oool0H@3oool0
0`000000JUNY06YGZ@02000000<061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H
09Mk/P030000003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL000000;l0oooo
002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf
[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?O>X@3gcZ40103gcZ400`000000oooo0?oo
o`1Q0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00L000000>g2A`3]`TL0kL9701DARP3]`TL00000
0;l0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000
gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M1@0000020?O>X@030000003oool0oooo0640
oooo00@0000006YGZ@1ZEjT00000100H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b
01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d01`000000kL970>g2A`3]`TL05A6:0>g2A`000000_`3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000l]bi0?;L^@020?;L^@<00000H`3oool0
10000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk803@2G
Nk800`000000Ug^b09Mk/P0809Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003bg;T0
l]bi00@0l]bi00<000000?ooo`3oool0H@3oool010000000JUNY06YGZ@00000401PCR`030000000=
2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]
`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/0
0`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed0
0`000000l]bi0?;L^@030?;L^@030000003oool0oooo0680oooo00@0000006YGZ@1ZEjT00000100H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0
001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0
n<]M00D0n<]M00<000000?;L^@3bg;T00`3bg;T00`000000oooo0?ooo`1R0?ooo`040000001ZEjT0
JUNY000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003bg;T0l]bi00<0l]bi00<000000?ooo`3oool0HP3oool0
10000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000l]bi0?;L^@030?;L^@030000003oool0
oooo0680oooo00@0000006YGZ@1ZEjT00000100H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?;L^@3bg;T00P3bg;T0
0`000000oooo0?ooo`1S0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@<000000P3bg;T0
0`000000oooo0?ooo`1S0?ooo`040000001ZEjT0JUNY000000@061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003Yild0
jNO=00<00000I@3oool010000000JUNY06YGZ@00000401PCR`030000000=2XH03@Z600/03@Z600<0
000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<0
00000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H
09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000jNO=0>WWc@02
0>WWc@030000003oool0oooo06@0oooo00<0000006YGZ@000000100H4h/00`0000003@Z600d:QP0;
00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`03
0>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk
/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00@000000>WW
c@3Yild0jNO=0P00001V0?ooo`030000001ZEjT0000000@061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@040000003Yild0jNO=
0>WWc@800000IP3oool00`000000JUNY0000000401PCR`030000000=2XH03@Z600/03@Z600<00000
09Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<00000
0?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk
/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed01P000000jNO=0>WWc@000000
n/aS000006H0oooo00<0000006YGZ@000000100H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00H000000>WWc@3Yild000000?[<
H`00001V0?ooo`030000001ZEjT0000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b
09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo
0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<0
00000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@060000003Yild0jNO=0000003jc6<0
0000I`3oool2000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P03
0000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00
_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh0
5P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003Yild000000080n/aS00<000000?ooo`3oool0
I@3oool2000000@061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@<000000P3jc6<00`000000oooo0?ooo`1U0?ooo`800000100H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M0P0000030?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M0P0000030?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H
4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q
^:d010000000kL970>g2A`0E4HX20>g2A`030000003oool0oooo0;d0oooo002n0?ooo`0300000000
07/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003h
bed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H
4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00@000000>g2A`3]`TL05A6:0P3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3o
ool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@040000003]`TL0kL9701DARP80kL9700<000000?ooo`3oool0
_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O
]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003o
ool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<0
0`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS
0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z6
00/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL97
00<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000
Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000
n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`000000
3@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000
kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k
00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M
00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;
00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]
00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000
N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;
G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PC
R`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h
[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<00000
0000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<00000
0?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<00000
01PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf
[P030000003hbed0n<]M00D0n<]M00H000000?[<H`3jc6<030Z60?[<H`00001X0?ooo`030000000H
4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q
^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool0
0`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh0
0`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool0
0`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk80
0`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool0
0;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^
01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo
06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b
01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo
0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000
gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000
oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000
Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000
oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b
00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS
00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z6
00<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL97
00<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk
/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<
H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:
QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2
A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<00000
09Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<00000
0?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<00000
00d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<00000
0>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000
N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;
G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PC
R`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h
[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`00
07/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3h
bed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H
4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000
003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000
000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000
003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3o
ool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O
]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3o
ool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0
gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0
oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80
Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0
oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`00
0000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`00
0000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`00
0000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`00
0000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0
Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080
n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/0
3@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0
kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b
09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS
0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z6
00d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL97
0>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0
000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<0
00000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0
000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<0
00000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`09
0000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@05
0?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`02
01PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E
0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000
N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;
G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PC
R`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h
[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`03
0000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P03
0000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`03
0000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P03
0000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00
_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh0
5P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0
IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80
602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0
_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O
]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003o
ool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002G
Nk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003o
ool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk80
0`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<0
0`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH0
0`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL0
0`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b
01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS
0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z6
00/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL97
00<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000
Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000
n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`000000
3@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000
kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k
00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M
00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;
00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]
00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000
N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;
G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PC
R`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h
[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<00000
0000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<00000
0?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000003oool0oooo06H0oooo00<00000
01PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<00000
0>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?oo
o`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0F0=nf
[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3jc6<00`000000oooo0?ooo`1V0?oo
o`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk
/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?oo
o`00_P3oool00`000000001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O
]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3o
ool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH03@Z600/03@Z600<0000009Mk/P2G
Nk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3o
ool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P030000
003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`000000n/aS0?[<H`020?[<H`030000
003oool0oooo06H0oooo00<0000001PCR`0H4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000
002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000
003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602G
Nk800`000000gkJ^0=nf[P0F0=nf[P030000003hbed0n<]M00D0n<]M00<000000?[<H`3jc6<00P3j
c6<00`000000oooo0?ooo`1V0?ooo`030000000H4h/061>;008061>;00<0000000d:QP0=2XH02`0=
2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]01D0hKR]00<000000>g2A`3]`TL00`3]
`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000001k0000N`090000N`030000002GNk80
Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000n<]M0?S;G@050?S;G@030000003jc6<0
n/aS0080n/aS00<000000?ooo`3oool0IP3oool00`00000061>;01PCR`0201PCR`030000000=2XH0
3@Z600/03@Z600<0000009Mk/P2GNk80602GNk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0
kL9700<0kL9700<000000?ooo`3oool0_@3oool00;h0oooo00<000000000N`0007/02@0007/00`00
0000Ug^b09Mk/P0H09Mk/P030000003O]Zh0gkJ^01H0gkJ^00<000000?S;G@3hbed01@3hbed00`00
0000n/aS0?[<H`020?[<H`030000003oool0oooo01@0oooo?000000F0?ooo`030000000H4h/061>;
008061>;00<0000000d:QP0=2XH02`0=2XH00`000000Ug^b09Mk/P0H09Mk/P030000003Q^:d0hKR]
01D0hKR]00<000000>g2A`3]`TL00`3]`TL00`000000oooo0?ooo`2m0?ooo`00_P3oool00`000000
001k0000N`090000N`030000002GNk80Ug^b01P0Ug^b00<000000=nf[P3O]Zh05P3O]Zh00`000000
n<]M0?S;G@050?S;G@030000003jc6<0n/aS0080n/aS00<000000?ooo`3oool05000000909j1/`03
0000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<01`38Y;<D00000080oooo00<0000001PCR`0H
4h/00P0H4h/00`0000003@Z600d:QP0;00d:QP030000002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q
^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`030000
000007/0001k00T0001k00<0000009Mk/P2GNk80602GNk800`000000gkJ^0=nf[P0E0=nf[Q400000
7@2NPK<00`000000]9>d0;BC]00V0;BC]00300000038Y;<0b:Bc01/0b:Bc4@00000400d:QP030000
002GNk80Ug^b01P0Ug^b00<000000>6h[@3Q^:d05@3Q^:d00`000000kL970>g2A`030>g2A`030000
003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk80602G
Nk800`000000gkJ^0=nf[P090=nf[P`000001P24K:l00`000000WX6c09j1/`0U09j1/`030000002d
Tk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_0=^b[`040=^b[``000004`2G
Nk800`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3o
ool00;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0H09Mk/P`000004P24K:l0
0`000000WX6c09j1/`0B09j1/e0000005038Y;<00`000000fk:_0=^b[`0@0=^b[``000001`2GNk80
0`000000hKR]0>6h[@0E0>6h[@030000003]`TL0kL9700<0kL9700<000000?ooo`3oool0_@3oool0
0;h0oooo00<000000000N`0007/02@0007/00`000000Ug^b09Mk/P0>09Mk/PX000006024K:lK0000
0500>;[T5@00000N0=^b[`X000005@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo
0;d0oooo002n0?ooo`030000000007/0001k00T0001k00<0000009Mk/P2GNk801P2GNk88000000<0
He2W00<0000008A/[`24K:l04024K:l<000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0
Y`P000003@3Q^:d00`000000kL970>g2A`030>g2A`030000003oool0oooo0;d0oooo002n0?ooo`03
0000000007/0001k00T0001k2@00000;06=@Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`0
00001P3K/Zl00`000000k<2W0>c0Y`090>c0Y`P000001@3Q^:d00`000000kL970>g2A`030>g2A`03
0000003oool0oooo0;d0oooo002n0?ooo`030000000007/0001k0080001k2000000@06=@Y`X00000
]P0h^^@7000001<0k<2W200000030>g2A`030000003oool0oooo0;d0oooo002m0?ooo`H00000401S
D:L800000<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0
He2W00T0He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?oo
o`D000001`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<
V03jc9P01@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D0
0000[`3oool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo
002U0?ooo`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool2
000000030000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`0
000000800000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rj
i1h0>;[T100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0
001l00<0000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0
om1l0P00002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000
V`3oool009P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F
0?ooo`800000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool30000
00H0001l0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`00
04/00000100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool0
0940oooo0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000
003`a4/00P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540
>;[T0P0000050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[T
E@0h^^@2000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h
^^@0>;[T0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=
0?ooo`040000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?oo
o`2;0?ooo`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000
S@3oool008d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2
000008`0oooo002<0?ooo`8000007@0h^^@403Vji900>;[T00<0000003Rji00h^^@0/00h^^@20000
08`0oooo002<0?ooo`800000>`0h^^@703Vji6H0>;[T2@2<L[400`000000eZna0=J_/@0=0=J_/J<0
>;[T0P00002<0?ooo`00S03oool00`000000>;[T03Rji01G03Rji0`0>K[T>P0h^^@00`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0000003Rji00h^^@0W00h^^@2000008`0oooo
002<0?ooo`030000000h^^@0>;[T07D0>;[T3`0i^^@G03Rji080001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0U@0h
^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000>;[T03Rji02B03Rji0<0>K[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg400`3ncg4@03Rji0L0>K[TP`0h^^@00`000000oooo0?ooo`2:0?ooo`00S03oool00`00
0000>;[T03Rji02E03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@07P0h^^@803Vj
i6l0>;[T00<000000?ooo`3oool0RP3oool008d0oooo00<0000003Rji00h^^@0U00h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T0300>;[T2@0i^^AK03Rji0030000003oool0oooo08/0
oooo002>0?ooo`800000U00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00d0>;[T
400i^^@V03Rji0L0>K[TB00h^^@2000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji00]03Rji0`0>K[T7@0h^^@503Vji3H0>;[T00<0
00000?ooo`3oool0SP3oool00940oooo00<0000003Rji00h^^@0T00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T04d0>;[T200i^^@C03Rji0@0>K[T900h^^@00`000000oooo0?ooo`2?
0?ooo`00TP3oool200000900>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rj
i0@0>K[T2P0h^^@203Vji140>;[T0P00002B0?ooo`00U03oool00`000000>;[T03Rji02=03Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0@0=J_/@03
08ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0S@0h^^@00`000000oooo0?ooo`2B0?ooo`00
UP3oool2000008`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0100eZna00<0SG>a0000003ncg401P3ncg400`000000>;[T03Rji02:03Rji0800000
UP3oool009P0oooo0P00002:03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0@0=J_/@0308ec/@000000o/ma00H0o/ma00<0000003Rji00h^^@0R00h
^^@2000009P0oooo002J0?ooo`<00000Q`0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k40403F[k400`2=Lk4000000?k?L@060?k?L@030000000h^^@0
>;[T08D0>;[T0`00002J0?ooo`00W@3oool2000008D0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji02303Rji0800000W@3oool009l0oooo0P00002303Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0P@0h^^@2000009l0oooo002Q0?ooo`@00000O`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T07d0>;[T1000002Q0?ooo`00Y@3oool5000007X0>;[T00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000>;[T03Rji01h03Rji0D00000Y@3oool00:X0oooo1@00001e
03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0L`0h^^@500000:X0oooo002_0?oo
o`D00000L00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04/0>;[T00<0000003Rj
i00h^^@0800h^^@500000:l0oooo002d0?ooo`D00000J`0h^^@00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000000h^^@0>;[T06T0>;[T1@00002d0?ooo`00^@3oool5000006H0>;[T00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000>;[T03Rji01T03Rji0D00000^@3oool00;h0oooo1@00001Q03Rji00300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<0000003Rji00h^^@0G`0h^^@500000;h0oooo00330?ooo`D00000G00h^^@0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k403`3F[k40
0`2=Lk40eZna000000070?k?L@030000000h^^@0>;[T05X0>;[T1@0000330?ooo`00b03oool50000
05L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
00l0eZna00<0SG>a0=J_/@0000001`3ncg400`000000>;[T03Rji01E03Rji0D00000b03oool00<d0
oooo1`00001@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0?0=J_/@0308ec/@3F[k40000000L0o/ma00<0000003Rji00h^^@0CP0h^^@700000<d0
oooo003D0?ooo`X00000AP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T04@0>;[T
2P00003D0?ooo`00gP3oool:000003`0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i00j03Rji0X00000gP3oool00>P0oooo3@00000_03Rji003000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
03Rji00h^^@0;@0h^^@=00000>P0oooo003e0?oooa0000007`0h^^@00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000000h^^@0>;[T01d0>;[T4000003e0?ooo`00o`3oool60?oooaT000001P0h^^@00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o0?oooal0oooo
1`0000070000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@L00000o`3ooolO0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0>0=J_/@0408ec/@3F[k40eZna000000L0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0=0=J_/@05
08ec/@3F[k40eZna0=J_/@0000001`3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00d0
eZna00D0SG>a0=J_/@3F[k40eZna000000070?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k403@3F[k401@2=Lk40eZna0=J_/@3F[k40000000L0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0<0=J_/@0308ec/@3F[k40eZna0080
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00`0eZna
00<0SG>a0=J_/@3F[k400P3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k40303F[k400`2=Lk40eZna0=J_/@020=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0;
0=J_/@0308ec/@3F[k40eZna00<0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o
0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna00/0eZna00<0SG>a0=J_/@3F[k400`3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3o
ool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool0
0?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k402P3F[k400`2=Lk40eZna0=J_/@040=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0:0=J_/@0308ec/@3F[k40eZna00@0eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00X0eZna00<0SG>a0=J_/@3F[k40103F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k402@3F[k400`2=Lk40eZna0=J_/@050=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@090=J_/@0308ec/@3F[k40eZna
00D0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna00P0eZna00<0SG>a0=J_/@3F[k401P3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40203F[k400`2=Lk40eZna0=J_
/@060=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@070=J_/@0308ec/@3F[k40eZna00L0eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna00L0eZna00<0SG>a0=J_
/@3F[k401`3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0
oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo
9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k401P3F[k400`2=Lk40eZna0=J_/@080=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@060=J_/@0308ec/@3F
[k40eZna00P0eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o
0?ooobD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?oo
obD0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo003o0?ooobD0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna00D0eZna00<0SG>a0=J_/@3F[k402@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
0?l0oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0
oooo8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo
8`3oool00?l0oooo9@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k40103F[k400`2=Lk40eZna0=J_/@0:0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00``3oool3000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002`0?ooo`8000004@3oool00`000000NUVP07YIX005000005T0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002]0?ooo`<0000000<0Nfjj000000000000
3`3oool00`000000NUVP07YIX00607YIX0<00000EP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:T0oooo1000000507]^^P030000003oool0oooo00d0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1D0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000001jFJ00
NUVP00L0NUVP0P00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00Y`3oool00`000000Nfjj07]^^P0807]^^P8000003P3oool00`000000NUVP07YIX00707YI
X0800000EP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k400`3F[k400`2=Lk40eZna0=J_/@0;0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00Z03oool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000
NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?ooo`3oool0
2`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0
`7T00000003oool02`3oool00`000000NUVP07YIX00707YIX0800000E`3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2
000000`0oooo00<0000007YIX01jFJ001`1jFJ02000005L0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?oo
o`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00
oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:T0oooo00<0000007]^^P1kK[X0
201kK[X00`30N@0000000?ooo`090?ooo`030000001jFJ00NUVP00L0NUVP0P00001H0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00Z@3oool00`000000Nfjj07]^
^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YIX01jFJ001`1jFJ02000005P0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?ooo`030000001kK[X0
Nfjj00L0Nfjj00<0`7T00000003oool0203oool00`000000NUVP07YIX00807YIX0030000003oool0
oooo05L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002Z0?oo
o`030000001kK[X0Nfjj00L0Nfjj0P0000090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?oo
o`3oool0E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:X0
oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`070?ooo`030000001jFJ00NUVP00L0
NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
ZP3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00L0oooo00<0000007YIX01jFJ00
1`1jFJ02000005T0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002[0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00L0NUVP00<0
gKjj0000003oool0F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<0
00000=J_/@3F[k400P3F[k400`2=Lk40eZna0=J_/@0<0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^^P8000001`3oool0
0`000000NUVP07YIX00807YIX0030000003oool0oooo05P0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`3o0?ooob<0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000
003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00:/0oooo00<0000007]^^P1kK[X0201kK[X00`30N@00
00000?ooo`050?ooo`030000001jFJ00NUVP00L0NUVP0P00001J0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0707]^^P800000
1@3oool00`000000NUVP07YIX00807YIX0800000FP3oool00`000000001a0000L@050000L@030000
002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000
003oool0oooo0?l0oooo8`3oool00:`0oooo00<0000007]^^P1kK[X01`1kK[X2000000D0oooo00<0
000007YIX01jFJ00201jFJ000`000000oooo0?ooo`1I0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool0
0`000000NUVP07YIX00707YIX0800000F`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo0?l0oooo8`3oool00:`0oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YI
X01jFJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?oo
ob<0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000001jFJ00NUVP00P0
NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP07YIX00807YIX0030000
003oool0oooo05X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002]0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP0P00
001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[@3oool2
000000T0Nfjj00D0`7T00000003oool0oooo0000000907YIX0800000G03oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00:h0oooo00<0000007]^^P1kK[X01`1kK[X2
000000030?ooo`000000NUVP00T0NUVP0P00001L0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P@00000201jFJ000`3M
_[X000000000001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00[P3oool00`000000Nfjj07]^^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002^0?ooo`8000002@1kK[X3000000T0NUVP
0P00001M0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3o
ool00`000000Nfjj07]^^P0707]^^P800000201jFJ00103M_[X0NUVP0<S7AP00001M0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00[`3oool00`000000Nfjj07]^
^P0707]^^P8000002@1jFJ02000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`3o0?ooob<0oooo002_0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ001`1jFJ02
000005h0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo002_0?oo
o`8000002@1kK[X00`000000NUVP07YIX00707YIX0800000GP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo0?l0oooo8`3oool00;00oooo00<0000007]^^P1kK[X01`1kK[X00`000000
NUVP07YIX00707YIX0030<S7AP000000oooo05d0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`3o0?ooob<0oooo002`0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX01jFJ00
1@1jFJ02000005l0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`3o0?ooob<0oooo
002`0?ooo`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;00oooo0P00000907]^^P030000001jFJ00
NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00/@3oool00`000000Nfjj07]^^P0707]^^P030000001jFJ00NUVP00D0NUVP00<0b<M60000
003oool0GP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40
oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP07YIX00307YIX0<00000G`3oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00@000000=J_/@3F[k40SG>a403F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo0?l0oooo8`3oool00;40oooo0P00000907]^^P06
0000001jFJ00NUVP07YIX03M_[X0NUVP0P00001P0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`2m0?ooo`00/@3oool2000000T0Nfjj00<0000007YI
X01jFJ000`1jFJ0200000600oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab
/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1P0?oo
o`<000006`3oool200000:80oooo002b0?ooo`030000001kK[X0Nfjj00L0Nfjj00<0000007YIX01j
FJ000`1jFJ000`38adH000000?ooo`1O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0G`3oool00`000000QcAL08LdG002000001L0oooo0`0000000`30H5P000000?ooo`2Q0?ooo`00
/P3oool00`000000Nfjj07]^^P0807]^^P040000001jFJ00gKjj07YIX0<00000H03oool00`000000
001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo0P00000308LdG08000004`3oool4000000@0
`61H00<000000?ooo`3oool0X03oool00;80oooo0P00000907]^^P040000001jFJ00NUVP07YIX080
0000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0oooo0P00000508LdG080
00004@3oool2000000P0`61H00<000000?ooo`3oool0X03oool00;80oooo0P00000907]^^P040000
001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05X0
oooo00<0000008LdG027=5`01@27=5`00`000000eYT<0?ooo`0@0?ooo`<000001`30H5P00`000000
oooo0?ooo`2P0?ooo`00/`3oool00`000000Nfjj07]^^P0707]^^P060000003M_[X0NUVP07YIX038
adH00000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0oooo0P00000808Ld
G0030000003FV@`0000000l0oooo00D0000006>;h`1SRn<0Hh_S000000060<1PF0030000003oool0
oooo0:00oooo002c0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0000007YIX00000000P00001Q0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0E`3oool2000000T0QcAL00<000000=JI
300000003`3oool00`000000Hh_S06>;h`0206>;h`0300000030H5P0`61H00<0`61H00<000000?oo
o`3oool0X03oool00;<0oooo0P00000907]^^P040000001jFJ00000000000680oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1G0?ooo`0300000012R^`0000000<000001@27=5`00`00
0000eYT<0000000>0?ooo`030000001SRn<0Hh_S00@0Hh_S0P0000030<1PF0030000003oool0oooo
0:00oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0F03oool00`000000@X[/04::k00204::k0@0000000D0QcAL0000
003FV@`0eYT<0000000=0?ooo`030000001SRn<0Hh_S00H0Hh_S00@000000<1PF030H5P00000XP3o
ool00;@0oooo00<0000007]^^P1kK[X01`1kK[X010000000NUVP0<S7AP00001R0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0F03oool00`000000@X[/04::k00604::k08000000P3F
V@`00`000000oooo0?ooo`0:0?ooo`030000001SRn<0Hh_S00P0Hh_S0`00002R0?ooo`00]03oool0
0`000000Nfjj07]^^P0807]^^P<00000HP3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05P0oooo00<0000004::k012R^`01`12R^`010000000eYT<0=JI3000000<0?ooo`030000001S
Rn<0Hh_S00X0Hh_S00<000000?ooo`3oool0X03oool00:h0oooo8`00001C0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0F@3oool00`000000@X[/04::k00704::k0030000003FV@`0
eYT<00/0oooo00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2P0?ooo`00X03oool>0000
00`0B3^N00<000000?74X`3aa:<0303aa:<?000004`0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1I0?ooo`0300000012R^`0@X[/00L0@X[/00@000000=JI303FV@`000002P3oool0
0`000000Hh_S06>;h`0:06>;h`030000003oool0oooo0:40oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0F@3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<
000000T0oooo00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2Q0?ooo`00X03oool00`00
0000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`00
0000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`00
0000o/ma0?k?L@050?k?L@030000003oool0oooo05T0oooo00<0000004::k012R^`02012R^`00`00
0000eYT<000000090?ooo`030000001SRn<0Hh_S00X0Hh_S00<000000?ooo`3oool0XP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0
oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140
eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1J0?ooo`0300000012R^`0@X[/00L0
@X[/00@000000=JI303FV@`000001`3oool00`000000Hh_S06>;h`0;06>;h`030000003oool0oooo
0:80oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool00`000000
@X[/04::k00704::k0040000003FV@`0eYT<000000L0oooo00<0000006>;h`1SRn<02P1SRn<00`00
0000oooo0?ooo`2S0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05X0
oooo00<0000004::k012R^`02012R^`00`000000eYT<000000060?ooo`030000001SRn<0Hh_S00/0
Hh_S00<000000?ooo`3oool0X`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1K0?ooo`0300000012R^`0@X[/00L0@X[/00<000000=JI300000001P3oool00`000000Hh_S
06>;h`0:06>;h`030000003oool0oooo0:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0F`3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<000000@0oooo
00<0000006>;h`1SRn<02`1SRn<00`000000oooo0?ooo`2T0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo05/0oooo00<0000004::k012R^`01`12R^`010000000eYT<0=JI
300000040?ooo`030000001SRn<0Hh_S00X0Hh_S00<000000?ooo`3oool0Y@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1L0?ooo`0300000012R^`0@X[/00L0@X[/00@0
00000=JI3000000000000P3oool00`000000Hh_S06>;h`0;06>;h`030000003oool0oooo0:D0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0G03oool00`000000@X[/04::
k00704::k0030000003FV@`0000000@00000301SRn<00`000000oooo0?ooo`2V0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo00<0000004::k012R^`01`12R^`0
1@000000eYT<0=JI30000000YTiO00800000301SRn<00`000000oooo0?ooo`2V0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo00<0000004::k012R^`02012R^`0
1@000000eYT<0000002VCUl0000000d0Hh_S00<000000?ooo`3oool0YP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`1M0?ooo`0300000012R^`0@X[/00L0@X[/00<00000
0=JI300000000P00000<06>;h`030000003oool0oooo0:L0oooo002P0?ooo`0300000018>ih0B3^N
01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0G@3oool00`000000@X[/04::k00704::k0040000003FV@`0eYT<
000000d0Hh_S00<000000?ooo`3oool0Y`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`1M0?ooo`0300000012R^`0@X[/00P0@X[/00<000000=JI30000000301SRn<00`00
0000oooo0?ooo`2X0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05h0
oooo00<0000004::k012R^`01`12R^`00`000000eYT<06>;h`0<06>;h`030000003oool0oooo0:P0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0GP3oool00`000000@X[/
04::k00704::k0030000003FV@`0Hh_S00/0Hh_S00<000000?ooo`3oool0Z@3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1M0?ooo`8000002P12R^`00`000000Hh_S06>;
h`0:06>;h`030000003oool0oooo0:T0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0G03oool2000000030:I>G`000000@X[/00P0@X[/00<000000=JI301SRn<02@1SRn<3
00000:X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool20000
00<0YTiO00<0000004::k012R^`01`12R^`00`000000eYT<06>;h`0906>;h`040000002VCUl00000
00000:T0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F@3oool20000
00@0YTiO00<0000004::k012R^`02012R^`00`000000Hh_S06>;h`0706>;h`030000002VCUl0YTiO
0080YTiO0P00002W0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0
oooo0P0000060:I>G`0300000012R^`0@X[/00L0@X[/00<0000006>;h`1SRn<01`1SRn<00`000000
YTiO0:I>G`030:I>G`800000YP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1F0?ooo`<000001`2VCUl00`000000@X[/04::k00704::k0030000003FV@`0Hh_S00L0Hh_S
00<000000:I>G`2VCUl01@2VCUl200000:@0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000E03oool2000000T0YTiO00<0
000004::k012R^`02012R^`00`000000Hh_S06>;h`0506>;h`030000002VCUl0YTiO00L0YTiO0P00
002S0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool;000000T03@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP07
0?o@QP/00000B03oool2000000X0YTiO00<0000004::k012R^`02012R^`00`000000Hh_S06>;h`05
06>;h`030000002VCUl0YTiO00T0YTiO00<000000?ooo`3oool0X03oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0A03oool3000000`0YTiO00<0000004::k012R^`01`12R^`00`000000Hh_S06>;h`0406>;
h`030000002VCUl0YTiO00/0YTiO0P00002P0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`130?ooo`80
00003P2VCUl00`000000@X[/04::k00704::k0030000003FV@`0Hh_S00@0Hh_S00<000000:I>G`2V
CUl0302VCUl2000009l0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0480oooo0P00000?0:I>G`030000
0012R^`0@X[/00P0@X[/00<0000006>;h`1SRn<00P1SRn<00`000000YTiO0:I>G`0?0:I>G`030000
003oool0oooo09`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3a
a:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo0400oooo0P00000B0:I>G`X0@X[/00<0
000006>;h`1SRn<00P1SRn<00`000000YTiO0:I>G`020:I>G`0302MMd@2VCUl0YTiO00/0YTiO0P00
002L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`030000002VCUl0YTiO0180YTiO2P12R^`0
1@000000Hh_S06>;h`1SRn<0000001D0YTiO00<000000?ooo`3oool0V@3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0?`3oool2000001D0YTiO2@12R^`010000000Hh_S06>;h`00000D0:I>G`800000V`3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0?`3oool0100000008e[@00000000000E0:I>G`L0@X[/00<0
000006>;h`0000001@2VCUl00`0WGM40YTiO0:I>G`0;0:I>G`80000000<0h_g:0000003oool0VP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0?`3oool01@0000008e[@02=Jd00SF]00000001H0YTiO00<0
000004::k012R^`00P12R^`00`000000Hh_S0000000B0:I>G`050000003RoLX0h_g:0>;mbP000000
V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=Jd00202=Jd0030000002V
CUl0YTiO01D0YTiO00D0000004::k012R^`0@X[/0000000B0:I>G`030000003RoLX0h_g:0080h_g:
00<000000?ooo`3oool0V@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=J
d00302=Jd08000006@2VCUl00`000000YTiO0:I>G`0?0:I>G`030000003RoLX0h_g:00<0h_g:00<0
00000?ooo`3oool0V@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?`3oool00`0000008e[@02=Jd005
02=Jd0030000002VCUl0YTiO02L0YTiO00<000000>;mbP3RoLX00`3RoLX00`000000oooo0?ooo`2J
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0o0?ooo`030000000SF]008e[@00H08e[@0P00000K0:I>
G`0302MMd@2VCUl0YTiO00L0YTiO0P0000060>;mbP030000003oool0oooo09X0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03h0oooo00<0000002=Jd00SF]002@0SF]000`000000YTiO0:I>G`0Q0:I>G`03
0000003RoLX0h_g:00H0h_g:00<000000?ooo`3oool0VP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
?P3oool00`0000008e[@02=Jd00:02=Jd0030000002VCUl0YTiO01l0YTiO00<000000>;mbP3RoLX0
1`3RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000S
F]008e[@00/08e[@0P00000F0:I>G`0302MMd@2VCUl0YTiO00D0YTiO00<000000>;mbP3RoLX0203R
oLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0
lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]00
8e[@00d08e[@00<000000:I>G`2VCUl06P2VCUl00`000000h_g:0>;mbP090>;mbP030000003oool0
oooo09X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`00
0000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo03h0oooo00<0000002=Jd00SF]003P0SF]000`00
0000YTiO0:I>G`0G0:I>G`800000303RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0n0?ooo`030000000SF]008e[@00l08e[@0P00000A0:I>G`0302MMd@2VCUl0YTiO0080
YTiO00<000000>;mbP3RoLX0303RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0n0?ooo`030000000SF]008e[@01408e[@00<000000:I>G`2VCUl04P2VCUl00`000000h_g:
0>;mbP0=0>;mbP030000003oool0oooo09X0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03h0oooo00<0
000002=Jd00SF]004P0SF]0200000140YTiO00<000000>;mbP3RoLX03P3RoLX00`000000oooo0?oo
o`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<00000
0?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]008e[@01@08e[@00<00000
0:I>G`2VCUl02P2VCUl0100WGM40YTiO0:I>G`00000A0>;mbP030000003oool0oooo09X0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03h0oooo00<0000002=Jd00SF]005@0SF]000`000000YTiO0:I>G`0:
0:I>G`8000004P3RoLX00`000000oooo0?ooo`2J0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0n0?oo
o`030000000SF]008e[@01H08e[@0P0000090:I>G`030000003RoLX0h_g:0140h_g:00<000000?oo
o`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0?P3oool00`0000008e[@02=Jd00H02=Jd003
0000002VCUl0YTiO00D0YTiO00<000000>;mbP3RoLX04P3RoLX00`000000oooo0?ooo`2K0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0n0?ooo`030000000SF]008e[@01T08e[@00<000000:I>G`2VCUl0
0`2VCUl00`000000h_g:0>;mbP0C0>;mbP030000003oool0oooo09/0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03h0oooo00<0000002=Jd00SF]006P0SF]02000000030:I>G`000000000001H0h_g:00<0
00000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?P3oool00`0000008e[@02=Jd00L
02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0?P3oool00`0000008e[@02=Jd00L02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?oo
o`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00M02=Jd003
0000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
?@3oool00`0000008e[@02=Jd00M02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0
V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00M02=Jd0030000003R
oLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0?@3oool0
0`0000008e[@02=Jd00M02=Jd0030000003RoLX0h_g:01H0h_g:00<000000?ooo`3oool0V`3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0?@3oool00`0000008e[@02=Jd00L02=Jd0800000603RoLX00`00
0000oooo0?ooo`2K0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`0
8e[@00<000000>;mbP3RoLX05`3RoLX00`000000oooo0?ooo`2K0?ooo`00X03oool00`000000B3^N
04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo
0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<0
00000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<0
00000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m
0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L
0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?oo
o`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;m
bP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP03
0000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`03
0000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX0
5P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003a
a:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000S
F]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool0
0`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool0
0`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H0
0`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX0
0`000000oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d
02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0m0?ooo`030000000SF]008e[@
01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2L0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0m0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000
oooo0?ooo`2L0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0l0?ooo`030000000SF]008e[@01`08e[@
0P00000H0>;mbP030000003oool0oooo09`0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<0
00000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<0
00000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0
000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0G0>;mbP030000003oool0oooo09`0oooo002P
0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F
0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=J
d00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP03
0000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00
700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003o
ool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo7`0SF]000`000000h_g:0>;mbP0F
0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=J
d00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP03
0000003oool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP03
0000003oool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<0
6P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]00
700SF]000`000000h_g:0>;mbP0F0>;mbP030000003oool0oooo09d0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo03`0oooo00<0000002=Jd00SF]00700SF]000`000000h_g:0>;mbP0F0>;mbP030000003o
ool0oooo09d0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<0
0`000000oooo0?ooo`0l0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo03`0oooo00<0000002=Jd00SF]006`0SF]02
000001P0h_g:00<000000?ooo`3oool0W@3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
00008e[@02=Jd00L02=Jd08000005`3RoLX00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000
B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`000000
3@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000
oooo0?ooo`0k0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000
oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0k0?ooo`030000000SF]008e[@01`08e[@
00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0?03oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0k0?ooo`030000000SF]008e[@01`08e[@00<000000>;mbP3RoLX05P3RoLX00`000000oooo0?oo
o`2N0?ooo`00X03oool00`000000B3^N04PkWP0404PkWRP00000203aa:<00`000000oooo0?ooo`0l
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo03/0oooo00<0000002=Jd00SF]002@0SF]0?000000@08e[@00@00000
0>;mbP3RoLX0h_g:4@0000040>;mbP030000003oool0oooo09h0oooo002C0?oooa@000004P17>Yh0
0`000000lLFS0?75X`0C0?75XaL00000<03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oooaT00000401EAJ<3
02=Jd0030000003RoLX0h_g:00l0mLRN5@00002C0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02P0EDFS00<08e[@0000003RoLX0903eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02P0EDFS00<08e[@0000003e
b9h0903eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0
]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0
EDFS02L0EDFS00<08e[@05E5X`0000009@3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`00
00003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`00
0000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0
]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02H0EDFS00@08e[@05E5X`1EAJ<000009@3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d
00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;
QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?oo
o`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<00000
0?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02D0EDFS00D08e[@
05E5X`1EAJ<0EDFS0000000R0?G8WP0405Q8Y03eb9h0mLRN000009<0oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=
2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003o
ool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0901EAJ<00`0SF]00
EDFS05E5X`0205E5X`030000003eb9h0mLRN01l0mLRN00D0F4RT0?G8WP3eb9h0mLRN0000002C0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02<0EDFS00<0000005E5X`1EAJ<00`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0N0?G8WP0305Q8Y03eb9h0
mLRN0080mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0R05E5X`030?C7X01EAJ<0EDFS00@0
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^6
00d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo
0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<0
00000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h07@3eb9h00`1HB:@0mLRN0?G8WP030?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^
0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A
0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<08@1EAJ<00`3daj00EDFS05E5X`05
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN01`0mLRN00<0F4RT0?G8WP3eb9h0
103eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002d
Tk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001E
AJ<0EDFS0200EDFS00<0m<NP05E5X`1EAJ<01P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@0
0`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^6
01403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo
02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000
oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000
om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<07`1EAJ<00`3daj00
EDFS05E5X`0705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0N05E5X`030?C7X01EAJ<0EDFS00P0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?oo
o`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?ooo`3o
ool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3o
d8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000
002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000
001EAJ<0EDFS01d0EDFS00<0m<NP05E5X`1EAJ<02@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02d
Tk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH0
3@^601403@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0
oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0:@1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^60140
3@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0
oooo00<0000005E5X`1EAJ<0701EAJ<00`3daj00EDFS05E5X`0:05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0K
05E5X`030?C7X01EAJ<0EDFS00/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000?oo
o`3oool0;P3oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@
QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8
WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP03
0000003aaJ<0lLFS02T0lLFS00<000000?ooo`3oool0;P3oool00`0000003@^600d;QP0A00d;QP03
0000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H00`000000oooo0?ooo`0^0?ooo`03
0000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h05`3eb9h00`1HB:@0mLRN0?G8WP090?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000oooo0?ooo`0^0?ooo`030000000=2hH03@^601403@^600<000000;BC]02dTk@0
:02dTk@00`000000om260?o@QP0A0?o@QP030000003oool0oooo02h0oooo00<0000005E5X`1EAJ<0
6P1EAJ<00`3daj00EDFS05E5X`0<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02l000004`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26;`00
00020?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS=000000A
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3od8H9000000P01@008@00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d
02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2000002/0EDFS00<000000?G8WP3eb9h05P3eb9h0
0`1HB:@0mLRN0?G8WP0:0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC
]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26@02]I7/2
000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<000000;BC
]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260440
[FAk0P00000[05E5X`030000003eb9h0mLRN01D0mLRN00<0F4RT0?G8WP3eb9h02`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`000000om260?o@QP110:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440[FAk0P0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000I
05E5X`030?C7X01EAJ<0EDFS00l0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000120:eT
N`0300d;QP000000]9>d02T0]9>d00<000000?o@QP2]I7/0@@2]I7/2000002/0EDFS00<000000?G8
WP3eb9h0503eb9h00`1HB:@0mLRN0?G8WP0<0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000480[FAk00<03@^60000002d
Tk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<200000480[FAk00<03@^60000002dTk@0:@2dTk@00`000000[FAk0:eTN`110:eTN`800000
601EAJ<00`3daj00EDFS05E5X`0@05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC
]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000
]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000
/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000E05E5X`030?C7X01EAJ<0EDFS01<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00
002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000001@0EDFS00<0m<NP05E5
X`1EAJ<0501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2a0:eTN`80
0000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1M0:eTN`030:jf
g`2]I7/0[FAk0580[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3a
aJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3e
b9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0
lLFS02T0lLFS00<000000:eTN`2]I7/0I02]I7/00`2^]]l0[FAk0:eTN`1;0:eTN`030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1_0:eTN`030:jfg`2]I7/0[FAk0400[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h03P3eb9h00`1HB:@0mLRN0?G8WP0B0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1f
0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS00l0EDFS00<0m<NP05E5
X`1EAJ<05`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`03
00000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`1m0:eTN`03
0:jfg`2]I7/0[FAk0380[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h0
3@3eb9h00`1HB:@0mLRN0?G8WP0C0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`240:eTN`030:jfg`2]
I7/0[FAk02/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<0
0`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0R`2]I7/00`2^]]l0[FAk0:eTN`0T0:eTN`030000001EAJ<0EDFS
02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<02`1E
AJ<00`3daj00EDFS05E5X`0K05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fh
h@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<00000
0:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80
[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04`3aaJ<G00000;@0[KSQ
6`00000A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0[VEl00<000000:fhh@2]^>40/P2]
^>400`000000[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0180lLFS5`2^IG`0
0`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl501EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05@2^IG`D05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<000000:fhh@2]^>40/P2]^>400`000000
[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0140lLFS602^IG`00`000000[KSQ
0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000
003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0403a
aJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^IG`05`2^IG`B05E5X`030000003e
b9h0mLRN00D0mLRN00<0F4RT0?G8WP3eb9h06`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6P2^IG`200000;80[KSQ0P00000J
0:iUO140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00l0lLFS6P2^IG`200000;80[KSQ0P00000J0:iU
O140EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000
AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00h0lLFS6`2^IG`200000;80[KSQ0P00000K0:iUO100
EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN
04LjWP0S04LjWP030000003aaJ<0lLFS00h0lLFS6`2^IG`200000;80[KSQ0P00000K0:iUO100EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00d0lLFS702^IG`200000;80[KSQ0P00000L0:iUO0l0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS00d0lLFS702^IG`200000;80[KSQ0P00000M0:iUO0h0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00`0lLFS0P2^IG`00`3aaJ<0[VEl0:iUO00I0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0702^IG`>05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0;0?75X`@0
[VEl00<0lLFS0:iUO02^IG`0602^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01d0
[VEl3@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<50:iUO0030?75X`2^IG`0[VEl01L0[VEl
00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M0:iUO0d0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00X0lLFS1`2^IG`00`3aaJ<0[VEl0:iUO00F0:iUO0030000002]^>40[KSQ0;00[KSQ00<0
00000:iUO02^IG`07P2^IG`<05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`090?75X`T0[VEl00<0lLFS
0:iUO02^IG`05@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl01l0[VEl2`1EAJ<0
0`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN
02<0AcZN00<000000?75X`3aaJ<02@3aaJ<Q0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iU
O02^IG`07`2^IG`;05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`080?75X`d0[VEl00<0lLFS0:iUO02^
IG`04P2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0200[VEl2P1EAJ<00`000000
mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN
00<000000?75X`3aaJ<0203aaJ<>0:iUO0030?75X`2^IG`0[VEl0140[VEl00<000000:fhh@2]^>40
/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00L0lLFS402^
IG`00`3aaJ<0[VEl0:iUO00@0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`08@2^
IG`905E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`060?75Xa80[VEl00<0lLFS0:iUO02^IG`03`2^IG`0
0`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0280[VEl201EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<01P3aaJ<T0:iUO0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`01@2^IG`00`1E
AJ<0[VEl0:iUO00J0:iUO0P0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?oo
o`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00D0lLFS9@2^IG`00`000000
[KSQ0:fhh@0b0:fhh@030;^I1P2]^>40[KSQ04H0[KSQ00<000000:fhh@2]^>40<P2]^>400`000000
[VEl0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00D0lLFS5`2^IG`00`3aaJ<0[VEl
0:iUO0100:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl
0:iUO00S0:iUO0L0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00@0lLFS6@2^IG`00`3aaJ<0[VEl0:iU
O00o0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iU
O00=0:iUO00305E5X`2^IG`0[VEl01@0[VEl1P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00`3aaJ<K
0:iUO0030?75X`2^IG`0[VEl0300[VEl00<0[KSQ0:iUO02^IG`02`2^IG`00`2kV@H0[KSQ0:fhh@16
0:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09@2^IG`505E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`030?75Xe`0[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iU
O0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iUO003
0;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00E0:iUO003
05E5X`2^IG`0[VEl00h0[VEl101EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<00P3aaJ=M0:iUO0030;^I
1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00V0:iUO0@0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP040000003aaJ<0lLFS0?75Xb80[VEl00<0lLFS0:iUO02^IG`0>@2^IG`00`2kV@H0[KSQ
0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09`2^IG`305E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0T0:iUO0030?75X`2^IG`0[VEl0340[VEl00<0[KSQ0:iUO02^IG`0102^
IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^
IG`205E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`1O0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<00000
0:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00X0:iUO080EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool7000001l0AcZN00<000000?75X`2^IG`0G`2^IG`00`2k
V@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:@2^IG`00`1E
AJ<000000?G8WP0N0?G8WPL00000T`3oool009X0oooo3000000C04LjWP030000003aaJ<0[VEl05l0
[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0
[VEl00<0EDFS0000003eb9h04P3eb9h<000009X0oooo002V0?ooo`d000001P17>Yh00`000000[VEl
0:iUO01O0:iUO0030;^I1P000000000004L00000=02^IG`00`000000[VEl0:iUO00Z0:iUO0030000
003eb9h0mLRN00@0mLRN3@00002V0?ooo`00/`3ooomZ000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000000001W00000;<0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>
0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`07
0?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g
0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]
^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP03
0000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000
000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000
003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3o
ool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P00
0000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82
000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P0:fhhP030000003oool0
oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
00`0oooo00<000060000002]^>80H02]^>800`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000
[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180
]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600
[KSR00<000000?ooo`3oool0]`3oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo
00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om27
00<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo
002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700H040f700<0
om290000002dTk@04`2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<0
00060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N
0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<00000
0?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`03
0000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]
^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0
^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80
[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>80
0`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0
oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo
0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<00000
0:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01@0@3HL00`3od8T040f70000000D
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O
0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?oo
o`030000000@3HL040f700D040f700<0om29010=Q`000000502dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?oo
o`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;/0oooo00<000000:fhhP2]^>80G@2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo
0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR
0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05h0[KSR
00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fhhP030000003oool0oooo0;T0oooo002k
0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`800000G`2]^>800`000000oooo0?ooo`2i0?oo
o`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`04010=Q`04
0?o@R@0@3HL040f7000001@0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?oo
o`800000G`2]^>800`000000oooo0?ooo`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP03
0000003oool0oooo00d0oooo00<00000010=Q`0@3HL0100@3HL0103od8T040f7010=Q`00000D0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3oool00`000000[KSR0:fhhP1M0:fh
hP030000003oool0oooo0;T0oooo002k0?ooof4000003`3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0=0?ooof40
0000^`3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool0
0?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700<040f700D0om29010=Q`0@3HL040f70000000D
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700<040f700D0om29010=Q`0@3HL040f70000000D0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00<040f700D0om29010=Q`0@3HL040f70000000D0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`020?o@Q`0301@@R@3od8L0om270080om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?oo
obX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL00P0@3HL00`3od8T040f7010=Q`02010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0050000003od8L0om270?o@
Q`0D48T01@3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00D00000010=Q`0@3HL040f70?o@
R@05010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00D00000010=Q`0@3HL040f70?o@R@05010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00D00000010=Q`0@3HL040f70?o@R@05010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00D00000
010=Q`0@3HL040f70?o@R@05010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00D00000010=Q`0@3HL040f70?o@
R@05010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@010000000om270?o@Q`0D48T60?o@Q`030000
003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002d
Tk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o
0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0
om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f7
00L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00@00000010=Q`0@3HL0om291P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`040000000@3HL040f70?o@
R@H040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo
0?l0oooo:P3oool00?l0oooo;03oool01000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`0D
48T01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`3od8T01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00k@3ooolo00000003010=Q`00000040f700H040f700<000000;BC]02dTk@04P2dTk@00`000000
om270?o@Q`070?o@Qcl00000k@3oool00>d0oooo00<0000008<51P231@H0?0231@H00`0@3HL0P`D6
010=Q`06010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01P3od8Lo08<51P030000
003oool0oooo0>/0oooo003]0?ooo`03000000231@H0P`D603d0P`D6200@3HL00`000000]9>d0;BC
]00B0;BC]0030000003od8L0om2700D0om27@0231@H00`000000oooo0?ooo`3[0?ooo`00k@3oool0
0`000000P`D608<51P0n08<51PL040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`04
0?o@Qd40P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H0?`231@H6010=
Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00`3od8M208<51P030000003oool0oooo
0>/0oooo003/0?ooo`03000000231@H0P`D60480P`D6100@3HL00`000000]9>d0;BC]00B0;BC]003
0000003od8L0om270080om27@`231@H00`000000oooo0?ooo`3[0?ooo`00k03oool00`000000P`D6
08<51P1308<51P<040f700<000000;BC]02dTk@04P2dTk@010000000om270?o@Q`3od8M508<51P03
0000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D604@0P`D60P0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2704H0P`D600<000000?ooo`3oool0jP3oool00>`0oooo00<0
000008<51P231@H0A@231@H00`0@3HL000000;BC]00C0;BC]0030000003od8L0P`D604H0P`D600<0
00000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0AP231@H00`000000]9>d0;BC]00B
0;BC]003000000231@H0P`D604H0P`D600<000000?ooo`3oool0jP3oool00>`0ooooZ000003/0?oo
o`00k03oool00`000000/G>>0;5cSP2T0;5cSP@00000j@3oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh01@000000bf110<]P@@3;H44000000>P0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>
00D000000<]P@@3;H440bf110000003X0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000
003;H440bf110080bf1100<000000?ooo`3oool0i@3oool00>`0oooo00<000000;5cSP2aLhh0Y02a
Lhh00`000000bf110<]P@@030<]P@@030000003oool0oooo0>@0oooo003/0?ooo`030000002aLhh0
/G>>0:@0/G>>00<000000<]P@@3;H4400`3;H4400`000000oooo0?ooo`3T0?ooo`00k03oool00`00
0000/G>>0;5cSP2T0;5cSP030000003;H440bf1100@0bf1100<000000?ooo`3oool0h`3oool00>`0
oooo00<000000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@040<]P@@030000003oool0oooo0><0
oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<]P@@3;H4401@3;H4400`000000oooo
0?ooo`3R0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003;H440bf1100D0bf1100<0
00000?ooo`3oool0hP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000bf110<]P@@06
0<]P@@030000003oool0oooo0>40oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000<]P
@@3;H4401`3;H4400`000000oooo0?ooo`3P0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP03
0000003;H440bf1100L0bf1100<000000?ooo`3oool0h03oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh00`000000bf110<]P@@080<]P@@030000003oool0oooo0=l0oooo003/0?ooo`030000002a
Lhh0/G>>0:@0/G>>00<000000<]P@@3;H4402@3;H47Q0?ooo`00k03oool00`000000/G>>0;5cSP2T
0;5cSP030000003;H440bf1100<0bf111`00003P0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5c
SPH000001@35mnd00`000000oooo0?ooo`3O0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP03
00000035mnd0aOO]00L0aOO]00<000000?ooo`3oool0h03oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh00`000000aOO]0<Ggk@070<Ggk@030000003oool0oooo0>00oooo003/0?ooo`030000002a
Lhh0/G>>0:@0/G>>00<000000<Ggk@35mnd01P35mnd00`000000oooo0?ooo`3Q0?ooo`00k03ooonX
000000L0aOO]00<000000?ooo`3oool0hP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`00
0000aOO]0<Ggk@040<Ggk@030000003oool0oooo0><0oooo003/0?ooo`030000002`/=L0/;3G0:@0
/;3G00<000000<Ggk@35mnd01035mnd00`000000oooo0?ooo`3S0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`0300000035mnd0aOO]00<0aOO]00<000000?ooo`3oool0i03oool00>`0oooo00<0
00000;2`e`2`/=L0Y02`/=L00`000000aOO]0<Ggk@020<Ggk@030000003oool0oooo0>D0oooo003/
0?ooo`030000002`/=L0/;3G0:@0/;3G00D000000<Ggk@35mnd0aOO]0000003X0?ooo`00k03oool0
0`000000/;3G0;2`e`2T0;2`e`0500000035mnd0aOO]0<Ggk@000000j03oool00>`0oooo00<00000
0;2`e`2`/=L0Y02`/=L400000>T0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?oo
o`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`
/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L0
0`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo
0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo
00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`
e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<00000
0?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?oo
o`00k03ooonX00000>`0oooo003/0?ooo`030000001Fb?D0E/Se0:@0E/Se00<000000?ooo`3oool0
jP3oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00k@3oool0
0`000000E/Se05K8m@2R05K8m@030000003oool0oooo0>/0oooo003]0?ooo`030000001Fb?D0E/Se
0:80E/Se00<000000?ooo`3oool0j`3oool00>d0ooooYP00003]0?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00001\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.4 1.8 1.11022e-016 1.8 [
[ 0 0 0 0 ]
[ 1 1.8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.8 L
0 1.8 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57964 .42914 m .52684 .43084 L .52684 .4259 L p .635 .519 .704 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L .57964 .42914 L p .635 .519 .704 r
F P
0 g
s
.64046 .2356 m .6404 .24848 L .6202 .24848 L p .706 .605 .74 r
F P
0 g
s
.6404 .24848 m .64046 .26081 L .62025 .26081 L p .706 .548 .671 r
F P
0 g
s
.62025 .26081 m .6202 .24848 L .6404 .24848 L p .706 .548 .671 r
F P
0 g
s
.64046 .26081 m .64064 .27207 L .62041 .27207 L p .698 .477 .584 r
F P
0 g
s
.62041 .27207 m .62025 .26081 L .64046 .26081 L p .698 .477 .584 r
F P
0 g
s
.66736 .41123 m .63073 .41357 L .63073 .28045 L p .561 .458 .694 r
F P
0 g
s
.63101 .28056 m .66736 .41123 L .63073 .28045 L .561 .458 .694 r
F
.64093 .2818 m .64105 .28428 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64064 .27207 m .64093 .2818 L .63436 .2818 L p .676 .382 .468 r
F P
0 g
s
.62835 .27805 m .64064 .27207 L .63947 .27389 L .676 .382 .468 r
F
.63073 .27953 m .63947 .27389 L .63436 .2818 L F
.62835 .27805 m .63947 .27389 L .63073 .27953 L F
.6202 .24848 m .62025 .2356 L .64046 .2356 L p .706 .605 .74 r
F P
0 g
s
.62025 .26081 m .6202 .24848 L .62025 .2356 L p 0 0 .058 r
F P
0 g
s
.64064 .22269 m .64046 .2356 L .62025 .2356 L p .7 .653 .8 r
F P
0 g
s
.62025 .2356 m .62041 .22269 L .64064 .22269 L p .7 .653 .8 r
F P
0 g
s
.62025 .2356 m .62041 .22269 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62041 .27207 m .64064 .27207 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62065 .2818 m .62043 .27311 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62043 .27311 m .62041 .27207 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.64046 .26081 m .6404 .24848 L .64046 .2356 L p 0 0 .068 r
F P
0 g
s
.64046 .2356 m .64064 .22269 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64093 .2818 m .64064 .27207 L .64046 .26081 L p 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64105 .28068 L .64093 .2818 L 0 0 .068 r
F
.66736 .30238 m .66736 .41123 L p .64105 .29283 L .561 .458 .694 r
F P
0 g
s
.63929 .28487 m .64105 .28597 L .64105 .29283 L .561 .458 .694 r
F
.64105 .28597 m .66736 .30238 L .64105 .29283 L F
.64046 .26081 m .64105 .27605 L .64105 .28068 L 0 0 .068 r
F
.64105 .28428 m .64093 .2818 L p .64105 .28068 L F P
0 g
s
.64046 .26081 m .64105 .27259 L .64105 .27605 L 0 0 .068 r
F
.64105 .26215 m .66736 .30238 L .64105 .28597 L .561 .458 .694 r
F
.64291 .29822 m .64233 .29799 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.6435 .29571 m .64291 .29822 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64409 .29053 m .6435 .29571 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64465 .28287 m .64409 .29053 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64514 .27307 m .64465 .28287 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.66736 .24321 m .66736 .30238 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64105 .24547 m .66736 .24321 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64046 .26081 m .64542 .26151 L .64514 .27307 L 0 0 .068 r
F
.63929 .28487 m .66736 .41123 L .63101 .28056 L .561 .458 .694 r
F
.63436 .2818 m .63101 .28056 L .63073 .27953 L F
.63929 .28487 m .63101 .28056 L .63436 .2818 L F
.62025 .26081 m .62076 .28068 L .62065 .2818 L 0 0 .058 r
F
.62076 .28597 m .62722 .2818 L .62076 .36555 L .831 .679 .694 r
F
.62076 .36555 m .62722 .2818 L .63073 .41357 L F
.63073 .28045 m .63073 .41357 L p .62722 .2818 L F P
0 g
s
.62076 .28428 m .62065 .2818 L .62722 .2818 L p .628 .248 .303 r
F P
0 g
s
.63073 .27953 m .63073 .28045 L p .62722 .2818 L .831 .679 .694 r
F P
0 g
s
.63073 .28045 m .63073 .27953 L p .63101 .28056 L .561 .458 .694 r
F P
0 g
s
.63436 .2818 m .62065 .2818 L p .62835 .27805 L .676 .382 .468 r
F P
0 g
s
.62076 .28428 m .62065 .2818 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.62065 .2818 m .62041 .27207 L .62025 .26081 L p 0 0 .058 r
F P
0 g
s
.62076 .2693 m .63073 .27953 L .62076 .28597 L .831 .679 .694 r
F
.62098 .28958 m .62076 .28428 L p .62085 .28426 L .628 .248 .303 r
F P
0 g
s
.6212 .28945 m .62103 .28423 L p .63436 .2818 L .628 .248 .303 r
F P
0 g
s
.62722 .2818 m .63436 .2818 L p .62076 .28428 L .628 .248 .303 r
F P
0 g
s
.63436 .2818 m .64093 .2818 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.63073 .27953 m .63073 .24636 L p .63898 .28351 L .561 .458 .694 r
F P
0 g
s
.63898 .28351 m .63929 .28487 L .63436 .2818 L .561 .458 .694 r
F
.63898 .28351 m .63436 .2818 L .63073 .27953 L F
.62098 .28958 m .63436 .2818 L .63773 .28305 L .628 .248 .303 r
F
.63073 .24636 m .63073 .27953 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.62025 .26081 m .62076 .27605 L .62076 .28068 L 0 0 .058 r
F
.64132 .28958 m .62098 .28958 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64132 .28958 m .64179 .29506 L .62139 .29506 L p .528 .047 .057 r
F P
0 g
s
.62139 .29506 m .62098 .28958 L .64132 .28958 L p .528 .047 .057 r
F P
0 g
s
.62185 .29799 m .62139 .29506 L .64179 .29506 L p .33 0 0 r
F P
0 g
s
.62185 .29799 m .62139 .29506 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.64179 .29506 m .64233 .29799 L .62185 .29799 L p .33 0 0 r
F P
0 g
s
.62234 .29822 m .62185 .29799 L .64233 .29799 L p .027 0 0 r
F P
0 g
s
.62234 .29822 m .62185 .29799 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62076 .24547 m .63073 .24636 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.62285 .29571 m .62234 .29822 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62336 .29053 m .62285 .29571 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62383 .28287 m .62336 .29053 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62426 .27307 m .62383 .28287 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62025 .26081 m .6245 .26151 L .62426 .27307 L 0 0 .058 r
F
.64105 .24547 m .66736 .24321 L p .64154 .24321 L .289 .763 .934 r
F P
0 g
s
.6435 .1725 m .64409 .17222 L p .6411 .24525 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64098 .24581 L .6411 .24525 L 0 0 .068 r
F
.64098 .24581 m .6435 .1725 L .6411 .24525 L F
.66736 .24321 m .64203 .24094 L .64154 .24321 L .289 .763 .934 r
F
.64514 .17995 m .64555 .18767 L p .64176 .2422 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64146 .24358 L .64176 .2422 L 0 0 .068 r
F
.64146 .24358 m .64514 .17995 L .64176 .2422 L F
.66736 .24321 m .64273 .23769 L .64203 .24094 L .289 .763 .934 r
F
.64555 .18767 m .64586 .19756 L p .64224 .23995 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64176 .2422 L .64224 .23995 L 0 0 .068 r
F
.64176 .2422 m .64555 .18767 L .64224 .23995 L F
.66736 .24321 m .64445 .22973 L .64273 .23769 L .289 .763 .934 r
F
.64586 .19756 m .64605 .20917 L p .6432 .23549 L 0 0 .068 r
F P
0 g
s
.64046 .26081 m .64224 .23995 L .6432 .23549 L 0 0 .068 r
F
.64224 .23995 m .64586 .19756 L .6432 .23549 L F
.67134 .22759 m .64542 .22521 L p .66736 .24321 L .289 .763 .934 r
F P
0 g
s
.64605 .20917 m .64612 .22197 L p .6432 .23549 L 0 0 .068 r
F P
0 g
s
.64465 .17473 m .64514 .17995 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64409 .17222 m .64465 .17473 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64291 .17553 m .6435 .1725 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64233 .18113 m .64291 .17553 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64179 .18905 m .64233 .18113 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64132 .19891 m .64179 .18905 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64093 .21029 m .64132 .19891 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64064 .22269 m .64093 .21029 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64542 .22521 m .63515 .22426 L p .64445 .22973 L .289 .763 .934 r
F P
0 g
s
.66736 .24321 m .64542 .22521 L .64445 .22973 L .289 .763 .934 r
F
.63515 .22426 m .6245 .22521 L p .64273 .23769 L F P
0 g
s
.64273 .23769 m .6245 .22521 L .62301 .23328 L .289 .763 .934 r
F
.64093 .21029 m .64064 .22269 L .62041 .22269 L p .687 .697 .853 r
F P
0 g
s
.62041 .22269 m .62065 .21029 L .64093 .21029 L p .687 .697 .853 r
F P
0 g
s
.64132 .19891 m .64093 .21029 L .62065 .21029 L p .667 .737 .902 r
F P
0 g
s
.62504 .20917 m .62509 .22197 L p .6226 .23549 L 0 0 .058 r
F P
0 g
s
.62065 .21029 m .62098 .19891 L .64132 .19891 L p .667 .737 .902 r
F P
0 g
s
.64179 .18905 m .64132 .19891 L .62098 .19891 L p .634 .774 .948 r
F P
0 g
s
.62178 .23995 m .62487 .19756 L .6226 .23549 L 0 0 .058 r
F
.62098 .19891 m .62139 .18905 L .64179 .18905 L p .634 .774 .948 r
F P
0 g
s
.64233 .18113 m .64179 .18905 L .62139 .18905 L p .579 .804 .985 r
F P
0 g
s
.62139 .18905 m .62185 .18113 L .64233 .18113 L p .579 .804 .985 r
F P
0 g
s
.62461 .18767 m .62487 .19756 L p .62178 .23995 L 0 0 .058 r
F P
0 g
s
.62136 .2422 m .62461 .18767 L .62178 .23995 L 0 0 .058 r
F
.64291 .17553 m .64233 .18113 L .62185 .18113 L p .483 .816 .999 r
F P
0 g
s
.62185 .18113 m .62234 .17553 L .64291 .17553 L p .483 .816 .999 r
F P
0 g
s
.62111 .24358 m .62426 .17995 L .62136 .2422 L 0 0 .058 r
F
.6435 .1725 m .64291 .17553 L .62234 .17553 L p .311 .772 .946 r
F P
0 g
s
.62234 .17553 m .62285 .1725 L .6435 .1725 L p .311 .772 .946 r
F P
0 g
s
.62383 .17473 m .62426 .17995 L p .62111 .24358 L 0 0 .058 r
F P
0 g
s
.62093 .24454 m .62383 .17473 L .62111 .24358 L 0 0 .058 r
F
.63073 .24636 m .64105 .24547 L p .62094 .24447 L .289 .763 .934 r
F P
0 g
s
.64409 .17222 m .6435 .1725 L .62285 .1725 L p .033 .603 .739 r
F P
0 g
s
.62285 .1725 m .62336 .17222 L .64409 .17222 L p .033 .603 .739 r
F P
0 g
s
.62336 .17222 m .62383 .17473 L p .62093 .24454 L 0 0 .058 r
F P
0 g
s
.6208 .24525 m .62336 .17222 L .62093 .24454 L 0 0 .058 r
F
.62076 .24547 m .63073 .24636 L p .62094 .24447 L .289 .763 .934 r
F P
0 g
s
.62285 .1725 m .62336 .17222 L p .6208 .24525 L 0 0 .058 r
F P
0 g
s
.62025 .26081 m .6207 .24581 L .6208 .24525 L 0 0 .058 r
F
.6207 .24581 m .62285 .1725 L .6208 .24525 L F
.64154 .24321 m .62118 .24321 L .64105 .24547 L .289 .763 .934 r
F
.62234 .17553 m .62285 .1725 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62185 .18113 m .62234 .17553 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62139 .18905 m .62185 .18113 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62098 .19891 m .62139 .18905 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62065 .21029 m .62098 .19891 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62041 .22269 m .62065 .21029 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62118 .24321 m .59536 .24321 L .62094 .24447 L .289 .763 .934 r
F
.62118 .24321 m .62094 .24447 L .64105 .24547 L F
.59536 .24321 m .62076 .24547 L p .62094 .24447 L F P
0 g
s
.62025 .26081 m .6208 .24525 L .62093 .24454 L 0 0 .058 r
F
.62025 .26081 m .62093 .24454 L .62111 .24358 L F
.64203 .24094 m .62193 .23913 L .64154 .24321 L .289 .763 .934 r
F
.62426 .17995 m .62461 .18767 L p .62136 .2422 L 0 0 .058 r
F P
0 g
s
.62193 .23913 m .58139 .23549 L .62165 .24066 L .289 .763 .934 r
F
.62193 .23913 m .62165 .24066 L .64154 .24321 L F
.58139 .23549 m .59536 .24321 L p .62118 .24321 L F P
0 g
s
.64154 .24321 m .62165 .24066 L .62118 .24321 L .289 .763 .934 r
F
.62165 .24066 m .58139 .23549 L .62118 .24321 L F
.62025 .26081 m .62111 .24358 L .62136 .2422 L 0 0 .058 r
F
.62025 .26081 m .62136 .2422 L .62178 .23995 L F
.64273 .23769 m .62301 .23328 L .64203 .24094 L .289 .763 .934 r
F
.62487 .19756 m .62504 .20917 L p .6226 .23549 L 0 0 .058 r
F P
0 g
s
.62301 .23328 m .59762 .22759 L .62267 .23512 L .289 .763 .934 r
F
.62301 .23328 m .62267 .23512 L .64203 .24094 L F
.59762 .22759 m .58139 .23549 L p .62193 .23913 L F P
0 g
s
.64203 .24094 m .62267 .23512 L .62193 .23913 L .289 .763 .934 r
F
.62267 .23512 m .59762 .22759 L .62193 .23913 L F
.62025 .26081 m .62178 .23995 L .6226 .23549 L 0 0 .058 r
F
.63073 .24636 m .64105 .26215 L .63929 .28487 L .561 .458 .694 r
F
.64105 .26215 m .64105 .28597 L .63929 .28487 L F
.64233 .29799 m .64179 .29506 L p .64105 .27605 L 0 0 .068 r
F P
0 g
s
.64105 .27259 m .64233 .29799 L .64105 .27605 L 0 0 .068 r
F
.64179 .29506 m .64132 .28958 L p .64105 .28068 L F P
0 g
s
.64105 .27605 m .64179 .29506 L .64105 .28068 L 0 0 .068 r
F
.64132 .28958 m .64105 .28428 L p .64105 .28068 L F P
0 g
s
.64465 .28287 m .64514 .27307 L .62426 .27307 L p .627 .779 .954 r
F P
0 g
s
.62426 .27307 m .62383 .28287 L .64465 .28287 L p .627 .779 .954 r
F P
0 g
s
.67134 .22759 m .64542 .22521 L p .64542 .26522 L .835 .682 .693 r
F P
0 g
s
.66141 .27411 m .64542 .26522 L .64542 .34901 L .835 .682 .693 r
F
.68441 .40548 m .66736 .41123 L .66736 .24321 L p 0 0 .497 r
F P
0 g
s
.66736 .24321 m .68441 .23549 L .68441 .40548 L p 0 0 .497 r
F P
0 g
s
.66736 .24321 m .68441 .23549 L .67134 .22759 L p .289 .763 .934 r
F P
0 g
s
.67134 .22759 m .64542 .26522 L .66141 .27411 L .835 .682 .693 r
F
.64542 .26522 m .64514 .27307 L p .64542 .26151 L 0 0 .068 r
F P
0 g
s
.64514 .27307 m .64542 .26522 L p .63139 .26153 L .663 .742 .908 r
F P
0 g
s
.64555 .26153 m .64542 .26522 L p .64542 .26151 L 0 0 .068 r
F P
0 g
s
.63877 .26153 m .63139 .26153 L p .64542 .26522 L .663 .742 .908 r
F P
0 g
s
.62792 .26339 m .64514 .27307 L .63139 .26153 L .663 .742 .908 r
F
.64445 .22973 m .63515 .22426 L .64273 .23769 L .289 .763 .934 r
F
.64046 .26081 m .6432 .23549 L .64612 .22197 L 0 0 .068 r
F
.64586 .24877 m .64555 .26153 L p .64046 .26081 L F P
0 g
s
.64605 .23538 m .64586 .24877 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.64612 .22197 m .64605 .23538 L p .64046 .26081 L 0 0 .068 r
F P
0 g
s
.63073 .24636 m .64105 .24547 L p .64105 .26215 L .561 .458 .694 r
F P
0 g
s
.64105 .28428 m .64132 .28958 L p .63773 .28305 L .628 .248 .303 r
F P
0 g
s
.64233 .29799 m .64291 .29822 L .62234 .29822 L p .027 0 0 r
F P
0 g
s
.64291 .29822 m .6435 .29571 L .62285 .29571 L p .266 .752 .921 r
F P
0 g
s
.62285 .29571 m .62234 .29822 L .64291 .29822 L p .266 .752 .921 r
F P
0 g
s
.6435 .29571 m .64409 .29053 L .62336 .29053 L p .458 .814 .997 r
F P
0 g
s
.62336 .29053 m .62285 .29571 L .6435 .29571 L p .458 .814 .997 r
F P
0 g
s
.64409 .29053 m .64465 .28287 L .62383 .28287 L p .566 .808 .99 r
F P
0 g
s
.62383 .28287 m .62336 .29053 L .64409 .29053 L p .566 .808 .99 r
F P
0 g
s
.63515 .22426 m .6245 .22521 L p .6245 .26522 L .556 .454 .694 r
F P
0 g
s
.63515 .22426 m .6245 .26522 L .62663 .26408 L .556 .454 .694 r
F
.62426 .27307 m .64514 .27307 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.6245 .26522 m .62426 .27307 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62139 .29506 m .62098 .28958 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.62076 .27605 m .62139 .29506 L .62076 .28068 L 0 0 .058 r
F
.60619 .29538 m .62076 .28597 L .62076 .36555 L .831 .679 .694 r
F
.63073 .41357 m .59536 .41123 L .59536 .24321 L p F P
0 g
s
.63515 .25857 m .63515 .22426 L p .62632 .26553 L .556 .454 .694 r
F P
0 g
s
.64542 .22521 m .63515 .22426 L p .63818 .26104 L .835 .682 .693 r
F P
0 g
s
.62485 .25014 m .62461 .26153 L .63877 .26153 L p .686 .701 .858 r
F P
0 g
s
.64542 .26697 m .63818 .26104 L .64542 .34901 L .835 .682 .693 r
F
.64542 .22521 m .63818 .26104 L .64542 .26697 L F
.63515 .22426 m .63515 .39713 L p .64542 .34901 L F P
0 g
s
.62487 .24877 m .62485 .25014 L p .64555 .26153 L .686 .701 .858 r
F P
0 g
s
.63877 .26153 m .64555 .26153 L p .62485 .25014 L .686 .701 .858 r
F P
0 g
s
.59762 .3996 m .63515 .39713 L .63515 .25857 L p .556 .454 .694 r
F P
0 g
s
.62632 .26553 m .59762 .3996 L .63515 .25857 L .556 .454 .694 r
F
.64586 .24877 m .62487 .24877 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.64555 .26153 m .64583 .25014 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.64583 .25014 m .64586 .24877 L p .63761 .25663 L .686 .701 .858 r
F P
0 g
s
.62461 .26153 m .6245 .26522 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62025 .26081 m .6226 .23549 L .6245 .22521 L 0 0 .058 r
F
.62025 .26081 m .6245 .22521 L .6245 .22676 L F
.6245 .22521 m .59762 .22759 L p .62301 .23328 L .289 .763 .934 r
F P
0 g
s
.62487 .24877 m .62461 .26153 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62504 .23538 m .62487 .24877 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.62509 .22197 m .62504 .23538 L p .62025 .26081 L 0 0 .058 r
F P
0 g
s
.59536 .24321 m .62076 .24547 L p .62076 .2693 L .831 .679 .694 r
F P
0 g
s
.6245 .22521 m .59762 .22759 L p .6206 .26731 L .556 .454 .694 r
F P
0 g
s
.6245 .26522 m .62426 .27307 L p .6245 .26151 L 0 0 .058 r
F P
0 g
s
.6245 .26522 m .6206 .26731 L .6245 .27403 L .556 .454 .694 r
F
.6245 .22521 m .6206 .26731 L .6245 .26522 L F
.64542 .26522 m .64555 .26153 L .63877 .26153 L p .663 .742 .908 r
F P
0 g
s
.63139 .26153 m .62461 .26153 L p .62792 .26339 L .663 .742 .908 r
F P
0 g
s
.62663 .26408 m .6245 .26522 L .6245 .27403 L .556 .454 .694 r
F
.6245 .22676 m .6245 .22521 L .62509 .22197 L 0 0 .058 r
F
.62461 .26153 m .6245 .26522 L p .6245 .26151 L F P
0 g
s
.59536 .24321 m .62076 .2693 L .60619 .29538 L .831 .679 .694 r
F
.62076 .2693 m .62076 .28597 L .60619 .29538 L F
.62098 .28958 m .62076 .28428 L p .62076 .28068 L 0 0 .058 r
F P
0 g
s
.59762 .22759 m .59762 .3996 L p .6245 .27403 L .556 .454 .694 r
F P
0 g
s
.67134 .3996 m .68441 .40548 L .68441 .23549 L p .989 .808 .421 r
F P
0 g
s
.52684 .4259 m .57964 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.62978 .42579 m .57964 .42914 L .57964 .42419 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L .62978 .42579 L p .553 .451 .693 r
F P
0 g
s
.57964 .42419 m .62978 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .42086 m .62978 .42579 L .62978 .4208 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L .67549 .42086 L p .452 .369 .672 r
F P
0 g
s
.62978 .4208 m .67549 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.67549 .41582 m .715 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .74661 .40682 L p .152 .124 .57 r
F P
0 g
s
.715 .40937 m .74661 .40163 L .7687 .39285 L p .224 .73 .894 r
F P
0 g
s
.7687 .39814 m .74661 .40682 L .74661 .40163 L p 0 0 .454 r
F P
0 g
s
.74661 .40163 m .7687 .39285 L .7687 .39814 L p 0 0 .454 r
F P
0 g
s
.52684 .43084 m .57964 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.52684 .43084 m .47316 .43084 L .47316 .4259 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L .52684 .43084 L p .707 .577 .707 r
F P
0 g
s
.47316 .4259 m .52684 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.59536 .41123 m .63073 .41357 L .66736 .41123 L p .224 .73 .894 r
F P
0 g
s
.59536 .41123 m .58139 .40548 L .58139 .23549 L p .995 .812 .445 r
F P
0 g
s
.58139 .23549 m .59536 .24321 L .59536 .41123 L p .995 .812 .445 r
F P
0 g
s
.58139 .40548 m .59536 .41123 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.59762 .3996 m .58139 .40548 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.63515 .39713 m .59762 .3996 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.67134 .3996 m .63515 .39713 L p .66736 .41123 L .224 .73 .894 r
F P
0 g
s
.66736 .41123 m .68441 .40548 L .67134 .3996 L p .224 .73 .894 r
F P
0 g
s
.47316 .43084 m .52684 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.47316 .43084 m .42036 .42914 L .42036 .42419 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L .47316 .43084 L p .772 .631 .704 r
F P
0 g
s
.42036 .42419 m .47316 .4259 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.42036 .42914 m .47316 .43084 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.715 .41448 m .67549 .42086 L .67549 .41582 L p .324 .265 .635 r
F P
0 g
s
.67549 .41582 m .715 .40937 L .715 .41448 L p .324 .265 .635 r
F P
0 g
s
.57964 .42914 m .62978 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.42036 .42914 m .37022 .42579 L .37022 .4208 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L .42036 .42914 L p .833 .681 .693 r
F P
0 g
s
.37022 .4208 m .42036 .42419 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.37022 .42579 m .42036 .42914 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.74661 .40682 m .715 .41448 L .715 .40937 L p .152 .124 .57 r
F P
0 g
s
.62978 .42579 m .67549 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.37022 .42579 m .32451 .42086 L .32451 .41582 L p .892 .728 .672 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L .37022 .42579 L p .892 .728 .672 r
F P
0 g
s
.37975 .2356 m .3798 .24848 L .3596 .24848 L p .706 .605 .74 r
F P
0 g
s
.3798 .24848 m .37975 .26081 L .35954 .26081 L p .706 .548 .671 r
F P
0 g
s
.35954 .26081 m .3596 .24848 L .3798 .24848 L p .706 .548 .671 r
F P
0 g
s
.37975 .26081 m .37959 .27207 L .35936 .27207 L p .698 .477 .584 r
F P
0 g
s
.35936 .27207 m .35954 .26081 L .37975 .26081 L p .698 .477 .584 r
F P
0 g
s
.37959 .27207 m .37935 .2818 L .37278 .2818 L p .676 .382 .468 r
F P
0 g
s
.36927 .41357 m .36927 .28045 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.36927 .28045 m .36927 .27953 L p .37024 .28082 L .556 .454 .694 r
F P
0 g
s
.37024 .28082 m .37924 .29283 L .36927 .28045 L .556 .454 .694 r
F
.37935 .2818 m .37924 .28428 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.36698 .27805 m .37959 .27207 L .37832 .27389 L .676 .382 .468 r
F
.36927 .27953 m .37832 .27389 L .37278 .2818 L F
.36698 .27805 m .37832 .27389 L .36927 .27953 L F
.3596 .24848 m .35954 .2356 L .37975 .2356 L p .706 .605 .74 r
F P
0 g
s
.35954 .26081 m .3596 .24848 L .35954 .2356 L p .772 .63 .068 r
F P
0 g
s
.35954 .2356 m .35936 .22269 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35907 .2818 m .35936 .27207 L .35954 .26081 L p .772 .63 .068 r
F P
0 g
s
.35954 .26081 m .35895 .28068 L .35907 .2818 L .772 .63 .068 r
F
.35895 .36555 m .36916 .2805 L .36927 .41357 L .828 .676 .694 r
F
.36927 .28045 m .36927 .41357 L p .36916 .2805 L F P
0 g
s
.34386 .29538 m .35895 .28597 L .35895 .36555 L .828 .676 .694 r
F
.35895 .28597 m .36927 .27953 L .35895 .36555 L F
.35895 .28428 m .35907 .2818 L .36564 .2818 L p .628 .248 .303 r
F P
0 g
s
.35954 .26081 m .35895 .27605 L .35895 .28068 L .772 .63 .068 r
F
.35895 .28428 m .35907 .2818 L p .35895 .28068 L F P
0 g
s
.36927 .27953 m .36927 .28045 L p .36916 .2805 L .828 .676 .694 r
F P
0 g
s
.37753 .28487 m .37924 .29283 L .37024 .28082 L .556 .454 .694 r
F
.37278 .2818 m .37024 .28082 L .36927 .27953 L F
.37753 .28487 m .37024 .28082 L .37278 .2818 L F
.35907 .2818 m .36698 .27805 L .36927 .27953 L .676 .382 .468 r
F
.37278 .2818 m .36564 .2818 L p .36927 .27953 L F P
0 g
s
.36564 .2818 m .35907 .2818 L p .36927 .27953 L .676 .382 .468 r
F P
0 g
s
.34276 .29028 m .35895 .28428 L .34386 .29538 L .828 .676 .694 r
F
.35895 .28428 m .36564 .2818 L .35895 .28597 L F
.35895 .28428 m .35895 .28597 L .34386 .29538 L F
.33264 .24321 m .35895 .2693 L .35895 .27397 L F
.35954 .26081 m .35895 .27259 L .35895 .27605 L .772 .63 .068 r
F
.33264 .24321 m .35895 .27397 L .34276 .29028 L .828 .676 .694 r
F
.35936 .27207 m .37959 .27207 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.35907 .2818 m .35933 .27311 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.35933 .27311 m .35936 .27207 L p .36698 .27805 L .676 .382 .468 r
F P
0 g
s
.37975 .26081 m .37924 .27605 L .37924 .28068 L .763 .623 .058 r
F
.37975 .26081 m .3798 .24848 L .37975 .2356 L p F P
0 g
s
.37959 .22269 m .37975 .2356 L .35954 .2356 L p .7 .653 .8 r
F P
0 g
s
.37975 .2356 m .37959 .22269 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37935 .2818 m .37959 .27207 L .37975 .26081 L p .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .37924 .28068 L .37935 .2818 L .763 .623 .058 r
F
.40464 .30238 m .40464 .41123 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.37753 .28487 m .37924 .28597 L .37924 .29283 L .556 .454 .694 r
F
.37924 .28597 m .40464 .30238 L .37924 .29283 L F
.37975 .26081 m .37924 .27259 L .37924 .27605 L .763 .623 .058 r
F
.37724 .28351 m .37924 .28489 L .37753 .28487 L .556 .454 .694 r
F
.37924 .28489 m .37924 .28597 L .37753 .28487 L F
.37975 .26081 m .37924 .26985 L .37924 .27259 L .763 .623 .058 r
F
.37278 .2818 m .37935 .2818 L p .37436 .28241 L .628 .248 .303 r
F P
0 g
s
.37924 .28428 m .37935 .2818 L p .37924 .28068 L .763 .623 .058 r
F P
0 g
s
.37603 .28305 m .37436 .28241 L .37935 .2818 L .628 .248 .303 r
F
.36927 .24636 m .37924 .26215 L .37724 .28351 L .556 .454 .694 r
F
.37924 .26215 m .37924 .28428 L .37724 .28351 L F
.37924 .28428 m .37924 .28489 L .37724 .28351 L F
.36927 .27953 m .36927 .24636 L p .37724 .28351 L F P
0 g
s
.37724 .28351 m .37753 .28487 L .37278 .2818 L .556 .454 .694 r
F
.37724 .28351 m .37278 .2818 L .36927 .27953 L F
.37902 .28958 m .35868 .28958 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.37924 .28428 m .37902 .28958 L p .37603 .28305 L .628 .248 .303 r
F P
0 g
s
.37902 .28958 m .37861 .29506 L .35821 .29506 L p .528 .047 .057 r
F P
0 g
s
.35821 .29506 m .35868 .28958 L .37902 .28958 L p .528 .047 .057 r
F P
0 g
s
.37861 .29506 m .37815 .29799 L .35767 .29799 L p .33 0 0 r
F P
0 g
s
.35767 .29799 m .35821 .29506 L .37861 .29506 L p .33 0 0 r
F P
0 g
s
.37815 .29799 m .37766 .29822 L .35709 .29822 L p .027 0 0 r
F P
0 g
s
.35709 .29822 m .35767 .29799 L .37815 .29799 L p .027 0 0 r
F P
0 g
s
.37715 .29571 m .37766 .29822 L p .37924 .26985 L .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .37924 .26759 L .37924 .26985 L .763 .623 .058 r
F
.37924 .26759 m .37715 .29571 L .37924 .26985 L F
.39769 .29136 m .40464 .30238 L .37924 .28489 L .556 .454 .694 r
F
.39769 .29136 m .37924 .28489 L .37924 .28428 L F
.37664 .29053 m .37715 .29571 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37617 .28287 m .37664 .29053 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37574 .27307 m .37617 .28287 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.36927 .24636 m .37924 .24547 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.37975 .26081 m .3755 .26151 L .37574 .27307 L .763 .623 .058 r
F
.36564 .2818 m .37278 .2818 L p .35895 .28428 L .628 .248 .303 r
F P
0 g
s
.35895 .28428 m .37278 .2818 L .37436 .28241 L .628 .248 .303 r
F
.35868 .28958 m .35895 .28428 L p .37436 .28241 L F P
0 g
s
.35868 .28958 m .37436 .28241 L .37603 .28305 L .628 .248 .303 r
F
.35954 .26081 m .35895 .26759 L .35895 .26985 L .772 .63 .068 r
F
.35954 .26081 m .35895 .26985 L .35895 .27259 L F
.36927 .24636 m .36927 .27953 L p .35895 .2693 L .828 .676 .694 r
F P
0 g
s
.35895 .27397 m .35895 .28428 L .34276 .29028 L .828 .676 .694 r
F
.33264 .24321 m .35895 .24547 L p .35895 .2693 L F P
0 g
s
.35591 .29053 m .3565 .29571 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35535 .28287 m .35591 .29053 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35486 .27307 m .35535 .28287 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35954 .26081 m .35458 .26151 L .35486 .27307 L .772 .63 .068 r
F
.35458 .26522 m .35486 .27307 L p .35458 .26151 L F P
0 g
s
.35445 .18767 m .35414 .19756 L p .35458 .20272 L .772 .63 .068 r
F P
0 g
s
.33264 .24321 m .35895 .24547 L p .35846 .24321 L .289 .763 .934 r
F P
0 g
s
.35486 .17995 m .35445 .18767 L p .35824 .2422 L .772 .63 .068 r
F P
0 g
s
.31559 .23549 m .33264 .24321 L p .35846 .24321 L .289 .763 .934 r
F P
0 g
s
.35758 .23913 m .31559 .23549 L .35846 .24321 L .289 .763 .934 r
F
.35954 .26081 m .35854 .24358 L .35824 .2422 L .772 .63 .068 r
F
.35854 .24358 m .35486 .17995 L .35824 .2422 L F
.35776 .23995 m .35458 .18956 L .35458 .20272 L F
.35824 .2422 m .35458 .18956 L .35776 .23995 L F
.35954 .2356 m .35936 .22269 L .37959 .22269 L p .7 .653 .8 r
F P
0 g
s
.37935 .21029 m .37959 .22269 L .35936 .22269 L p .687 .697 .853 r
F P
0 g
s
.35936 .22269 m .35907 .21029 L .37935 .21029 L p .687 .697 .853 r
F P
0 g
s
.37902 .19891 m .37935 .21029 L .35907 .21029 L p .667 .737 .902 r
F P
0 g
s
.35907 .21029 m .35868 .19891 L .37902 .19891 L p .667 .737 .902 r
F P
0 g
s
.37861 .18905 m .37902 .19891 L .35868 .19891 L p .634 .774 .948 r
F P
0 g
s
.37513 .19756 m .37496 .20917 L p .3774 .23549 L .763 .623 .058 r
F P
0 g
s
.35414 .19756 m .35395 .20917 L p .3568 .23549 L .772 .63 .068 r
F P
0 g
s
.32866 .22759 m .31559 .23549 L p .35758 .23913 L .289 .763 .934 r
F P
0 g
s
.35632 .23328 m .32866 .22759 L .35758 .23913 L .289 .763 .934 r
F
.35954 .26081 m .35776 .23995 L .3568 .23549 L .772 .63 .068 r
F
.35776 .23995 m .35414 .19756 L .3568 .23549 L F
.37822 .23995 m .37513 .19756 L .3774 .23549 L .763 .623 .058 r
F
.35868 .19891 m .35821 .18905 L .37861 .18905 L p .634 .774 .948 r
F P
0 g
s
.37815 .18113 m .37861 .18905 L .35821 .18905 L p .579 .804 .985 r
F P
0 g
s
.37539 .18767 m .37513 .19756 L p .37822 .23995 L .763 .623 .058 r
F P
0 g
s
.35458 .22521 m .32866 .22759 L p .35632 .23328 L .289 .763 .934 r
F P
0 g
s
.35954 .26081 m .3568 .23549 L .35458 .22521 L .772 .63 .068 r
F
.35954 .26081 m .35458 .22521 L .35458 .22676 L F
.35954 .26081 m .35824 .2422 L .35776 .23995 L F
.35458 .22521 m .35083 .26731 L .35458 .26522 L .55 .449 .693 r
F
.35414 .24877 m .35445 .26153 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35395 .23538 m .35414 .24877 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35458 .22521 m .32866 .22759 L p .35083 .26731 L .55 .449 .693 r
F P
0 g
s
.35388 .22197 m .35395 .23538 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35535 .17473 m .35486 .17995 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35591 .17222 m .35535 .17473 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.3565 .1725 m .35591 .17222 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35709 .17553 m .3565 .1725 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35767 .18113 m .35709 .17553 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35821 .18905 m .35767 .18113 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35868 .19891 m .35821 .18905 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35907 .21029 m .35868 .19891 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35936 .22269 m .35907 .21029 L p .35954 .26081 L .772 .63 .068 r
F P
0 g
s
.35895 .25288 m .36927 .24636 L .35895 .2693 L .828 .676 .694 r
F
.35395 .20917 m .35388 .22197 L p .3568 .23549 L .772 .63 .068 r
F P
0 g
s
.37864 .2422 m .37539 .18767 L .37822 .23995 L .763 .623 .058 r
F
.37496 .20917 m .37491 .22197 L p .3774 .23549 L F P
0 g
s
.36485 .22426 m .35458 .22521 L p .37699 .23327 L .289 .763 .934 r
F P
0 g
s
.35821 .18905 m .35767 .18113 L .37815 .18113 L p .579 .804 .985 r
F P
0 g
s
.37766 .17553 m .37815 .18113 L .35767 .18113 L p .483 .816 .999 r
F P
0 g
s
.37574 .17995 m .37539 .18767 L p .37864 .2422 L .763 .623 .058 r
F P
0 g
s
.37889 .24358 m .37574 .17995 L .37864 .2422 L .763 .623 .058 r
F
.35767 .18113 m .35709 .17553 L .37766 .17553 L p .483 .816 .999 r
F P
0 g
s
.37715 .1725 m .37766 .17553 L .35709 .17553 L p .311 .772 .946 r
F P
0 g
s
.37617 .17473 m .37574 .17995 L p .37889 .24358 L .763 .623 .058 r
F P
0 g
s
.37911 .24548 m .37924 .24547 L p .37911 .24545 L .289 .763 .934 r
F P
0 g
s
.37911 .24545 m .35846 .24321 L .37911 .24548 L .289 .763 .934 r
F
.36927 .24636 m .37911 .24548 L p .35846 .24321 L F P
0 g
s
.37882 .24321 m .35846 .24321 L .37924 .24547 L .289 .763 .934 r
F
.37975 .26081 m .37907 .24454 L .37889 .24358 L .763 .623 .058 r
F
.37907 .24454 m .37617 .17473 L .37889 .24358 L F
.37781 .23769 m .35458 .22521 L .35632 .23328 L .289 .763 .934 r
F
.35709 .17553 m .3565 .1725 L .37715 .1725 L p .311 .772 .946 r
F P
0 g
s
.37664 .17222 m .37715 .1725 L .3565 .1725 L p .033 .603 .739 r
F P
0 g
s
.37664 .17222 m .37617 .17473 L p .37907 .24454 L .763 .623 .058 r
F P
0 g
s
.37975 .26081 m .3792 .24525 L .37907 .24454 L .763 .623 .058 r
F
.3792 .24525 m .37664 .17222 L .37907 .24454 L F
.37715 .1725 m .37664 .17222 L p .37975 .26081 L F P
0 g
s
.37766 .17553 m .37715 .1725 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37815 .18113 m .37766 .17553 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37861 .18905 m .37815 .18113 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37902 .19891 m .37861 .18905 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37935 .21029 m .37902 .19891 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37959 .22269 m .37935 .21029 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.40238 .22759 m .3755 .22521 L p .40464 .24321 L .289 .763 .934 r
F P
0 g
s
.3755 .22521 m .36485 .22426 L p .37634 .22973 L .289 .763 .934 r
F P
0 g
s
.40464 .24321 m .3755 .22521 L .37634 .22973 L .289 .763 .934 r
F
.40464 .24321 m .37699 .23327 L .37781 .23769 L F
.37699 .23327 m .35458 .22521 L .37781 .23769 L F
.40464 .24321 m .37634 .22973 L .37699 .23327 L F
.37634 .22973 m .36485 .22426 L .37699 .23327 L F
.37882 .24321 m .35758 .23913 L .35846 .24321 L F
.37841 .24094 m .35758 .23913 L .37882 .24321 L F
.37975 .26081 m .37889 .24358 L .37864 .2422 L .763 .623 .058 r
F
.37841 .24094 m .37264 .23894 L .37234 .24041 L .289 .763 .934 r
F
.37264 .23894 m .35632 .23328 L .37234 .24041 L F
.37234 .24041 m .35632 .23328 L .35758 .23913 L F
.37781 .23769 m .35632 .23328 L .37841 .24094 L F
.35895 .24547 m .36927 .24636 L p .35846 .24321 L F P
0 g
s
.36045 .2456 m .36927 .24636 L p .35895 .25288 L .828 .676 .694 r
F P
0 g
s
.3755 .22521 m .36485 .22426 L p .36799 .26104 L .831 .678 .694 r
F P
0 g
s
.3755 .22521 m .36799 .26104 L .36803 .26107 L .831 .678 .694 r
F
.35895 .24547 m .36045 .2456 L p .35895 .25288 L .828 .676 .694 r
F P
0 g
s
.36485 .22426 m .35458 .22521 L p .35458 .26522 L .55 .449 .693 r
F P
0 g
s
.35458 .26522 m .35486 .27307 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35506 .26495 m .35458 .26522 L .35458 .26697 L .55 .449 .693 r
F
.36485 .22426 m .35458 .26522 L .35506 .26495 L F
.3565 .29571 m .35709 .29822 L p .35895 .26985 L .772 .63 .068 r
F P
0 g
s
.35895 .26759 m .3565 .29571 L .35895 .26985 L .772 .63 .068 r
F
.35709 .29822 m .35767 .29799 L p .35895 .27259 L F P
0 g
s
.35895 .26985 m .35709 .29822 L .35895 .27259 L .772 .63 .068 r
F
.35895 .27259 m .35767 .29799 L .35895 .27605 L F
.35895 .2693 m .36927 .27953 L .35895 .27397 L .828 .676 .694 r
F
.35486 .27307 m .37574 .27307 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.36485 .22426 m .35458 .26697 L .35633 .26553 L .55 .449 .693 r
F
.35445 .26153 m .35458 .26522 L p .35458 .26151 L .772 .63 .068 r
F P
0 g
s
.36123 .26153 m .36861 .26153 L p .36485 .25857 L .686 .701 .858 r
F P
0 g
s
.37574 .27307 m .3755 .26522 L p .36123 .26153 L .663 .742 .908 r
F P
0 g
s
.36861 .26153 m .36123 .26153 L p .3755 .26522 L .663 .742 .908 r
F P
0 g
s
.35788 .26339 m .37574 .27307 L .36123 .26153 L .663 .742 .908 r
F
.35895 .27397 m .36564 .2818 L .35895 .28428 L .828 .676 .694 r
F
.35767 .29799 m .35821 .29506 L p .35895 .27605 L .772 .63 .068 r
F P
0 g
s
.35895 .27397 m .36927 .27953 L .36564 .2818 L .828 .676 .694 r
F
.35821 .29506 m .35868 .28958 L p .35895 .28068 L .772 .63 .068 r
F P
0 g
s
.35895 .27605 m .35821 .29506 L .35895 .28068 L .772 .63 .068 r
F
.35868 .28958 m .35895 .28428 L p .35895 .28068 L F P
0 g
s
.36927 .41357 m .33264 .41123 L .33264 .24321 L p .828 .676 .694 r
F P
0 g
s
.37766 .29822 m .37715 .29571 L .3565 .29571 L p .266 .752 .921 r
F P
0 g
s
.3565 .29571 m .35709 .29822 L .37766 .29822 L p .266 .752 .921 r
F P
0 g
s
.37715 .29571 m .37664 .29053 L .35591 .29053 L p .458 .814 .997 r
F P
0 g
s
.35591 .29053 m .3565 .29571 L .37715 .29571 L p .458 .814 .997 r
F P
0 g
s
.37664 .29053 m .37617 .28287 L .35535 .28287 L p .566 .808 .99 r
F P
0 g
s
.35535 .28287 m .35591 .29053 L .37664 .29053 L p .566 .808 .99 r
F P
0 g
s
.37617 .28287 m .37574 .27307 L .35486 .27307 L p .627 .779 .954 r
F P
0 g
s
.35486 .27307 m .35535 .28287 L .37617 .28287 L p .627 .779 .954 r
F P
0 g
s
.36485 .39713 m .36485 .25857 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.36485 .25857 m .36485 .22426 L p .35633 .26553 L .55 .449 .693 r
F P
0 g
s
.35633 .26553 m .35458 .27403 L .36485 .25857 L .55 .449 .693 r
F
.37924 .41291 m .36927 .41357 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.36485 .22426 m .36485 .39713 L p .3755 .34901 L .831 .678 .694 r
F P
0 g
s
.35414 .24877 m .35417 .25014 L p .36684 .25694 L .686 .701 .858 r
F P
0 g
s
.3755 .22521 m .36803 .26107 L .3755 .26522 L .831 .678 .694 r
F
.36803 .26107 m .36801 .26121 L .36861 .26153 L F
.36803 .26107 m .36861 .26153 L .3755 .26522 L F
.36722 .25663 m .36684 .25694 L .37539 .26153 L .686 .701 .858 r
F
.35414 .24877 m .36684 .25694 L .36722 .25663 L F
.35445 .26153 m .35458 .26522 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35417 .25014 m .35445 .26153 L .36123 .26153 L p .686 .701 .858 r
F P
0 g
s
.35417 .25014 m .36123 .26153 L .36485 .25857 L .686 .701 .858 r
F
.35633 .26553 m .35458 .26697 L .35458 .27403 L .55 .449 .693 r
F
.36861 .26153 m .37539 .26153 L p .35417 .25014 L .686 .701 .858 r
F P
0 g
s
.36803 .26107 m .36799 .26104 L .36801 .26121 L .831 .678 .694 r
F
.3755 .26522 m .36801 .26121 L .3755 .34901 L F
.3755 .26522 m .37539 .26153 L .36861 .26153 L p .663 .742 .908 r
F P
0 g
s
.36123 .26153 m .35445 .26153 L p .35788 .26339 L .663 .742 .908 r
F P
0 g
s
.35458 .26522 m .35083 .26731 L .35458 .27403 L .55 .449 .693 r
F
.35458 .22676 m .35458 .22521 L .35388 .22197 L .772 .63 .068 r
F
.37975 .26081 m .37864 .2422 L .37822 .23995 L .763 .623 .058 r
F
.40464 .24321 m .37781 .23769 L .37841 .24094 L .289 .763 .934 r
F
.37975 .26081 m .37822 .23995 L .3774 .23549 L .763 .623 .058 r
F
.40464 .24321 m .37841 .24094 L .37882 .24321 L .289 .763 .934 r
F
.37975 .26081 m .3774 .23549 L .37491 .22197 L .763 .623 .058 r
F
.37924 .24547 m .40464 .24321 L p .37882 .24321 L .289 .763 .934 r
F P
0 g
s
.35458 .18956 m .35445 .18767 L .35458 .20272 L .772 .63 .068 r
F
.33264 .41123 m .31559 .40548 L .31559 .23549 L p 1 .816 .497 r
F P
0 g
s
.31559 .23549 m .33264 .24321 L .33264 .41123 L p 1 .816 .497 r
F P
0 g
s
.32866 .22759 m .32866 .3996 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.32866 .3996 m .35458 .39783 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.35458 .39783 m .36485 .39713 L p .35458 .27403 L .55 .449 .693 r
F P
0 g
s
.37539 .26153 m .3755 .26522 L p .3755 .26151 L .763 .623 .058 r
F P
0 g
s
.3755 .26522 m .37574 .27307 L p .3755 .26151 L .763 .623 .058 r
F P
0 g
s
.37924 .26215 m .39769 .29136 L .37924 .28428 L .556 .454 .694 r
F
.37766 .29822 m .37815 .29799 L p .37924 .27259 L .763 .623 .058 r
F P
0 g
s
.37924 .26985 m .37766 .29822 L .37924 .27259 L .763 .623 .058 r
F
.37924 .28489 m .40464 .30238 L .37924 .28597 L .556 .454 .694 r
F
.37815 .29799 m .37861 .29506 L p .37924 .27605 L .763 .623 .058 r
F P
0 g
s
.37924 .27259 m .37815 .29799 L .37924 .27605 L .763 .623 .058 r
F
.37902 .28958 m .37924 .28428 L p .37924 .28068 L F P
0 g
s
.40464 .24321 m .40464 .30238 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.37513 .24877 m .37539 .26153 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37496 .23538 m .37513 .24877 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37491 .22197 m .37496 .23538 L p .37975 .26081 L .763 .623 .058 r
F P
0 g
s
.37924 .24547 m .40464 .24321 L p .37924 .26215 L .556 .454 .694 r
F P
0 g
s
.40464 .41123 m .37924 .41291 L p .37924 .29283 L .556 .454 .694 r
F P
0 g
s
.37861 .29506 m .37902 .28958 L p .37924 .28068 L .763 .623 .058 r
F P
0 g
s
.37924 .27605 m .37861 .29506 L .37924 .28068 L .763 .623 .058 r
F
.40238 .22759 m .3755 .22521 L p .3755 .34901 L .831 .678 .694 r
F P
0 g
s
.58139 .40548 m .59762 .3996 L .59762 .22759 L p 0 0 .479 r
F P
0 g
s
.59762 .22759 m .58139 .23549 L .58139 .40548 L p 0 0 .479 r
F P
0 g
s
.68441 .23549 m .67134 .22759 L .67134 .3996 L p .989 .808 .421 r
F P
0 g
s
.63515 .39713 m .67134 .3996 L .67134 .22759 L p .835 .682 .693 r
F P
0 g
s
.32451 .41582 m .37022 .4208 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.32451 .42086 m .37022 .42579 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.67549 .42086 m .715 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.32451 .42086 m .285 .41448 L .285 .40937 L p .946 .772 .635 r
F P
0 g
s
.285 .40937 m .32451 .41582 L .32451 .42086 L p .946 .772 .635 r
F P
0 g
s
.41861 .40548 m .40464 .41123 L .40464 .24321 L p 0 0 .445 r
F P
0 g
s
.40464 .24321 m .41861 .23549 L .41861 .40548 L p 0 0 .445 r
F P
0 g
s
.40238 .3996 m .41861 .40548 L .41861 .23549 L p .999 .816 .479 r
F P
0 g
s
.285 .40937 m .32451 .41582 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.33264 .41123 m .36927 .41357 L .40464 .41123 L p .224 .73 .894 r
F P
0 g
s
.31559 .40548 m .33264 .41123 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.32866 .3996 m .31559 .40548 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.36485 .39713 m .32866 .3996 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.40238 .3996 m .36485 .39713 L p .40464 .41123 L .224 .73 .894 r
F P
0 g
s
.40464 .41123 m .41861 .40548 L .40238 .3996 L p .224 .73 .894 r
F P
0 g
s
.285 .41448 m .32451 .42086 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.40464 .24321 m .41861 .23549 L .40238 .22759 L p .289 .763 .934 r
F P
0 g
s
.715 .41448 m .74661 .40682 L .7687 .39814 L p .222 .729 .893 r
F P
0 g
s
.285 .41448 m .25339 .40682 L .25339 .40163 L p .988 .807 .57 r
F P
0 g
s
.25339 .40163 m .285 .40937 L .285 .41448 L p .988 .807 .57 r
F P
0 g
s
.31559 .40548 m .32866 .3996 L .32866 .22759 L p 0 0 .421 r
F P
0 g
s
.32866 .22759 m .31559 .23549 L .31559 .40548 L p 0 0 .421 r
F P
0 g
s
.41861 .23549 m .40238 .22759 L .40238 .3996 L p .999 .816 .479 r
F P
0 g
s
.36485 .39713 m .40238 .3996 L .40238 .22759 L p .831 .678 .694 r
F P
0 g
s
.25339 .40163 m .285 .40937 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.25339 .40682 m .285 .41448 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.3565 .1725 m .35591 .17222 L .37664 .17222 L p .033 .603 .739 r
F P
0 g
s
.64465 .17473 m .64409 .17222 L .62336 .17222 L p .283 0 0 r
F P
0 g
s
.37617 .17473 m .37664 .17222 L .35591 .17222 L p .283 0 0 r
F P
0 g
s
.62336 .17222 m .62383 .17473 L .64465 .17473 L p .283 0 0 r
F P
0 g
s
.35591 .17222 m .35535 .17473 L .37617 .17473 L p .283 0 0 r
F P
0 g
s
.25339 .40682 m .2313 .39814 L .2313 .39285 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L .25339 .40682 L p .996 .813 .454 r
F P
0 g
s
.2313 .39285 m .25339 .40163 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.2313 .39814 m .25339 .40682 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64514 .17995 m .64465 .17473 L .62383 .17473 L p .505 .008 .009 r
F P
0 g
s
.37574 .17995 m .37617 .17473 L .35535 .17473 L p .505 .008 .009 r
F P
0 g
s
.62383 .17473 m .62426 .17995 L .64514 .17995 L p .505 .008 .009 r
F P
0 g
s
.35535 .17473 m .35486 .17995 L .37574 .17995 L p .505 .008 .009 r
F P
0 g
s
.64555 .18767 m .64514 .17995 L .62426 .17995 L p .619 .226 .277 r
F P
0 g
s
.37539 .18767 m .37574 .17995 L .35486 .17995 L p .619 .226 .277 r
F P
0 g
s
.62426 .17995 m .62461 .18767 L .64555 .18767 L p .619 .226 .277 r
F P
0 g
s
.35486 .17995 m .35445 .18767 L .37539 .18767 L p .619 .226 .277 r
F P
0 g
s
.64586 .19756 m .64555 .18767 L .62461 .18767 L p .673 .371 .455 r
F P
0 g
s
.37513 .19756 m .37539 .18767 L .35445 .18767 L p .673 .371 .455 r
F P
0 g
s
.62461 .18767 m .62487 .19756 L .64586 .19756 L p .673 .371 .455 r
F P
0 g
s
.35445 .18767 m .35414 .19756 L .37513 .19756 L p .673 .371 .455 r
F P
0 g
s
.37539 .26153 m .37513 .24877 L .35414 .24877 L p .686 .701 .858 r
F P
0 g
s
.29653 1.15371 m .29861 1.09633 L .44517 1.09633 L p .682 .405 .496 r
F P
0 g
s
.29861 .8749 m .35899 .87438 L .35899 .98856 L p .298 .244 .626 r
F P
0 g
s
.32849 1.043 m .36386 1.043 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.36462 1.07222 m .29861 1.09633 L .36386 1.043 L .678 .717 .878 r
F
.36616 1.0217 m .36478 1.07831 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.70139 1.09633 m .63476 1.09633 L p .63508 1.08393 L .678 .717 .878 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63384 1.0217 m .63522 1.07831 L p .44498 1.07831 L .682 .404 .495 r
F P
0 g
s
.44502 1.07439 m .44498 1.07831 L .43099 1.07831 L .682 .404 .495 r
F
.63384 1.0217 m .44498 1.07831 L .44502 1.07439 L F
.44517 1.09633 m .36524 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44498 1.07831 m .44517 1.09633 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.44517 1.09633 m .4446 1.15371 L .29653 1.15371 L p .682 .405 .496 r
F P
0 g
s
.44459 1.11724 m .44479 1.09692 L .44517 1.09633 L .732 .598 .026 r
F
.44498 1.07831 m .44516 1.0956 L p .44479 1.09692 L F P
0 g
s
.44516 1.0956 m .44517 1.09633 L p .44479 1.09692 L .732 .598 .026 r
F P
0 g
s
.3605 1.10246 m .36432 1.09692 L .44479 1.09692 L p .09 0 0 r
F P
0 g
s
.44371 1.10079 m .3605 1.10246 L .44479 1.09692 L .09 0 0 r
F
.43099 1.07831 m .44497 1.07958 L .36432 1.09692 L .682 .404 .495 r
F
.55483 1.09633 m .60506 1.07831 L .63508 1.08393 L .678 .717 .878 r
F
.63476 1.09633 m .55483 1.09633 L p .63508 1.08393 L F P
0 g
s
.55446 1.0217 m .63384 1.0217 L p .55468 1.04379 L .682 .404 .495 r
F P
0 g
s
.63568 .94981 m .63384 1.0217 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.6371 1.00646 m .63568 .94981 L .6359 1.04275 L 0 0 .063 r
F
.63614 1.043 m .6359 1.04275 L .63593 1.05141 L F
.6371 1.00646 m .6359 1.04275 L .63614 1.043 L F
.77017 1.10042 m .70139 1.09633 L .70139 .8749 L p .347 .283 .642 r
F P
0 g
s
.64101 .87438 m .70139 .8749 L .70139 1.04154 L p .954 .779 .626 r
F P
0 g
s
.70139 1.04154 m .70139 1.09633 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.68668 1.04226 m .64101 .87438 L .70139 1.04154 L .954 .779 .626 r
F
.63614 1.043 m .67151 1.043 L p .63551 1.06739 L .678 .717 .878 r
F P
0 g
s
.63551 1.06739 m .67151 1.043 L .67686 1.05255 L .678 .717 .878 r
F
.67151 1.043 m .63614 1.043 L p .65515 1.0438 L .066 0 0 r
F P
0 g
s
.63769 1.04463 m .63806 1.04464 L .63614 1.043 L .066 0 0 r
F
.64101 .98856 m .64101 .87438 L p .68668 1.04226 L .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .67151 1.043 L .68668 1.04226 L .954 .779 .626 r
F
.67151 1.043 m .64101 .98856 L .68668 1.04226 L F
.55483 1.09633 m .5554 1.043 L .63614 1.043 L p .678 .717 .878 r
F P
0 g
s
.5554 1.043 m .55656 1.04601 L .60986 1.04601 L p .066 0 0 r
F P
0 g
s
.70347 1.043 m .7021 1.07831 L p .6913 1.07831 L .678 .717 .878 r
F P
0 g
s
.67686 1.05255 m .70347 1.043 L .6913 1.07831 L .678 .717 .878 r
F
.63522 1.07831 m .67686 1.05255 L .6913 1.07831 L F
.60506 1.07831 m .63551 1.06739 L .63522 1.07831 L F
.63551 1.06739 m .67686 1.05255 L .63522 1.07831 L F
.64101 1.04469 m .64101 1.04449 L p .64125 1.0447 L .954 .779 .626 r
F P
0 g
s
.7021 1.07831 m .70139 1.09633 L p .60506 1.07831 L .678 .717 .878 r
F P
0 g
s
.70139 1.09633 m .64101 1.04469 L .64125 1.0447 L .954 .779 .626 r
F
.5554 1.15371 m .55483 1.09633 L .70139 1.09633 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .64101 1.04469 L p .954 .779 .626 r
F P
0 g
s
.70139 1.09633 m .64101 1.04449 L .67151 1.043 L .954 .779 .626 r
F
.67151 1.043 m .70347 1.043 L p .67686 1.05255 L .678 .717 .878 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .70139 1.09633 L p .091 0 0 r
F P
0 g
s
.70347 1.15371 m .70139 1.09633 L .70347 1.043 L p 0 0 .093 r
F P
0 g
s
.70347 1.043 m .70775 1.04601 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.63806 1.04464 m .65515 1.0438 L .63614 1.043 L .066 0 0 r
F
.64101 1.04449 m .64101 .98856 L p .67151 1.043 L .954 .779 .626 r
F P
0 g
s
.70277 .73937 m .74865 .73714 L .74865 .87438 L p .345 .281 .642 r
F P
0 g
s
.74865 .87438 m .70277 .87473 L .70277 .73937 L p .345 .281 .642 r
F P
0 g
s
.70849 .87402 m .74865 .87438 L .74865 .73714 L p .959 .783 .621 r
F P
0 g
s
.70996 .87384 m .77017 .87438 L .70139 .8749 L p .012 .587 .719 r
F P
0 g
s
.66253 .73714 m .70277 .73937 L .70277 .87473 L p .955 .78 .625 r
F P
0 g
s
.70277 .87473 m .66253 .87438 L .66253 .73714 L p .955 .78 .625 r
F P
0 g
s
.7105 .73763 m .73164 .65308 L p .71176 .73667 L 0 0 0 r
F P
0 g
s
.71372 .73515 m .74865 .73714 L .72778 .73816 L p .074 .635 .777 r
F P
0 g
s
.72778 .73816 m .70861 .73909 L p .7105 .73763 L .074 .635 .777 r
F P
0 g
s
.7105 .73763 m .71372 .73515 L .72778 .73816 L .074 .635 .777 r
F
.71668 .64842 m .73164 .65308 L .71087 .73616 L p .873 .753 .727 r
F P
0 g
s
.7106 .73622 m .71668 .64842 L .71087 .73616 L .873 .753 .727 r
F
.71027 .73762 m .71033 .73686 L .7105 .73763 L F
.71033 .73686 m .71668 .64842 L .7105 .73763 L F
.72887 .66474 m .73304 .65159 L .71145 .73796 L p 0 0 0 r
F P
0 g
s
.73304 .65159 m .73086 .65635 L p .73164 .65308 L 0 0 0 r
F P
0 g
s
.71018 .73633 m .69391 .67126 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.7102 .73631 m .71018 .73633 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.67362 .65364 m .68872 .65048 L .71018 .73633 L p .875 .674 .628 r
F P
0 g
s
.71018 .73633 m .70518 .73747 L p .67362 .65364 L .875 .674 .628 r
F P
0 g
s
.6945 .73714 m .69376 .73418 L p .70518 .73747 L .875 .674 .628 r
F P
0 g
s
.69376 .73418 m .67362 .65364 L p .70518 .73747 L .875 .674 .628 r
F P
0 g
s
.7102 .73631 m .71018 .73633 L .70518 .73747 L p .22 .739 .734 r
F P
0 g
s
.71027 .73762 m .70282 .70386 L .71033 .73686 L .873 .753 .727 r
F
.7099 .73761 m .70282 .70386 L .71027 .73762 L F
.70861 .73909 m .70277 .73937 L p .70753 .73754 L .074 .635 .777 r
F P
0 g
s
.7099 .73761 m .70518 .73747 L .70966 .73644 L .873 .753 .727 r
F
.70282 .70386 m .71668 .64842 L p .71033 .73686 L F P
0 g
s
.71087 .73616 m .7105 .73763 L p .7106 .73622 L .873 .753 .727 r
F P
0 g
s
.69515 .73453 m .70282 .70386 L p .70966 .73644 L .873 .753 .727 r
F P
0 g
s
.70518 .73747 m .69515 .73453 L p .70966 .73644 L .873 .753 .727 r
F P
0 g
s
.71142 .73536 m .7102 .73631 L p .70282 .70386 L 0 0 .28 r
F P
0 g
s
.7102 .73631 m .7052 .73746 L .706 .73682 L .22 .739 .734 r
F
.69515 .73453 m .706 .73682 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.70753 .73754 m .7105 .73763 L .70861 .73909 L .074 .635 .777 r
F
.70518 .73747 m .69515 .73453 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.70518 .73747 m .7052 .73746 L .7102 .73631 L .22 .739 .734 r
F
.70277 .73937 m .706 .73682 L .70967 .73671 L .074 .635 .777 r
F
.71018 .73893 m .70518 .73747 L p .7099 .73761 L .873 .753 .727 r
F P
0 g
s
.70518 .73747 m .7052 .73746 L .7102 .73891 L 0 .493 .774 r
F
.70277 .73937 m .69798 .73911 L p .70518 .73747 L .074 .635 .777 r
F P
0 g
s
.7017 .69894 m .7018 .69937 L .68872 .65048 L 0 0 .28 r
F
.71215 .73517 m .73304 .65159 L p .706 .73682 L .495 .367 .634 r
F P
0 g
s
.70519 .71255 m .70917 .72684 L .70528 .71236 L .495 .367 .634 r
F
.70519 .71255 m .70913 .72696 L .70917 .72684 L F
.73164 .65308 m .71668 .64842 L .73304 .65159 L closepath p 0 .521 .807 r
F P
0 g
s
.73304 .65159 m .71668 .64842 L .69515 .73453 L p .495 .367 .634 r
F P
0 g
s
.69391 .67126 m .68872 .65048 L p .71142 .73536 L 0 0 .28 r
F P
0 g
s
.70528 .71236 m .70917 .72684 L .73304 .65159 L .495 .367 .634 r
F
.71136 .73501 m .68872 .65048 L .71137 .73501 L 0 0 .28 r
F
.68872 .65048 m .68985 .64897 L .71137 .73501 L p F P
0 g
s
.68872 .65048 m .67362 .65364 L .68985 .64897 L closepath p .259 .767 .77 r
F P
0 g
s
.68985 .64897 m .67362 .65364 L .6945 .73714 L p .498 .444 .727 r
F P
0 g
s
.69798 .73911 m .67337 .73774 L p .70518 .73747 L .074 .635 .777 r
F P
0 g
s
.67337 .73774 m .68772 .73733 L .70518 .73747 L .074 .635 .777 r
F
.69499 .73713 m .68985 .64897 L .6945 .73714 L .498 .444 .727 r
F
.69515 .73453 m .706 .73682 L p .70913 .72696 L .495 .367 .634 r
F P
0 g
s
.71145 .73534 m .71142 .73536 L p .7018 .69937 L 0 0 .28 r
F P
0 g
s
.71145 .73534 m .7018 .69937 L .7017 .69894 L 0 0 .28 r
F
.69515 .73453 m .70913 .72696 L .70519 .71255 L .495 .367 .634 r
F
.71137 .73501 m .71145 .73534 L p .71136 .73501 L 0 0 .28 r
F P
0 g
s
.71145 .73534 m .68985 .64897 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.706 .73682 m .71145 .73534 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.66253 .73714 m .70849 .73485 L p .706 .73682 L .074 .635 .777 r
F P
0 g
s
.70518 .73747 m .68772 .73733 L .706 .73682 L .074 .635 .777 r
F
.68772 .73733 m .66253 .73714 L .706 .73682 L F
.70518 .73747 m .69515 .73975 L .6945 .73714 L p .875 .674 .628 r
F P
0 g
s
.69515 .73975 m .706 .73682 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.6945 .73714 m .69515 .73975 L p .69499 .73713 L .498 .444 .727 r
F P
0 g
s
.67337 .73774 m .66253 .73714 L p .68772 .73733 L .074 .635 .777 r
F P
0 g
s
.70518 .73747 m .69515 .73975 L p .7052 .73746 L .22 .739 .734 r
F P
0 g
s
.69515 .73975 m .706 .73682 L p .7052 .73746 L .22 .739 .734 r
F P
0 g
s
.71018 .73893 m .71017 .7389 L .71018 .73891 L .873 .753 .727 r
F
.71017 .7389 m .7099 .73761 L .71018 .73891 L F
.71018 .73891 m .7099 .73761 L .71027 .73762 L F
.7105 .73763 m .71018 .73893 L p .71027 .73762 L F P
0 g
s
.71145 .73796 m .71018 .73893 L .7105 .73763 L p 0 0 0 r
F P
0 g
s
.71145 .73796 m .7102 .73891 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.71142 .73536 m .7102 .73631 L p .706 .73682 L .22 .739 .734 r
F P
0 g
s
.71177 .73665 m .71215 .73517 L p .706 .73682 L .495 .367 .634 r
F P
0 g
s
.70753 .73754 m .71372 .73515 L .7105 .73763 L .074 .635 .777 r
F
.706 .73682 m .71145 .73796 L p .7052 .73746 L 0 .493 .774 r
F P
0 g
s
.706 .73682 m .71145 .73534 L .71142 .73536 L p .22 .739 .734 r
F P
0 g
s
.7102 .73891 m .71018 .73893 L .70518 .73747 L p 0 .493 .774 r
F P
0 g
s
.71145 .73796 m .7105 .73763 L .71176 .73667 L 0 0 0 r
F
.706 .73682 m .71145 .73796 L .71177 .73665 L p .495 .367 .634 r
F P
0 g
s
.70849 .73485 m .71372 .73515 L p .70967 .73671 L .074 .635 .777 r
F P
0 g
s
.706 .73682 m .70849 .73485 L .70967 .73671 L .074 .635 .777 r
F
.70849 .73485 m .66253 .73714 L .66253 .87438 L p .335 .274 .639 r
F P
0 g
s
.74865 .73714 m .70849 .73485 L .70849 .87402 L p .959 .783 .621 r
F P
0 g
s
.66253 .87438 m .70849 .87402 L .70849 .73485 L p .335 .274 .639 r
F P
0 g
s
.70139 .8749 m .64101 .87438 L .70996 .87384 L p .012 .587 .719 r
F P
0 g
s
.70139 .8749 m .77017 .87438 L .77017 1.10042 L p .347 .283 .642 r
F P
0 g
s
.70849 .87402 m .74865 .87438 L .70277 .87473 L p .012 .587 .719 r
F P
0 g
s
.70277 .87473 m .66253 .87438 L .70849 .87402 L p .012 .587 .719 r
F P
0 g
s
.70996 .87384 m .64101 .87438 L .64101 1.04449 L p .333 .272 .638 r
F P
0 g
s
.64101 1.04449 m .64101 1.10042 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.64915 1.04486 m .64994 1.04489 L .70775 1.04601 L .066 0 0 r
F
.70775 1.04601 m .70996 1.10469 L p .70347 1.15371 L 0 0 .093 r
F P
0 g
s
.64101 1.10042 m .68665 1.06543 L .6578 1.04524 L .333 .272 .638 r
F
.70996 1.10469 m .70775 1.04601 L .67512 1.04601 L p .68 .398 .487 r
F P
0 g
s
.68665 1.06543 m .70996 1.04757 L .67512 1.04601 L .333 .272 .638 r
F
.68665 1.06543 m .67512 1.04601 L .6578 1.04524 L F
.70139 1.09633 m .70347 1.15371 L .5554 1.15371 L p .682 .405 .496 r
F P
0 g
s
.70139 1.09633 m .64101 1.10042 L .70996 1.10469 L p .091 0 0 r
F P
0 g
s
.64101 1.10042 m .70996 1.10469 L .70996 1.04757 L p .333 .272 .638 r
F P
0 g
s
.63981 1.07786 m .65741 1.08458 L .63901 1.04601 L .68 .398 .487 r
F
.65741 1.08458 m .70996 1.10469 L .68565 1.08458 L F
.65741 1.08458 m .68565 1.08458 L .63901 1.04601 L F
.6395 1.10246 m .6395 1.06543 L .63919 1.05309 L 0 0 .063 r
F
.67512 1.04601 m .63901 1.04601 L p .70996 1.10469 L .68 .398 .487 r
F P
0 g
s
.63901 1.04601 m .67512 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.63772 1.04465 m .67512 1.04601 L .64994 1.04489 L .066 0 0 r
F
.63806 1.04464 m .63772 1.04465 L .64994 1.04489 L F
.63806 1.04464 m .64994 1.04489 L .64915 1.04486 L F
.63806 1.04464 m .70775 1.04601 L .65515 1.0438 L F
.63806 1.04502 m .63854 .95086 L .6371 1.00646 L 0 0 .063 r
F
.6395 1.10246 m .63919 1.05309 L .63806 1.04502 L F
.55483 1.09633 m .63614 1.043 L .63551 1.06739 L .678 .717 .878 r
F
.63769 1.04463 m .63772 1.04465 L .63806 1.04464 L .066 0 0 r
F
.6395 1.10246 m .6371 1.00646 L .63593 1.05141 L 0 0 .063 r
F
.55521 1.09692 m .63568 1.09692 L p .55566 1.09853 L .09 0 0 r
F P
0 g
s
.5554 1.15371 m .55483 1.09633 L .55484 1.0956 L p 0 0 .026 r
F P
0 g
s
.55484 1.0956 m .55502 1.07831 L p .55511 1.09658 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55484 1.0956 L .55511 1.09658 L 0 0 .026 r
F
.5554 1.15371 m .55511 1.09658 L .5554 1.11604 L F
.55511 1.09658 m .55502 1.07831 L .55521 1.09692 L F
.55511 1.09658 m .55521 1.09692 L .5554 1.11604 L F
.63568 1.09692 m .6395 1.10246 L .55676 1.10246 L p .09 0 0 r
F P
0 g
s
.44479 1.09692 m .36432 1.09692 L p .44497 1.07958 L .682 .404 .495 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36616 1.0217 m .55446 1.0217 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.55468 1.04379 m .43099 1.07831 L .55446 1.0217 L .682 .404 .495 r
F
.36478 1.07831 m .36616 1.0217 L p .43099 1.07831 L F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .39206 1.07831 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .44498 1.07831 L p .44461 1.09757 L .732 .598 .026 r
F P
0 g
s
.29225 1.15905 m .29653 1.15371 L .4446 1.15371 L p .115 0 0 r
F P
0 g
s
.4446 1.15371 m .44344 1.15905 L .29225 1.15905 L p .115 0 0 r
F P
0 g
s
.44344 1.15905 m .44404 1.09962 L .44461 1.09757 L .732 .598 .026 r
F
.44404 1.09962 m .4446 1.043 L .44461 1.09757 L F
.44344 1.15905 m .44498 1.07831 L .44459 1.11724 L F
.44517 1.09633 m .4446 1.15371 L .44344 1.15905 L p F P
0 g
s
.44497 1.07958 m .55513 1.08959 L .44479 1.09692 L .682 .404 .495 r
F
.63568 1.09692 m .55521 1.09692 L p .55513 1.08959 L F P
0 g
s
.55521 1.09692 m .44479 1.09692 L p .55513 1.08959 L .682 .404 .495 r
F P
0 g
s
.55502 1.07831 m .5554 1.043 L p .5554 1.11604 L 0 0 .026 r
F P
0 g
s
.63568 1.09692 m .55676 1.10246 L .55566 1.09853 L .09 0 0 r
F
.5554 1.043 m .55656 1.04601 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.44324 1.10246 m .3605 1.10246 L p .44371 1.10079 L .09 0 0 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L p .44344 1.15905 L .732 .598 .026 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .5554 1.15371 L 0 0 .026 r
F P
0 g
s
.5554 1.15371 m .55696 1.08458 L .55655 1.12172 L 0 0 .026 r
F
.39456 1.28634 m .41565 1.26525 L .43673 1.28634 L p .707 .577 .707 r
F P
0 g
s
.43673 1.28634 m .41565 1.30743 L .39456 1.28634 L p .707 .577 .707 r
F P
0 g
s
.56327 1.28634 m .58435 1.26525 L .60544 1.28634 L p .707 .577 .707 r
F P
0 g
s
.60544 1.28634 m .58435 1.30743 L .56327 1.28634 L p .707 .577 .707 r
F P
0 g
s
.60544 1.28634 m .58435 1.26525 L .58517 1.2688 L p .587 .075 0 r
F P
0 g
s
.58435 1.30743 m .60544 1.28634 L .60616 1.28899 L p 0 0 0 r
F P
0 g
s
.56327 1.28634 m .58435 1.30743 L .58469 1.30906 L p .6 .086 0 r
F P
0 g
s
.57519 1.29998 m .56327 1.28634 L .58469 1.30906 L .6 .086 0 r
F
.57199 1.29763 m .56327 1.28634 L .58517 1.31139 L F
.58517 1.31139 m .58584 1.31208 L .57644 1.3207 L .694 .457 .559 r
F
.58584 1.31208 m .5875 1.31382 L .57644 1.3207 L F
.6274 1.28899 m .62791 1.3207 L .57644 1.3207 L p F P
0 g
s
.5637 1.28899 m .56327 1.28634 L p .57199 1.29763 L .6 .086 0 r
F P
0 g
s
.58469 1.30906 m .58517 1.31139 L p .57519 1.29998 L .6 .086 0 r
F P
0 g
s
.59388 1.30209 m .58435 1.30743 L .60616 1.28899 L 0 0 0 r
F
.60844 1.29134 m .61413 1.29725 L .5875 1.31382 L .694 .457 .559 r
F
.60844 1.29134 m .5875 1.31382 L .58584 1.31208 L F
.60337 1.29197 m .60844 1.29134 L .58584 1.31208 L F
.60337 1.29197 m .58584 1.31208 L .58517 1.31139 L F
.60764 1.29439 m .58611 1.31592 L .58435 1.30743 L p 0 0 0 r
F P
0 g
s
.57644 1.3207 m .42356 1.3207 L p .60337 1.29197 L .694 .457 .559 r
F P
0 g
s
.41047 1.31593 m .41819 1.31498 L .4059 1.3207 L .694 .457 .559 r
F
.41483 1.31139 m .41565 1.30743 L p .42374 1.30209 L 0 0 0 r
F P
0 g
s
.39456 1.28634 m .41565 1.30743 L .41531 1.30906 L p .645 .129 0 r
F P
0 g
s
.41531 1.30906 m .41483 1.31139 L p .40559 1.29998 L .645 .129 0 r
F P
0 g
s
.40559 1.29998 m .39456 1.28634 L .41531 1.30906 L .645 .129 0 r
F
.40194 1.29763 m .40014 1.29488 L .41483 1.31139 L F
.40014 1.29488 m .39456 1.28634 L .40559 1.29998 L F
.40014 1.29488 m .40559 1.29998 L .41483 1.31139 L F
.58435 1.26525 m .56327 1.28634 L .5637 1.28899 L p 0 0 0 r
F P
0 g
s
.57626 1.27718 m .58435 1.26525 L .5637 1.28899 L 0 0 0 r
F
.43673 1.28634 m .41565 1.26525 L .41483 1.2688 L p .634 .118 0 r
F P
0 g
s
.42801 1.28119 m .43673 1.28634 L .41483 1.2688 L .634 .118 0 r
F
.37209 1.3207 m .3726 1.28899 L .39384 1.28899 L p .694 .457 .559 r
F P
0 g
s
.39384 1.28899 m .39456 1.28634 L p .40194 1.29763 L .645 .129 0 r
F P
0 g
s
.41565 1.30743 m .43673 1.28634 L .4363 1.28899 L p 0 0 0 r
F P
0 g
s
.4363 1.28899 m .5637 1.28899 L p .41483 1.31139 L .694 .457 .559 r
F P
0 g
s
.5637 1.28899 m .6274 1.28899 L p .55667 1.29644 L .694 .457 .559 r
F P
0 g
s
.41483 1.31139 m .5637 1.28899 L .55667 1.29644 L .694 .457 .559 r
F
.41819 1.31498 m .41483 1.31139 L .6274 1.28899 L F
.41819 1.31498 m .60337 1.29197 L .42356 1.3207 L F
.58611 1.31592 m .56458 1.29439 L .5637 1.28899 L p .6 .086 0 r
F P
0 g
s
.58611 1.31592 m .5637 1.28899 L .57199 1.29763 L .6 .086 0 r
F
.60616 1.28899 m .5637 1.28899 L p .58517 1.2688 L .691 .686 .84 r
F P
0 g
s
.60616 1.28899 m .60544 1.28634 L p .59986 1.28245 L .587 .075 0 r
F P
0 g
s
.58611 1.27286 m .60616 1.28899 L .59986 1.28245 L .587 .075 0 r
F
.59806 1.28119 m .60544 1.28634 L .58517 1.2688 L F
.58517 1.2688 m .62791 1.2604 L .60616 1.28899 L .691 .686 .84 r
F
.58517 1.2688 m .58469 1.26671 L p .57887 1.27472 L 0 0 0 r
F P
0 g
s
.58469 1.26671 m .58435 1.26525 L p .57995 1.27175 L 0 0 0 r
F P
0 g
s
.57626 1.27718 m .58469 1.26671 L .57995 1.27175 L 0 0 0 r
F
.56458 1.29439 m .57887 1.27472 L .57626 1.27718 L F
.57887 1.27472 m .58469 1.26671 L .57626 1.27718 L F
.4363 1.28899 m .43673 1.28634 L p .42801 1.28119 L .634 .118 0 r
F P
0 g
s
.42952 1.28261 m .58953 1.2647 L .4363 1.28899 L .691 .686 .84 r
F
.58953 1.2647 m .62791 1.2604 L .58773 1.2664 L F
.58953 1.2647 m .58773 1.2664 L .4363 1.28899 L F
.58335 1.26705 m .58773 1.2664 L .58517 1.2688 L F
.58773 1.2664 m .62791 1.2604 L .58517 1.2688 L F
.56458 1.29439 m .58611 1.27286 L .58517 1.2688 L p 0 0 0 r
F P
0 g
s
.56458 1.29439 m .58517 1.2688 L .57887 1.27472 L 0 0 0 r
F
.4363 1.28899 m .43542 1.29439 L p .42374 1.30209 L F P
0 g
s
.42374 1.30209 m .41565 1.30743 L .4363 1.28899 L 0 0 0 r
F
.39384 1.28899 m .4363 1.28899 L p .41483 1.31139 L .694 .457 .559 r
F P
0 g
s
.37209 1.3207 m .39384 1.28899 L .41819 1.31498 L .694 .457 .559 r
F
.41389 1.31592 m .39236 1.29439 L .39384 1.28899 L p .645 .129 0 r
F P
0 g
s
.41389 1.31592 m .39384 1.28899 L .40194 1.29763 L .645 .129 0 r
F
.41565 1.26525 m .39456 1.28634 L .39384 1.28899 L p 0 0 0 r
F P
0 g
s
.40612 1.27718 m .41565 1.26525 L .39384 1.28899 L 0 0 0 r
F
.39663 1.2863 m .41483 1.2688 L .42952 1.28261 L .691 .686 .84 r
F
.4363 1.28899 m .39384 1.28899 L p .42952 1.28261 L F P
0 g
s
.39156 1.28686 m .42952 1.28261 L .39384 1.28899 L .691 .686 .84 r
F
.39236 1.29439 m .41389 1.27286 L .41483 1.2688 L p 0 0 0 r
F P
0 g
s
.41483 1.2688 m .41565 1.26525 L p .40612 1.27718 L 0 0 0 r
F P
0 g
s
.39236 1.29439 m .41483 1.2688 L .40612 1.27718 L 0 0 0 r
F
.42952 1.28261 m .41483 1.2688 L .62791 1.2604 L .691 .686 .84 r
F
.4059 1.2604 m .42356 1.2604 L p .41483 1.2688 L F P
0 g
s
.42356 1.2604 m .62791 1.2604 L p .41483 1.2688 L .691 .686 .84 r
F P
0 g
s
.39156 1.28686 m .4059 1.2604 L .41483 1.2688 L .691 .686 .84 r
F
.39156 1.28686 m .41483 1.2688 L .39663 1.2863 L F
.39384 1.28899 m .39236 1.29439 L p .40612 1.27718 L 0 0 0 r
F P
0 g
s
.41389 1.27286 m .43542 1.29439 L .4363 1.28899 L p .634 .118 0 r
F P
0 g
s
.41389 1.27286 m .4363 1.28899 L .42801 1.28119 L .634 .118 0 r
F
.37209 1.2604 m .4059 1.2604 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.3726 1.28899 m .37224 1.2688 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.37224 1.2688 m .37209 1.2604 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.39384 1.28899 m .3726 1.28899 L p .39156 1.28686 L .691 .686 .84 r
F P
0 g
s
.43542 1.29439 m .41389 1.31592 L .41483 1.31139 L p 0 0 0 r
F P
0 g
s
.43542 1.29439 m .41483 1.31139 L .42374 1.30209 L 0 0 0 r
F
.42356 1.3207 m .4059 1.3207 L p .41819 1.31498 L .694 .457 .559 r
F P
0 g
s
.4059 1.3207 m .37209 1.3207 L p .41047 1.31593 L .694 .457 .559 r
F P
0 g
s
.41483 1.31139 m .41389 1.31592 L p .40194 1.29763 L .645 .129 0 r
F P
0 g
s
.5637 1.28899 m .56458 1.29439 L p .57626 1.27718 L 0 0 0 r
F P
0 g
s
.5637 1.28899 m .58335 1.26705 L .58517 1.2688 L .691 .686 .84 r
F
.5637 1.28899 m .4363 1.28899 L p .54651 1.27255 L F P
0 g
s
.54651 1.27255 m .58335 1.26705 L .5637 1.28899 L .691 .686 .84 r
F
.58517 1.31139 m .58611 1.31592 L p .57199 1.29763 L .6 .086 0 r
F P
0 g
s
.60844 1.29134 m .6274 1.28899 L .61413 1.29725 L .694 .457 .559 r
F
.60616 1.28899 m .60764 1.29439 L p .59388 1.30209 L 0 0 0 r
F P
0 g
s
.58611 1.27286 m .60764 1.29439 L .60616 1.28899 L p .587 .075 0 r
F P
0 g
s
.58517 1.2688 m .58611 1.27286 L p .59806 1.28119 L .587 .075 0 r
F P
0 g
s
.62791 1.2604 m .6274 1.28899 L .60616 1.28899 L p .691 .686 .84 r
F P
0 g
s
.41483 1.2688 m .41389 1.27286 L p .42801 1.28119 L .634 .118 0 r
F P
0 g
s
.62791 1.2604 m .51457 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.62801 1.25967 m .62791 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .484 1.25967 L .48456 1.25996 L .365 .792 .97 r
F
.37209 1.2604 m .39284 1.25967 L .48456 1.25996 L F
.48489 1.26013 m .48456 1.25996 L .51526 1.26005 L F
.37209 1.2604 m .48456 1.25996 L .48489 1.26013 L F
.55521 1.09692 m .52783 1.09787 L .51462 1.09771 L .09 0 0 r
F
.55521 1.09692 m .51462 1.09771 L .51036 1.09725 L F
.49267 1.09692 m .55521 1.09692 L p .48814 1.09741 L F P
0 g
s
.53229 1.09965 m .53229 1.25133 L p .51878 1.09817 L .08 .066 .539 r
F P
0 g
s
.484 1.09787 m .484 1.25967 L p .47036 1.09936 L .997 .814 .539 r
F P
0 g
s
.44479 1.09692 m .49267 1.09692 L p .48814 1.09741 L .09 0 0 r
F P
0 g
s
.47 1.0994 m .484 1.25967 L .48163 1.25846 L .997 .814 .539 r
F
.452 1.09787 m .44371 1.10079 L .44453 1.09787 L .09 0 0 r
F
.484 1.09787 m .46446 1.09928 L .452 1.09787 L F
.46446 1.09928 m .44371 1.10079 L .452 1.09787 L F
.46368 1.10009 m .44371 1.10079 L .46446 1.09928 L F
.46771 1.09965 m .46446 1.09928 L .484 1.09787 L F
.46368 1.10009 m .46446 1.09928 L .46771 1.09965 L F
.47036 1.09936 m .484 1.25967 L .47 1.0994 L .997 .814 .539 r
F
.51457 1.2604 m .37209 1.2604 L p .51526 1.26005 L .365 .792 .97 r
F P
0 g
s
.51462 1.09771 m .44453 1.09787 L .44479 1.09692 L .09 0 0 r
F
.52783 1.09787 m .516 1.09787 L .51462 1.09771 L F
.516 1.09787 m .44453 1.09787 L .51462 1.09771 L F
.48028 1.24005 m .48163 1.25846 L .46771 1.25133 L .997 .814 .539 r
F
.516 1.25967 m .516 1.09787 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.52783 1.09787 m .51885 1.09818 L .516 1.09787 L .09 0 0 r
F
.516 1.09787 m .516 1.06663 L p .51825 1.09811 L .08 .066 .539 r
F P
0 g
s
.51825 1.09811 m .52932 1.25285 L .516 1.09787 L .08 .066 .539 r
F
.46771 1.25133 m .46771 1.09965 L p .48028 1.24005 L .997 .814 .539 r
F P
0 g
s
.46771 1.09965 m .46771 1.06813 L p .47 1.0994 L .997 .814 .539 r
F P
0 g
s
.47 1.0994 m .48028 1.24005 L .46771 1.09965 L .997 .814 .539 r
F
.51825 1.09811 m .53229 1.25133 L .529 1.24838 L .08 .066 .539 r
F
.51878 1.09817 m .53229 1.25133 L .51825 1.09811 L F
.484 1.25967 m .484 1.09787 L p .51083 1.25967 L .707 .577 .707 r
F P
0 g
s
.48456 1.25996 m .516 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.25967 m .516 1.25967 L .48456 1.25996 L F
.48846 1.09787 m .51155 1.25967 L .484 1.09787 L .707 .577 .707 r
F
.51155 1.25967 m .516 1.29086 L .51083 1.25967 L F
.51155 1.25967 m .51083 1.25967 L .484 1.09787 L F
.46771 1.09965 m .46771 1.25133 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.529 1.24838 m .53229 1.25133 L .52932 1.25285 L .08 .066 .539 r
F
.51036 1.09725 m .51462 1.09771 L .48814 1.09741 L .09 0 0 r
F
.516 1.25967 m .62801 1.25967 L .51526 1.26005 L .365 .792 .97 r
F
.484 1.06663 m .516 1.06663 L .516 1.09787 L p .707 .577 .707 r
F P
0 g
s
.516 1.09787 m .516 1.29086 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.484 1.06663 m .516 1.09787 L .48846 1.09787 L .707 .577 .707 r
F
.46771 1.25133 m .53229 1.25133 L p .45621 1.25744 L .365 .792 .97 r
F P
0 g
s
.53229 1.25133 m .62917 1.25133 L p .53833 1.25454 L .365 .792 .97 r
F P
0 g
s
.45621 1.25744 m .53229 1.25133 L .53833 1.25454 L .365 .792 .97 r
F
.51434 1.25793 m .54175 1.25635 L .52667 1.25967 L F
.54175 1.25635 m .62917 1.25133 L .54517 1.25817 L F
.54175 1.25635 m .54517 1.25817 L .52667 1.25967 L F
.53008 1.0999 m .51999 1.24481 L .53229 1.09965 L .998 .815 .53 r
F
.484 1.25967 m .51434 1.25793 L .52667 1.25967 L .365 .792 .97 r
F
.62917 1.25133 m .62801 1.25967 L p .52667 1.25967 L F P
0 g
s
.4813 1.25829 m .54018 1.25552 L .484 1.25967 L .365 .792 .97 r
F
.54018 1.25552 m .62917 1.25133 L .54175 1.25635 L F
.54018 1.25552 m .54175 1.25635 L .484 1.25967 L F
.54451 1.09826 m .44371 1.10079 L .52783 1.09787 L .09 0 0 r
F
.53926 1.09886 m .44371 1.10079 L .54451 1.09826 L F
.55547 1.09787 m .52783 1.09787 L .55521 1.09692 L F
.55566 1.09853 m .52783 1.09787 L .55547 1.09787 L F
.45621 1.25744 m .62917 1.25133 L .452 1.25967 L .365 .792 .97 r
F
.53229 1.25133 m .53229 1.29439 L p .52932 1.25285 L .08 .066 .539 r
F P
0 g
s
.53229 1.29439 m .516 1.29086 L .516 1.25967 L p .08 .066 .539 r
F P
0 g
s
.52932 1.25285 m .53229 1.29439 L .516 1.25967 L .08 .066 .539 r
F
.516 1.29086 m .53229 1.29439 L .51629 1.29798 L p .174 0 0 r
F P
0 g
s
.51629 1.29798 m .53229 1.29439 L .53229 1.25133 L p .998 .815 .53 r
F P
0 g
s
.53229 1.25133 m .46771 1.25133 L p .52377 1.25926 L .513 .022 .027 r
F P
0 g
s
.452 1.25967 m .4813 1.25829 L .484 1.25967 L .365 .792 .97 r
F
.484 1.29086 m .46771 1.29439 L .46771 1.25133 L p .997 .814 .539 r
F P
0 g
s
.48163 1.25846 m .484 1.29086 L .46771 1.25133 L .997 .814 .539 r
F
.46771 1.25133 m .46771 1.29439 L p .47058 1.25401 L .063 .051 .53 r
F P
0 g
s
.51083 1.25967 m .516 1.29086 L .484 1.25967 L .707 .577 .707 r
F
.47468 1.25782 m .52213 1.26079 L .46771 1.25133 L .513 .022 .027 r
F
.52213 1.26079 m .52377 1.25926 L .46771 1.25133 L F
.47144 1.24935 m .47102 1.25442 L .48371 1.24284 L .063 .051 .53 r
F
.47102 1.25442 m .46771 1.29439 L .47808 1.26098 L F
.51906 1.26364 m .51629 1.29798 L .53229 1.25133 L .998 .815 .53 r
F
.516 1.29086 m .484 1.29086 L .484 1.25967 L p .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .484 1.29086 L .516 1.29086 L p .174 0 0 r
F P
0 g
s
.48371 1.29798 m .46771 1.29439 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.51629 1.29798 m .48371 1.29798 L p .516 1.29086 L .174 0 0 r
F P
0 g
s
.48371 1.29798 m .51629 1.29798 L .51629 1.26622 L p .707 .577 .707 r
F P
0 g
s
.48897 1.26622 m .48371 1.29798 L .51629 1.26622 L .707 .577 .707 r
F
.48824 1.26622 m .48371 1.29798 L .48897 1.26622 L F
.51629 1.26622 m .51629 1.29798 L p .51866 1.26402 L .998 .815 .53 r
F P
0 g
s
.484 1.25967 m .484 1.29086 L p .48163 1.25846 L .997 .814 .539 r
F P
0 g
s
.48209 1.26471 m .48371 1.26622 L .484 1.26622 L .513 .022 .027 r
F
.48209 1.26471 m .484 1.26622 L .51629 1.26622 L F
.47468 1.25782 m .48209 1.26471 L .51629 1.26622 L F
.51866 1.26402 m .51629 1.29798 L .51906 1.26364 L .998 .815 .53 r
F
.52213 1.26079 m .51629 1.26622 L .60911 1.26622 L .513 .022 .027 r
F
.47468 1.25782 m .51629 1.26622 L .52213 1.26079 L F
.51999 1.24481 m .51866 1.26402 L .52056 1.24511 L .998 .815 .53 r
F
.51866 1.26402 m .51906 1.26364 L .52056 1.24511 L F
.51629 1.24284 m .51629 1.26622 L p .51999 1.24481 L F P
0 g
s
.51999 1.24481 m .51629 1.26622 L .51866 1.26402 L .998 .815 .53 r
F
.62791 1.3207 m .6274 1.28899 L .62791 1.2604 L p 0 0 .059 r
F P
0 g
s
.62791 1.2604 m .62917 1.25133 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62917 1.25133 m .63045 1.26755 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.60911 1.26622 m .51521 1.26723 L .63045 1.26755 L .513 .022 .027 r
F
.53645 1.09918 m .47146 1.10147 L .4687 1.10147 L .09 0 0 r
F
.53616 1.09921 m .47166 1.10147 L .53645 1.09918 L F
.36524 1.09633 m .29861 1.09633 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.4446 1.043 m .36524 1.09633 L .36462 1.07222 L .678 .717 .878 r
F
.36432 1.09692 m .36478 1.07831 L p .43099 1.07831 L .682 .404 .495 r
F P
0 g
s
.36432 .94981 m .36616 1.0217 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.3605 1.10246 m .36194 1.04502 L .36407 1.05141 L .767 .626 .063 r
F
.35899 1.04449 m .35899 1.10042 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.35899 1.10042 m .29861 1.09633 L .29861 1.04154 L p .298 .244 .626 r
F P
0 g
s
.36194 1.04502 m .36386 1.043 L .36407 1.05141 L .767 .626 .063 r
F
.36386 1.043 m .3641 1.04275 L .36407 1.05141 L F
.36386 1.043 m .4446 1.043 L p .36462 1.07222 L .678 .717 .878 r
F P
0 g
s
.44344 1.04601 m .4446 1.043 L .36386 1.043 L p .066 0 0 r
F P
0 g
s
.36386 1.043 m .32849 1.043 L p .363 1.04391 L .066 0 0 r
F P
0 g
s
.44344 1.04601 m .36386 1.043 L .363 1.04391 L .066 0 0 r
F
.3629 1.00646 m .36432 .94981 L .3641 1.04275 L .767 .626 .063 r
F
.3629 1.00646 m .3641 1.04275 L .36386 1.043 L F
.36257 1.04436 m .32849 1.043 L .3516 1.04413 L .066 0 0 r
F
.44344 1.04601 m .363 1.04391 L .36257 1.04436 L F
.363 1.04391 m .32849 1.043 L .36257 1.04436 L F
.35899 1.10042 m .29861 1.04154 L .34382 1.04375 L .298 .244 .626 r
F
.22983 .87438 m .29861 .8749 L .29861 1.09633 L p .938 .766 .642 r
F P
0 g
s
.32804 1.04379 m .29653 1.043 L .32849 1.043 L p .678 .717 .878 r
F P
0 g
s
.29653 1.043 m .32767 1.04446 L p .29861 1.09633 L .678 .717 .878 r
F P
0 g
s
.29861 1.04154 m .29861 .8749 L p .34382 1.04375 L .298 .244 .626 r
F P
0 g
s
.33873 1.02473 m .29861 .8749 L .35899 .98856 L .298 .244 .626 r
F
.29723 .73937 m .33747 .73714 L .33747 .87438 L p .295 .241 .625 r
F P
0 g
s
.33747 .87438 m .29723 .87473 L .29723 .73937 L p .295 .241 .625 r
F P
0 g
s
.25135 .73714 m .29723 .73937 L .29723 .87473 L p .939 .766 .642 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .25135 .73714 L p .939 .766 .642 r
F P
0 g
s
.30023 .73633 m .29482 .73747 L p .26244 .65364 L .866 .669 .635 r
F P
0 g
s
.28331 .73714 m .28257 .73418 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.28257 .73418 m .26244 .65364 L p .29482 .73747 L .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .26244 .65364 L .27743 .64897 L closepath p .301 .796 .807 r
F P
0 g
s
.26244 .65364 m .27877 .65048 L .30023 .73633 L p .866 .669 .635 r
F P
0 g
s
.27877 .65048 m .27743 .64897 L .28266 .66988 L p .753 .475 0 r
F P
0 g
s
.28397 .73453 m .29164 .70386 L p .29962 .73644 L .864 .743 .727 r
F P
0 g
s
.30021 .73631 m .30023 .73633 L .29482 .73747 L p .264 .771 .774 r
F P
0 g
s
.29991 .73761 m .29688 .73703 L .29962 .73644 L .864 .743 .727 r
F
.29688 .73703 m .28397 .73453 L .29962 .73644 L F
.29482 .73747 m .28397 .73453 L p .29991 .73761 L F P
0 g
s
.29723 .73937 m .29482 .73747 L .30056 .73763 L .074 .635 .777 r
F
.31916 .73816 m .30235 .73909 L p .30056 .73763 L F P
0 g
s
.30235 .73909 m .29723 .73937 L p .30056 .73763 L .074 .635 .777 r
F P
0 g
s
.29951 .73601 m .29164 .70386 L .29981 .73481 L .864 .743 .727 r
F
.29951 .73601 m .29981 .73481 L .30035 .73686 L F
.30023 .73893 m .29951 .73601 L .30035 .73686 L F
.28397 .73453 m .294 .73682 L p .29707 .72696 L .478 .35 .627 r
F P
0 g
s
.28397 .73453 m .29707 .72696 L .29368 .71255 L .478 .35 .627 r
F
.29905 .73536 m .30023 .73633 L .28396 .67126 L p .753 .475 0 r
F P
0 g
s
.30035 .73686 m .29981 .73481 L .30067 .73138 L .864 .743 .727 r
F
.29981 .73481 m .29164 .70386 L .30067 .73138 L F
.29164 .70386 m .30549 .64842 L p .30067 .73138 L F P
0 g
s
.32169 .65308 m .30549 .64842 L .32062 .65159 L closepath p 0 .489 .77 r
F P
0 g
s
.30549 .64842 m .32169 .65308 L .30023 .73893 L p .864 .743 .727 r
F P
0 g
s
.29972 .73517 m .32062 .65159 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.32062 .65159 m .30549 .64842 L .28397 .73453 L p .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .27877 .65048 L .753 .475 0 r
F P
0 g
s
.28396 .67126 m .27877 .65048 L p .29905 .73536 L .753 .475 0 r
F P
0 g
s
.29368 .71255 m .29707 .72696 L .32062 .65159 L .478 .35 .627 r
F
.30021 .73631 m .2948 .73746 L .2989 .7354 L .264 .771 .774 r
F
.29905 .73536 m .30021 .73631 L p .2989 .7354 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29723 .73937 m .2637 .73774 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28397 .73453 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.28397 .73453 m .294 .73682 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.27743 .64897 m .26244 .65364 L .28331 .73714 L p .482 .433 .727 r
F P
0 g
s
.28378 .73713 m .27743 .64897 L .28331 .73714 L .482 .433 .727 r
F
.29903 .73534 m .27743 .64897 L p .28378 .73713 L F P
0 g
s
.294 .73682 m .29903 .73534 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.26195 .73654 m .29151 .73485 L p .294 .73682 L .074 .635 .777 r
F P
0 g
s
.29482 .73747 m .28331 .73714 L .294 .73682 L .074 .635 .777 r
F
.28331 .73714 m .26195 .73654 L .294 .73682 L F
.29723 .73937 m .26195 .73654 L .29482 .73747 L F
.29482 .73747 m .28397 .73975 L .28331 .73714 L p .866 .669 .635 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.29482 .73747 m .28397 .73975 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73631 L .264 .771 .774 r
F
.30023 .73893 m .29482 .73747 L p .29991 .73761 L .864 .743 .727 r
F P
0 g
s
.29482 .73747 m .2948 .73746 L .30021 .73891 L 0 .459 .734 r
F
.33747 .73714 m .31916 .73816 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.29935 .73665 m .29972 .73517 L p .294 .73682 L .478 .35 .627 r
F P
0 g
s
.29903 .73534 m .29905 .73536 L p .2989 .7354 L .264 .771 .774 r
F P
0 g
s
.32169 .65308 m .32062 .65159 L .29935 .73665 L p .784 .778 .275 r
F P
0 g
s
.29937 .73667 m .32169 .65308 L .29935 .73665 L .784 .778 .275 r
F
.28266 .66988 m .29903 .73534 L p .29034 .69894 L .753 .475 0 r
F P
0 g
s
.29903 .73796 m .30023 .73893 L .30056 .73763 L p .784 .778 .275 r
F P
0 g
s
.30056 .73763 m .32169 .65308 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29482 .73747 m .29811 .73564 L .30056 .73763 L .074 .635 .777 r
F
.29903 .73796 m .30056 .73763 L .29937 .73667 L .784 .778 .275 r
F
.29482 .73747 m .29151 .73485 L .29811 .73564 L .074 .635 .777 r
F
.30056 .73763 m .29811 .73564 L .31916 .73816 L F
.29151 .73485 m .31688 .73611 L p .3051 .73648 L F P
0 g
s
.31688 .73611 m .33747 .73714 L p .3051 .73648 L .074 .635 .777 r
F P
0 g
s
.294 .73682 m .29903 .73796 L .29935 .73665 L p .478 .35 .627 r
F P
0 g
s
.28397 .73975 m .294 .73682 L p .2948 .73746 L .264 .771 .774 r
F P
0 g
s
.29903 .73796 m .30021 .73891 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.294 .73682 m .29903 .73796 L p .2948 .73746 L 0 .459 .734 r
F P
0 g
s
.29935 .73665 m .29903 .73796 L p .29937 .73667 L .784 .778 .275 r
F P
0 g
s
.29034 .69894 m .27877 .65048 L .28266 .66988 L .753 .475 0 r
F
.30021 .73891 m .30023 .73893 L .29482 .73747 L p 0 .459 .734 r
F P
0 g
s
.28331 .73714 m .28397 .73975 L p .28378 .73713 L .482 .433 .727 r
F P
0 g
s
.25135 .73714 m .26195 .73654 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.2637 .73774 m .25135 .73714 L p .27329 .73745 L .074 .635 .777 r
F P
0 g
s
.25135 .87438 m .29151 .87402 L .29151 .73485 L p .284 .232 .621 r
F P
0 g
s
.33747 .73714 m .29151 .73485 L .29151 .87402 L p .942 .769 .639 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .33747 .73714 L p .942 .769 .639 r
F P
0 g
s
.29004 .87384 m .35899 .87438 L .29861 .8749 L p .012 .587 .719 r
F P
0 g
s
.29151 .73485 m .25135 .73714 L .25135 .87438 L p .284 .232 .621 r
F P
0 g
s
.29861 .8749 m .22983 .87438 L .29004 .87384 L p .012 .587 .719 r
F P
0 g
s
.29151 .87402 m .33747 .87438 L .29723 .87473 L p .012 .587 .719 r
F P
0 g
s
.29723 .87473 m .25135 .87438 L .29151 .87402 L p .012 .587 .719 r
F P
0 g
s
.35899 .87438 m .29004 .87384 L .29004 1.04757 L p .943 .77 .638 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .22983 .87438 L p .938 .766 .642 r
F P
0 g
s
.29861 1.09633 m .22983 1.10042 L .29004 1.10469 L p .091 0 0 r
F P
0 g
s
.29653 1.043 m .29861 1.09633 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.04601 m .29653 1.043 L p .29225 1.15905 L .794 .648 .093 r
F P
0 g
s
.29225 1.15905 m .29004 1.10469 L .29225 1.04601 L p .794 .648 .093 r
F P
0 g
s
.29861 1.09633 m .29653 1.15371 L .29225 1.15905 L p .794 .648 .093 r
F P
0 g
s
.29004 1.10469 m .35899 1.10042 L .29861 1.09633 L p .091 0 0 r
F P
0 g
s
.35787 1.04454 m .29653 1.043 L .34335 1.04519 L .066 0 0 r
F
.32849 1.043 m .29653 1.043 L p .3516 1.04413 L F P
0 g
s
.36257 1.04436 m .36221 1.04435 L .36228 1.04465 L .066 0 0 r
F
.36221 1.04435 m .3516 1.04413 L .35899 1.04449 L F
.36221 1.04435 m .35899 1.04449 L .36228 1.04465 L F
.29004 1.10469 m .35899 1.10042 L .35899 1.04449 L p .943 .77 .638 r
F P
0 g
s
.29004 1.10469 m .35899 1.04449 L .32488 1.04601 L .943 .77 .638 r
F
.3516 1.04413 m .29653 1.043 L .35787 1.04454 L .066 0 0 r
F
.35899 1.04449 m .35787 1.04454 L .36228 1.04465 L F
.3516 1.04413 m .35787 1.04454 L .35899 1.04449 L F
.29653 1.043 m .29225 1.04601 L .36099 1.04601 L p F P
0 g
s
.3605 1.10246 m .3605 1.06543 L .36194 1.04502 L .767 .626 .063 r
F
.3605 1.06543 m .36099 1.04601 L .36194 1.04502 L F
.3605 1.10246 m .44324 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44344 1.04601 m .36099 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.44304 1.08458 m .44344 1.04601 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.36099 1.04601 m .29225 1.04601 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.36432 1.09692 m .3605 1.10246 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.36478 1.07831 m .36432 1.09692 L p .36407 1.05141 L .767 .626 .063 r
F P
0 g
s
.35899 .98856 m .35899 1.04449 L p .33873 1.02473 L .298 .244 .626 r
F P
0 g
s
.34382 1.04375 m .33873 1.02473 L .35899 1.04449 L .298 .244 .626 r
F
.35899 1.04449 m .35899 .98856 L p .32488 1.04601 L .943 .77 .638 r
F P
0 g
s
.36032 1.07254 m .29225 1.04601 L .35951 1.10469 L .68 .398 .487 r
F
.36228 1.04465 m .35787 1.04454 L .36099 1.04601 L .066 0 0 r
F
.35787 1.04454 m .34335 1.04519 L .36099 1.04601 L F
.3605 1.10246 m .35851 1.02865 L .3605 .95121 L p .767 .626 .063 r
F P
0 g
s
.36002 1.08458 m .3605 1.10246 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44284 1.10469 m .36099 1.04601 L .36032 1.07254 L .68 .398 .487 r
F
.3605 1.04653 m .3605 .95121 L .36159 1.02223 L .767 .626 .063 r
F
.36099 1.04601 m .36159 1.02223 L .36194 1.04502 L F
.3605 1.04653 m .36159 1.02223 L .36099 1.04601 L F
.35951 1.10469 m .44284 1.10469 L p .36032 1.07254 L .68 .398 .487 r
F P
0 g
s
.3605 1.06543 m .3605 1.04653 L .36099 1.04601 L .767 .626 .063 r
F
.3605 .95121 m .36432 .94981 L p .36194 1.04502 L F P
0 g
s
.36194 1.04502 m .3629 1.00646 L .36386 1.043 L .767 .626 .063 r
F
.36099 1.04601 m .44344 1.04601 L p .36257 1.04436 L .066 0 0 r
F P
0 g
s
.35851 1.02865 m .36002 1.08458 L p .42272 1.08458 L .676 .72 .882 r
F P
0 g
s
.44267 1.05076 m .35851 1.02865 L .44324 1.10246 L .676 .72 .882 r
F
.44284 1.10469 m .44304 1.08458 L p .41479 1.08458 L .68 .398 .487 r
F P
0 g
s
.35899 .98856 m .35899 .87438 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.29225 1.04601 m .29004 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.10469 m .32488 1.04601 L .30737 1.04679 L .943 .77 .638 r
F
.32488 1.04601 m .35899 .98856 L .30737 1.04679 L F
.29004 1.10469 m .35951 1.10469 L p .31374 1.06477 L .68 .398 .487 r
F P
0 g
s
.29004 1.04757 m .29004 1.10469 L p .30737 1.04679 L .943 .77 .638 r
F P
0 g
s
.30737 1.04679 m .35899 .87438 L .29004 1.04757 L .943 .77 .638 r
F
.44304 1.08458 m .44344 1.04601 L p .44344 1.12059 L .732 .598 .026 r
F P
0 g
s
.47166 1.10147 m .44324 1.10246 L .47146 1.10147 L .09 0 0 r
F
.47166 1.10147 m .47146 1.10147 L .53645 1.09918 L F
.53008 1.0999 m .51629 1.24284 L .51999 1.24481 L .998 .815 .53 r
F
.53926 1.09886 m .4687 1.10147 L .46043 1.10045 L .09 0 0 r
F
.53645 1.09918 m .4687 1.10147 L .53926 1.09886 L F
.52938 1.09998 m .51629 1.24284 L .53008 1.0999 L .998 .815 .53 r
F
.51175 1.10147 m .48371 1.26622 L .48824 1.26622 L .707 .577 .707 r
F
.51102 1.10147 m .48371 1.26622 L .51175 1.10147 L F
.48371 1.10147 m .48371 1.26622 L p .51102 1.10147 L F P
0 g
s
.51175 1.10147 m .48824 1.26622 L .51629 1.10147 L .707 .577 .707 r
F
.48824 1.26622 m .48897 1.26622 L .51629 1.10147 L F
.51629 1.26622 m .51629 1.10147 L p .48897 1.26622 L F P
0 g
s
.51629 1.10147 m .51629 1.24284 L p .52938 1.09998 L .998 .815 .53 r
F P
0 g
s
.51999 1.24481 m .52056 1.24511 L .53229 1.09965 L .998 .815 .53 r
F
.53229 1.25133 m .53229 1.09965 L p .52056 1.24511 L F P
0 g
s
.48146 1.10121 m .46771 1.25133 L .47089 1.24964 L .063 .051 .53 r
F
.48371 1.24284 m .48371 1.10147 L p .47144 1.24935 L F P
0 g
s
.48146 1.10121 m .46771 1.29439 L .48371 1.10147 L .063 .051 .53 r
F
.55676 1.10246 m .44324 1.10246 L p .53019 1.09942 L .09 0 0 r
F P
0 g
s
.55566 1.09853 m .55672 1.10233 L .53019 1.09942 L .09 0 0 r
F
.516 1.06663 m .53229 1.06813 L .53229 1.09965 L p .08 .066 .539 r
F P
0 g
s
.516 1.06663 m .53229 1.09965 L .51878 1.09817 L .08 .066 .539 r
F
.53229 1.06813 m .52938 1.09998 L .53008 1.0999 L .998 .815 .53 r
F
.55566 1.09853 m .53645 1.09918 L .53926 1.09886 L .09 0 0 r
F
.4687 1.10147 m .44328 1.10233 L .45112 1.10147 L F
.4687 1.10147 m .45112 1.10147 L .46043 1.10045 L F
.516 1.09787 m .46368 1.10009 L .484 1.09787 L F
.51885 1.09818 m .46368 1.10009 L .516 1.09787 L F
.516 1.06663 m .51878 1.09817 L .51825 1.09811 L .08 .066 .539 r
F
.51629 1.06966 m .51102 1.10147 L .51175 1.10147 L .707 .577 .707 r
F
.46771 1.06813 m .484 1.06663 L .484 1.09787 L p .997 .814 .539 r
F P
0 g
s
.46771 1.06813 m .484 1.09787 L .47036 1.09936 L .997 .814 .539 r
F
.484 1.09787 m .484 1.06663 L p .48846 1.09787 L .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L .48371 1.10147 L p .707 .577 .707 r
F P
0 g
s
.51629 1.06966 m .48371 1.10147 L .51102 1.10147 L .707 .577 .707 r
F
.51629 1.10147 m .51629 1.06966 L p .51175 1.10147 L F P
0 g
s
.4687 1.10147 m .44324 1.10246 L .44328 1.10233 L .09 0 0 r
F
.47146 1.10147 m .44324 1.10246 L .4687 1.10147 L F
.55566 1.09853 m .53616 1.09921 L .53645 1.09918 L F
.53229 1.06813 m .51629 1.06966 L .51629 1.10147 L p .998 .815 .53 r
F P
0 g
s
.53229 1.06813 m .51629 1.10147 L .52938 1.09998 L .998 .815 .53 r
F
.53229 1.09965 m .53229 1.06813 L p .53008 1.0999 L F P
0 g
s
.55566 1.09853 m .53926 1.09886 L .54451 1.09826 L .09 0 0 r
F
.46043 1.10045 m .44328 1.10233 L .44371 1.10079 L F
.48371 1.10147 m .48371 1.06966 L p .48146 1.10121 L .063 .051 .53 r
F P
0 g
s
.46771 1.06813 m .47036 1.09936 L .47 1.0994 L .997 .814 .539 r
F
.48371 1.06966 m .46771 1.06813 L .46771 1.09965 L p .063 .051 .53 r
F P
0 g
s
.48371 1.06966 m .46771 1.09965 L .48146 1.10121 L .063 .051 .53 r
F
.55672 1.10233 m .55676 1.10246 L .53019 1.09942 L .09 0 0 r
F
.44324 1.10246 m .6395 1.10246 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.59496 1.09076 m .61173 1.08458 L .57144 1.08458 L .676 .72 .882 r
F
.6395 1.10246 m .61173 1.08458 L .59496 1.09076 L F
.63568 1.09692 m .6395 1.10246 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.63522 1.07831 m .63568 1.09692 L p .63593 1.05141 L 0 0 .063 r
F P
0 g
s
.64049 1.10469 m .70996 1.10469 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.67512 1.04601 m .70775 1.04601 L p .64994 1.04489 L .066 0 0 r
F P
0 g
s
.65515 1.0438 m .70775 1.04601 L .67151 1.043 L .066 0 0 r
F
.6578 1.04524 m .70996 .87384 L .64101 1.04449 L .333 .272 .638 r
F
.6395 1.10246 m .64149 1.02865 L .6395 .95121 L p 0 0 .063 r
F P
0 g
s
.6395 1.10246 m .63998 1.08458 L p .61173 1.08458 L .676 .72 .882 r
F P
0 g
s
.55716 1.10469 m .64049 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.55656 1.04601 m .55696 1.08458 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.57144 1.08458 m .44304 1.08458 L .44324 1.10246 L .676 .72 .882 r
F
.55696 1.08458 m .55716 1.10469 L p .61173 1.08458 L .68 .398 .487 r
F P
0 g
s
.46771 1.06813 m .484 1.06663 L .516 1.06663 L p .076 0 0 r
F P
0 g
s
.48371 1.06966 m .46771 1.06813 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.51629 1.06966 m .48371 1.06966 L p .516 1.06663 L .076 0 0 r
F P
0 g
s
.57144 1.08458 m .44267 1.05076 L .44304 1.08458 L .676 .72 .882 r
F
.44344 1.15905 m .44284 1.10469 L .44304 1.08458 L p .732 .598 .026 r
F P
0 g
s
.44344 1.15905 m .44304 1.08458 L .44344 1.12059 L .732 .598 .026 r
F
.48371 1.26622 m .48371 1.29798 L p .48824 1.26622 L .707 .577 .707 r
F P
0 g
s
.46771 1.29439 m .48371 1.29798 L .48371 1.24284 L p .063 .051 .53 r
F P
0 g
s
.37209 1.3207 m .3726 1.28899 L .37209 1.2604 L p .763 .623 .059 r
F P
0 g
s
.37209 1.2604 m .37083 1.25133 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.37083 1.25133 m .36955 1.26755 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .48514 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.37083 1.25133 m .46771 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .46771 1.25133 L .45621 1.25744 L .365 .792 .97 r
F
.37209 1.2604 m .37199 1.25967 L p .39284 1.25967 L F P
0 g
s
.37199 1.25967 m .37083 1.25133 L p .39284 1.25967 L .365 .792 .97 r
F P
0 g
s
.39284 1.25967 m .45621 1.25744 L .452 1.25967 L .365 .792 .97 r
F
.37083 1.25133 m .36966 1.26622 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.36966 1.26622 m .36955 1.26755 L p .47575 1.26622 L .513 .022 .027 r
F P
0 g
s
.48514 1.26755 m .51486 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.51486 1.26755 m .63045 1.26755 L p .51521 1.26723 L .513 .022 .027 r
F P
0 g
s
.48371 1.26622 m .48514 1.26755 L .60911 1.26622 L .513 .022 .027 r
F
.47102 1.25442 m .47808 1.26098 L .48371 1.24284 L .063 .051 .53 r
F
.37083 1.25133 m .48514 1.26755 L .47468 1.25782 L .513 .022 .027 r
F
.4614 1.25699 m .47468 1.25782 L .46771 1.25133 L F
.47089 1.24964 m .46771 1.25133 L .47058 1.25401 L .063 .051 .53 r
F
.52056 1.24511 m .51906 1.26364 L .53229 1.25133 L .998 .815 .53 r
F
.52213 1.26079 m .54437 1.26218 L .52377 1.25926 L .513 .022 .027 r
F
.52377 1.25926 m .54437 1.26218 L .53229 1.25133 L F
.46771 1.25133 m .37083 1.25133 L p .4614 1.25699 L F P
0 g
s
.63045 1.26755 m .62917 1.25133 L .53229 1.25133 L p .513 .022 .027 r
F P
0 g
s
.54437 1.26218 m .63045 1.26755 L .53229 1.25133 L .513 .022 .027 r
F
.55696 1.08458 m .55716 1.10469 L p .55655 1.12172 L 0 0 .026 r
F P
0 g
s
.55656 1.04601 m .64049 1.10469 L .63981 1.07786 L .68 .398 .487 r
F
.63915 1.04616 m .63854 .95086 L .63806 1.04502 L 0 0 .063 r
F
.5554 1.043 m .60986 1.04601 L .63772 1.04465 L .066 0 0 r
F
.5554 1.043 m .63772 1.04465 L .63769 1.04463 L F
.56188 1.04601 m .55656 1.04601 L p .56243 1.04826 L .68 .398 .487 r
F P
0 g
s
.56243 1.04826 m .63981 1.07786 L .56188 1.04601 L .68 .398 .487 r
F
.63919 1.05309 m .63901 1.04601 L .63806 1.04502 L 0 0 .063 r
F
.63901 1.04601 m .56188 1.04601 L p .63981 1.07786 L .68 .398 .487 r
F P
0 g
s
.60986 1.04601 m .63901 1.04601 L p .63772 1.04465 L .066 0 0 r
F P
0 g
s
.6395 .95121 m .63854 .95086 L p .63915 1.04616 L 0 0 .063 r
F P
0 g
s
.6395 1.04653 m .6395 .95121 L .63915 1.04616 L 0 0 .063 r
F
.63614 1.043 m .5554 1.043 L p .63769 1.04463 L .066 0 0 r
F P
0 g
s
.64149 1.02865 m .55757 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.516 1.06663 m .53229 1.06813 L .51629 1.06966 L p .076 0 0 r
F P
0 g
s
.55757 1.02865 m .35851 1.02865 L p .557 1.08079 L .676 .72 .882 r
F P
0 g
s
.57144 1.08458 m .55757 1.02865 L .557 1.08079 L .676 .72 .882 r
F
.63919 1.05309 m .63915 1.04616 L .63901 1.04601 L 0 0 .063 r
F
.63919 1.05309 m .6395 1.04653 L .63915 1.04616 L F
.6395 1.06543 m .6395 1.04653 L .63919 1.05309 L F
.63998 1.08458 m .64149 1.02865 L p .57144 1.08458 L .676 .72 .882 r
F P
0 g
s
.70775 1.04601 m .70347 1.043 L .67151 1.043 L p .066 0 0 r
F P
0 g
s
.70996 1.04757 m .70996 .87384 L p .6578 1.04524 L .333 .272 .638 r
F P
0 g
s
.63854 .95086 m .63568 .94981 L p .6371 1.00646 L 0 0 .063 r
F P
0 g
s
.36616 1.0217 m .36488 .97151 L p .46828 .97151 L .68 .714 .875 r
F P
0 g
s
.47427 .98893 m .36616 1.0217 L .46828 .97151 L .68 .714 .875 r
F
.43542 .87593 m .43542 .77622 L p .46332 .94974 L .996 .813 .543 r
F P
0 g
s
.46332 .94974 m .46554 .96355 L .46082 .94981 L .996 .813 .543 r
F
.46332 .94974 m .46082 .94981 L .43542 .87593 L F
.53172 .77841 m .55293 .90982 L .53918 .94981 L .089 .073 .543 r
F
.53172 .97151 m .53172 .94961 L p .53918 .94981 L F P
0 g
s
.53172 .94961 m .53172 .77841 L p .53918 .94981 L .089 .073 .543 r
F P
0 g
s
.46828 .97151 m .46828 .77841 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.53172 .97151 m .47427 .98893 L .46828 .97151 L .68 .714 .875 r
F
.55431 .97151 m .52944 .97815 L .53172 .97151 L F
.52944 .97815 m .36616 1.0217 L .53172 .97151 L F
.46828 .77841 m .53172 .77841 L .53172 .97151 L p .707 .577 .707 r
F P
0 g
s
.63384 1.0217 m .51447 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.51447 1.0217 m .36616 1.0217 L p .52944 .97815 L .68 .714 .875 r
F P
0 g
s
.55431 .97151 m .51447 1.0217 L .52944 .97815 L .68 .714 .875 r
F
.53172 .77841 m .56458 .77622 L .56458 .87593 L p .089 .073 .543 r
F P
0 g
s
.63568 .94981 m .63512 .97151 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63512 .97151 m .63384 1.0217 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.63568 .94981 m .55431 .97151 L .53257 .96903 L .68 .714 .875 r
F
.46828 .77841 m .53172 .97151 L .52888 .97151 L .707 .577 .707 r
F
.46828 .94961 m .46828 .97151 L p .46461 .94971 L .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .97151 L .46554 .96355 L .996 .813 .543 r
F
.53918 .94981 m .53257 .96903 L .46476 .96128 L .68 .714 .875 r
F
.46082 .94981 m .53918 .94981 L p .46476 .96128 L F P
0 g
s
.53918 .94981 m .63568 .94981 L p .53257 .96903 L .68 .714 .875 r
F P
0 g
s
.6395 .95121 m .63568 .94981 L .58822 .94981 L p .023 0 0 r
F P
0 g
s
.58822 .94981 m .53918 .94981 L p .57236 .95027 L .023 0 0 r
F P
0 g
s
.6395 .95121 m .58822 .94981 L .57236 .95027 L .023 0 0 r
F
.6395 .95121 m .53918 .94981 L .57946 .95091 L F
.56458 .9505 m .56458 .98202 L p .55947 .95036 L .089 .073 .543 r
F P
0 g
s
.56458 .98202 m .53172 .98057 L .53172 .97151 L p .089 .073 .543 r
F P
0 g
s
.36488 .97151 m .36432 .94981 L p .55431 .97151 L .68 .714 .875 r
F P
0 g
s
.55293 .90982 m .56458 .98202 L .53172 .97151 L .089 .073 .543 r
F
.53172 .98057 m .56458 .98202 L .53288 .98353 L p .037 0 0 r
F P
0 g
s
.53288 .98353 m .56458 .98202 L .56458 .9505 L p .999 .815 .526 r
F P
0 g
s
.54028 .95121 m .53288 .98353 L .56458 .9505 L .999 .815 .526 r
F
.46828 .97151 m .46828 .98057 L p .46554 .96355 L .996 .813 .543 r
F P
0 g
s
.36432 .94981 m .46082 .94981 L p .46476 .96128 L .68 .714 .875 r
F P
0 g
s
.53172 .97151 m .53172 .98057 L p .52888 .97151 L .707 .577 .707 r
F P
0 g
s
.46082 .94981 m .36432 .94981 L p .4456 .95022 L .023 0 0 r
F P
0 g
s
.43542 .9505 m .36432 .94981 L .4093 .95121 L .023 0 0 r
F
.4456 .95022 m .42179 .9501 L .43542 .9505 L F
.42179 .9501 m .36432 .94981 L .43542 .9505 L F
.43542 .87593 m .46828 .98057 L .43542 .9505 L .996 .813 .543 r
F
.46828 .98057 m .43542 .98202 L .43542 .9505 L p F P
0 g
s
.43542 .77622 m .46828 .77841 L .46828 .94961 L p .996 .813 .543 r
F P
0 g
s
.43542 .77622 m .46828 .94961 L .46461 .94971 L .996 .813 .543 r
F
.46554 .96355 m .46828 .98057 L .43542 .87593 L F
.7687 .39814 m .526 .39397 L .5 .39572 L .222 .729 .893 r
F
.53586 .39814 m .5 .39572 L .46414 .39814 L F
.7687 .39814 m .5 .39572 L .53586 .39814 L F
.22014 .38333 m .2313 .39285 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.46985 .39369 m .46985 .38836 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .39572 m .5 .39041 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.2313 .39814 m .22014 .38872 L .22014 .38333 L p .916 .748 .257 r
F P
0 g
s
.22014 .38333 m .2313 .39285 L .2313 .39814 L p .916 .748 .257 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .39041 m .53015 .38836 L .53015 .39369 L p .551 .45 .693 r
F P
0 g
s
.7687 .39814 m .56837 .39111 L .53015 .39369 L .222 .729 .893 r
F
.52928 .39402 m .53015 .39369 L .526 .39397 L F
.7687 .39814 m .53015 .39369 L .52928 .39402 L F
.54306 .77622 m .53015 .77742 L .53015 .39369 L p 0 0 .46 r
F P
0 g
s
.53015 .39369 m .53015 .38836 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.5 .39041 m .53015 .39369 L .50041 .39569 L .551 .45 .693 r
F
.46985 .38836 m .5 .39041 L .5 .39572 L p .834 .681 .693 r
F P
0 g
s
.46985 .38836 m .5 .39572 L .47027 .39372 L .834 .681 .693 r
F
.46985 .38836 m .5 .39041 L .53015 .38836 L p .224 .73 .894 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .54306 .38872 L p 0 0 .46 r
F P
0 g
s
.56837 .39111 m .53946 .3901 L .53015 .39369 L .222 .729 .893 r
F
.53015 .38836 m .54306 .38872 L .53032 .39362 L 0 0 .46 r
F
.45694 .38333 m .46985 .38836 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.46925 .37821 m .45694 .38333 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53075 .37821 m .5 .37606 L p .53015 .38836 L .224 .73 .894 r
F P
0 g
s
.53015 .38836 m .54306 .38333 L .53075 .37821 L p .224 .73 .894 r
F P
0 g
s
.23459 .36923 m .22102 .37893 L p .45263 .38705 L .222 .729 .893 r
F P
0 g
s
.45694 .38872 m .45694 .38333 L p .45712 .38878 L .997 .814 .46 r
F P
0 g
s
.45694 .38333 m .46985 .38836 L .46985 .39369 L p .997 .814 .46 r
F P
0 g
s
.46067 .39015 m .45426 .38982 L .46175 .39057 L .222 .729 .893 r
F
.45426 .38982 m .28332 .38112 L .45351 .39013 L F
.45426 .38982 m .45351 .39013 L .46175 .39057 L F
.45694 .38333 m .46985 .39369 L .45712 .38878 L .997 .814 .46 r
F
.46925 .37821 m .45694 .38333 L .45694 .38872 L p 0 0 .442 r
F P
0 g
s
.46925 .37821 m .45694 .38872 L .46908 .38371 L 0 0 .442 r
F
.53946 .3901 m .46032 .38732 L .53015 .39369 L .222 .729 .893 r
F
.46032 .38732 m .28332 .38112 L .45426 .38982 L F
.46032 .38732 m .45426 .38982 L .53015 .39369 L F
.28332 .38112 m .33234 .38442 L .40578 .38804 L F
.40937 .38779 m .40578 .38804 L .526 .39397 L F
.28332 .38112 m .40578 .38804 L .40937 .38779 L F
.47883 .39715 m .22014 .38872 L .46414 .39814 L F
.526 .39397 m .46799 .39297 L .47883 .39715 L F
.46799 .39297 m .22014 .38872 L .47883 .39715 L F
.46985 .39369 m .46985 .77742 L p .46324 .57549 L .997 .814 .46 r
F P
0 g
s
.53015 .39369 m .46067 .39015 L .526 .39397 L .222 .729 .893 r
F
.46067 .39015 m .46175 .39057 L .526 .39397 L F
.46925 .38364 m .46925 .37821 L p .46908 .38371 L 0 0 .442 r
F P
0 g
s
.37496 .20917 m .37513 .19756 L .35414 .19756 L p .697 .472 .578 r
F P
0 g
s
.35414 .19756 m .35395 .20917 L .37496 .20917 L p .697 .472 .578 r
F P
0 g
s
.37513 .24877 m .37496 .23538 L .35395 .23538 L p .699 .656 .803 r
F P
0 g
s
.35395 .23538 m .35414 .24877 L .37513 .24877 L p .699 .656 .803 r
F P
0 g
s
.37491 .22197 m .37496 .20917 L .35395 .20917 L p .706 .546 .669 r
F P
0 g
s
.35395 .20917 m .35388 .22197 L .37491 .22197 L p .706 .546 .669 r
F P
0 g
s
.37496 .23538 m .37491 .22197 L .35388 .22197 L p .706 .606 .742 r
F P
0 g
s
.35388 .22197 m .35395 .23538 L .37496 .23538 L p .706 .606 .742 r
F P
0 g
s
.3687 .17459 m .36877 .18869 L .34671 .18869 L p .706 .607 .743 r
F P
0 g
s
.36877 .18869 m .3687 .20212 L .34664 .20212 L p .706 .545 .667 r
F P
0 g
s
.34664 .20212 m .34671 .18869 L .36877 .18869 L p .706 .545 .667 r
F P
0 g
s
.3687 .20212 m .36852 .21434 L .34643 .21434 L p .696 .466 .571 r
F P
0 g
s
.34643 .21434 m .34664 .20212 L .3687 .20212 L p .696 .466 .571 r
F P
0 g
s
.36852 .21434 m .36823 .22483 L .36106 .22483 L p .67 .361 .442 r
F P
0 g
s
.35723 .36876 m .35723 .22339 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.35723 .22339 m .35723 .22238 L p .35828 .22378 L .541 .442 .691 r
F P
0 g
s
.35828 .22378 m .3681 .23682 L .35723 .22339 L .541 .442 .691 r
F
.36823 .22483 m .3681 .22748 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.35473 .22078 m .36852 .21434 L .36713 .21629 L .67 .361 .442 r
F
.35723 .22238 m .36713 .21629 L .36106 .22483 L F
.35473 .22078 m .36713 .21629 L .35723 .22238 L F
.34671 .18869 m .34664 .17459 L .3687 .17459 L p .706 .607 .743 r
F P
0 g
s
.34664 .20212 m .34671 .18869 L .34664 .17459 L p .772 .63 .068 r
F P
0 g
s
.34664 .17459 m .34643 .16041 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34608 .22483 m .34643 .21434 L .34664 .20212 L p .772 .63 .068 r
F P
0 g
s
.34664 .20212 m .34593 .22355 L .34608 .22483 L .772 .63 .068 r
F
.34593 .31625 m .3571 .22343 L .35723 .36876 L .837 .683 .692 r
F
.35723 .22339 m .35723 .36876 L p .3571 .22343 L F P
0 g
s
.32942 .23949 m .34593 .22933 L .34593 .31625 L .837 .683 .692 r
F
.34593 .22933 m .35723 .22238 L .34593 .31625 L F
.34593 .22748 m .34608 .22483 L .35325 .22483 L p .613 .212 .26 r
F P
0 g
s
.34664 .20212 m .34593 .21849 L .34593 .22355 L .772 .63 .068 r
F
.34593 .22748 m .34608 .22483 L p .34593 .22355 L F P
0 g
s
.35723 .22238 m .35723 .22339 L p .3571 .22343 L .837 .683 .692 r
F P
0 g
s
.36624 .22814 m .3681 .23682 L .35828 .22378 L .541 .442 .691 r
F
.36106 .22483 m .35828 .22378 L .35723 .22238 L F
.36624 .22814 m .35828 .22378 L .36106 .22483 L F
.34608 .22483 m .35473 .22078 L .35723 .22238 L .67 .361 .442 r
F
.36106 .22483 m .35325 .22483 L p .35723 .22238 L F P
0 g
s
.35325 .22483 m .34608 .22483 L p .35723 .22238 L .67 .361 .442 r
F P
0 g
s
.32822 .23391 m .34593 .22748 L .32942 .23949 L .837 .683 .692 r
F
.34593 .22748 m .35325 .22483 L .34593 .22933 L F
.34593 .22748 m .34593 .22933 L .32942 .23949 L F
.31714 .1824 m .34593 .21112 L .34593 .21623 L F
.34664 .20212 m .34593 .21471 L .34593 .21849 L .772 .63 .068 r
F
.31714 .1824 m .34593 .21623 L .32822 .23391 L .837 .683 .692 r
F
.34643 .21434 m .36852 .21434 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.34608 .22483 m .34639 .21545 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.34639 .21545 m .34643 .21434 L p .35473 .22078 L .67 .361 .442 r
F P
0 g
s
.3687 .20212 m .3681 .21849 L .3681 .22355 L .763 .623 .058 r
F
.3687 .20212 m .36877 .18869 L .3687 .17459 L p F P
0 g
s
.36852 .16041 m .3687 .17459 L .34664 .17459 L p .699 .659 .807 r
F P
0 g
s
.3687 .17459 m .36852 .16041 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36823 .22483 m .36852 .21434 L .3687 .20212 L p .763 .623 .058 r
F P
0 g
s
.3687 .20212 m .3681 .22355 L .36823 .22483 L .763 .623 .058 r
F
.39581 .24704 m .39581 .36597 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.36624 .22814 m .3681 .22933 L .3681 .23682 L .541 .442 .691 r
F
.3681 .22933 m .39581 .24704 L .3681 .23682 L F
.3687 .20212 m .3681 .21471 L .3681 .21849 L .763 .623 .058 r
F
.36592 .22666 m .3681 .22815 L .36624 .22814 L .541 .442 .691 r
F
.3681 .22815 m .3681 .22933 L .36624 .22814 L F
.3687 .20212 m .3681 .21172 L .3681 .21471 L .763 .623 .058 r
F
.36106 .22483 m .36823 .22483 L p .36278 .22548 L .613 .212 .26 r
F P
0 g
s
.3681 .22748 m .36823 .22483 L p .3681 .22355 L .763 .623 .058 r
F P
0 g
s
.3646 .22616 m .36278 .22548 L .36823 .22483 L .613 .212 .26 r
F
.35723 .18615 m .3681 .20331 L .36592 .22666 L .541 .442 .691 r
F
.3681 .20331 m .3681 .22748 L .36592 .22666 L F
.3681 .22748 m .3681 .22815 L .36592 .22666 L F
.35723 .22238 m .35723 .18615 L p .36592 .22666 L F P
0 g
s
.36592 .22666 m .36624 .22814 L .36106 .22483 L .541 .442 .691 r
F
.36592 .22666 m .36106 .22483 L .35723 .22238 L F
.36783 .23315 m .34562 .23315 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.3681 .22748 m .36783 .23315 L p .3646 .22616 L .613 .212 .26 r
F P
0 g
s
.36783 .23315 m .36735 .23894 L .34506 .23894 L p .498 0 0 r
F P
0 g
s
.34506 .23894 m .34562 .23315 L .36783 .23315 L p .498 0 0 r
F P
0 g
s
.36735 .23894 m .3668 .24191 L .34441 .24191 L p .289 0 0 r
F P
0 g
s
.34441 .24191 m .34506 .23894 L .36735 .23894 L p .289 0 0 r
F P
0 g
s
.3668 .24191 m .36621 .24192 L .34372 .24192 L p 0 0 0 r
F P
0 g
s
.34372 .24192 m .34441 .24191 L .3668 .24191 L p 0 0 0 r
F P
0 g
s
.3656 .23891 m .36621 .24192 L p .3681 .21172 L .763 .623 .058 r
F P
0 g
s
.3687 .20212 m .3681 .20925 L .3681 .21172 L .763 .623 .058 r
F
.3681 .20925 m .3656 .23891 L .3681 .21172 L F
.38823 .23507 m .39581 .24704 L .3681 .22815 L .541 .442 .691 r
F
.38823 .23507 m .3681 .22815 L .3681 .22748 L F
.36499 .23298 m .3656 .23891 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.34562 .23315 m .36278 .22548 L .3646 .22616 L .613 .212 .26 r
F
.36442 .22436 m .36499 .23298 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36392 .2134 m .36442 .22436 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.35723 .18615 m .3681 .18509 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.3687 .20212 m .36363 .20061 L .36392 .2134 L .763 .623 .058 r
F
.35325 .22483 m .36106 .22483 L p .34593 .22748 L .613 .212 .26 r
F P
0 g
s
.34593 .22748 m .36106 .22483 L .36278 .22548 L .613 .212 .26 r
F
.34562 .23315 m .34593 .22748 L p .36278 .22548 L F P
0 g
s
.34664 .20212 m .34593 .20925 L .34593 .21172 L .772 .63 .068 r
F
.34664 .20212 m .34593 .21172 L .34593 .21471 L F
.35723 .18615 m .35723 .22238 L p .34593 .21112 L .837 .683 .692 r
F P
0 g
s
.34593 .21623 m .34593 .22748 L .32822 .23391 L .837 .683 .692 r
F
.31714 .1824 m .34593 .18509 L p .34593 .21112 L F P
0 g
s
.3423 .23298 m .34301 .23891 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34164 .22436 m .3423 .23298 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34105 .2134 m .34164 .22436 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34664 .20212 m .34071 .20061 L .34105 .2134 L .772 .63 .068 r
F
.34071 .20468 m .34105 .2134 L p .34071 .20061 L F P
0 g
s
.34164 .10596 m .34105 .11142 L p .34545 .18284 L .772 .63 .068 r
F P
0 g
s
.31714 .1824 m .34593 .18509 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34664 .20212 m .34569 .18398 L .34545 .18284 L .772 .63 .068 r
F
.34569 .18398 m .34164 .10596 L .34545 .18284 L F
.29829 .17317 m .31714 .1824 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34105 .11142 m .34071 .11702 L p .34522 .18178 L .772 .63 .068 r
F P
0 g
s
.34545 .18284 m .34105 .11142 L .34522 .18178 L .772 .63 .068 r
F
.3443 .17752 m .29829 .17317 L .34535 .1824 L .289 .763 .934 r
F
.34509 .18119 m .34071 .11702 L .34071 .12181 L .772 .63 .068 r
F
.34664 .20212 m .34522 .18178 L .34509 .18119 L F
.34522 .18178 m .34071 .11702 L .34509 .18119 L F
.31238 .16371 m .29829 .17317 L p .3443 .17752 L .289 .763 .934 r
F P
0 g
s
.34664 .17459 m .34643 .16041 L .36852 .16041 L p .699 .659 .807 r
F P
0 g
s
.36823 .14672 m .36852 .16041 L .34643 .16041 L p .684 .704 .862 r
F P
0 g
s
.34643 .16041 m .34608 .14672 L .36823 .14672 L p .684 .704 .862 r
F P
0 g
s
.36783 .13411 m .36823 .14672 L .34608 .14672 L p .661 .745 .912 r
F P
0 g
s
.34608 .14672 m .34562 .13411 L .36783 .13411 L p .661 .745 .912 r
F P
0 g
s
.36735 .12309 m .36783 .13411 L .34562 .13411 L p .625 .78 .956 r
F P
0 g
s
.36318 .13034 m .36298 .14297 L p .3659 .17317 L .763 .623 .058 r
F P
0 g
s
.34279 .17052 m .31238 .16371 L .3443 .17752 L .289 .763 .934 r
F
.34071 .16085 m .31238 .16371 L p .34279 .17052 L F P
0 g
s
.34664 .20212 m .34337 .17317 L .34071 .16085 L .772 .63 .068 r
F
.34664 .20212 m .34071 .16085 L .34071 .16256 L F
.34664 .20212 m .34545 .18284 L .34522 .18178 L F
.34071 .16085 m .33661 .207 L .34071 .20468 L .534 .436 .69 r
F
.34018 .18646 m .34055 .20057 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.33995 .17169 m .34018 .18646 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34071 .16085 m .31238 .16371 L p .33661 .207 L .534 .436 .69 r
F P
0 g
s
.33987 .15697 m .33995 .17169 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34018 .13034 m .33995 .14297 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34055 .11966 m .34018 .13034 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.3423 .1035 m .34164 .10596 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34301 .10412 m .3423 .1035 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34372 .10774 m .34301 .10412 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34441 .11417 m .34372 .10774 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34506 .12309 m .34441 .11417 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34562 .13411 m .34506 .12309 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34608 .14672 m .34562 .13411 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34643 .16041 m .34608 .14672 L p .34664 .20212 L .772 .63 .068 r
F P
0 g
s
.34593 .18894 m .35723 .18615 L .34593 .21112 L .837 .683 .692 r
F
.33995 .14297 m .33987 .15697 L p .34337 .17317 L .772 .63 .068 r
F P
0 g
s
.36689 .1785 m .36318 .13034 L .3659 .17317 L .763 .623 .058 r
F
.36298 .14297 m .36291 .15697 L p .3659 .17317 L F P
0 g
s
.35194 .15972 m .34071 .16085 L p .36541 .17051 L .289 .763 .934 r
F P
0 g
s
.34562 .13411 m .34506 .12309 L .36735 .12309 L p .625 .78 .956 r
F P
0 g
s
.3668 .11417 m .36735 .12309 L .34506 .12309 L p .567 .808 .989 r
F P
0 g
s
.36349 .11966 m .36318 .13034 L p .36689 .1785 L .763 .623 .058 r
F P
0 g
s
.36738 .18119 m .36349 .11966 L .36689 .1785 L .763 .623 .058 r
F
.34506 .12309 m .34441 .11417 L .3668 .11417 L p .567 .808 .989 r
F P
0 g
s
.36621 .10774 m .3668 .11417 L .34441 .11417 L p .472 .815 .999 r
F P
0 g
s
.36392 .11142 m .36349 .11966 L p .36738 .18119 L .763 .623 .058 r
F P
0 g
s
.36769 .18284 m .36392 .11142 L .36738 .18119 L .763 .623 .058 r
F
.3676 .1824 m .3443 .17752 L .34535 .1824 L .289 .763 .934 r
F
.34441 .11417 m .34372 .10774 L .36621 .10774 L p .472 .815 .999 r
F P
0 g
s
.3656 .10412 m .36621 .10774 L .34372 .10774 L p .311 .772 .946 r
F P
0 g
s
.36442 .10596 m .36392 .11142 L p .36769 .18284 L .763 .623 .058 r
F P
0 g
s
.3679 .18398 m .36442 .10596 L .36769 .18284 L .763 .623 .058 r
F
.35723 .18615 m .3681 .18509 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34372 .10774 m .34301 .10412 L .3656 .10412 L p .311 .772 .946 r
F P
0 g
s
.36499 .1035 m .3656 .10412 L .34301 .10412 L p .059 .624 .764 r
F P
0 g
s
.36499 .1035 m .36442 .10596 L p .3679 .18398 L .763 .623 .058 r
F P
0 g
s
.3676 .1824 m .34535 .1824 L .3681 .18509 L .289 .763 .934 r
F
.3687 .20212 m .36805 .18483 L .3679 .18398 L .763 .623 .058 r
F
.36805 .18483 m .36499 .1035 L .3679 .18398 L F
.3656 .10412 m .36499 .1035 L p .36805 .18483 L F P
0 g
s
.3687 .20212 m .36818 .1855 L .36805 .18483 L .763 .623 .058 r
F
.36818 .1855 m .3656 .10412 L .36805 .18483 L F
.36621 .10774 m .3656 .10412 L p .3687 .20212 L F P
0 g
s
.3668 .11417 m .36621 .10774 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36735 .12309 m .3668 .11417 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36783 .13411 m .36735 .12309 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36823 .14672 m .36783 .13411 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36852 .16041 m .36823 .14672 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.3931 .16371 m .36363 .16085 L p .39581 .1824 L .289 .763 .934 r
F P
0 g
s
.36363 .16085 m .35194 .15972 L p .36463 .16628 L .289 .763 .934 r
F P
0 g
s
.39581 .1824 m .36363 .16085 L .36463 .16628 L .289 .763 .934 r
F
.39581 .1824 m .3671 .17968 L .3676 .1824 L F
.3671 .17968 m .3443 .17752 L .3676 .1824 L F
.3687 .20212 m .3679 .18398 L .36769 .18284 L .763 .623 .058 r
F
.3687 .20212 m .36769 .18284 L .36738 .18119 L F
.36639 .17581 m .34071 .16085 L .34279 .17052 L .289 .763 .934 r
F
.39581 .1824 m .36541 .17051 L .36639 .17581 L F
.36541 .17051 m .34071 .16085 L .36639 .17581 L F
.39581 .1824 m .36463 .16628 L .36541 .17051 L F
.36463 .16628 m .35194 .15972 L .36541 .17051 L F
.3671 .17968 m .34279 .17052 L .3443 .17752 L F
.36639 .17581 m .34279 .17052 L .3671 .17968 L F
.3687 .20212 m .36738 .18119 L .36689 .1785 L .763 .623 .058 r
F
.34593 .18509 m .35723 .18615 L p .34535 .1824 L .289 .763 .934 r
F P
0 g
s
.34671 .18516 m .35723 .18615 L p .34593 .18894 L .837 .683 .692 r
F P
0 g
s
.36363 .16085 m .35194 .15972 L p .35539 .20004 L .841 .686 .691 r
F P
0 g
s
.36363 .16085 m .35539 .20004 L .35543 .20007 L .841 .686 .691 r
F
.35194 .15972 m .34071 .16085 L p .34071 .20468 L .534 .436 .69 r
F P
0 g
s
.34071 .20468 m .34105 .2134 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34124 .20438 m .34071 .20468 L .34071 .20659 L .534 .436 .69 r
F
.35194 .15972 m .34071 .20468 L .34124 .20438 L F
.34301 .23891 m .34372 .24192 L p .34593 .21172 L .772 .63 .068 r
F P
0 g
s
.34593 .20925 m .34301 .23891 L .34593 .21172 L .772 .63 .068 r
F
.34593 .21172 m .34372 .24192 L .34593 .21471 L F
.34593 .21112 m .35723 .22238 L .34593 .21623 L .837 .683 .692 r
F
.34105 .2134 m .36392 .2134 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34593 .18509 m .34671 .18516 L p .34593 .18894 L .837 .683 .692 r
F P
0 g
s
.35194 .15972 m .34071 .20659 L .34263 .205 L .534 .436 .69 r
F
.34055 .20057 m .34071 .20468 L p .34071 .20061 L .772 .63 .068 r
F P
0 g
s
.34798 .20057 m .35606 .20057 L p .35194 .1973 L .682 .709 .868 r
F P
0 g
s
.36392 .2134 m .36363 .20468 L p .34798 .20057 L .657 .75 .919 r
F P
0 g
s
.35606 .20057 m .34798 .20057 L p .36363 .20468 L .657 .75 .919 r
F P
0 g
s
.34432 .20264 m .36392 .2134 L .34798 .20057 L .657 .75 .919 r
F
.34593 .21623 m .35325 .22483 L .34593 .22748 L .837 .683 .692 r
F
.34372 .24192 m .34441 .24191 L p .34593 .21471 L .772 .63 .068 r
F P
0 g
s
.34441 .24191 m .34506 .23894 L p .34593 .21849 L .772 .63 .068 r
F P
0 g
s
.34593 .21471 m .34441 .24191 L .34593 .21849 L .772 .63 .068 r
F
.34593 .21623 m .35723 .22238 L .35325 .22483 L .837 .683 .692 r
F
.34506 .23894 m .34562 .23315 L p .34593 .22355 L .772 .63 .068 r
F P
0 g
s
.34593 .21849 m .34506 .23894 L .34593 .22355 L .772 .63 .068 r
F
.34562 .23315 m .34593 .22748 L p .34593 .22355 L F P
0 g
s
.35723 .36876 m .31714 .36597 L .31714 .1824 L p .837 .683 .692 r
F P
0 g
s
.36621 .24192 m .3656 .23891 L .34301 .23891 L p .266 .752 .921 r
F P
0 g
s
.34301 .23891 m .34372 .24192 L .36621 .24192 L p .266 .752 .921 r
F P
0 g
s
.3656 .23891 m .36499 .23298 L .3423 .23298 L p .446 .812 .995 r
F P
0 g
s
.3423 .23298 m .34301 .23891 L .3656 .23891 L p .446 .812 .995 r
F P
0 g
s
.36499 .23298 m .36442 .22436 L .34164 .22436 L p .553 .811 .994 r
F P
0 g
s
.34164 .22436 m .3423 .23298 L .36499 .23298 L p .553 .811 .994 r
F P
0 g
s
.36442 .22436 m .36392 .2134 L .34105 .2134 L p .617 .786 .963 r
F P
0 g
s
.34105 .2134 m .34164 .22436 L .36442 .22436 L p .617 .786 .963 r
F P
0 g
s
.35194 .34909 m .35194 .1973 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.35194 .1973 m .35194 .15972 L p .34263 .205 L .534 .436 .69 r
F P
0 g
s
.34263 .205 m .34071 .21433 L .35194 .1973 L .534 .436 .69 r
F
.3681 .36797 m .35723 .36876 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.35194 .15972 m .35194 .34909 L p .36363 .29646 L .841 .686 .691 r
F P
0 g
s
.34018 .18646 m .34022 .18797 L p .35412 .1955 L .682 .709 .868 r
F P
0 g
s
.36363 .16085 m .35543 .20007 L .36363 .20468 L .841 .686 .691 r
F
.35543 .20007 m .3554 .20022 L .35606 .20057 L F
.35543 .20007 m .35606 .20057 L .36363 .20468 L F
.35454 .19515 m .35412 .1955 L .36349 .20057 L .682 .709 .868 r
F
.34018 .18646 m .35412 .1955 L .35454 .19515 L F
.34055 .20057 m .34071 .20468 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34022 .18797 m .34055 .20057 L .34798 .20057 L p .682 .709 .868 r
F P
0 g
s
.34022 .18797 m .34798 .20057 L .35194 .1973 L .682 .709 .868 r
F
.34263 .205 m .34071 .20659 L .34071 .21433 L .534 .436 .69 r
F
.35606 .20057 m .36349 .20057 L p .34022 .18797 L .682 .709 .868 r
F P
0 g
s
.35543 .20007 m .35539 .20004 L .3554 .20022 L .841 .686 .691 r
F
.36363 .20468 m .3554 .20022 L .36363 .29646 L F
.36363 .20468 m .36349 .20057 L .35606 .20057 L p .657 .75 .919 r
F P
0 g
s
.34798 .20057 m .34055 .20057 L p .34432 .20264 L .657 .75 .919 r
F P
0 g
s
.34071 .20468 m .33661 .207 L .34071 .21433 L .534 .436 .69 r
F
.34071 .16256 m .34071 .16085 L .33987 .15697 L .772 .63 .068 r
F
.3687 .20212 m .36689 .1785 L .3659 .17317 L .763 .623 .058 r
F
.39581 .1824 m .36639 .17581 L .3671 .17968 L .289 .763 .934 r
F
.34071 .11702 m .34055 .11966 L p .34071 .12181 L .772 .63 .068 r
F P
0 g
s
.31714 .36597 m .29829 .35911 L .29829 .17317 L p .999 .816 .478 r
F P
0 g
s
.29829 .17317 m .31714 .1824 L .31714 .36597 L p .999 .816 .478 r
F P
0 g
s
.31238 .16371 m .31238 .35206 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.3687 .20212 m .3659 .17317 L .36291 .15697 L .763 .623 .058 r
F
.3681 .18509 m .39581 .1824 L p .3676 .1824 L .289 .763 .934 r
F P
0 g
s
.31238 .35206 m .34071 .34994 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.34071 .34994 m .35194 .34909 L p .34071 .21433 L .534 .436 .69 r
F P
0 g
s
.36349 .20057 m .36363 .20468 L p .36363 .20061 L .763 .623 .058 r
F P
0 g
s
.36363 .20468 m .36392 .2134 L p .36363 .20061 L .763 .623 .058 r
F P
0 g
s
.3681 .20331 m .38823 .23507 L .3681 .22748 L .541 .442 .691 r
F
.36621 .24192 m .3668 .24191 L p .3681 .21471 L .763 .623 .058 r
F P
0 g
s
.3681 .21172 m .36621 .24192 L .3681 .21471 L .763 .623 .058 r
F
.3681 .22815 m .39581 .24704 L .3681 .22933 L .541 .442 .691 r
F
.3668 .24191 m .36735 .23894 L p .3681 .21849 L .763 .623 .058 r
F P
0 g
s
.3681 .21471 m .3668 .24191 L .3681 .21849 L .763 .623 .058 r
F
.36783 .23315 m .3681 .22748 L p .3681 .22355 L F P
0 g
s
.39581 .1824 m .39581 .24704 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.36318 .18646 m .36349 .20057 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36298 .17169 m .36318 .18646 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.36291 .15697 m .36298 .17169 L p .3687 .20212 L .763 .623 .058 r
F P
0 g
s
.3681 .18509 m .39581 .1824 L p .3681 .20331 L .541 .442 .691 r
F P
0 g
s
.39581 .36597 m .3681 .36797 L p .3681 .23682 L .541 .442 .691 r
F P
0 g
s
.36735 .23894 m .36783 .23315 L p .3681 .22355 L .763 .623 .058 r
F P
0 g
s
.3681 .21849 m .36735 .23894 L .3681 .22355 L .763 .623 .058 r
F
.3931 .16371 m .36363 .16085 L p .36363 .29646 L .841 .686 .691 r
F P
0 g
s
.41098 .35911 m .39581 .36597 L .39581 .1824 L p 0 0 .419 r
F P
0 g
s
.29829 .35911 m .31238 .35206 L .31238 .16371 L p 0 0 .392 r
F P
0 g
s
.31238 .16371 m .29829 .17317 L .29829 .35911 L p 0 0 .392 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.5 .37606 m .46925 .37821 L .46925 .38364 L p .547 .446 .692 r
F P
0 g
s
.54706 .39037 m .4718 .38347 L .45263 .38705 L .222 .729 .893 r
F
.4718 .38347 m .44766 .38514 L .45263 .38705 L F
.5 .37606 m .46925 .38364 L .49958 .38154 L .547 .446 .692 r
F
.53525 .3855 m .43443 .38004 L .54706 .39037 L .222 .729 .893 r
F
.46895 .39334 m .46985 .39369 L .46324 .57549 L .997 .814 .46 r
F
.22102 .37893 m .22014 .38872 L p .526 .39397 L .222 .729 .893 r
F P
0 g
s
.22014 .38872 m .2313 .39814 L p .46414 .39814 L .222 .729 .893 r
F P
0 g
s
.46985 .77742 m .45694 .77622 L .45694 .38872 L p .997 .814 .46 r
F P
0 g
s
.45712 .38878 m .46985 .77742 L .45694 .38872 L .997 .814 .46 r
F
.5 .39572 m .5 .77791 L p .47027 .39372 L .834 .681 .693 r
F P
0 g
s
.5 .77791 m .46985 .77742 L .46985 .39369 L p .834 .681 .693 r
F P
0 g
s
.47027 .39372 m .5 .77791 L .46985 .39369 L .834 .681 .693 r
F
.54306 .38872 m .54306 .38333 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.5 .38151 m .5 .37606 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.53525 .3855 m .46939 .37939 L .23459 .36923 L .222 .729 .893 r
F
.53075 .38364 m .53075 .37821 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .37606 L .5 .38151 L p .837 .684 .692 r
F P
0 g
s
.53075 .37821 m .5 .38151 L .53033 .38362 L .837 .684 .692 r
F
.31714 .36597 m .35723 .36876 L .39581 .36597 L p .224 .73 .894 r
F P
0 g
s
.29829 .35911 m .31714 .36597 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.52081 .37955 m .2609 .36006 L .46939 .37939 L .222 .729 .893 r
F
.53075 .38364 m .46939 .37939 L .53525 .3855 L F
.52081 .37955 m .46939 .37939 L .53075 .38364 L F
.53015 .39369 m .53015 .77742 L p .50041 .39569 L .551 .45 .693 r
F P
0 g
s
.53015 .77742 m .5 .77791 L .5 .39572 L p .551 .45 .693 r
F P
0 g
s
.50041 .39569 m .53015 .77742 L .5 .39572 L .551 .45 .693 r
F
.5 .38151 m .5 .77447 L p .53033 .38362 L .837 .684 .692 r
F P
0 g
s
.54306 .38872 m .54306 .77622 L p .53032 .39362 L 0 0 .46 r
F P
0 g
s
.53032 .39362 m .54306 .77622 L .53015 .39369 L 0 0 .46 r
F
.5 .77447 m .53075 .77499 L .53075 .38364 L p .837 .684 .692 r
F P
0 g
s
.53033 .38362 m .5 .77447 L .53075 .38364 L .837 .684 .692 r
F
.2609 .36006 m .2492 .36414 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.2492 .36414 m .23459 .36923 L p .46939 .37939 L .222 .729 .893 r
F P
0 g
s
.54306 .38333 m .53075 .37821 L .53075 .38364 L p .994 .812 .442 r
F P
0 g
s
.54306 .38333 m .53075 .38364 L .54289 .38865 L .994 .812 .442 r
F
.7687 .39814 m .52081 .37955 L .53525 .3855 L .222 .729 .893 r
F
.53075 .38364 m .53075 .77499 L p .54289 .38865 L .994 .812 .442 r
F P
0 g
s
.46925 .38364 m .46925 .77499 L p .49958 .38154 L .547 .446 .692 r
F P
0 g
s
.4718 .38347 m .43443 .38004 L .44766 .38514 L .222 .729 .893 r
F
.7687 .39814 m .53525 .3855 L .54706 .39037 L F
.53075 .77499 m .54306 .77622 L .54306 .38872 L p .994 .812 .442 r
F P
0 g
s
.54289 .38865 m .53075 .77499 L .54306 .38872 L .994 .812 .442 r
F
.46925 .77499 m .5 .77447 L .5 .38151 L p .547 .446 .692 r
F P
0 g
s
.49958 .38154 m .46925 .77499 L .5 .38151 L .547 .446 .692 r
F
.45712 .38878 m .46895 .39334 L .46324 .57549 L .997 .814 .46 r
F
.45694 .77622 m .46925 .77499 L .46925 .38364 L p 0 0 .442 r
F P
0 g
s
.46908 .38371 m .45694 .77622 L .46925 .38364 L 0 0 .442 r
F
.45694 .38872 m .45694 .77622 L p .46908 .38371 L F P
0 g
s
.43443 .38004 m .23459 .36923 L .45263 .38705 L .222 .729 .893 r
F
.28332 .38112 m .22102 .37893 L .33234 .38442 L F
.43542 .77622 m .46828 .77841 L .53172 .77841 L p .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.45694 .77622 m .46985 .77742 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46925 .77499 m .45694 .77622 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.46712 .77394 m .43542 .77622 L .43542 .9505 L p .053 .044 .526 r
F P
0 g
s
.43542 .9505 m .43542 .98202 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.53172 .98057 m .46828 .98057 L .46828 .97151 L p .707 .577 .707 r
F P
0 g
s
.52888 .97151 m .53172 .98057 L .46828 .97151 L .707 .577 .707 r
F
.43542 .98202 m .46828 .98057 L .53172 .98057 L p .037 0 0 r
F P
0 g
s
.46712 .98353 m .43542 .98202 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.53288 .98353 m .46712 .98353 L p .53172 .98057 L .037 0 0 r
F P
0 g
s
.46712 .98353 m .53288 .98353 L .53288 .97414 L p .707 .577 .707 r
F P
0 g
s
.54028 .95121 m .45972 .95121 L p .49291 .97414 L .679 .394 .482 r
F P
0 g
s
.53288 .97414 m .54028 .95121 L .49291 .97414 L .679 .394 .482 r
F
.47006 .97414 m .46712 .98353 L .53288 .97414 L .707 .577 .707 r
F
.5256 .99671 m .49291 .97414 L .4694 .98122 L .679 .394 .482 r
F
.49291 .97414 m .45972 .95121 L .46712 .97414 L F
.46712 .97414 m .46712 .98353 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.49291 .97414 m .46712 .97414 L .4694 .98122 L .679 .394 .482 r
F
.54028 .95121 m .4456 .95022 L .43542 .9505 L .023 0 0 r
F
.45972 .95121 m .54028 .95121 L p .43542 .9505 L F P
0 g
s
.5498 .95093 m .4456 .95022 L .54028 .95121 L .023 0 0 r
F
.57946 .95091 m .4456 .95022 L .5907 .95121 L F
.53918 .94981 m .46082 .94981 L p .57946 .95091 L F P
0 g
s
.57946 .95091 m .46082 .94981 L .4456 .95022 L .023 0 0 r
F
.53288 .77394 m .46712 .77394 L p .53172 .77841 L .056 .621 .761 r
F P
0 g
s
.46985 .77742 m .5 .77791 L .53015 .77742 L p .056 .621 .761 r
F P
0 g
s
.5 .77447 m .46925 .77499 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53075 .77499 m .5 .77447 L p .53015 .77742 L .056 .621 .761 r
F P
0 g
s
.53015 .77742 m .54306 .77622 L .53075 .77499 L p .056 .621 .761 r
F P
0 g
s
.53288 .77394 m .46712 .77394 L .46712 .97414 L p .707 .577 .707 r
F P
0 g
s
.53288 .77394 m .46712 .97414 L .47006 .97414 L .707 .577 .707 r
F
.53172 .77841 m .56458 .87593 L .55293 .90982 L .089 .073 .543 r
F
.53172 .77841 m .56458 .77622 L .53288 .77394 L p .056 .621 .761 r
F P
0 g
s
.53288 .97414 m .53288 .77394 L p .47006 .97414 L .707 .577 .707 r
F P
0 g
s
.5256 .99671 m .53288 .97414 L .49291 .97414 L .679 .394 .482 r
F
.43542 .98202 m .46712 .98353 L .46712 .97414 L p .053 .044 .526 r
F P
0 g
s
.46153 .95682 m .43542 .98202 L .46712 .97414 L .053 .044 .526 r
F
.4402 .95064 m .43542 .98202 L .46153 .95682 L F
.45972 .95121 m .46153 .95682 L .46712 .95143 L F
.4402 .95064 m .46153 .95682 L .45972 .95121 L F
.3605 .95121 m .35851 1.02865 L .48471 1.02865 L p .679 .394 .482 r
F P
0 g
s
.48471 1.02865 m .64149 1.02865 L p .4694 .98122 L .679 .394 .482 r
F P
0 g
s
.4694 .98122 m .3605 .95121 L .48471 1.02865 L .679 .394 .482 r
F
.45972 .95121 m .3605 .95121 L p .4694 .98122 L F P
0 g
s
.46712 .97414 m .46712 .95143 L p .46153 .95682 L .053 .044 .526 r
F P
0 g
s
.46712 .95143 m .46712 .77394 L p .4402 .95064 L .053 .044 .526 r
F P
0 g
s
.4093 .95121 m .45972 .95121 L p .43542 .9505 L .023 0 0 r
F P
0 g
s
.54028 .95121 m .5907 .95121 L p .5498 .95093 L .023 0 0 r
F P
0 g
s
.56458 .77622 m .53288 .77394 L .53288 .95143 L p .999 .815 .526 r
F P
0 g
s
.53288 .95143 m .53288 .98353 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.56458 .77622 m .53288 .95143 L .53781 .95129 L .999 .815 .526 r
F
.46712 .77394 m .43542 .9505 L .4402 .95064 L .053 .044 .526 r
F
.53781 .95129 m .53561 .96569 L .54028 .95121 L .999 .815 .526 r
F
.53561 .96569 m .53288 .98353 L .54028 .95121 L F
.64149 1.02865 m .6395 .95121 L .54028 .95121 L p .679 .394 .482 r
F P
0 g
s
.64149 1.02865 m .54028 .95121 L .5256 .99671 L .679 .394 .482 r
F
.5907 .95121 m .6395 .95121 L p .57946 .95091 L .023 0 0 r
F P
0 g
s
.56458 .87593 m .56458 .9505 L p .55293 .90982 L .089 .073 .543 r
F P
0 g
s
.55293 .90982 m .56458 .9505 L .55947 .95036 L .089 .073 .543 r
F
.56458 .9505 m .56458 .77622 L p .53781 .95129 L .999 .815 .526 r
F P
0 g
s
.37661 .95121 m .4093 .95121 L p .36432 .94981 L .023 0 0 r
F P
0 g
s
.36432 .94981 m .3605 .95121 L .37661 .95121 L p .023 0 0 r
F P
0 g
s
.64605 .20917 m .64586 .19756 L .62487 .19756 L p .697 .472 .578 r
F P
0 g
s
.62487 .19756 m .62504 .20917 L .64605 .20917 L p .697 .472 .578 r
F P
0 g
s
.64586 .24877 m .64605 .23538 L .62504 .23538 L p .699 .656 .803 r
F P
0 g
s
.62504 .23538 m .62487 .24877 L .64586 .24877 L p .699 .656 .803 r
F P
0 g
s
.64612 .22197 m .64605 .20917 L .62504 .20917 L p .706 .546 .669 r
F P
0 g
s
.62504 .20917 m .62509 .22197 L .64612 .22197 L p .706 .546 .669 r
F P
0 g
s
.64605 .23538 m .64612 .22197 L .62509 .22197 L p .706 .606 .742 r
F P
0 g
s
.62509 .22197 m .62504 .23538 L .64605 .23538 L p .706 .606 .742 r
F P
0 g
s
.39581 .1824 m .41098 .17317 L .41098 .35911 L p 0 0 .419 r
F P
0 g
s
.3931 .35206 m .41098 .35911 L .41098 .17317 L p .997 .814 .457 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.31238 .35206 m .29829 .35911 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.35194 .34909 m .31238 .35206 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.3931 .35206 m .35194 .34909 L p .39581 .36597 L .224 .73 .894 r
F P
0 g
s
.39581 .36597 m .41098 .35911 L .3931 .35206 L p .224 .73 .894 r
F P
0 g
s
.29927 .35195 m .2609 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.39581 .1824 m .41098 .17317 L .3931 .16371 L p .289 .763 .934 r
F P
0 g
s
.41098 .17317 m .3931 .16371 L .3931 .35206 L p .997 .814 .457 r
F P
0 g
s
.35194 .34909 m .3931 .35206 L .3931 .16371 L p .841 .686 .691 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.3482 .34535 m .29927 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.4054 .34069 m .3482 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.65336 .17459 m .65329 .18869 L .63123 .18869 L p .706 .607 .743 r
F P
0 g
s
.65329 .18869 m .65336 .20212 L .6313 .20212 L p .706 .545 .667 r
F P
0 g
s
.6313 .20212 m .63123 .18869 L .65329 .18869 L p .706 .545 .667 r
F P
0 g
s
.65336 .20212 m .65357 .21434 L .63148 .21434 L p .696 .466 .571 r
F P
0 g
s
.63148 .21434 m .6313 .20212 L .65336 .20212 L p .696 .466 .571 r
F P
0 g
s
.68286 .36597 m .64277 .36876 L .64277 .22339 L p .548 .447 .692 r
F P
0 g
s
.64308 .2235 m .68286 .36597 L .64277 .22339 L .548 .447 .692 r
F
.65392 .22483 m .65407 .22748 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65357 .21434 m .65392 .22483 L .64675 .22483 L p .67 .361 .442 r
F P
0 g
s
.64017 .22078 m .65357 .21434 L .6523 .21629 L .67 .361 .442 r
F
.64277 .22238 m .6523 .21629 L .64675 .22483 L F
.64017 .22078 m .6523 .21629 L .64277 .22238 L F
.63123 .18869 m .6313 .17459 L .65336 .17459 L p .706 .607 .743 r
F P
0 g
s
.6313 .20212 m .63123 .18869 L .6313 .17459 L p 0 0 .058 r
F P
0 g
s
.65357 .16041 m .65336 .17459 L .6313 .17459 L p .699 .659 .807 r
F P
0 g
s
.6313 .17459 m .63148 .16041 L .65357 .16041 L p .699 .659 .807 r
F P
0 g
s
.6313 .17459 m .63148 .16041 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63148 .21434 m .65357 .21434 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.63177 .22483 m .63151 .21545 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.63151 .21545 m .63148 .21434 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.65336 .20212 m .65329 .18869 L .65336 .17459 L p 0 0 .068 r
F P
0 g
s
.65336 .17459 m .65357 .16041 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65392 .22483 m .65357 .21434 L .65336 .20212 L p 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65407 .22355 L .65392 .22483 L 0 0 .068 r
F
.68286 .24704 m .68286 .36597 L p .65407 .23682 L .548 .447 .692 r
F P
0 g
s
.65213 .22814 m .65407 .22933 L .65407 .23682 L .548 .447 .692 r
F
.65407 .22933 m .68286 .24704 L .65407 .23682 L F
.65336 .20212 m .65407 .21849 L .65407 .22355 L 0 0 .068 r
F
.65407 .22748 m .65392 .22483 L p .65407 .22355 L F P
0 g
s
.65336 .20212 m .65407 .21471 L .65407 .21849 L 0 0 .068 r
F
.65407 .20331 m .68286 .24704 L .65407 .22933 L .548 .447 .692 r
F
.65628 .24192 m .65559 .24191 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65699 .23891 m .65628 .24192 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.6577 .23298 m .65699 .23891 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65836 .22436 m .6577 .23298 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65895 .2134 m .65836 .22436 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.68286 .1824 m .68286 .24704 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65407 .18509 m .68286 .1824 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65336 .20212 m .65929 .20061 L .65895 .2134 L 0 0 .068 r
F
.65213 .22814 m .68286 .36597 L .64308 .2235 L .548 .447 .692 r
F
.64675 .22483 m .64308 .2235 L .64277 .22238 L F
.65213 .22814 m .64308 .2235 L .64675 .22483 L F
.6313 .20212 m .6319 .22355 L .63177 .22483 L 0 0 .058 r
F
.6319 .22933 m .63894 .22483 L .6319 .31625 L .841 .687 .691 r
F
.6319 .31625 m .63894 .22483 L .64277 .36876 L F
.64277 .22339 m .64277 .36876 L p .63894 .22483 L F P
0 g
s
.6319 .22748 m .63177 .22483 L .63894 .22483 L p .613 .212 .26 r
F P
0 g
s
.64277 .22238 m .64277 .22339 L p .63894 .22483 L .841 .687 .691 r
F P
0 g
s
.64277 .22339 m .64277 .22238 L p .64308 .2235 L .548 .447 .692 r
F P
0 g
s
.64675 .22483 m .63177 .22483 L p .64017 .22078 L .67 .361 .442 r
F P
0 g
s
.6319 .22748 m .63177 .22483 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.63177 .22483 m .63148 .21434 L .6313 .20212 L p 0 0 .058 r
F P
0 g
s
.6319 .21112 m .64277 .22238 L .6319 .22933 L .841 .687 .691 r
F
.63217 .23315 m .6319 .22748 L p .63201 .22746 L .613 .212 .26 r
F P
0 g
s
.63243 .233 m .63223 .22742 L p .64675 .22483 L .613 .212 .26 r
F P
0 g
s
.63894 .22483 m .64675 .22483 L p .6319 .22748 L .613 .212 .26 r
F P
0 g
s
.64675 .22483 m .65392 .22483 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.64277 .22238 m .64277 .18615 L p .6518 .22666 L .548 .447 .692 r
F P
0 g
s
.6518 .22666 m .65213 .22814 L .64675 .22483 L .548 .447 .692 r
F
.6518 .22666 m .64675 .22483 L .64277 .22238 L F
.63217 .23315 m .64675 .22483 L .65043 .22616 L .613 .212 .26 r
F
.64277 .18615 m .64277 .22238 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.6313 .20212 m .6319 .21849 L .6319 .22355 L 0 0 .058 r
F
.65438 .23315 m .63217 .23315 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65438 .23315 m .65494 .23894 L .63265 .23894 L p .498 0 0 r
F P
0 g
s
.63265 .23894 m .63217 .23315 L .65438 .23315 L p .498 0 0 r
F P
0 g
s
.6332 .24191 m .63265 .23894 L .65494 .23894 L p .289 0 0 r
F P
0 g
s
.6332 .24191 m .63265 .23894 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.65494 .23894 m .65559 .24191 L .6332 .24191 L p .289 0 0 r
F P
0 g
s
.63379 .24192 m .6332 .24191 L .65559 .24191 L p 0 0 0 r
F P
0 g
s
.63379 .24192 m .6332 .24191 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6319 .18509 m .64277 .18615 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.6344 .23891 m .63379 .24192 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63501 .23298 m .6344 .23891 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63558 .22436 m .63501 .23298 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63608 .2134 m .63558 .22436 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6313 .20212 m .63637 .20061 L .63608 .2134 L 0 0 .058 r
F
.65392 .14672 m .65357 .16041 L .63148 .16041 L p .684 .704 .862 r
F P
0 g
s
.65407 .18509 m .68286 .1824 L p .65465 .1824 L .289 .763 .934 r
F P
0 g
s
.65699 .10412 m .6577 .1035 L p .65412 .18483 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65398 .1855 L .65412 .18483 L 0 0 .068 r
F
.65398 .1855 m .65699 .10412 L .65412 .18483 L F
.68286 .1824 m .65523 .17968 L .65465 .1824 L .289 .763 .934 r
F
.65895 .11142 m .65945 .11966 L p .65491 .18119 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65455 .18284 L .65491 .18119 L 0 0 .068 r
F
.65455 .18284 m .65895 .11142 L .65491 .18119 L F
.68286 .1824 m .65607 .17581 L .65523 .17968 L .289 .763 .934 r
F
.65945 .11966 m .65982 .13034 L p .65549 .1785 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65491 .18119 L .65549 .1785 L 0 0 .068 r
F
.65491 .18119 m .65945 .11966 L .65549 .1785 L F
.68286 .1824 m .65812 .16628 L .65607 .17581 L .289 .763 .934 r
F
.65982 .13034 m .66005 .14297 L p .65663 .17317 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65549 .1785 L .65663 .17317 L 0 0 .068 r
F
.65549 .1785 m .65982 .13034 L .65663 .17317 L F
.68762 .16371 m .65929 .16085 L p .68286 .1824 L .289 .763 .934 r
F P
0 g
s
.66005 .14297 m .66013 .15697 L p .65663 .17317 L 0 0 .068 r
F P
0 g
s
.65836 .10596 m .65895 .11142 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.6577 .1035 m .65836 .10596 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65628 .10774 m .65699 .10412 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65559 .11417 m .65628 .10774 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65494 .12309 m .65559 .11417 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65438 .13411 m .65494 .12309 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65392 .14672 m .65438 .13411 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65357 .16041 m .65392 .14672 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.65929 .16085 m .64806 .15972 L p .65812 .16628 L .289 .763 .934 r
F P
0 g
s
.68286 .1824 m .65929 .16085 L .65812 .16628 L .289 .763 .934 r
F
.64806 .15972 m .63637 .16085 L p .65607 .17581 L F P
0 g
s
.65607 .17581 m .63637 .16085 L .63459 .17052 L .289 .763 .934 r
F
.63148 .16041 m .63177 .14672 L .65392 .14672 L p .684 .704 .862 r
F P
0 g
s
.65438 .13411 m .65392 .14672 L .63177 .14672 L p .661 .745 .912 r
F P
0 g
s
.63177 .14672 m .63217 .13411 L .65438 .13411 L p .661 .745 .912 r
F P
0 g
s
.63702 .14297 m .63709 .15697 L p .6341 .17317 L 0 0 .058 r
F P
0 g
s
.65494 .12309 m .65438 .13411 L .63217 .13411 L p .625 .78 .956 r
F P
0 g
s
.63217 .13411 m .63265 .12309 L .65494 .12309 L p .625 .78 .956 r
F P
0 g
s
.63311 .1785 m .63682 .13034 L .6341 .17317 L 0 0 .058 r
F
.65559 .11417 m .65494 .12309 L .63265 .12309 L p .567 .808 .989 r
F P
0 g
s
.63265 .12309 m .6332 .11417 L .65559 .11417 L p .567 .808 .989 r
F P
0 g
s
.63651 .11966 m .63682 .13034 L p .63311 .1785 L 0 0 .058 r
F P
0 g
s
.63262 .18119 m .63651 .11966 L .63311 .1785 L 0 0 .058 r
F
.65628 .10774 m .65559 .11417 L .6332 .11417 L p .472 .815 .999 r
F P
0 g
s
.6332 .11417 m .63379 .10774 L .65628 .10774 L p .472 .815 .999 r
F P
0 g
s
.63231 .18284 m .63608 .11142 L .63262 .18119 L 0 0 .058 r
F
.65699 .10412 m .65628 .10774 L .63379 .10774 L p .311 .772 .946 r
F P
0 g
s
.63379 .10774 m .6344 .10412 L .65699 .10412 L p .311 .772 .946 r
F P
0 g
s
.63558 .10596 m .63608 .11142 L p .63231 .18284 L 0 0 .058 r
F P
0 g
s
.6321 .18398 m .63558 .10596 L .63231 .18284 L 0 0 .058 r
F
.64277 .18615 m .65407 .18509 L p .63212 .1839 L .289 .763 .934 r
F P
0 g
s
.6577 .1035 m .65699 .10412 L .6344 .10412 L p .059 .624 .764 r
F P
0 g
s
.6344 .10412 m .63501 .1035 L .6577 .1035 L p .059 .624 .764 r
F P
0 g
s
.63501 .1035 m .63558 .10596 L p .6321 .18398 L 0 0 .058 r
F P
0 g
s
.63195 .18483 m .63501 .1035 L .6321 .18398 L 0 0 .058 r
F
.6319 .18509 m .64277 .18615 L p .63212 .1839 L .289 .763 .934 r
F P
0 g
s
.6344 .10412 m .63501 .1035 L p .63195 .18483 L 0 0 .058 r
F P
0 g
s
.6313 .20212 m .63182 .1855 L .63195 .18483 L 0 0 .058 r
F
.63182 .1855 m .6344 .10412 L .63195 .18483 L F
.65465 .1824 m .6324 .1824 L .65407 .18509 L .289 .763 .934 r
F
.63379 .10774 m .6344 .10412 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6332 .11417 m .63379 .10774 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63265 .12309 m .6332 .11417 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63217 .13411 m .63265 .12309 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63177 .14672 m .63217 .13411 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63148 .16041 m .63177 .14672 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.6324 .1824 m .60419 .1824 L .63212 .1839 L .289 .763 .934 r
F
.6324 .1824 m .63212 .1839 L .65407 .18509 L F
.60419 .1824 m .6319 .18509 L p .63212 .1839 L F P
0 g
s
.6313 .20212 m .63195 .18483 L .6321 .18398 L 0 0 .058 r
F
.6313 .20212 m .6321 .18398 L .63231 .18284 L F
.65523 .17968 m .63329 .17752 L .65465 .1824 L .289 .763 .934 r
F
.63608 .11142 m .63651 .11966 L p .63262 .18119 L 0 0 .058 r
F P
0 g
s
.63329 .17752 m .58902 .17317 L .63296 .17935 L .289 .763 .934 r
F
.63329 .17752 m .63296 .17935 L .65465 .1824 L F
.58902 .17317 m .60419 .1824 L p .6324 .1824 L F P
0 g
s
.65465 .1824 m .63296 .17935 L .6324 .1824 L .289 .763 .934 r
F
.63296 .17935 m .58902 .17317 L .6324 .1824 L F
.6313 .20212 m .63231 .18284 L .63262 .18119 L 0 0 .058 r
F
.6313 .20212 m .63262 .18119 L .63311 .1785 L F
.65607 .17581 m .63459 .17052 L .65523 .17968 L .289 .763 .934 r
F
.63682 .13034 m .63702 .14297 L p .6341 .17317 L 0 0 .058 r
F P
0 g
s
.63459 .17052 m .6069 .16371 L .63418 .17272 L .289 .763 .934 r
F
.63459 .17052 m .63418 .17272 L .65523 .17968 L F
.6069 .16371 m .58902 .17317 L p .63329 .17752 L F P
0 g
s
.65523 .17968 m .63418 .17272 L .63329 .17752 L .289 .763 .934 r
F
.63418 .17272 m .6069 .16371 L .63329 .17752 L F
.6313 .20212 m .63311 .1785 L .6341 .17317 L 0 0 .058 r
F
.64277 .18615 m .65407 .20331 L .65213 .22814 L .548 .447 .692 r
F
.65407 .20331 m .65407 .22933 L .65213 .22814 L F
.65559 .24191 m .65494 .23894 L p .65407 .21849 L 0 0 .068 r
F P
0 g
s
.65407 .21471 m .65559 .24191 L .65407 .21849 L 0 0 .068 r
F
.65407 .21849 m .65494 .23894 L .65407 .22355 L F
.65836 .22436 m .65895 .2134 L .63608 .2134 L p .617 .786 .963 r
F P
0 g
s
.65494 .23894 m .65438 .23315 L p .65407 .22355 L 0 0 .068 r
F P
0 g
s
.65438 .23315 m .65407 .22748 L p .65407 .22355 L 0 0 .068 r
F P
0 g
s
.63608 .2134 m .63558 .22436 L .65836 .22436 L p .617 .786 .963 r
F P
0 g
s
.65929 .20468 m .65895 .2134 L p .65929 .20061 L 0 0 .068 r
F P
0 g
s
.65336 .20212 m .65663 .17317 L .65929 .16085 L 0 0 .068 r
F
.65336 .20212 m .65929 .16085 L .65929 .16256 L F
.68762 .16371 m .65929 .16085 L p .65929 .20468 L .845 .69 .69 r
F P
0 g
s
.65982 .18646 m .65945 .20057 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.66005 .17169 m .65982 .18646 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.66013 .15697 m .66005 .17169 L p .65336 .20212 L 0 0 .068 r
F P
0 g
s
.64277 .18615 m .65407 .18509 L p .65407 .20331 L .548 .447 .692 r
F P
0 g
s
.65895 .2134 m .65929 .20468 L p .64394 .20057 L .657 .75 .919 r
F P
0 g
s
.65945 .20057 m .65929 .20468 L p .65929 .20061 L 0 0 .068 r
F P
0 g
s
.65202 .20057 m .64394 .20057 L p .65929 .20468 L .657 .75 .919 r
F P
0 g
s
.64013 .20264 m .65895 .2134 L .64394 .20057 L .657 .75 .919 r
F
.65812 .16628 m .64806 .15972 L .65607 .17581 L .289 .763 .934 r
F
.65407 .22748 m .65438 .23315 L p .65043 .22616 L .613 .212 .26 r
F P
0 g
s
.65559 .24191 m .65628 .24192 L .63379 .24192 L p 0 0 0 r
F P
0 g
s
.65628 .24192 m .65699 .23891 L .6344 .23891 L p .266 .752 .921 r
F P
0 g
s
.6344 .23891 m .63379 .24192 L .65628 .24192 L p .266 .752 .921 r
F P
0 g
s
.65699 .23891 m .6577 .23298 L .63501 .23298 L p .446 .812 .995 r
F P
0 g
s
.63501 .23298 m .6344 .23891 L .65699 .23891 L p .446 .812 .995 r
F P
0 g
s
.6577 .23298 m .65836 .22436 L .63558 .22436 L p .553 .811 .994 r
F P
0 g
s
.63558 .22436 m .63501 .23298 L .6577 .23298 L p .553 .811 .994 r
F P
0 g
s
.64806 .15972 m .63637 .16085 L p .63637 .20468 L .541 .442 .691 r
F P
0 g
s
.64806 .15972 m .63637 .20468 L .63871 .20341 L .541 .442 .691 r
F
.63608 .2134 m .65895 .2134 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63637 .20468 m .63608 .2134 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63265 .23894 m .63217 .23315 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.6319 .21849 m .63265 .23894 L .6319 .22355 L 0 0 .058 r
F
.61601 .23949 m .6319 .22933 L .6319 .31625 L .841 .687 .691 r
F
.64277 .36876 m .60419 .36597 L .60419 .1824 L p F P
0 g
s
.64806 .1973 m .64806 .15972 L p .63837 .205 L .541 .442 .691 r
F P
0 g
s
.65929 .16085 m .64806 .15972 L p .65137 .20004 L .845 .69 .69 r
F P
0 g
s
.63679 .18797 m .63651 .20057 L .65202 .20057 L p .682 .709 .868 r
F P
0 g
s
.65929 .20659 m .65137 .20004 L .65929 .29646 L .845 .69 .69 r
F
.65929 .16085 m .65137 .20004 L .65929 .20659 L F
.64806 .15972 m .64806 .34909 L p .65929 .29646 L F P
0 g
s
.63682 .18646 m .63679 .18797 L p .65945 .20057 L .682 .709 .868 r
F P
0 g
s
.65202 .20057 m .65945 .20057 L p .63679 .18797 L .682 .709 .868 r
F P
0 g
s
.6069 .35206 m .64806 .34909 L .64806 .1973 L p .541 .442 .691 r
F P
0 g
s
.63837 .205 m .6069 .35206 L .64806 .1973 L .541 .442 .691 r
F
.65982 .18646 m .63682 .18646 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.65945 .20057 m .65978 .18797 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.65978 .18797 m .65982 .18646 L p .65075 .19515 L .682 .709 .868 r
F P
0 g
s
.63651 .20057 m .63637 .20468 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.6313 .20212 m .6341 .17317 L .63637 .16085 L 0 0 .058 r
F
.6313 .20212 m .63637 .16085 L .63637 .16256 L F
.63637 .16085 m .6069 .16371 L p .63459 .17052 L .289 .763 .934 r
F P
0 g
s
.63682 .18646 m .63651 .20057 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63702 .17169 m .63682 .18646 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.63709 .15697 m .63702 .17169 L p .6313 .20212 L 0 0 .058 r
F P
0 g
s
.60419 .1824 m .6319 .18509 L p .6319 .21112 L .841 .687 .691 r
F P
0 g
s
.63637 .16085 m .6069 .16371 L p .6321 .207 L .541 .442 .691 r
F P
0 g
s
.63637 .20468 m .63608 .2134 L p .63637 .20061 L 0 0 .058 r
F P
0 g
s
.63637 .20468 m .6321 .207 L .63637 .21433 L .541 .442 .691 r
F
.63637 .16085 m .6321 .207 L .63637 .20468 L F
.65929 .20468 m .65945 .20057 L .65202 .20057 L p .657 .75 .919 r
F P
0 g
s
.67677 .21456 m .65929 .20468 L .65929 .29646 L .845 .69 .69 r
F
.70171 .35911 m .68286 .36597 L .68286 .1824 L p 0 0 .478 r
F P
0 g
s
.68286 .1824 m .70171 .17317 L .70171 .35911 L p 0 0 .478 r
F P
0 g
s
.68286 .1824 m .70171 .17317 L .68762 .16371 L p .289 .763 .934 r
F P
0 g
s
.68762 .16371 m .65929 .20468 L .67677 .21456 L .845 .69 .69 r
F
.65929 .16256 m .65929 .16085 L .66013 .15697 L 0 0 .068 r
F
.64394 .20057 m .63651 .20057 L p .64013 .20264 L .657 .75 .919 r
F P
0 g
s
.63871 .20341 m .63637 .20468 L .63637 .21433 L .541 .442 .691 r
F
.63637 .16256 m .63637 .16085 L .63709 .15697 L 0 0 .058 r
F
.63651 .20057 m .63637 .20468 L p .63637 .20061 L F P
0 g
s
.60419 .1824 m .6319 .21112 L .61601 .23949 L .841 .687 .691 r
F
.6319 .21112 m .6319 .22933 L .61601 .23949 L F
.63217 .23315 m .6319 .22748 L p .6319 .22355 L 0 0 .058 r
F P
0 g
s
.6069 .16371 m .6069 .35206 L p .63637 .21433 L .541 .442 .691 r
F P
0 g
s
.60419 .36597 m .58902 .35911 L .58902 .17317 L p .989 .807 .419 r
F P
0 g
s
.58902 .17317 m .60419 .1824 L .60419 .36597 L p .989 .807 .419 r
F P
0 g
s
.58902 .35911 m .6069 .35206 L .6069 .16371 L p 0 0 .457 r
F P
0 g
s
.6069 .16371 m .58902 .17317 L .58902 .35911 L p 0 0 .457 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.60419 .36597 m .64277 .36876 L .68286 .36597 L p .224 .73 .894 r
F P
0 g
s
.58902 .35911 m .60419 .36597 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.46786 .33828 m .4054 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.6069 .35206 m .58902 .35911 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.53214 .33828 m .46786 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.64806 .34909 m .6069 .35206 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.5946 .34069 m .53214 .33828 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.64806 .34909 m .68762 .35206 L .68762 .16371 L p .845 .69 .69 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.68762 .35206 m .64806 .34909 L p .68286 .36597 L .224 .73 .894 r
F P
0 g
s
.68286 .36597 m .70171 .35911 L .68762 .35206 L p .224 .73 .894 r
F P
0 g
s
.6518 .34535 m .5946 .34069 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.68762 .35206 m .70171 .35911 L .70171 .17317 L p .981 .801 .392 r
F P
0 g
s
.70171 .17317 m .68762 .16371 L .68762 .35206 L p .981 .801 .392 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.70073 .35195 m .6518 .34535 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7391 .36006 m .70073 .35195 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.76541 .36923 m .7391 .36006 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.77986 .38872 m .7687 .39814 L .7687 .39285 L p 0 0 .257 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77986 .38872 L p 0 0 .257 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L p .7687 .39285 L .224 .73 .894 r
F P
0 g
s
.7687 .39285 m .77986 .38333 L .77898 .37345 L p .224 .73 .894 r
F P
0 g
s
.77898 .37893 m .76541 .36923 L p .7687 .39814 L .222 .729 .893 r
F P
0 g
s
.7687 .39814 m .77986 .38872 L .77898 .37893 L p .222 .729 .893 r
F P
0 g
s
.70996 1.10469 m .70775 1.15905 L .70347 1.15371 L p 0 0 .093 r
F P
0 g
s
.70347 1.15371 m .70775 1.15905 L .55656 1.15905 L p .115 0 0 r
F P
0 g
s
.55656 1.15905 m .5554 1.15371 L .70347 1.15371 L p .115 0 0 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .5554 1.15371 L p 0 0 .026 r
F P
0 g
s
.63045 1.32905 m .62917 1.33744 L .62791 1.3207 L p 0 0 .059 r
F P
0 g
s
.63099 1.29994 m .63045 1.32905 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.63045 1.26755 m .63099 1.29994 L p .62791 1.3207 L 0 0 .059 r
F P
0 g
s
.62791 1.3207 m .62917 1.33744 L .37083 1.33744 L p .525 .043 .052 r
F P
0 g
s
.37083 1.33744 m .37209 1.3207 L .62791 1.3207 L p .525 .043 .052 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .37209 1.3207 L p .763 .623 .059 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L p .37209 1.3207 L .763 .623 .059 r
F P
0 g
s
.39236 1.29439 m .41389 1.27286 L .43542 1.29439 L p .707 .577 .707 r
F P
0 g
s
.43542 1.29439 m .41389 1.31592 L .39236 1.29439 L p .707 .577 .707 r
F P
0 g
s
.56458 1.29439 m .58611 1.27286 L .60764 1.29439 L p .707 .577 .707 r
F P
0 g
s
.60764 1.29439 m .58611 1.31592 L .56458 1.29439 L p .707 .577 .707 r
F P
0 g
s
.77898 .37893 m .77986 .38872 L .77986 .38333 L p .728 .594 .021 r
F P
0 g
s
.77986 .38333 m .77898 .37345 L .77898 .37893 L p .728 .594 .021 r
F P
0 g
s
.29004 .87384 m .22983 .87438 L .22983 1.10042 L p .28 .229 .62 r
F P
0 g
s
.22983 1.10042 m .29004 1.10469 L .29004 .87384 L p .28 .229 .62 r
F P
0 g
s
.77017 .87438 m .70996 .87384 L .70996 1.10469 L p .96 .784 .62 r
F P
0 g
s
.70996 1.10469 m .77017 1.10042 L .77017 .87438 L p .96 .784 .62 r
F P
0 g
s
.36955 1.32905 m .37083 1.33744 L .62917 1.33744 L p .339 .783 .96 r
F P
0 g
s
.62917 1.33744 m .63045 1.32905 L .36955 1.32905 L p .339 .783 .96 r
F P
0 g
s
.22014 .38872 m .22102 .37893 L .22102 .37345 L p 0 0 .021 r
F P
0 g
s
.22102 .37345 m .22014 .38333 L .22014 .38872 L p 0 0 .021 r
F P
0 g
s
.63099 1.29994 m .63045 1.26755 L .36955 1.26755 L p .693 .453 .555 r
F P
0 g
s
.36955 1.26755 m .36901 1.29994 L .63099 1.29994 L p .693 .453 .555 r
F P
0 g
s
.63045 1.32905 m .63099 1.29994 L .36901 1.29994 L p .69 .689 .843 r
F P
0 g
s
.36901 1.29994 m .36955 1.32905 L .63045 1.32905 L p .69 .689 .843 r
F P
0 g
s
.29004 1.10469 m .29225 1.15905 L .44344 1.15905 L p .676 .721 .883 r
F P
0 g
s
.44344 1.15905 m .44284 1.10469 L .29004 1.10469 L p .676 .721 .883 r
F P
0 g
s
.70775 1.15905 m .70996 1.10469 L .55716 1.10469 L p .676 .721 .883 r
F P
0 g
s
.55716 1.10469 m .55656 1.15905 L .70775 1.15905 L p .676 .721 .883 r
F P
0 g
s
.76541 .36923 m .77898 .37893 L .77898 .37345 L p .938 .766 .296 r
F P
0 g
s
.77898 .37345 m .76541 .36364 L .76541 .36923 L p .938 .766 .296 r
F P
0 g
s
.22102 .37893 m .23459 .36923 L .23459 .36364 L p 0 0 .296 r
F P
0 g
s
.23459 .36364 m .22102 .37345 L .22102 .37893 L p 0 0 .296 r
F P
0 g
s
.7391 .36006 m .76541 .36923 L .76541 .36364 L p 1 .816 .486 r
F P
0 g
s
.76541 .36364 m .7391 .35438 L .7391 .36006 L p 1 .816 .486 r
F P
0 g
s
.23459 .36923 m .2609 .36006 L .2609 .35438 L p 0 0 .486 r
F P
0 g
s
.2609 .35438 m .23459 .36364 L .23459 .36923 L p 0 0 .486 r
F P
0 g
s
.34301 .10412 m .3423 .1035 L .36499 .1035 L p .059 .624 .764 r
F P
0 g
s
.36442 .10596 m .36499 .1035 L .3423 .1035 L p .238 0 0 r
F P
0 g
s
.65836 .10596 m .6577 .1035 L .63501 .1035 L p .238 0 0 r
F P
0 g
s
.3423 .1035 m .34164 .10596 L .36442 .10596 L p .238 0 0 r
F P
0 g
s
.63501 .1035 m .63558 .10596 L .65836 .10596 L p .238 0 0 r
F P
0 g
s
.70073 .35195 m .7391 .36006 L .7391 .35438 L p .977 .798 .595 r
F P
0 g
s
.7391 .35438 m .70073 .34618 L .70073 .35195 L p .977 .798 .595 r
F P
0 g
s
.2609 .36006 m .29927 .35195 L .29927 .34618 L p .213 .174 .595 r
F P
0 g
s
.29927 .34618 m .2609 .35438 L .2609 .36006 L p .213 .174 .595 r
F P
0 g
s
.36392 .11142 m .36442 .10596 L .34164 .10596 L p .47 0 0 r
F P
0 g
s
.65895 .11142 m .65836 .10596 L .63558 .10596 L p .47 0 0 r
F P
0 g
s
.34164 .10596 m .34105 .11142 L .36392 .11142 L p .47 0 0 r
F P
0 g
s
.63558 .10596 m .63608 .11142 L .65895 .11142 L p .47 0 0 r
F P
0 g
s
.36349 .11966 m .36392 .11142 L .34105 .11142 L p .601 .186 .228 r
F P
0 g
s
.65945 .11966 m .65895 .11142 L .63608 .11142 L p .601 .186 .228 r
F P
0 g
s
.34105 .11142 m .34055 .11966 L .36349 .11966 L p .601 .186 .228 r
F P
0 g
s
.63608 .11142 m .63651 .11966 L .65945 .11966 L p .601 .186 .228 r
F P
0 g
s
.36318 .13034 m .36349 .11966 L .34055 .11966 L p .665 .348 .426 r
F P
0 g
s
.65982 .13034 m .65945 .11966 L .63651 .11966 L p .665 .348 .426 r
F P
0 g
s
.34055 .11966 m .34018 .13034 L .36318 .13034 L p .665 .348 .426 r
F P
0 g
s
.63651 .11966 m .63682 .13034 L .65982 .13034 L p .665 .348 .426 r
F P
0 g
s
.36349 .20057 m .36318 .18646 L .34018 .18646 L p .682 .709 .868 r
F P
0 g
s
.36298 .14297 m .36318 .13034 L .34018 .13034 L p .695 .46 .564 r
F P
0 g
s
.66005 .14297 m .65982 .13034 L .63682 .13034 L p .695 .46 .564 r
F P
0 g
s
.34018 .13034 m .33995 .14297 L .36298 .14297 L p .695 .46 .564 r
F P
0 g
s
.63682 .13034 m .63702 .14297 L .66005 .14297 L p .695 .46 .564 r
F P
0 g
s
.36318 .18646 m .36298 .17169 L .33995 .17169 L p .698 .662 .811 r
F P
0 g
s
.33995 .17169 m .34018 .18646 L .36318 .18646 L p .698 .662 .811 r
F P
0 g
s
.65982 .18646 m .66005 .17169 L .63702 .17169 L p .698 .662 .811 r
F P
0 g
s
.63702 .17169 m .63682 .18646 L .65982 .18646 L p .698 .662 .811 r
F P
0 g
s
.36291 .15697 m .36298 .14297 L .33995 .14297 L p .706 .543 .665 r
F P
0 g
s
.66013 .15697 m .66005 .14297 L .63702 .14297 L p .706 .543 .665 r
F P
0 g
s
.33995 .14297 m .33987 .15697 L .36291 .15697 L p .706 .543 .665 r
F P
0 g
s
.63702 .14297 m .63709 .15697 L .66013 .15697 L p .706 .543 .665 r
F P
0 g
s
.36298 .17169 m .36291 .15697 L .33987 .15697 L p .706 .608 .745 r
F P
0 g
s
.33987 .15697 m .33995 .17169 L .36298 .17169 L p .706 .608 .745 r
F P
0 g
s
.66005 .17169 m .66013 .15697 L .63709 .15697 L p .706 .608 .745 r
F P
0 g
s
.63709 .15697 m .63702 .17169 L .66005 .17169 L p .706 .608 .745 r
F P
0 g
s
.6518 .34535 m .70073 .35195 L .70073 .34618 L p .922 .753 .655 r
F P
0 g
s
.70073 .34618 m .6518 .33951 L .6518 .34535 L p .922 .753 .655 r
F P
0 g
s
.29927 .35195 m .3482 .34535 L .3482 .33951 L p .387 .316 .655 r
F P
0 g
s
.3482 .33951 m .29927 .34618 L .29927 .35195 L p .387 .316 .655 r
F P
0 g
s
.5946 .34069 m .6518 .34535 L .6518 .33951 L p .856 .699 .686 r
F P
0 g
s
.6518 .33951 m .5946 .33481 L .5946 .34069 L p .856 .699 .686 r
F P
0 g
s
.3482 .34535 m .4054 .34069 L .4054 .33481 L p .517 .422 .686 r
F P
0 g
s
.4054 .33481 m .3482 .33951 L .3482 .34535 L p .517 .422 .686 r
F P
0 g
s
.53214 .33828 m .5946 .34069 L .5946 .33481 L p .784 .641 .702 r
F P
0 g
s
.5946 .33481 m .53214 .33237 L .53214 .33828 L p .784 .641 .702 r
F P
0 g
s
.4054 .34069 m .46786 .33828 L .46786 .33237 L p .62 .506 .702 r
F P
0 g
s
.46786 .33237 m .4054 .33481 L .4054 .34069 L p .62 .506 .702 r
F P
0 g
s
.46786 .33828 m .53214 .33828 L .53214 .33237 L p .707 .577 .707 r
F P
0 g
s
.53214 .33237 m .46786 .33237 L .46786 .33828 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{512.75, 922.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00004PB000`400?l00000o`00003oo`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00f`3oool?00000:`0oooo3`00003K0?oo
o`00fP3oool00`000000?00003`0000<03`000030000003oool0oooo0:T0oooo0P00000=03`00003
0000003oool0oooo0=T0oooo003J0?oooa000000Z`3ooolA00000=X0oooo003J0?ooo`030000001h
0000N00000`0N0000P00002Z0?ooo`8000003P1h00000`000000oooo0?ooo`3H0?ooo`00fP3oool0
0`000000N00007P0000;07P0000300000033W`h000000:X0oooo0P00000>07P000030000003oool0
oooo0=P0oooo003J0?ooo`030000001h0000N00000/0N00000<000000<>O3P000000ZP3oool00`00
0000000>0000000=07P000030000003oool0oooo0=P0oooo003J0?ooo`l0000000<0`il>0000003o
ool0Z@3oool00`000000000>0000000>00000=X0oooo003J0?ooo`030000002I;cX0VBlj00/0VBlj
00<000000<>O3P000000ZP3oool00`000000000>0000000=09T_>P030000003oool0oooo0=P0oooo
003J0?ooo`030000002I;cX0VBlj00/0VBlj00<000000<>O3P000000ZP3oool00`000000000>0000
000=09T_>P030000003oool0oooo0=P0oooo003I0?ooo`030000002I;cX0VBlj00`0VBlj00<00000
0<>O3P000000ZP3oool00`000000000>0000000>09T_>P030000003oool0oooo0=L0oooo003I0?oo
o`030000002I;cX0VBlj00`0VBlj00<000000<>O3P000000Z@3oool010000000000>00003P00000>
09T_>P030000003oool0oooo0=L0oooo003I0?oooa0000000P33W`h00`000000oooo0?ooo`2V0?oo
o`030000000000h0000>01000000f@3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000
`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool0
0=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?ooo`040000000000h0
000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd0
10000000`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0
e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?ooo`040000
000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0
302ZFFd010000000`il>0<>O3P00002X0?ooo`040000000000h0000>000000h0ZUU]00<000000?oo
o`3oool0e`3oool00=T0oooo00<000000:YIK@2ZFFd0302ZFFd010000000`il>0<>O3P00002X0?oo
o`040000000000h0000>000000h0ZUU]00<000000?ooo`3oool0e`3oool00=T0oooo400000020<>O
3P030000003oool0oooo0:H0oooo00<0000000003P0000h04000003I0?ooo`00f@3oool00`000000
/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI00
0`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>
00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool0
0`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P0000h00000
3P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033
W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00
f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@0000000003P00
00h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT004
00000033W`h0`il>00000:P0oooo00@0000000003P0000h000003P2aMI000`000000oooo0?ooo`3G
0?ooo`00f@3oool00`000000/GF@0;5eT00<0;5eT00400000033W`h0`il>00000:P0oooo00@00000
00003P0000h000003P2aMI000`000000oooo0?ooo`3G0?ooo`00f@3oool@00000080`il>00<00000
0?ooo`3oool0YP3oool00`000000000>00003P0@00000=T0oooo003I0?ooo`030000002dRjX0]8^Z
00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003o
ool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03o
ool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002d
RjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP03
0000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h0
0000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`03
0000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>00003P00000>
0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O
3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0oooo003I
0?ooo`030000002dRjX0]8^Z00`0]8^Z00@000000<>O3P33W`h00000Z03oool010000000000>0000
3P00000>0;B;ZP030000003oool0oooo0=L0oooo003I0?ooo`030000002dRjX0]8^Z00`0]8^Z00@0
00000<>O3P33W`h00000Z03oool010000000000>00003P00000>0;B;ZP030000003oool0oooo0=L0
oooo003I0?oooa0000000P33W`h00`000000oooo0?ooo`2V0?ooo`030000000000h0000>01000000
f@3oool00=T0oooo00<000000;BK_P2dVkh0302dVkh010000000`il>0<>O3P00002X0?ooo`040000
000000h0000>000000h0]9^n00<000000?ooo`3oool0e`3oool00=H0oooo1000000>0;BK_PD00000
YP3oool5000000h0]9^n1000003F0?ooo`00c03oool:000000<0R6n`00<000000;BK_P2dVkh0302d
Vkh00`000000ejn`0=N_/0020=N_/0X00000TP3oool:000000@0RW6`00<000000;BK_P2dVkh0302d
Vkh010000000f;2`0=R`/03H/;0:00000<`0oooo00370?ooo`D000003@28Kk000`000000]9^n0;BK
_P0<0;BK_P030000003G[k00ejn`00`0ejn`1@0000280?ooo`D000003P2:LK000`000000]9^n0;BK
_P0<0;BK_P030000003H/;00f;2`00/0f;2`1@0000370?ooo`00a@3oool300000140R6n`00<00000
0;BK_P2dVkh0302dVkh00`000000ejn`0=N_/00@0=N_/0<00000Q03oool300000180RW6`00<00000
0;BK_P2dVkh0302dVkh00`000000f;2`0=R`/00?0=R`/0<00000a@3oool00<@0oooo00@000000000
I00006@000004@28Kk000`000000]9^n0;BK_P0<0;BK_P030000003G[k00ejn`0100ejn`00<00000
0?o@M03od7@00P0000200?ooo`8000000P0007@00`000000RW6`08Ya/00@08Ya/0030000002dVkh0
]9^n00`0]9^n00<000000=R`/03H/;003`3H/;0010000000nleT0?_=I00000340?ooo`00`P3oool2
000000<0001T00<0000008Q_/028Kk003`28Kk000`000000]9^n0;BK_P0<0;BK_P030000003G[k00
ejn`0100ejn`00<000000?o@M03od7@00P3od7@2000007`0oooo0P0000040000M0030000002:LK00
RW6`0100RW6`00<000000;BK_P2dVkh0302dVkh00`000000f;2`0=R`/00?0=R`/0040000003kcF@0
nleT0?_=I0800000`P3oool00<40oooo00<000000000I00006@00`0006@00`000000R6n`08Q_/00?
08Q_/0030000002dVkh0]9^n00`0]9^n00<000000=N_/03G[k00403G[k000`000000om1d0?o@M004
0?o@M0800000N03oool2000000H0001d00<0000008Ya/02:LK00402:LK000`000000]9^n0;BK_P0<
0;BK_P030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@00`3kcF@00`000000oooo0?ooo`2o
0?ooo`00_`3oool2000000H0001T00<0000008Q_/028Kk003`28Kk0@00000180ejn`00<000000?o@
M03od7@01P3od7@2000007@0oooo0P0000080000M0030000002:LK00RW6`0100RW6`4000000A0=R`
/0030000003kcF@0nleT00@0nleT0P00002o0?ooo`00_P3oool00`000000001T0000I0060000I003
00000028Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/003
0000003od7@0om1d00P0om1d0P00001`0?ooo`8000002P0007@00`000000RW6`08Ya/00@08Ya/003
0000002bZLl0/ZW?00`0/ZW?00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
3`28Kk000`000000/ZW?0;:Yc`0<0;:Yc`030000003G[k00ejn`0100ejn`00<000000?o@M03od7@0
2@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK00
402:LK000`000000/ZW?0;:Yc`0<0;:Yc`030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@0
1P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028
Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/0030000003o
d7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:
LK00RW6`0100RW6`00<000000;:Yc`2bZLl0302bZLl00`000000f;2`0=R`/00?0=R`/0030000003k
cF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@0
0`000000R6n`08Q_/00?08Q_/0030000002bZLl0/ZW?00`0/ZW?00<000000=N_/03G[k003P3G[k00
0`19`nl0ejn`0000000;0?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00@08Ya/0030000002bZLl0/ZW?00`0/ZW?00<000000=R`/03H/;003`3H/;00
0`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T
00H0001T00<0000008Q_/028Kk003`28Kk000`000000/ZW?0;:Yc`0<0;:Yc`030000003G[k00ejn`
0100ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d
00T0001d00<0000008Ya/02:LK00402:LK000`000000/ZW?0;:Yc`0<0;:Yc`030000003H/;00f;2`
00l0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`00l0R6n`00<000000;:Yc`2bZLl0302bZLl00`000000
ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000
001d0000M0090000M0030000002:LK00RW6`0100RW6`00<000000;:Yc`2bZLl0302bZLl00`000000
f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002bZLl0/ZW?00`0/ZW?
00<000000=N_/03G[k00403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo
00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002bZLl0/ZW?00`0/ZW?
00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk003`28Kk000`000000/ZW?0;:Y
c`0<0;:Yc`030000003G[k00ejn`0100ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?oo
o`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK00402:LK000`000000/ZW?0;:Y
c`0<0;:Yc`030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`00l0R6n`00<00000
0;:Yc`2bZLl0302bZLl00`000000ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<00000
0?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00RW6`0100RW6`00<00000
0;:Yc`2bZLl0302bZLl00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_
/10000004P3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000
M00007@02@0007@00`000000RW6`08Ya/00@08Ya/10000004@3H/;000`000000nleT0?_=I0060?_=
I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028
Kk003`28Kk000`000000[[GN0:jegP0<0:jegP030000003G[k00ejn`0100ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK00402:LK000`000000[[GN0:jegP0<0:jegP030000003H/;00f;2`00l0f;2`00<000000?_=I03k
cF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I0030000
0028Kk00R6n`00l0R6n`00<000000:jegP28Kk00302^]Mh00`000000ejn`0=N_/00@0=N_/0030000
003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000
002:LK00RW6`0100RW6`00<000000:jegP2^]Mh0302^]Mh00`000000f;2`0=R`/00?0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00?08Q_/0050000002^]Mh0[[GN0:jegP28Kk002P2^]Mh00`000000ejn`
0=N_/00<0=N_/00508Ya/03G[k00ejn`0=N_/00000002`3od7@00`000000oooo0?ooo`1^0?ooo`03
0000000007@0001d00T0001d00<0000008Ya/02:LK00402:LK000`000000[[GN0:jegP020:jegP03
08Ya/02^]Mh0[[GN00L0[[GN00<000000=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
3`28Kk000`000000[[GN0:jegP030:jegP0308Q_/02^]Mh0[[GN00H0[[GN00<000000=N_/03G[k00
403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@0
2@0007@00`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN00@0[[GN00<000000:jegP2^]Mh0
1@2^]Mh00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002^
]Mh0[[GN00D0[[GN00<000000:jegP2^]Mh0102^]Mh00`000000ejn`0=N_/00@0=N_/0030000003o
d7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:
LK00RW6`0100RW6`00<000000:jegP2^]Mh0302^]Mh00`000000f;2`0=R`/00?0=R`/0030000003k
cF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@0
0`000000R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN00`0[[GN00<000000=N_/03G[k00403G[k00
0`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN00L0[[GN00<0f;2`0:jegP2^]Mh00P2^]Mh0
0`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool0
0;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN
00`0[[GN00<000000=N_/03G[k00403G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo
06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002^]Mh0[[GN
00@0[[GN00<000000:jegP2^]Mh01@2^]Mh00`000000f;2`0=R`/00?0=R`/0030000003kcF@0nleT
00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000
R6n`08Q_/00?08Q_/0030000002^]Mh0[[GN00@0[[GN00@0R6n`0000002^]Mh0ejn`102^]Mh00`00
0000ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`00
0000001d0000M0090000M0030000002:LK00RW6`0100RW6`00<000000:jegP2^]Mh00`2^]Mh00`2:
LK0000000=R`/0060:jegP030000003H/;00f;2`00l0f;2`00<000000?_=I03kcF@01P3kcF@00`00
0000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`00l0
R6n`1P00000208Q_/0030000003G[k00000000D000004P3G[k000`000000om1d0?o@M0090?o@M003
0000003oool0oooo06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0H0
000000@0RW6`0000003H/;00f;2`1P00000A0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00?08Q_/003
0000002X_n/0Z;o[00D0R6n`00<000000=N_/03G[k000P3G[k020:Roja<0ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK00402:LK000`000000Z;o[08Ya/00408Ya/0030000003H/;00f;2`0080f;2`0P2X_n/00`000000
f;2`0=R`/00@0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00@08Q_/00300000028Kk00R6n`00@0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo
00<000000000M00007@02@0007@00`000000RW6`08Ya/00@08Ya/0030000002:LK00RW6`00@0RW6`
00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_
/00A0=N_/00308Ya/03G[k00ejn`00<0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?oo
o`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`
/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<00000
0000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<00000
0?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_
/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?oo
o`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:
LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3o
ool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000
003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000
000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`0100ejn`00<0RW6`0=N_/03G[k00103G
[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@00
07@00`000000RW6`08Ya/00@08Ya/0030000002:LK00RW6`00@0RW6`00<000000=R`/03H/;005`3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0
om1d00T0om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00
RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0
oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`00
0000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00<000000?ooo`3oool0KP3oool00`00
0000001d0000M0090000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00<000000?ooo`3oool0KP3oool00`000000001d0000M0090000M0030000002:LK00RW6`01L0
RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0
oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`
0=N_/00?0=N_/00308Ya/03G[k00ejn`00D0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo
0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<0
00000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^
0?ooo`030000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G
0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000
I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@
M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`030000000007@0001d00T0001d00<0000008Ya
/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/003
0000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@00`000000oooo0?ooo`1^0?ooo`03
0000000007@0001d00T0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/003
0000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@0
1P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00h0ejn`00<0RW6`0=N_/03G[k00
1P3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@0
2@0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@0
1P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028
Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003o
ool0oooo06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000003H
/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k00
0`000000om1d0?o@M0090?o@M0030000003oool0oooo06h0oooo00<000000000M00007@02@0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003oool0oooo
06h0oooo00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k003@3G[k000`2:LK00
ejn`0=N_/0070=N_/0030000003od7@0om1d00T0om1d0`00001/0?ooo`<000002`0007@00`000000
RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0030000003od7X0om1j00800000
J03oool200000080001j00<000000000M00007@02@0007@00`000000RW6`08Ya/00G08Ya/0030000
003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3o
ool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G
[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j
0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/003
0000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@0
1P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@0
2@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000
M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=
I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028
Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3o
d7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G
08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l
0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_
/03G[k00303G[k000`2:LK00ejn`0=N_/0080=N_/0030000003od7@0om1d00T0om1d00D000000?o@
NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya
/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<00000
0=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<0
00000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0
001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000
nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T
00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d
00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`00
0000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`00
0000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0
R6n`00<000000=N_/03G[k002`3G[k000`2:LK00ejn`0=N_/0090=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j
0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:
LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03o
ool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00
ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
5`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`0300000000
06@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003o
d7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP00
00002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03k
cF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I0030000
0028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000
003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya
/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?oo
o`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/003
0000003G[k00ejn`00X0ejn`00<0RW6`0=N_/03G[k002P3G[k000`000000om1d0?o@M0090?o@M005
0000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00:0=R`/00308ab/@3H/;00f;2`00X0f;2`00<00000
0?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000
I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@
M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3o
d7X0000006P0oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`
00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo
002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_
/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000
000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0
f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T
0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k002@3G[k000`2:LK00ejn`
0=N_/00;0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`05
0000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k002@3G[k000`2:LK00
ejn`0=N_/00;0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?oo
o`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00
f;2`00T0f;2`00<0S7:a0=R`/03H/;002`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0
oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`00
0000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X
0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H
/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k00
0`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000
NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3o
d7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000M003
0000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I0060?_=I003
0000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk00
5`28Kk000`000000ejn`0=N_/0080=N_/00308Ya/03G[k00ejn`00`0ejn`00<000000?o@M03od7@0
2@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;0000
M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00203H/;000`2<L[40f;2`0=R`/00<0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;
0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I006
0?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_
/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@
NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya
/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?oo
o`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<00000
0=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<0
00000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00L0ejn`00<0
RW6`0=N_/03G[k003@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000
J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000
f;2`0=R`/0070=R`/00308ab/@3H/;00f;2`00d0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k001`3G[k000`2:LK00ejn`0=N_/00=0=N_/0030000003od7@0om1d00T0om1d
00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`00
0000RW6`08Ya/00G08Ya/0030000003H/;00f;2`00L0f;2`00<0S7:a0=R`/03H/;003@3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j
0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:
LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03o
ool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00
ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
5`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`0300000000
06@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/0060=N_/00308Ya/03G
[k00ejn`00h0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo
00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H
/;001P3H/;000`2<L[40f;2`0=R`/00>0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3o
ool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000
003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0
oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`
/03H/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`03
0000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/003
0000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j
0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<00000
0?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000
I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@
M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0
000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<0
00000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G
08Q_/0030000003G[k00ejn`00D0ejn`00<0RW6`0=N_/03G[k003`3G[k000`000000om1d0?o@M009
0?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d
00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/0050=R`/00308ab/@3H/;00f;2`00l0f;2`
00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000
I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k001@3G[k000`2:LK00ejn`0=N_
/00?0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000
000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`00D0
f;2`00<0S7:a0=R`/03H/;003`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0
oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`
0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`05
0000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`
01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000
001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000
om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0
000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0
nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`00
0000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00@0ejn`00<0RW6`0=N_/03G[k00403G[k000`00
0000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP00
07X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/0040=R`/00308ab/@3H
/;00f;2`0100f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool0
0`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k00103G[k00
0`2:LK00ejn`0=N_/00@0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000
001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000
003H/;00f;2`00@0f;2`00<0S7:a0=R`/03H/;00403H/;000`000000nleT0?_=I0060?_=I0030000
003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28
Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j
0000001X0?ooo`050000000007X0001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/003
0000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00
_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k00
5`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000
001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`
/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I000
06@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03o
d7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000000;
0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`000000nleT0?_=I006
0?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00<0000008Q_
/028Kk005`28Kk000`000000ejn`0=N_/0030=N_/00308Ya/03G[k00ejn`0140ejn`00<000000?o@
M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP0007X0001j0000
000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;000`3H/;000`2<L[40f;2`0=R`
/00A0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<00000
0000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`00<0ejn`00<0RW6`
0=N_/03G[k004@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000J03o
ool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000f;2`
0=R`/0030=R`/00308ab/@3H/;00f;2`0140f;2`00<000000?_=I03kcF@01P3kcF@00`000000oooo
0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`00<0
00000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP000000
J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`000000
f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo
00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0ejn`
00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000NP00
07X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;000`00
0000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0
001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d00T0
om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`0007@0
0`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@0
0`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`
01L0R6n`00<000000=N_/03G[k000P3G[k000`2:LK00ejn`0=N_/00B0=N_/0030000003od7@0om1d
00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`00
07@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`0080f;2`00<0S7:a0=R`/03H/;004P3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/0020=N_/00308Ya/03G[k00
ejn`0180ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D0
00000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;00
0P3H/;000`2<L[40f;2`0=R`/00B0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G
[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo
00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H
/;005`3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000
000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000
003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000
NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=
I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I003
00000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M005
0000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<00000
08Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<00000
0?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_
/0050000003G[k00ejn`0=N_/02:LK005@3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0
om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK00
5`2:LK001@000000f;2`0=R`/03H/;00S7:a01D0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP00
0000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`00
0000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0
oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0
ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0oooo00D000000000
NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00<000000=R`/03H/;005`3H/;00
0`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T
00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_/0030000003od7@0om1d
00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0001j0000NP0000002`00
07@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3k
cF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00
R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0
om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK00
5`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0
_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0040000003G
[k00ejn`000001H0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@NP3od7X0000006P0
oooo00D000000000NP0007X0001j0000000;0000M0030000002:LK00RW6`01L0RW6`00@000000=R`
/03H/;00S7:a5P3H/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?oo
o`030000000006@0001T00H0001T00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00G0=N_
/0030000003od7@0om1d00T0om1d00D000000?o@NP3od7X0om1j0000001X0?ooo`050000000007X0
001j0000NP0000002`0007@00`000000RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<0
00000?_=I03kcF@01P3kcF@00`000000oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I006
0000I00300000028Kk00R6n`01L0R6n`00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M009
0?o@M0050000003od7X0om1j0?o@NP000000J03oool01@000000001j0000NP0007X0000000/0001d
00<0000008Ya/02:LK005`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT
00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_
/00G08Q_/0030000003G[k00ejn`01L0ejn`00<000000?o@M03od7@02@3od7@01@000000om1j0?o@
NP3od7X0000001H0oooo?000000F0?ooo`050000000007X0001j0000NP0000002`0007@00`000000
RW6`08Ya/00G08Ya/0030000003H/;00f;2`01L0f;2`00<000000?_=I03kcF@01P3kcF@00`000000
oooo0?ooo`2l0?ooo`00_P3oool00`000000001T0000I0060000I00300000028Kk00R6n`01L0R6n`
00<000000=N_/03G[k005`3G[k000`000000om1d0?o@M0090?o@M0050000003od7X0om1j0?o@NP00
00000P3ooolD000000T0WX6c00<000000;BC]02dTk@09P2dTk@00`000000b:Bc0<RT/`070<RT/a@0
00000P3oool01@000000001j0000NP0007X0000000/0001d00<0000008Ya/02:LK005`2:LK000`00
0000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0
oooo00<000000000I00006@01P0006@00`000000R6n`08Q_/00G08Q_/0030000003G[k00ejn`01L0
ejn`00<000000?o@M00000004000000M09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38
Y;<06`38Y;<A000000030000M0000000RW6`01P0RW6`00<000000=R`/03H/;005`3H/;000`000000
nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T
00<0000008Q_/028Kk005`28Kk000`000000ejn`0=N_/00=0=N_/0`000001P24K:l00`000000WX6c
09j1/`0U09j1/`030000002dTk@0]9>d02H0]9>d00<000000<RT/`38Y;<09@38Y;<00`000000fk:_
0=^b[`040=^b[``000003`2:LK000`000000f;2`0=R`/00G0=R`/0030000003kcF@0nleT00H0nleT
00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P0006@00`000000R6n`08Q_
/00G08Q_/0040000003G[k00ejn`0=N_/0`000004P24K:l00`000000WX6c09j1/`0B09j1/e000000
5038Y;<00`000000fk:_0=^b[`0@0=^b[``000000`2:LK000`000000f;2`0=R`/00G0=R`/0030000
003kcF@0nleT00H0nleT00<000000?ooo`3oool0_03oool00;h0oooo00<000000000I00006@01P00
06@00`000000R6n`08Q_/00A08Q_/0X000006024K:lK00000500>;[T5@00000N0=^b[`X000004`3H
/;000`000000nleT0?_=I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0
001T00H0001T00<0000008Q_/028Kk002@28Kk08000000<0He2W00<0000008A/[`24K:l04024K:l<
000008H0>;[T3000000B0=^b[`040000003/`:L0k<2W0>c0Y`P000002`3H/;000`000000nleT0?_=
I0060?_=I0030000003oool0oooo0;`0oooo002n0?ooo`030000000006@0001T00H0001T00@00000
08Q_/028Kk00R6n`2000000;06=@Y`0300000024K:l0Q6b_00@0Q6b_3000002N03Rji0`000001P3K
/Zl00`000000k<2W0>c0Y`090>c0Y`P000000`3H/;000`000000nleT0?_=I0060?_=I0030000003o
ool0oooo0;`0oooo002n0?ooo`030000000006@0001T0080001T2000000@06=@Y`X00000]P0h^^@7
000001<0k<2W200000040?_=I0030000003oool0oooo0;`0oooo002m0?ooo`H00000401SD:L80000
0<X0>;[T2000000@0>c0Y`H00000_@3oool00;P0oooo1@00000203H/V0030000001SD:L0He2W00T0
He2W2000003J03Rji0P000002`3/`:L00`000000n/bH0?[<V00500000;P0oooo002c0?ooo`D00000
1`0f;9P00`000000He2W06=@Y`0206=@Y`L00000jP0h^^@8000000<0k<2W00<000000?[<V03jc9P0
1@3jc9P400000;@0oooo002^0?ooo`D000002P0f;9P600000?X0>;[T1000000;0?[<V0D00000[`3o
ool00:T0oooo1@00000;03H/V0@00000o`0h^^@603Rji0@000002`3jc9P500000:X0oooo002U0?oo
o`@00000300f;9P400000?l0>;[T3P0h^^@4000000`0n/bH1000002V0?ooo`00X`3oool200000003
0000O0000000=RbH00T0=RbH1000003o03Rji1H0>;[T1000000:0?[<V0030000003od7`000000080
0000X`3oool00:00oooo0`0000030000O0030000000f;9P0=RbH00@0=RbH1000003o03Rji1h0>;[T
100000060?[<V0030000003od7`0om1l0080om1l0`00002P0?ooo`00W@3oool3000000H0001l00<0
000003H/V00f;9P01000003o03Rji2H0>;[T100000020?[<V0030000003od7`0om1l00D0om1l0P00
002N0?ooo`00V`3oool2000000P0001l1000003o03Rji2h0>;[T0`0000090?o@O0<00000V`3oool0
09P0oooo0`0000080000O0800000o`0h^^@f03Rji0<00000203od7`3000009P0oooo002F0?ooo`80
0000200007`300000?l0>;[T>`0h^^@3000000P0om1l0P00002F0?ooo`00U03oool3000000H0001l
0`00003o03Rji440>;[T0P0000070?o@O0<00000U03oool009<0oooo00@000000000B`0004/00000
100007`200000?l0>;[TAP0h^^@3000000@0om1l00@000000?34B`3`a4/00000T`3oool00940oooo
0P0000030000B`030000000007`0000000800000o`0h^^A;03Rji0<0000000<0om1l0000003`a4/0
0P3`a4/200000940oooo002@0?ooo`030000000004/0001;00<0001;0P00003o03Rji540>;[T0P00
00050?34B`030000003oool0oooo08h0oooo002>0?ooo`800000100004/200000?l0>;[TE@0h^^@2
000000@0l<A;0P00002>0?ooo`00S@3oool00`000000001;0000B`030000B`030000000h^^@0>;[T
0?l0>;[TE`0h^^@00`000000l<A;0?34B`030?34B`030000003oool0oooo08/0oooo002=0?ooo`04
0000000004/0001;0000B`800000o`0h^^AK03Rji08000000`3`a4/00`000000oooo0?ooo`2;0?oo
o`00S@3oool010000000001;0000B`00003o03Rji5l0>;[T00@000000?34B`3`a4/00000S@3oool0
08d0oooo0`00003o03Rji640>;[T0`00002=0?ooo`00S03oool200000?l0>;[TI@0h^^@2000008`0
oooo002<0?ooo`8000005@0h^^@203Vji9X0>;[T00<0000003Rji00h^^@03@0h^^@00`3F[k40>;[T
03Rji02P03Rji0800000S03oool008`0oooo0P00000[03Rji0@0>K[TJ@0h^^@2000000<0001a2`0h
^^@908ab/@030000003F[k40eZna00L0eZna200h^^@00`3F[k40>;[T03Rji02N03Rji0800000S03o
ool008`0oooo00<0000003Rji00h^^@0?`0h^^@603Vji5P0>;[T00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000000h^^@0>;[T09`0>;[T0P00002<0?ooo`00S03oool00`00
0000>;[T03Rji02K03Rji080001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma09d0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h
^^@0V00h^^@50000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000
o/ma0?k?L@030?k?LIX0>;[T00<000000?ooo`3oool0RP3oool008`0oooo00<0000003Rji00h^^@0
U@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T09D0>;[T00<000000?ooo`3oool0
RP3oool008d0oooo00<0000003Rji00h^^@0<@0h^^@=03Vji5H0>;[T00<000000000L@0007401@00
07400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3n
cg400`000000>K[T03Vji02D03Rji0030000003oool0oooo08/0oooo002>0?ooo`800000IP0h^^@I
03Vji1D0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40
eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji00=03Rji100>K[TM@0h^^@2
000008h0oooo002@0?ooo`030000000h^^@0>;[T0940>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji00]03Rji0`0>K[TF00h^^@00`000000oooo0?ooo`2>0?ooo`00T@3oool00`000000
>;[T03Rji02@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@09P0h^^@00`0i^^@0
>;[T03Rji00T03Rji0P0>K[T>`0h^^@00`000000oooo0?ooo`2?0?ooo`00TP3oool200000900>;[T
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01]03Rji0@0>K[T7@0h^^@200000980oooo
002D0?ooo`030000000h^^@0>;[T08d0>;[T00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rj
i02=03Rji0030000003oool0oooo0980oooo002F0?ooo`800000S00h^^@00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000000h^^@0>;[T08X0>;[T0P00002F0?ooo`00V03oool2000008X0>;[T00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000>;[T03Rji02803Rji0800000V03oool009X0oooo0`00002703Rji003
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0Q@0h^^@3000009X0oooo002M0?ooo`800000
Q@0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T08<0>;[T0P00002M0?ooo`00W`3o
ool2000008<0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji02103Rji0800000W`3o
ool00:40oooo1000001o03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0O@0h^^@4
00000:40oooo002U0?ooo`D00000NP0h^^@00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T
07P0>;[T1@00002U0?ooo`00ZP3oool5000007D0>;[T00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
>;[T03Rji01c03Rji0D00000ZP3oool00:l0oooo1@00001`03Rji003000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<0000003Rji00h^^@0KP0h^^@500000:l0oooo002d0?ooo`D00000J`0h^^@00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000000h^^@0>;[T06T0>;[T1@00002d0?ooo`00^@3oool5000006H0>;[T00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000>;[T03Rji01T03Rji0D00000^@3oool00;h0oooo1@00001Q03Rj
i003000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0G`0h^^@500000;h0oooo00330?ooo`D0
0000G00h^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T05X0>;[T1@0000330?ooo`00
b03oool5000005L0>;[T00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000>;[T03Rji01E03Rji0D00000
b03oool00<d0oooo1`00001@03Rji003000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0000003Rji00h^^@0CP0h
^^@700000<d0oooo003D0?ooo`X00000AP0h^^@00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0
>;[T04@0>;[T2P00003D0?ooo`00gP3oool:000003`0>;[T00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000>;[T03Rji00j03Rji0X00000gP3oool00>P0oooo3@00000_03Rji003000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<0000003Rji00h^^@0;@0h^^@=00000>P0oooo003e0?oooa0000007`0h^^@00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000000h^^@0>;[T01d0>;[T4000003e0?ooo`00o`3oool60?oooaT000001P0h
^^@00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000000h^^@0>;[T00@0>;[T6@00003o0?ooo`H0oooo003o
0?oooal0oooo1`0000070000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@L00000o`3ooolO0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0
001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0
o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a
00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma
00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
o`3ooolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<
L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3o
oolS0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[40
0`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS
0?ooo`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`00
0000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?oo
o`00o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00
o`3ooolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3o
oolU0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU
0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A
0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?oo
o`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_
/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00o`3ooolU0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0o`3ooolS0?ooo`00``3oool3000005h0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1/0?ooo`<00000/`3oool00;00oooo0P00000A
0?ooo`030000001jFJ00NUVP00D00000F@3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05X0oooo0P00000@0?ooo`030000001nGJ80OUfR00H00000[@3oool00:d0oooo0`0000000`1k
K[X000000000000?0?ooo`030000001jFJ00NUVP00H0NUVP0`00001F0?ooo`03000000000740001a
00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma
00D0o/ma00<000000?ooo`3oool0E`3oool30000000307ma^P000000oooo00h0oooo00<0000007iM
XP1nGJ801`1nGJ8300000:X0oooo002Y0?ooo`@000001@1kK[X00`000000oooo0?ooo`0=0?ooo`03
0000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E03oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo05<0oooo1000000507ma^P030000003oool0oooo00`0oooo00<0000007iMXP1n
GJ802@1nGJ800`000000oooo0?ooo`2X0?ooo`00Y`3oool2000000T0Nfjj0P00000>0?ooo`030000
001jFJ00NUVP00L0NUVP0P00001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
D@3oool2000000T0Og6j00<000000?ooo`3oool0303oool00`000000OUfR07iMXP0907iMXZ/0oooo
002W0?ooo`030000001kK[X0Nfjj00P0Nfjj0P00000>0?ooo`030000001jFJ00NUVP00L0NUVP0P00
001F0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0D@3oool00`000000Og6j07ma
^P0807ma^P030000003oool0oooo00`0oooo00<0000007iMXP1nGJ80201nGJ800`000000oooo0?oo
o`2Y0?ooo`00Z03oool00`000000Nfjj07]^^P0707]^^P8000003@3oool00`000000NUVP07YIX008
07YIX0030000003oool0oooo05D0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@
08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1A
0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool02`3oool00`000000OUfR07iMXP09
07iMXP030000003oool0oooo0:T0oooo002X0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00?oo
o`3oool02`3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05D0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?oo
o`3oool02P3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:T0oooo002X0?ooo`03
0000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02`3oool00`000000NUVP07YIX00707YIX080
0000E`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo0580oooo00<0000007ma^P1o
LKX0201oLKX00`000000oooo0?ooo`0:0?ooo`030000001nGJ80OUfR00P0OUfR00<000000?ooo`3o
ool0ZP3oool00:P0oooo00<0000007]^^P1kK[X0201kK[X2000000`0oooo00<0000007YIX01jFJ00
1`1jFJ02000005L0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1B0?ooo`030000
001oLKX0Og6j00P0Og6j00<000000?ooo`3oool02P3oool00`000000OUfR07iMXP0807iMXP030000
003oool0oooo0:X0oooo002Y0?ooo`030000001kK[X0Nfjj00L0Nfjj0P00000;0?ooo`030000001j
FJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool00`000000001a0000L@050000L@030000002<
L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003o
ool0oooo0580oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo0?ooo`090?ooo`030000001n
GJ80OUfR00T0OUfR00<000000?ooo`3oool0ZP3oool00:T0oooo00<0000007]^^P1kK[X0201kK[X0
0`30N@00oooo0?ooo`090?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0EP3oool0
0`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k40
0`000000o/ma0?k?L@050?k?L@030000003oool0oooo05<0oooo00<0000007ma^P1oLKX0201oLKX0
0`000000oooo0?ooo`080?ooo`030000001nGJ80OUfR00P0OUfR0P00002/0?ooo`00Z@3oool00`00
0000Nfjj07]^^P0807]^^P030<1i00000000oooo00T0oooo00<0000007YIX01jFJ001`1jFJ020000
05P0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1C0?ooo`030000001oLKX0Og6j
00P0Og6j00<000000?ooo`3oool0203oool00`000000OUfR07iMXP0807iMXP030000003oool0oooo
0:/0oooo002Y0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool02@3oool00`000000
NUVP07YIX00707YIX0800000F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05<0
oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo0?ooo`080?ooo`030000001nGJ80OUfR00P0
OUfR00<000000?ooo`3oool0Z`3oool00:X0oooo00<0000007]^^P1kK[X01`1kK[X00`30N@000000
0?ooo`080?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3oool0E`3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05<0oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo
0?ooo`070?ooo`030000001nGJ80OUfR00P0OUfR0P00002]0?ooo`00ZP3oool00`000000Nfjj07]^
^P0707]^^P8000002@3oool00`000000NUVP07YIX00807YIX0030000003oool0oooo05L0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1D0?ooo`030000001oLKX0Og6j00P0Og6j00<0
00000?ooo`3oool01P3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:/0oooo002Z
0?ooo`030000001kK[X0Nfjj00P0Nfjj00<0`7T00000003oool01`3oool00`000000NUVP07YIX007
07YIX0800000F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05@0oooo00<00000
07ma^P1oLKX0201oLKX00`000000oooo0?ooo`060?ooo`030000001nGJ80OUfR00P0OUfR00<00000
0?ooo`3oool0[03oool00:X0oooo00<0000007]^^P1kK[X0201kK[X00`30N@0000000?ooo`070?oo
o`030000001jFJ00NUVP00L0NUVP0P00001I0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0E03oool00`000000Og6j07ma^P0807ma^P030000003oool0oooo00H0oooo00<0000007iM
XP1nGJ801@1nGJ80103O`;X0OUfR00000000002^0?ooo`00Z`3oool00`000000Nfjj07]^^P0707]^
^P8000001`3oool00`000000NUVP07YIX00707YIX0030=fn^P000000oooo05T0oooo00<000000000
L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?
L@3ncg401@3ncg400`000000oooo0?ooo`1D0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?oo
o`3oool01@3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:`0oooo002[0?ooo`03
0000001kK[X0Nfjj00L0Nfjj0P0000070?ooo`030000001jFJ00NUVP00P0NUVP00<000000?ooo`3o
ool0F03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F
[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05D0oooo00<0000007ma^P1o
LKX0201oLKX00`000000oooo0?ooo`040?ooo`030000001nGJ80OUfR00D0OUfR00D0gl2j07iMXP1n
GJ80OUfR0000002^0?ooo`00Z`3oool00`000000Nfjj07]^^P0807]^^P030<1i00000000oooo00D0
oooo00<0000007YIX01jFJ001`1jFJ02000005X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`1E0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool0103oool00`000000
OUfR07iMXP0707iMXP030=o0^P000000oooo0:h0oooo002[0?ooo`030000001kK[X0Nfjj00P0Nfjj
00<0`7T00000003oool01@3oool00`000000NUVP07YIX00707YIX0800000FP3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05D0oooo00<0000007ma^P1oLKX0201oLKX00`000000oooo
0?ooo`040?ooo`030000001nGJ80OUfR00P0OUfR00<000000?ooo`3oool0[@3oool00:`0oooo00<0
000007]^^P1kK[X01`1kK[X2000000D0oooo00<0000007YIX01jFJ00201jFJ02000005X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1E0?ooo`030000001oLKX0Og6j00P0Og6j00<0
00000?ooo`3oool00`3oool00`000000OUfR07iMXP0907iMXP030000003oool0oooo0:d0oooo002/
0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000050?ooo`030000001jFJ00NUVP00P0NUVP00<00000
0?ooo`3oool0F@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<00000
0=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05D0oooo0P00000:
07ma^P030000003oool0oooo0080oooo00<0000007iMXP1nGJ801`1nGJ800`3O`;X0OUfR0000002_
0?ooo`00[03oool00`000000Nfjj07]^^P0807]^^P800000103oool00`000000NUVP07YIX00707YI
X0800000F`3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_
/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05H0oooo00<0000007ma
^P1oLKX0201oLKX00`000000oooo0?ooo`020?ooo`030000001nGJ80OUfR00P0OUfR00<000000?oo
o`3oool0[P3oool00:`0oooo0P00000907]^^P030<1i00000000oooo00<0oooo00<0000007YIX01j
FJ001`1jFJ02000005/0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1F0?ooo`03
0000001oLKX0Og6j00P0Og6j00<000000?ooo`3oool00P3oool00`000000OUfR07iMXP0807iMXP03
0000003oool0oooo0:h0oooo002]0?ooo`030000001kK[X0Nfjj00L0Nfjj0P0000030?ooo`030000
001jFJ00NUVP00P0NUVP0P00001K0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
EP3oool00`000000Og6j07ma^P0807ma^P050000003oool0oooo0?ooo`0000002@1nGJ800`3O`;X0
OUfR0000002`0?ooo`00[@3oool00`000000Nfjj07]^^P0707]^^P8000000`3oool00`000000NUVP
07YIX00807YIX0030000003oool0oooo05X0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1F0?ooo`8000002P1oLKX010000000oooo0?ooo`00000;07iMXP030000003oool0oooo0:h0
oooo002]0?ooo`030000001kK[X0Nfjj00P0Nfjj0P0000020?ooo`030000001jFJ00NUVP00L0NUVP
0P00001L0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0E`3oool00`000000Og6j
07ma^P0807ma^P040000003oool0oooo000000X0OUfR00<000000?ooo`3oool0[`3oool00:d0oooo
0P00000907]^^P050<1i00000000oooo0?ooo`0000002@1jFJ02000005`0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1G0?ooo`030000001oLKX0Og6j00P0Og6j00@000000?ooo`3o
ool00000201nGJ800`3O`;X0OUfR0000002a0?ooo`00[P3oool00`000000Nfjj07]^^P0707]^^P80
000000<0oooo0000001jFJ002@1jFJ02000005`0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`1G0?ooo`030000001oLKX0Og6j00P0Og6j00<000000?ooo`0000001@1nGJ800`3O`;X0
OUfR07iMXP0307iMXP030000003oool0oooo0:l0oooo002^0?ooo`030000001kK[X0Nfjj00L0Nfjj
1000000807YIX0030=fn^P000000000005d0oooo00<000000000L@0007401@0007400`000000S7:a
08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo
0?ooo`1G0?ooo`8000002P1oLKX2000000X0OUfR0P00002a0?ooo`00[P3oool00`000000Nfjj07]^
^P0807]^^P<000002@1jFJ02000005d0oooo00<000000000L@0007401@0007400`000000S7:a08ab
/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?oo
o`1H0?ooo`030000001oLKX0Og6j00P0Og6j0P00000407iMXP070=o0^P1nGJ80OUfR07iMXP3O`;X0
OUfR0000002b0?ooo`00[P3oool2000000T0Nfjj0`00000907YIX0800000G@3oool00`000000001a
0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma
0?k?L@050?k?L@030000003oool0oooo05P0oooo00<0000007ma^P1oLKX0201oLKX2000000X0OUfR
00<000000?ooo`3oool0/03oool00:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000P0NUVP00@0
gKjj07YIX038adH00000G@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05P0oooo
00<0000007ma^P1oLKX0201oLKX00`000000OUfR07iMXP0207iMXP030=o0^P1nGJ80OUfR00@0OUfR
00<000000?ooo`3oool0/03oool00:l0oooo00<0000007]^^P1kK[X01`1kK[X2000000T0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F03oool2000000X0Og6j00<0
000007iMXP1nGJ801@1nGJ80103O`;X0OUfR00000000002b0?ooo`00[`3oool00`000000Nfjj07]^
^P0807]^^P030000001jFJ00NUVP00L0NUVP0P00001N0?ooo`03000000000740001a00D0001a00<0
000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<0
00000?ooo`3oool0F@3oool00`000000Og6j07ma^P0807ma^P040000001nGJ80OUfR0=o0^PH0OUfR
00<000000?ooo`3oool0/@3oool00:l0oooo0P00000907]^^P030000001jFJ00NUVP00L0NUVP0P00
001N0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F@3oool00`000000Og6j07ma
^P0807ma^P030000001nGJ80OUfR00L0OUfR00<000000?ooo`3oool0/@3oool00;00oooo00<00000
07]^^P1kK[X01`1kK[X00`000000NUVP07YIX00707YIX0030<S7AP000000oooo05d0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`1I0?ooo`030000001oLKX0Og6j00P0Og6j00<00000
07iMXP1nGJ80101nGJ80103O`;X0OUfR07iMXP00002c0?ooo`00/03oool00`000000Nfjj07]^^P08
07]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03000000000740001a00D0001a00<00000
08ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<00000
0?ooo`3oool0F@3oool2000000X0Og6j00<0000007iMXP1nGJ801@1nGJ8200000;<0oooo002`0?oo
o`8000002@1kK[X00`000000NUVP07YIX00507YIX0800000G`3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo05T0oooo0P00000:07ma^P030000001nGJ80OUfR00D0OUfR00<000000?oo
o`3oool0/P3oool00;00oooo0P00000907]^^P030000001jFJ00NUVP00D0NUVP0P00001O0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0FP3oool00`000000Og6j07ma^P0807ma^P03
0000001nGJ80OUfR0080OUfR00@0gl2j07iMXP1nGJ800000]03oool00;40oooo00<0000007]^^P1k
K[X01`1kK[X00`000000NUVP07YIX00507YIX0030<S7AP000000oooo05h0oooo00<000000000L@00
07401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3n
cg401@3ncg400`000000oooo0?ooo`1J0?ooo`030000001oLKX0Og6j00P0Og6j00<0000007iMXP1n
GJ801@1nGJ800`000000oooo0?ooo`2b0?ooo`00/@3oool00`000000Nfjj07]^^P0807]^^P030000
001jFJ00NUVP00<0NUVP0`00001O0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40
402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0
FP3oool2000000X0Og6j00<0000007iMXP1nGJ800`1nGJ8200000;@0oooo002a0?ooo`8000002@1k
K[X01P000000NUVP07YIX01jFJ00gKjj07YIX0800000H03oool00`000000001a0000L@050000L@03
0000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@03
0000003oool0oooo05X0oooo0P00000:07ma^P040000001nGJ80OUfR0=o0^P80OUfR00<000000?oo
o`3oool0/`3oool00;40oooo0P00000907]^^P030000001jFJ00NUVP00<0NUVP0P00001P0?ooo`03
000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@03
0000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0F`3oool00`000000Og6j07ma^P0807ma^P03
0000001nGJ80OUfR00<0OUfR00<000000?ooo`3oool0/`3oool00;80oooo00<0000007]^^P1kK[X0
1`1kK[X00`000000NUVP07YIX00307YIX0030<S7AP000000oooo05l0oooo00<000000000L@000740
1@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg40
1@3ncg400`000000oooo0?ooo`1K0?ooo`030000001oLKX0Og6j00P0Og6j00<0000007iMXP1nGJ80
0`1nGJ800`000000oooo0?ooo`2c0?ooo`00/P3oool00`000000Nfjj07]^^P0807]^^P040000001j
FJ00gKjj07YIX0<00000H03oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0oooo
0P00000:07ma^P040000003O`;X0OUfR07iMXP800000]@3oool00;80oooo0P00000907]^^P040000
001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05/0
oooo0P00000:07ma^P050000001nGJ80OUfR07iMXP000000]P3oool00;80oooo0P00000907]^^P04
0000001jFJ00NUVP07YIX0800000H@3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
05`0oooo00<0000007ma^P1oLKX0201oLKX01@000000OUfR07iMXP1nGJ8000000;H0oooo002c0?oo
o`030000001kK[X0Nfjj00L0Nfjj00H000000=fn^P1jFJ00NUVP0<S7AP00001Q0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0G03oool00`000000Og6j07ma^P0807ma^P050000001n
GJ80OUfR07iMXP000000]P3oool00;<0oooo00<0000007]^^P1kK[X0201kK[X00`000000NUVP0000
000200000640oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F
[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`1L0?ooo`8000002P1o
LKX010000000OUfR00000000002f0?ooo`00/`3oool2000000T0Nfjj00@0000007YIX00000000000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05`0oooo0P00000:07ma^P030000
001nGJ8000000;L0oooo002c0?ooo`8000002@1kK[X010000000NUVP00000000001R0?ooo`030000
00000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000
003ncg40o/ma00D0o/ma00<000000?ooo`3oool0G@3oool00`000000Og6j07ma^P0807ma^P030000
001nGJ8000000;L0oooo002d0?ooo`030000001kK[X0Nfjj00L0Nfjj00@0000007YIX038adH00000
HP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo00<0000007ma^P1oLKX0
201oLKX00`000000OUfR0000002g0?ooo`00]03oool00`000000Nfjj07]^^P0807]^^P<00000HP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo05d0oooo00<0000007ma^P1oLKX02@1o
LKX200000;L0oooo002^0?ooob<00000D`3oool00`000000001a0000L@050000L@030000002<L[40
S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0
oooo05T0oooo7@00002/0?ooo`00X03oool>000000`0B3^N00<000000?74X`3aa:<0303aa:<?0000
04`0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna
0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?oooa0000003P1EAZ<00`00
0000mLRN0?G8WP0:0?G8WPh00000X03oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000
S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000
oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000
oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS
00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a
00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo
00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo
002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?oo
o`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_
/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<00000
0000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<00000
0?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<00000
0?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04Pk
WP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000
L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?
L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8
WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3a
a:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<
L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3o
ool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000
003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000
001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03o
ool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3o
ool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F
[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1E
AZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0
B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740
001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40
o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@0007400`00
0000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`00
0000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`00
0000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0
lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100
S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0
oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0
oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo
0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna
0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<0
00000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<0
00000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<0
00000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G
04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@05
0000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@05
0?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G
0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74
X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab
/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?oo
o`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo04X0oooo00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@03
0000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`03
0000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00
X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0
BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k40
4@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<0
6`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018
>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`1:0?ooo`0300000000
0740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000eZna0=J_/@0A0=J_/@030000003n
cg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo00<000000000L@0007401@000740
0`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna00<000000?k?L@3ncg401@3ncg40
0`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS00<000000?G8WP3eb9h05`3eb9h0
0`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04PkWP0G04PkWP030000003aa:<0lLBS
01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000L@050000L@030000002<L[40S7:a
0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?L@050?k?L@030000003oool0oooo
04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo
09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000
oooo0?ooo`1:0?ooo`03000000000740001a00D0001a00<0000008ab/@2<L[40402<L[400`000000
eZna0=J_/@0A0=J_/@030000003ncg40o/ma00D0o/ma00<000000?ooo`3oool0B@3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo04X0oooo
00<000000000L@0007401@0007400`000000S7:a08ab/@0@08ab/@030000003F[k40eZna0140eZna
00<000000?k?L@3ncg401@3ncg400`000000oooo0?ooo`190?ooo`030000001EAZ<0EDJS01/0EDJS
00<000000?G8WP3eb9h05`3eb9h00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000B3^N04Pk
WP0G04PkWP030000003aa:<0lLBS01X0lLBS00<000000?ooo`3oool0BP3oool00`000000001a0000
L@050000L@030000002<L[40S7:a0100S7:a00<000000=J_/@3F[k404@3F[k400`000000o/ma0?k?
L@050?k?L@030000003oool0oooo04T0oooo00<0000005E6X`1EAZ<06`1EAZ<00`000000mLRN0?G8
WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`0300000018>ih0B3^N01L0B3^N00<00000
0?74X`3aa:<06P3aa:<00`000000oooo0?ooo`170?oooch00000B03oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo2`00000900d;
QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H01`3od8H;000003d0oooo00<0000005E6
X`1EAZ<06`1EAZ<00`000000mLRN0?G8WP0G0?G8WP030000003oool0oooo09h0oooo002P0?ooo`03
00000018>ih0B3^N01L0B3^N00<000000?74X`3aa:<06P3aa:<00`000000oooo0?ooo`0l0?ooo`03
0000000=2hH03@^601403@^600<000000;BC]02dTk@09`2dTk@2000001<0om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000
003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000
003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18
>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3o
ool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3o
ool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0
oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0
mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`00
0000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`00
0000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00
oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0
mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS
0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS
05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0
000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<0
00000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J
0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K
05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004Pk
WP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?oo
o`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`03
0000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`03
0000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih0
5`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0
WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003o
ool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003e
b9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih0
0`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool0
0`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool0
0:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo
03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN
01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000
lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000
EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo
00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN
00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74
X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6
X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<00000
04PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<00000
0?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18>ih05`18>ih00`000000lLBS0?74X`0J0?74
X`030000003oool0oooo03`0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0>`3oool00`000000EDJS05E6X`0K05E6
X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3oool0WP3oool00:00oooo00<0000004PkWP18
>ih05`18>ih00`000000lLBS0?74X`0J0?74X`030000003oool0oooo03`0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0>`3oool00`000000EDJS05E6X`0K05E6X`030000003eb9h0mLRN01L0mLRN00<000000?ooo`3o
ool0WP3oool00:00oooo00<0000004PkWP18>ih01018>ihX000000P0lLBS00<000000?ooo`3oool0
?03oool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0
4@3od8H00`000000oooo0?ooo`0k0?ooo`030000001EAZ<0EDJS00L0EDJS:00000060?G8WP030000
003oool0oooo09h0oooo002C0?oooa@000004P17>Yh00`000000lLFS0?75X`0C0?75XaL00000<03o
ool00`0000003@^600d;QP0A00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H04@3o
d8H00`000000oooo0?ooo`0^0?oooaL000005@1EAJ<00`000000mLRN0?G8WP0@0?G8WQ@00000T`3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo
02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]003
0000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH0
4@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0
;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003o
ool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH0
0`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool0
0`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo
02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om26
0140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000
]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo
00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om26
00<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC
]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5
X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<00000
00d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<00000
0?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC
]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=
2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3o
ool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3o
ool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000
003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000
003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=
2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3o
ool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0
oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0
om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`00
0000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0
oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d
0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS
05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0
000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<0
00000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000003oool0oooo02h0oooo00<0000000d;QP0=2hH04@0=2hH00`000000]9>d0;BC]00X
0;BC]0030000003od8H0om260140om2600<000000?ooo`3oool0;P3oool00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000003oool0oooo02h0oooo00<0000000d;
QP0=2hH04@0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140om2600<000000?oo
o`3oool0;P3oool00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000003oool0oooo02l000004`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0om260140
om26;`0000020?ooo`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS
<@00000300d;QPh000000`0=2hH00`000000]9>d0;BC]00X0;BC]1@0om262@00000800D002400000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC
]00X0;BC]0040000003od8H0om260?o@QT00[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75
X`0Y0?75X`800000@02]I7/300d;QP030000002dTk@0]9>d02P0]9>d00@000000?o@QP3od8H0om26
@02]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P0000100:eTN`<03@^600<0
00000;BC]02dTk@0:02dTk@010000000om260?o@QP3od8I00:eTN`800000:`1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<200000400[FAk0`0=2hH00`000000]9>d0;BC]00X0;BC]0030000003o
d8H0om260440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@@2]I7/2
00d;QP030000002dTk@0]9>d02P0]9>d00<000000?o@QP3od8H0@@2]I7/2000002/0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS0P0000110:eTN`803@^600<000000;BC]02dTk@0:02dTk@00`00
0000om260?o@QP110:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo
0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000440
[FAk0P0=2hH00`000000]9>d0;BC]00X0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000
003od8H0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]
I7/00`0=2hH000000;BC]00Y0;BC]0030000003od8H0[FAk0440[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=2hH000000;BC]00Y0;BC]0030000002]I7/0
[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@P2]I7/00`0=
2hH000000;BC]00Y0;BC]0030000002]I7/0[FAk0440[FAk0P00000[05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]0030000002]I7/0[FAk0440
[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]I7/00`000000]9>d
0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0
T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000@`2]
I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`800000@`2]I7/00`000000]9>d0;BC]00X0;BC]4@0[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk
0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`800000/P2]I7/2000002/0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000:`1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`80
0000/P2]I7/2000002/0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00
T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS0P00002b0:eTN`800000
:`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<200000;80[FAk0P00000[05E5X`030000003e
b9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh0
0`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;40[FAk0P00000[05E5X`030000003eb9h0
mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`00
0000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk05d0[FAk00<0[[KO0:eTN`2]I7/0DP2]I7/00`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80
[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk
0:eTN`1T0:eTN`030:jfg`2]I7/0[FAk04/0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk06l0[FAk00<0[[KO0:eT
N`2]I7/0@02]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`03
0000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP03
0000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0
:@3aaJ<00`000000[FAk0:eTN`1f0:eTN`030:jfg`2]I7/0[FAk03T0[FAk00<0000005E5X`1EAJ<0
:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001E
AJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool0
0`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0O@2]I7/0
0`2^]]l0[FAk0:eTN`0b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0Y0?75X`030000002]I7/0[FAk08@0[FAk00<0[[KO0:eTN`2]I7/0:`2]I7/00`000000
EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk
00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo
002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eT
N`2;0:eTN`030:jfg`2]I7/0[FAk02@0[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8
WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<00000
0?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1E
AJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000
001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3o
ool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:eTN`2]I7/0/P2]
I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]I7/0
[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0
oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`00
0000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`00
0000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0
lLFS00<000000:eTN`2]I7/0/P2]I7/00`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0
mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS
0?75X`0Y0?75X`030000002]I7/0[FAk0;80[FAk00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<0:@3aaJ<00`000000[FAk0:eTN`2b0:eTN`030000001EAJ<0EDFS02T0EDFS00<0
00000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S
04LjWP030000003aaJ<0lLFS02T0lLFS]P00000[05E5X`030000003eb9h0mLRN02<0mLRN00<00000
0?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75
X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8
WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3a
aJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1E
AJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0
AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ0:fhh@2b0:fhh@030000001EAJ<0
EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<000000:fhh@2]^>40/P2]^>400`00
0000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y0?75X`030000002]^>40[KSQ0;80
[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0:@3aaJ<00`000000[KSQ
0:fhh@2b0:fhh@030000001EAJ<0EDFS02T0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo
0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS02T0lLFS00<0
00000:fhh@2]^>40/P2]^>400`000000EDFS05E5X`0Y05E5X`030000003eb9h0mLRN02<0mLRN00<0
00000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0Y
0?75X`030000002]^>40[KSQ0;80[KSQ00<0000005E5X`1EAJ<0:@1EAJ<00`000000mLRN0?G8WP0S
0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75
X`3aaJ<04`3aaJ<G00000;@0[KSQ6`00000A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0C0?75XaH0
[VEl00<000000:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00D0:iUO1D0EDFS00<000000?G8WP3e
b9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000
003aaJ<0lLFS0180lLFS5`2^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01D0[VEl
501EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017
>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<04P3aaJ<G0:iUO0030000002]^>40[KSQ0;80[KSQ00<0
00000:iUO02^IG`05@2^IG`D05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0A0?75XaP0[VEl00<00000
0:fhh@2]^>40/P2]^>400`000000[VEl0:iUO00F0:iUO1<0EDFS00<000000?G8WP3eb9h08`3eb9h0
0`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS
0140lLFS602^IG`00`000000[KSQ0:fhh@2b0:fhh@030000002^IG`0[VEl01H0[VEl4`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0403aaJ<I0:iUO0030000002]^>40[KSQ0;80[KSQ00<000000:iUO02^
IG`05`2^IG`B05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo
00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75XaX0[VEl0P00002b0:fhh@800000
6P2^IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0
000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0?0?75XaX0[VEl0P00002b0:fhh@8000006P2^
IG`A05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<00000
04LjWP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75Xa/0[VEl0P00002b0:fhh@8000006`2^IG`@
05E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004Lj
WP17>Yh08`17>Yh00`000000lLFS0?75X`0>0?75Xa/0[VEl0P00002b0:fhh@8000006`2^IG`@05E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh00`000000lLFS0?75X`0=0?75Xa`0[VEl0P00002b0:fhh@800000702^IG`?05E5X`03
0000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh0
8`17>Yh00`000000lLFS0?75X`0=0?75Xa`0[VEl0P00002b0:fhh@8000007@2^IG`>05E5X`030000
003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17
>Yh00`000000lLFS0?75X`0<0?75X`80[VEl00<0lLFS0:iUO02^IG`06@2^IG`00`000000[KSQ0:fh
h@2`0:fhh@030000002^IG`0[VEl01`0[VEl3P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003o
ool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02`3aaJ<4
0:iUO0030?75X`2^IG`0[VEl01P0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00M
0:iUO0d0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`00
0000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00/0lLFS1@2^IG`00`3aaJ<0[VEl0:iUO00G0:iU
O0030000002]^>40[KSQ0;00[KSQ00<000000:iUO02^IG`07@2^IG`=05E5X`030000003eb9h0mLRN
02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000
lLFS0?75X`0:0?75X`L0[VEl00<0lLFS0:iUO02^IG`05P2^IG`00`000000[KSQ0:fhh@2`0:fhh@03
0000002^IG`0[VEl01h0[VEl301EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940
oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<02@3aaJ<90:iUO0030?75
X`2^IG`0[VEl01D0[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00O0:iUO0/0EDFS
00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04Lj
WP0S04LjWP030000003aaJ<0lLFS00T0lLFS8@2^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^
IG`0[VEl01l0[VEl2`1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C
0?ooo`0300000017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0203aaJ<=0:iUO0030?75X`2^IG`0
[VEl0180[VEl00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00P0:iUO0X0EDFS00<00000
0?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04Lj
WP030000003aaJ<0lLFS00P0lLFS3P2^IG`00`3aaJ<0[VEl0:iUO00A0:iUO0030000002]^>40[KSQ
0;00[KSQ00<000000:iUO02^IG`0802^IG`:05E5X`030000003eb9h0mLRN02<0mLRN00<000000?oo
o`3oool0T@3oool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`070?75Xa00
[VEl00<0lLFS0:iUO02^IG`0402^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl0240
[VEl2@1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<01P3aaJ<B0:iUO0030?75X`2^IG`0[VEl00l0[VEl
00<000000:fhh@2]^>40/02]^>400`000000[VEl0:iUO00R0:iUO0P0EDFS00<000000?G8WP3eb9h0
8`3eb9h00`000000oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003a
aJ<0lLFS00H0lLFS902^IG`00`000000[KSQ0:fhh@2`0:fhh@030000002^IG`0[VEl00D0[VEl00<0
EDFS0:iUO02^IG`06P2^IG`805E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3o
ool009<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XbD0[VEl00<00000
0:fhh@2]^>40<P2]^>400`2kV@H0[KSQ0:fhh@160:fhh@030000002]^>40[KSQ0380[KSQ00<00000
0:iUO02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool0
09<0oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`050?75XaL0[VEl00<0lLFS0:iU
O02^IG`0@02^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iU
O02^IG`08`2^IG`705E5X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0
oooo00<0000004LjWP17>Yh08`17>Yh00`000000lLFS0?75X`040?75XaT0[VEl00<0lLFS0:iUO02^
IG`0?`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^
IG`03@2^IG`00`1EAJ<0[VEl0:iUO00D0:iUO0H0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000
oooo0?ooo`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS00<0lLFS
6`2^IG`00`3aaJ<0[VEl0:iUO00`0:iUO0030:fhh@2^IG`0[VEl00/0[VEl00<0^iT60:fhh@2]^>40
AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02D0[VEl1@1EAJ<00`000000mLRN
0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0AcZN00<0
00000?75X`3aaJ<00`3aaJ=L0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^
IG`00`000000[VEl0:iUO00U0:iUO0D0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?oo
o`2A0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`0
0`2kV@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`05@2^IG`0
0`1EAJ<0[VEl0:iUO00>0:iUO0@0EDFS00<000000?G8WP3eb9h08`3eb9h00`000000oooo0?ooo`2A
0?ooo`00T`3oool00`000000AcZN04LjWP0S04LjWP030000003aaJ<0lLFS0080lLFSG@2^IG`00`2k
V@H0[KSQ0:fhh@160:fhh@030000002^IG`0[VEl0380[VEl00<000000:iUO02^IG`09P2^IG`405E5
X`030000003eb9h0mLRN02<0mLRN00<000000?ooo`3oool0T@3oool009<0oooo00<0000004LjWP17
>Yh08`17>Yh010000000lLFS0?75X`3aaJ<R0:iUO0030?75X`2^IG`0[VEl03T0[VEl00<0^iT60:fh
h@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02L0[VEl0`1EAJ<00`00
0000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`0300000017>Yh0AcZN02<0
AcZN00<000000?75X`3aaJ<0902^IG`00`3aaJ<0[VEl0:iUO00a0:iUO0030:fhh@2^IG`0[VEl00@0
[VEl00<0^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02P0
[VEl0P1EAJ<00`000000mLRN0?G8WP0S0?G8WP030000003oool0oooo0940oooo002C0?ooo`030000
0017>Yh0AcZN02<0AcZN00<000000?75X`3aaJ<0G`2^IG`00`2kV@H0[KSQ0:fhh@160:fhh@030000
002^IG`0[VEl0380[VEl00<000000:iUO02^IG`0:02^IG`205E5X`030000003eb9h0mLRN02<0mLRN
00<000000?ooo`3oool0T@3oool009<0oooo1`00000O04LjWP030000003aaJ<0[VEl05l0[VEl00<0
^iT60:fhh@2]^>40AP2]^>400`000000[VEl0:iUO00b0:iUO0030000002^IG`0[VEl02T0[VEl00<0
EDFS0000003eb9h07P3eb9h7000009<0oooo002J0?ooo``000004`17>Yh00`000000lLFS0:iUO01O
0:iUO0030;^I1P2]^>40[KSQ04H0[KSQ00<000000:iUO02^IG`0<P2^IG`00`000000[VEl0:iUO00Y
0:iUO00305E5X`000000mLRN0180mLRN3000002J0?ooo`00YP3oool=000000H0AcZN00<000000:iU
O02^IG`0G`2^IG`00`2kV@H0000000000017000003@0[VEl00<000000:iUO02^IG`0:P2^IG`00`00
0000mLRN0?G8WP040?G8WPd00000YP3oool00;<0ooooJP00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<00006000000000000I`00002c0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP800000
3P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0
]`3oool00;T0oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303o
ool00`0000H000000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80
[KSR05l0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>80
0`000000oooo0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0
oooo00<000000:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H0
00000:fhhP1P0:fhhP030000003oool0oooo0;L0oooo002i0?ooo`030000002]^>80[KSR05l0[KSR
0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80H02]^>800`000000oooo
0?ooo`2g0?ooo`00^@3oool00`000000[KSR0:fhhP1O0:fhhP8000003P3oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`0<0?ooo`0300001P000000[KSR0600[KSR00<000000?ooo`3oool0]`3oool00;T0oooo00<00000
0:fhhP2]^>80G`2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1P
0:fhhP030000003oool0oooo0;L0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?oo
o`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`03
00001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80
GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000
003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo00`0oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool0
0`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000
[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>820000
00h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om27
00L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo
0;P0oooo002j0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L0
40f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0
oooo00<000060000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR
0:fhhP1N0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d
00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR
00<000000?ooo`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<0
0000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<0
00000?ooo`3oool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j
0?ooo`030000002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<00000
0;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<00006
0000002]^>80G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fh
hP8000003P3oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@
Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?oo
o`3oool0^03oool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@
3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3o
ool0303oool00`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000
002]^>80[KSR05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80
G`2]^>800`000000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3o
ool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03o
ool00;X0oooo00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool0
0`0000H000000:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002j0?ooo`030000002]^>80[KSR
05h0[KSR0P00000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80G`2]^>800`00
0000oooo0?ooo`2h0?ooo`00^P3oool00`000000[KSR0:fhhP1N0:fhhP8000003P3oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`0<0?ooo`0300001P000000[KSR05l0[KSR00<000000?ooo`3oool0^03oool00;X0oooo
00<000000:fhhP2]^>80GP2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H00000
0:fhhP1O0:fhhP030000003oool0oooo0;P0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00
000>0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?oo
o`2i0?ooo`00^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<
0?ooo`0300001P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fh
hP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool00`0000H000000:fhhP1N0:fh
hP030000003oool0oooo0;T0oooo002k0?ooo`030000002]^>80[KSR05d0[KSR0P00000>0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo00`0oooo00<000060000002]^>80GP2]^>800`000000oooo0?ooo`2i0?ooo`00
^`3oool00`000000[KSR0:fhhP1M0:fhhP8000003P3oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`0<0?ooo`030000
1P000000[KSR05h0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]
^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0303oool2000005l0[KSR00<000000?ooo`3oool0^@3o
ool00;/0oooo00<000000:fhhP2]^>80G@2]^>82000000h0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0303oool2
000005l0[KSR00<000000?ooo`3oool0^@3oool00;/0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`0=0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo00d0oooo00<000000:fhhP2]^>80G@2]^>800`00
0000oooo0?ooo`2i0?ooo`00^`3ooomQ000000l0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool03@3ooomQ00000;/0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003o
ool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0
]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?oo
ob`0oooo00<00000010=Q`0@3HL00`0@3HL01@3od8T040f7010=Q`0@3HL0000001@0]9>d00<00000
0?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=
Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?oo
o`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02d
Tk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo
;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L0
1`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@
3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3o
oolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@0
0`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00
000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`00
0000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000
]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00
o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=
Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?oo
o`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B
0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?oo
o`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@
Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0
oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000
003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@
3HL040f7008040f700<0om29010=Q`0@3HL00P0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
0`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L0
0`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`00
0000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3oool/0?ooo`050000000@3HL040f7010=Q`3od8T01@0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d
0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f7
00<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo
:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<0
00000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000
010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<00000
0?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC
]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo;03oool00`00000040f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3o
d8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL0
1`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0
o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2d
Tk@00`000000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool0
1000000040f7010=Q`3od8T6010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3o
d8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL0
0`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ
0?ooo`00o`3oool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`00
0000om270?o@Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`000000
40f7010=Q`07010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000
oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d
0;BC]00B0;BC]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3o
ool/0?ooo`030000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@
Q`070?o@Q`030000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07
010=Q`030000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o
0?ooobX0oooo003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC
]0030000003od8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`03
0000000@3HL040f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`03
0000003oool0oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`07010=Q`030000
002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo
003o0?ooob`0oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003o
d8L0om2700L0om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3oool/0?ooo`030000000@3HL0
40f700L040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`070?o@Q`030000003oool0
oooo0?l0oooo:P3oool00?l0oooo;03oool00`00000040f7010=Q`06010=Q`030?o@R@000000]9>d
01<0]9>d00<000000?o@Q`3od8L01`3od8L00`000000oooo0?ooo`3o0?ooobX0oooo003o0?ooob`0
oooo00<00000010=Q`0@3HL01`0@3HL00`000000]9>d0;BC]00B0;BC]0030000003od8L0om2700L0
om2700<000000?ooo`3oool0o`3ooolZ0?ooo`00k@3ooolo000000T040f700<000000;BC]02dTk@0
4P2dTk@00`000000om270?o@Q`070?o@Qcl00000k@3oool00>d0oooo00<0000008<51P231@H01023
1@H00`1Mb_P0P`D608<51P0e08<51PL040f700<0P`D6010=Q`000000502dTk@00`000000om270?o@
Q`060?o@Qcl0P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H02`231@H0
0`1Mb_P0P`D608<51P0_08<51PP040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`05
0?o@Qd00P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H04P231@H00`1M
b_P0P`D608<51P0Y08<51PL040f700<000000;BC]02dTk@04P2dTk@00`000000om270?o@Q`040?o@
Qd40P`D600<000000?ooo`3oool0j`3oool00>d0oooo00<0000008<51P231@H060231@H305g:n2@0
P`D60`0@3HL010231@H040f7010=Q`00000D0;BC]0030000003od8L0om2700<0om27@P231@H00`00
0000oooo0?ooo`3[0?ooo`00k03oool00`000000P`D608<51P0P08<51P<0GL[h7`231@H4010=Q`03
0000002dTk@0]9>d0180]9>d00<000000?o@Q`3od8L00P3od8M308<51P030000003oool0oooo0>/0
oooo003/0?ooo`03000000231@H0P`D602L0P`D60`00000I08<51P<040f700<000000;BC]02dTk@0
4P2dTk@010000000om270?o@Q`3od8M508<51P030000003oool0oooo0>X0oooo003/0?ooo`030000
00231@H0P`D602d0P`D61@2`[mLB08<51P8040f700<000000;BC]02dTk@04P2dTk@00`000000om27
0?o@Q`1608<51P030000003oool0oooo0>X0oooo003/0?ooo`03000000231@H0P`D603@0P`D61@2`
[mL<08<51P03010=Q`000000]9>d01<0]9>d00<000000?o@Q`231@H07@231@H50;2_eb@0P`D600<0
00000?ooo`3oool0jP3oool00>`0oooo00<0000008<51P231@H0>`231@H00`2`[mL00000010=Q`02
010=Q`H0P`D600<000000;BC]02dTk@04P2dTk@00`000000P`D608<51P0[08<51P030?ooo`2`[mL0
/:oG00H0/:oG4P231@H00`000000oooo0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003/0?ooo`03
0000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0
Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003o
ool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>
00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?oo
o`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2a
Lhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000
003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3o
ool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03oool00`00
0000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/0?ooo`030000002aLhh0/G>>0:@0
/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5cSP2aLhh0Y02aLhh00`000000oooo
0?ooo`3Z0?ooo`00k03oool00`000000/G>>0;5cSP2T0;5cSP030000003oool0oooo0>X0oooo003/
0?ooo`030000002aLhh0/G>>0:@0/G>>00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;5c
SP2aLhh0Y02aLhh00`000000oooo0?ooo`3Z0?ooo`00k03ooonX00000>`0oooo003/0?ooo`030000
002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`
/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0
oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0
oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G
0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<0
00000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z
0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`03
0000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0
Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003o
ool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G00<000000?ooo`3oool0jP3oool0
0>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?ooo`3Z0?ooo`00k03oool00`000000
/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?ooo`030000002`/=L0/;3G0:@0/;3G
00<000000?ooo`3oool0jP3oool00>`0oooo00<000000;2`e`2`/=L0Y02`/=L00`000000oooo0?oo
o`3Z0?ooo`00k03oool00`000000/;3G0;2`e`2T0;2`e`030000003oool0oooo0>X0oooo003/0?oo
ojP00000k03oool00>`0oooo00<0000005K8m@1Fb?D0Y01Fb?D00`000000oooo0?ooo`3Z0?ooo`00
k03oool00`000000E/Se05K8m@2T05K8m@030000003oool0oooo0>X0oooo003]0?ooo`030000001F
b?D0E/Se0:80E/Se00<000000?ooo`3oool0j`3oool00>d0oooo00<0000005K8m@1Fb?D0XP1Fb?D0
0`000000oooo0?ooo`3[0?ooo`00k@3ooonV00000>d0oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3o
ool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0oooo
o`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?oo
o`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo
0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo
003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0
ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool0
0?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3o
oon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00
o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oo
oh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o
0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0oooo
PP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0
ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon2
0?ooo`00o`3ooooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3o
oooo0?oooh80oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80
oooo003o0?ooool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00o`3ooooo0?oooh80oooo003o0?oo
ool0ooooPP3oool00?l0ooooo`3ooon20?ooo`00\
\>"],
  ImageRangeCache->{{{0, 639.938}, {1152.63, 0}} -> {0.222219, -0.00032513, \
0.00108519, 0.00108519}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[1] // TraditionalForm\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{T \[Rule] 1, X2 \[Rule] 4.98093069493551`*^-35, 
      Y2 \[Rule] \(-1.01549889597271`*^-34\), 
      Z2 \[Rule] \(-6.393594172640903`*^-36\), Eo2 \[Rule] 1.`, 
      Ei2 \[Rule] \(-1.7122074683798404`*^-31\), 
      Ej2 \[Rule] 8.22864062973095`*^-40, 
      Ek2 \[Rule] 3.358715966152135`*^-23, X3 \[Rule] \(-6.45`\), 
      Y3 \[Rule] 6.45`, Z3 \[Rule] \(-8.25`\), Eo3 \[Rule] 1.`, 
      Ei3 \[Rule] \(-1.7122131842211213`*^-31\), 
      Ej3 \[Rule] 2.427259247084109`*^-37, 
      Ek3 \[Rule] \(-6.123031045097541`*^-16\), X4 \[Rule] 6.45`, 
      Y4 \[Rule] 6.45`, Z4 \[Rule] \(-8.25`\), Eo4 \[Rule] 1.`, 
      Ei4 \[Rule] \(-1.7122099956926947`*^-31\), 
      Ej4 \[Rule] 9.408986925415629`*^-37, 
      Ek4 \[Rule] \(-6.123031179722129`*^-16\), X5 \[Rule] 6.45`, 
      Y5 \[Rule] \(-6.45`\), Z5 \[Rule] \(-8.25`\), Eo5 \[Rule] 1.`, 
      Ei5 \[Rule] \(-1.7122118177089385`*^-31\), 
      Ej5 \[Rule] 1.6989144830234797`*^-36, 
      Ek5 \[Rule] \(-6.123031180152263`*^-16\), X6 \[Rule] \(-6.45`\), 
      Y6 \[Rule] \(-6.45`\), Z6 \[Rule] \(-8.25`\), Eo6 \[Rule] 1.`, 
      Ei6 \[Rule] \(-1.7122122732129994`*^-31\), 
      Ej6 \[Rule] 9.380482496781474`*^-37, 
      Ek6 \[Rule] \(-6.123031705305424`*^-16\), X7 \[Rule] \(-6.45`\), 
      Y7 \[Rule] 6.45`, Z7 \[Rule] \(-8.25`\), 
      Eo7 \[Rule] 1.0000000000003566`, Ei7 \[Rule] 1.522026558309876`*^-13, 
      Ej7 \[Rule] 3.0738220869040264`*^-13, 
      Ek7 \[Rule] 1.2127058776090509`*^-13, X8 \[Rule] 6.45`, 
      Y8 \[Rule] 6.45`, Z8 \[Rule] \(-8.25`\), 
      Eo8 \[Rule] 1.0000000000003566`, Ei8 \[Rule] 1.522026558309876`*^-13, 
      Ej8 \[Rule] 3.0738220869040264`*^-13, 
      Ek8 \[Rule] 1.2127058776090509`*^-13, X9 \[Rule] 6.45`, 
      Y9 \[Rule] \(-6.45`\), Z9 \[Rule] \(-8.25`\), 
      Eo9 \[Rule] 1.0000000000003566`, Ei9 \[Rule] 1.522026558309876`*^-13, 
      Ej9 \[Rule] 3.0738220866393286`*^-13, 
      Ek9 \[Rule] 1.2127058776090509`*^-13, X10 \[Rule] \(-6.45`\), 
      Y10 \[Rule] \(-6.45`\), Z10 \[Rule] \(-8.25`\), 
      Eo10 \[Rule] 1.0000000000003566`, Ei10 \[Rule] 1.522026558309876`*^-13, 
      Ej10 \[Rule] 3.0738220869040264`*^-13, 
      Ek10 \[Rule] 1.2127058770796553`*^-13, 
      X11 \[Rule] 4.534232497785895`*^-35, 
      Y11 \[Rule] 6.24942731897151`*^-30, Z11 \[Rule] 18.25`, 
      Eo11 \[Rule] 1.`, Ei11 \[Rule] \(-1.7124316498462216`*^-31\), 
      Ej11 \[Rule] \(-8.365973405048864`*^-43\), 
      Ek11 \[Rule] \(-2.7567155245858407`*^-23\), 
      X12 \[Rule] 4.5342324977859034`*^-35, 
      Y12 \[Rule] 6.249427271951736`*^-30, Z12 \[Rule] 18.25`, 
      Eo12 \[Rule] 1.`, Ei12 \[Rule] \(-1.7125104814361236`*^-31\), 
      Ej12 \[Rule] \(-8.367563437786331`*^-43\), 
      Ek12 \[Rule] \(-2.756715524584637`*^-23\), 
      X13 \[Rule] 4.5342321185228576`*^-35, 
      Y13 \[Rule] 1.0893541906217139`*^-29, Z13 \[Rule] 31.810000000000002`, 
      Eo13 \[Rule] 1.`, Ei13 \[Rule] \(-1.7122720911817769`*^-31\), 
      Ej13 \[Rule] \(-8.366504382332843`*^-43\), 
      Ek13 \[Rule] \(-2.756715524584637`*^-23\), 
      X14 \[Rule] 4.534232118533258`*^-35, 
      Y14 \[Rule] 1.0893622215991187`*^-29, Z14 \[Rule] 31.810000000000002`, 
      Eo14 \[Rule] 1.`, Ei14 \[Rule] \(-4.379390573435859`*^-31\), 
      Ej14 \[Rule] \(-7.703962476399262`*^-43\), 
      Ek14 \[Rule] \(-2.756715524584637`*^-23\), 
      X15 \[Rule] 4.5342321030331726`*^-35, 
      Y15 \[Rule] 2.0099101196122413`*^-29, Z15 \[Rule] 42.32`, 
      Eo15 \[Rule] 1.`, Ei15 \[Rule] \(-7.028515822436621`*^-32\), 
      Ej15 \[Rule] \(-8.60414662807421`*^-43\), 
      Ek15 \[Rule] \(-2.756715364873285`*^-23\), X16 \[Rule] 4.`, 
      Y16 \[Rule] \(-2.205372090907616`*^-22\), Z16 \[Rule] 42.32`, 
      Eo16 \[Rule] 1.`, Ei16 \[Rule] \(-7.02849554515907`*^-32\), 
      Ej16 \[Rule] \(-6.755074714271241`*^-38\), 
      Ek16 \[Rule] 6.123031493441067`*^-16, X17 \[Rule] \(-4.`\), 
      Y17 \[Rule] 2.20537249288964`*^-22, Z17 \[Rule] 42.32`, 
      Eo17 \[Rule] 1.`, Ei17 \[Rule] \(-7.02849554515907`*^-32\), 
      Ej17 \[Rule] \(-6.755065745961069`*^-38\), 
      Ek17 \[Rule] 6.123031493441067`*^-16, X18 \[Rule] 9.55`, 
      Y18 \[Rule] \(-5.265326537888785`*^-22\), Z18 \[Rule] 33.31`, 
      Eo18 \[Rule] 1.`, Ei18 \[Rule] 1.3518129844996535`*^-30, 
      Ej18 \[Rule] 2.841200607330861`*^-43, 
      Ek18 \[Rule] \(-2.756715524584637`*^-23\), X19 \[Rule] 9.55`, 
      Y19 \[Rule] \(-5.265326537888785`*^-22\), Z19 \[Rule] 33.31`, 
      Eo19 \[Rule] 1.`, Ei19 \[Rule] 1.3518129844996535`*^-30, 
      Ej19 \[Rule] 2.8471554368991376`*^-43, 
      Ek19 \[Rule] \(-2.756715488205024`*^-23\), X20 \[Rule] 9.55`, 
      Y20 \[Rule] \(-5.265326537888785`*^-22\), Z20 \[Rule] 33.31`, 
      Eo20 \[Rule] 1.`, Ei20 \[Rule] 1.3518129844996535`*^-30, 
      Ej20 \[Rule] 3.89732994390662`*^-42, 
      Ek20 \[Rule] \(-2.756715488205024`*^-23\), X21 \[Rule] 9.55`, 
      Y21 \[Rule] \(-5.2653262540067115`*^-22\), 
      Z21 \[Rule] 22.810000000000002`, Eo21 \[Rule] 1.`, 
      Ei21 \[Rule] 6.123031769112612`*^-16, 
      Ej21 \[Rule] \(-8.225691385958109`*^-34\), 
      Ek21 \[Rule] \(-2.756715488451784`*^-23\), X22 \[Rule] \(-9.55`\), 
      Y22 \[Rule] 5.265326766030595`*^-22, Z22 \[Rule] 33.31`, 
      Eo22 \[Rule] 1.`, Ei22 \[Rule] \(-1.6725798787341712`*^-31\), 
      Ej22 \[Rule] \(-8.114893513995743`*^-42\), 
      Ek22 \[Rule] \(-2.756715573108442`*^-23\), X23 \[Rule] \(-9.55`\), 
      Y23 \[Rule] 5.265326766030595`*^-22, Z23 \[Rule] 33.31`, 
      Eo23 \[Rule] 1.`, Ei23 \[Rule] \(-1.6725798787341712`*^-31\), 
      Ej23 \[Rule] \(-8.114892586880484`*^-42\), 
      Ek23 \[Rule] \(-2.756715623662899`*^-23\), X24 \[Rule] \(-9.55`\), 
      Y24 \[Rule] 5.265326766030595`*^-22, Z24 \[Rule] 33.31`, 
      Eo24 \[Rule] 1.`, Ei24 \[Rule] \(-2.16614532636438`*^-31\), 
      Ej24 \[Rule] \(-8.374675509951867`*^-42\), 
      Ek24 \[Rule] \(-2.756715623662899`*^-23\), X25 \[Rule] \(-9.55`\), 
      Y25 \[Rule] 5.265326720540129`*^-22, Z25 \[Rule] 22.810000000000002`, 
      Eo25 \[Rule] 1.`, Ei25 \[Rule] \(-2.16614532636438`*^-31\), 
      Ej25 \[Rule] \(-8.37468730995749`*^-42\), 
      Ek25 \[Rule] \(-2.756715634485422`*^-23\), X26 \[Rule] 9.55`, 
      Y26 \[Rule] 7.806864979085024`*^-15, Z26 \[Rule] 16.435000000000006`, 
      Eo26 \[Rule] 1.`, Ei26 \[Rule] 6.123031769112612`*^-16, 
      Ej26 \[Rule] \(-8.225691615546849`*^-34\), 
      Ek26 \[Rule] \(-2.756715488451784`*^-23\), X27 \[Rule] \(-9.55`\), 
      Y27 \[Rule] 5.265326692922294`*^-22, Z27 \[Rule] 16.435000000000002`, 
      Eo27 \[Rule] 1.`, Ei27 \[Rule] \(-2.16614532636438`*^-31\), 
      Ej27 \[Rule] \(-8.374692305688829`*^-42\), 
      Ek27 \[Rule] \(-2.756715687137939`*^-23\)}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1117}},
WindowSize->{1590, 1083},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 64, 0, 41, "Text"],
Cell[1784, 51, 31, 0, 38, "Text"],
Cell[1818, 53, 58, 1, 35, "Input"],
Cell[1879, 56, 41, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[1945, 60, 226, 4, 98, "Input"],
Cell[2174, 66, 182, 3, 30, "Message"],
Cell[2359, 71, 187, 3, 30, "Message"],
Cell[2549, 76, 194, 3, 30, "Message"]
}, Open  ]],
Cell[2758, 82, 38, 0, 38, "Text"],
Cell[2799, 84, 2818, 52, 1127, "Input"],
Cell[5620, 138, 40, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[5685, 142, 278, 6, 119, "Input"],
Cell[5966, 150, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6053, 156, 1156, 20, 371, "Input"],
Cell[7212, 178, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7299, 184, 453, 8, 182, "Input"],
Cell[7755, 194, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7842, 200, 448, 8, 182, "Input"],
Cell[8293, 210, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8380, 216, 442, 8, 182, "Input"],
Cell[8825, 226, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8912, 232, 445, 8, 182, "Input"],
Cell[9360, 242, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9447, 248, 567, 11, 182, "Input"],
Cell[10017, 261, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10104, 267, 562, 11, 182, "Input"],
Cell[10669, 280, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10756, 286, 567, 11, 182, "Input"],
Cell[11326, 299, 50, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11413, 305, 559, 11, 182, "Input"],
Cell[11975, 318, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12063, 324, 1207, 21, 371, "Input"],
Cell[13273, 347, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13361, 353, 379, 8, 140, "Input"],
Cell[13743, 363, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13831, 369, 440, 9, 161, "Input"],
Cell[14274, 380, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14362, 386, 508, 10, 182, "Input"],
Cell[14873, 398, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14961, 404, 692, 13, 245, "Input"],
Cell[15656, 419, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15744, 425, 333, 7, 140, "Input"],
Cell[16080, 434, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16168, 440, 333, 7, 140, "Input"],
Cell[16504, 449, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16592, 455, 459, 9, 161, "Input"],
Cell[17054, 466, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17142, 472, 294, 6, 119, "Input"],
Cell[17439, 480, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17527, 486, 290, 6, 119, "Input"],
Cell[17820, 494, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17908, 500, 440, 9, 161, "Input"],
Cell[18351, 511, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18439, 517, 459, 9, 161, "Input"],
Cell[18901, 528, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18989, 534, 294, 6, 119, "Input"],
Cell[19286, 542, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19374, 548, 290, 6, 119, "Input"],
Cell[19667, 556, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19755, 562, 440, 9, 161, "Input"],
Cell[20198, 573, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20286, 579, 438, 9, 161, "Input"],
Cell[20727, 590, 51, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20815, 596, 438, 9, 161, "Input"],
Cell[21256, 607, 51, 1, 35, "Output"]
}, Open  ]],
Cell[21322, 611, 270, 4, 56, "Input"],
Cell[21595, 617, 91, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[21711, 623, 118, 3, 35, "Input"],
Cell[21832, 628, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21928, 634, 118, 3, 35, "Input"],
Cell[22049, 639, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22145, 645, 118, 3, 35, "Input"],
Cell[22266, 650, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22362, 656, 118, 3, 35, "Input"],
Cell[22483, 661, 59, 1, 35, "Output"]
}, Open  ]],
Cell[22557, 665, 97, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[22679, 671, 106, 2, 35, "Input"],
Cell[22788, 675, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22884, 681, 104, 2, 35, "Input"],
Cell[22991, 685, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23087, 691, 104, 2, 35, "Input"],
Cell[23194, 695, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23290, 701, 104, 2, 35, "Input"],
Cell[23397, 705, 59, 1, 35, "Output"]
}, Open  ]],
Cell[23471, 709, 63, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[23559, 713, 157, 3, 35, "Input"],
Cell[23719, 718, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23821, 724, 159, 3, 35, "Input"],
Cell[23983, 729, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24085, 735, 157, 3, 35, "Input"],
Cell[24245, 740, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24347, 746, 159, 3, 35, "Input"],
Cell[24509, 751, 65, 1, 35, "Output"]
}, Open  ]],
Cell[24589, 755, 48, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[24662, 759, 160, 3, 35, "Input"],
Cell[24825, 764, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24927, 770, 160, 3, 35, "Input"],
Cell[25090, 775, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25192, 781, 160, 3, 35, "Input"],
Cell[25355, 786, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25457, 792, 160, 3, 35, "Input"],
Cell[25620, 797, 65, 1, 35, "Output"]
}, Open  ]],
Cell[25700, 801, 28, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[25753, 805, 74, 1, 35, "Input"],
Cell[25830, 808, 61, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25928, 814, 81, 1, 35, "Input"],
Cell[26012, 817, 63, 1, 35, "Output"]
}, Open  ]],
Cell[26090, 821, 45, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[26160, 825, 104, 2, 35, "Input"],
Cell[26267, 829, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26363, 835, 108, 2, 35, "Input"],
Cell[26474, 839, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26570, 845, 148, 3, 35, "Input"],
Cell[26721, 850, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26823, 856, 156, 3, 35, "Input"],
Cell[26982, 861, 65, 1, 35, "Output"]
}, Open  ]],
Cell[27062, 865, 37, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[27124, 869, 109, 2, 35, "Input"],
Cell[27236, 873, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27332, 879, 145, 3, 35, "Input"],
Cell[27480, 884, 65, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27582, 890, 107, 2, 35, "Input"],
Cell[27692, 894, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27788, 900, 142, 3, 35, "Input"],
Cell[27933, 905, 65, 1, 35, "Output"]
}, Open  ]],
Cell[28013, 909, 36, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[28074, 913, 107, 2, 35, "Input"],
Cell[28184, 917, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28280, 923, 146, 3, 35, "Input"],
Cell[28429, 928, 65, 1, 35, "Output"]
}, Open  ]],
Cell[28509, 932, 23, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[28557, 936, 108, 2, 35, "Input"],
Cell[28668, 940, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28764, 946, 157, 3, 35, "Input"],
Cell[28924, 951, 65, 1, 35, "Output"]
}, Open  ]],
Cell[29004, 955, 23, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[29052, 959, 108, 2, 35, "Input"],
Cell[29163, 963, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29259, 969, 157, 3, 35, "Input"],
Cell[29419, 974, 65, 1, 35, "Output"]
}, Open  ]],
Cell[29499, 978, 35, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[29559, 982, 125, 3, 35, "Input"],
Cell[29687, 987, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29783, 993, 157, 3, 35, "Input"],
Cell[29943, 998, 65, 1, 35, "Output"]
}, Open  ]],
Cell[30023, 1002, 28, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[30076, 1006, 125, 3, 35, "Input"],
Cell[30204, 1011, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30300, 1017, 157, 3, 35, "Input"],
Cell[30460, 1022, 65, 1, 35, "Output"]
}, Open  ]],
Cell[30540, 1026, 29, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[30594, 1030, 124, 3, 35, "Input"],
Cell[30721, 1035, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30817, 1041, 157, 3, 35, "Input"],
Cell[30977, 1046, 65, 1, 35, "Output"]
}, Open  ]],
Cell[31057, 1050, 36, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[31118, 1054, 121, 3, 35, "Input"],
Cell[31242, 1059, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31338, 1065, 162, 3, 35, "Input"],
Cell[31503, 1070, 65, 1, 35, "Output"]
}, Open  ]],
Cell[31583, 1074, 35, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[31643, 1078, 125, 3, 35, "Input"],
Cell[31771, 1083, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31867, 1089, 157, 3, 35, "Input"],
Cell[32027, 1094, 65, 1, 35, "Output"]
}, Open  ]],
Cell[32107, 1098, 27, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[32159, 1102, 129, 3, 35, "Input"],
Cell[32291, 1107, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32387, 1113, 157, 3, 35, "Input"],
Cell[32547, 1118, 65, 1, 35, "Output"]
}, Open  ]],
Cell[32627, 1122, 28, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[32680, 1126, 124, 3, 35, "Input"],
Cell[32807, 1131, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32903, 1137, 157, 3, 35, "Input"],
Cell[33063, 1142, 65, 1, 35, "Output"]
}, Open  ]],
Cell[33143, 1146, 36, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[33204, 1150, 121, 3, 35, "Input"],
Cell[33328, 1155, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33424, 1161, 150, 3, 35, "Input"],
Cell[33577, 1166, 65, 1, 35, "Output"]
}, Open  ]],
Cell[33657, 1170, 25, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[33707, 1174, 107, 2, 35, "Input"],
Cell[33817, 1178, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33913, 1184, 144, 3, 35, "Input"],
Cell[34060, 1189, 65, 1, 35, "Output"]
}, Open  ]],
Cell[34140, 1193, 24, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[34189, 1197, 120, 3, 35, "Input"],
Cell[34312, 1202, 59, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34408, 1208, 144, 3, 35, "Input"],
Cell[34555, 1213, 65, 1, 35, "Output"]
}, Open  ]],
Cell[34635, 1217, 496, 7, 77, "Input"],
Cell[35134, 1226, 370, 6, 161, "Input"],

Cell[CellGroupData[{
Cell[35529, 1236, 46, 1, 35, "Input"],
Cell[35578, 1239, 38, 1, 35, "Output"]
}, Open  ]],
Cell[35631, 1243, 3153, 56, 1064, "Input"],
Cell[38787, 1301, 48, 1, 35, "Input"],
Cell[38838, 1304, 70, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[38933, 1309, 122, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[39080, 1315, 325473, 9069, 1164, 154066, 6948, "GraphicsData", \
"PostScript", "Graphics"],
Cell[364556, 10386, 313822, 8807, 1164, 150479, 6786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[678381, 19195, 323632, 9188, 1164, 161630, 7184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1002016, 28385, 337539, 9474, 1164, 167805, 7374, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1339558, 37861, 319812, 8918, 1164, 151645, 6837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1659373, 46781, 334140, 9289, 1164, 159631, 7130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1993516, 56072, 323509, 8957, 1164, 152062, 6836, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2317028, 65031, 325715, 9084, 1164, 154815, 6970, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2642746, 74117, 314000, 8802, 1164, 150037, 6773, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2956749, 82921, 323810, 9183, 1164, 161188, 7171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3280562, 92106, 337861, 9483, 1164, 167694, 7378, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3618426, 101591, 319553, 8920, 1164, 152030, 6847, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3937982, 110513, 334677, 9293, 1164, 159978, 7132, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4272662, 119808, 323509, 8957, 1164, 152062, 6836, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4596220, 128771, 64, 1, 35, "Input"],
Cell[4596287, 128774, 6717, 112, 403, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

